/*!
 *  Lang.js for Laravel localization in JavaScript.
 *
 *  @version 1.1.10
 *  @license MIT https://github.com/rmariuzzo/Lang.js/blob/master/LICENSE
 *  @site    https://github.com/rmariuzzo/Lang.js
 *  @author  Rubens Mariuzzo <rubens@mariuzzo.com>
 */
(function(root,factory){"use strict";if(typeof define==="function"&&define.amd){define([],factory)}else if(typeof exports==="object"){module.exports=factory()}else{root.Lang=factory()}})(this,function(){"use strict";function inferLocale(){if(typeof document!=="undefined"&&document.documentElement){return document.documentElement.lang}}function convertNumber(str){if(str==="-Inf"){return-Infinity}else if(str==="+Inf"||str==="Inf"||str==="*"){return Infinity}return parseInt(str,10)}var intervalRegexp=/^({\s*(\-?\d+(\.\d+)?[\s*,\s*\-?\d+(\.\d+)?]*)\s*})|([\[\]])\s*(-Inf|\*|\-?\d+(\.\d+)?)\s*,\s*(\+?Inf|\*|\-?\d+(\.\d+)?)\s*([\[\]])$/;var anyIntervalRegexp=/({\s*(\-?\d+(\.\d+)?[\s*,\s*\-?\d+(\.\d+)?]*)\s*})|([\[\]])\s*(-Inf|\*|\-?\d+(\.\d+)?)\s*,\s*(\+?Inf|\*|\-?\d+(\.\d+)?)\s*([\[\]])/;var defaults={locale:"en"};var Lang=function(options){options=options||{};this.locale=options.locale||inferLocale()||defaults.locale;this.fallback=options.fallback;this.messages=options.messages};Lang.prototype.setMessages=function(messages){this.messages=messages};Lang.prototype.getLocale=function(){return this.locale||this.fallback};Lang.prototype.setLocale=function(locale){this.locale=locale};Lang.prototype.getFallback=function(){return this.fallback};Lang.prototype.setFallback=function(fallback){this.fallback=fallback};Lang.prototype.has=function(key,locale){if(typeof key!=="string"||!this.messages){return false}return this._getMessage(key,locale)!==null};Lang.prototype.get=function(key,replacements,locale){if(!this.has(key,locale)){return key}var message=this._getMessage(key,locale);if(message===null){return key}if(replacements){message=this._applyReplacements(message,replacements)}return message};Lang.prototype.trans=function(key,replacements){return this.get(key,replacements)};Lang.prototype.choice=function(key,number,replacements,locale){replacements=typeof replacements!=="undefined"?replacements:{};replacements.count=number;var message=this.get(key,replacements,locale);if(message===null||message===undefined){return message}var messageParts=message.split("|");var explicitRules=[];for(var i=0;i<messageParts.length;i++){messageParts[i]=messageParts[i].trim();if(anyIntervalRegexp.test(messageParts[i])){var messageSpaceSplit=messageParts[i].split(/\s/);explicitRules.push(messageSpaceSplit.shift());messageParts[i]=messageSpaceSplit.join(" ")}}if(messageParts.length===1){return message}for(var j=0;j<explicitRules.length;j++){if(this._testInterval(number,explicitRules[j])){return messageParts[j]}}var pluralForm=this._getPluralForm(number);return messageParts[pluralForm]};Lang.prototype.transChoice=function(key,count,replacements){return this.choice(key,count,replacements)};Lang.prototype._parseKey=function(key,locale){if(typeof key!=="string"||typeof locale!=="string"){return null}var segments=key.split(".");var source=segments[0].replace(/\//g,".");return{source:locale+"."+source,sourceFallback:this.getFallback()+"."+source,entries:segments.slice(1)}};Lang.prototype._getMessage=function(key,locale){locale=locale||this.getLocale();key=this._parseKey(key,locale);if(this.messages[key.source]===undefined&&this.messages[key.sourceFallback]===undefined){return null}var message=this.messages[key.source];var entries=key.entries.slice();var subKey="";while(entries.length&&message!==undefined){var subKey=!subKey?entries.shift():subKey.concat(".",entries.shift());if(message[subKey]!==undefined){message=message[subKey];subKey=""}}if(typeof message!=="string"&&this.messages[key.sourceFallback]){message=this.messages[key.sourceFallback];entries=key.entries.slice();subKey="";while(entries.length&&message!==undefined){var subKey=!subKey?entries.shift():subKey.concat(".",entries.shift());if(message[subKey]){message=message[subKey];subKey=""}}}if(typeof message!=="string"){return null}return message};Lang.prototype._findMessageInTree=function(pathSegments,tree){while(pathSegments.length&&tree!==undefined){var dottedKey=pathSegments.join(".");if(tree[dottedKey]){tree=tree[dottedKey];break}tree=tree[pathSegments.shift()]}return tree};Lang.prototype._applyReplacements=function(message,replacements){for(var replace in replacements){message=message.replace(new RegExp(":"+replace,"gi"),function(match){var value=replacements[replace];var allCaps=match===match.toUpperCase();if(allCaps){return value.toUpperCase()}var firstCap=match===match.replace(/\w/i,function(letter){return letter.toUpperCase()});if(firstCap){return value.charAt(0).toUpperCase()+value.slice(1)}return value})}return message};Lang.prototype._testInterval=function(count,interval){if(typeof interval!=="string"){throw"Invalid interval: should be a string."}interval=interval.trim();var matches=interval.match(intervalRegexp);if(!matches){throw"Invalid interval: "+interval}if(matches[2]){var items=matches[2].split(",");for(var i=0;i<items.length;i++){if(parseInt(items[i],10)===count){return true}}}else{matches=matches.filter(function(match){return!!match});var leftDelimiter=matches[1];var leftNumber=convertNumber(matches[2]);if(leftNumber===Infinity){leftNumber=-Infinity}var rightNumber=convertNumber(matches[3]);var rightDelimiter=matches[4];return(leftDelimiter==="["?count>=leftNumber:count>leftNumber)&&(rightDelimiter==="]"?count<=rightNumber:count<rightNumber)}return false};Lang.prototype._getPluralForm=function(count){switch(this.locale){case"az":case"bo":case"dz":case"id":case"ja":case"jv":case"ka":case"km":case"kn":case"ko":case"ms":case"th":case"tr":case"vi":case"zh":return 0;case"af":case"bn":case"bg":case"ca":case"da":case"de":case"el":case"en":case"eo":case"es":case"et":case"eu":case"fa":case"fi":case"fo":case"fur":case"fy":case"gl":case"gu":case"ha":case"he":case"hu":case"is":case"it":case"ku":case"lb":case"ml":case"mn":case"mr":case"nah":case"nb":case"ne":case"nl":case"nn":case"no":case"om":case"or":case"pa":case"pap":case"ps":case"pt":case"so":case"sq":case"sv":case"sw":case"ta":case"te":case"tk":case"ur":case"zu":return count==1?0:1;case"am":case"bh":case"fil":case"fr":case"gun":case"hi":case"hy":case"ln":case"mg":case"nso":case"xbr":case"ti":case"wa":return count===0||count===1?0:1;case"be":case"bs":case"hr":case"ru":case"sr":case"uk":return count%10==1&&count%100!=11?0:count%10>=2&&count%10<=4&&(count%100<10||count%100>=20)?1:2;case"cs":case"sk":return count==1?0:count>=2&&count<=4?1:2;case"ga":return count==1?0:count==2?1:2;case"lt":return count%10==1&&count%100!=11?0:count%10>=2&&(count%100<10||count%100>=20)?1:2;case"sl":return count%100==1?0:count%100==2?1:count%100==3||count%100==4?2:3;case"mk":return count%10==1?0:1;case"mt":return count==1?0:count===0||count%100>1&&count%100<11?1:count%100>10&&count%100<20?2:3;case"lv":return count===0?0:count%10==1&&count%100!=11?1:2;case"pl":return count==1?0:count%10>=2&&count%10<=4&&(count%100<12||count%100>14)?1:2;case"cy":return count==1?0:count==2?1:count==8||count==11?2:3;case"ro":return count==1?0:count===0||count%100>0&&count%100<20?1:2;case"ar":return count===0?0:count==1?1:count==2?2:count%100>=3&&count%100<=10?3:count%100>=11&&count%100<=99?4:5;default:return 0}};return Lang});(function(){Lang=new Lang();Lang.setMessages({"ar.messages":{"about_us":"\u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0639\u0646\u0627","account":{"account":"\u0627\u0644\u062d\u0633\u0627\u0628","account_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u062d\u0633\u0627\u0628","accounts":"\u062d\u0633\u0627\u0628\u0627\u062a","credit":"\u062a\u0646\u0633\u0628 \u0625\u0644\u064a\u0647","debit":"\u0645\u062f\u064a\u0646","description":"\u0648\u0635\u0641","edit_account":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062d\u0633\u0627\u0628","name":"\u0627\u0633\u0645","new_account":"\u062d\u0633\u0627\u0628 \u062c\u062f\u064a\u062f","payments":"\u0627\u0644\u0645\u062f\u0641\u0648\u0639\u0627\u062a","status":"\u0627\u0644\u062d\u0627\u0644\u0629","type":"\u0627\u0643\u062a\u0628"},"account_manager":"\u0625\u062f\u0627\u0631\u0629 \u062d\u0633\u0627\u0628 \u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645","accountant":{"accountant_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u062d\u0627\u0633\u0628","accountants":"\u0627\u0644\u0645\u062d\u0627\u0633\u0628\u064a\u0646","edit_accountant":"\u062a\u062d\u0631\u064a\u0631 \u0645\u062d\u0627\u0633\u0628","new_accountant":"\u0645\u062d\u0627\u0633\u0628 \u062c\u062f\u064a\u062f"},"accountants":"\u0627\u0644\u0645\u062d\u0627\u0633\u0628\u064a\u0646","accounts":"\u062d\u0633\u0627\u0628\u0627\u062a","admin":"\u0627\u0644\u0645\u0634\u0631\u0641\u0648\u0646","admins":"\u0645\u0633\u0624\u0644","advanced_payment":{"advanced_payment":"\u062f\u0641\u0639\u0647 \u0645\u0642\u062f\u0645\u0647","advanced_payment_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u062f\u0641\u0639 \u0627\u0644\u0645\u0633\u0628\u0642","advanced_payments":"\u062f\u0641\u0639\u0627\u062a \u0645\u0642\u062f\u0645\u0629","amount":"\u0643\u0645\u064a\u0629","date":"\u062a\u0627\u0631\u064a\u062e","edit_advanced_payment":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062f\u0641\u0639 \u0627\u0644\u0645\u0633\u0628\u0642","new_advanced_payment":"\u062f\u0641\u0639\u0629 \u0645\u0642\u062f\u0645\u0629 \u062c\u062f\u064a\u062f\u0629","patient":"\u0635\u0628\u0648\u0631","patient_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u064a\u0636","receipt_no":"\u0631\u0642\u0645 \u0627\u0644\u0625\u064a\u0635\u0627\u0644"},"advanced_payments":"\u062f\u0641\u0639\u0627\u062a \u0645\u0642\u062f\u0645\u0629","allow_file_type":"\u0623\u0646\u0648\u0627\u0639 \u0627\u0644\u0645\u0644\u0641\u0627\u062a \u0627\u0644\u0645\u0633\u0645\u0648\u062d \u0628\u0647\u0627: png\u060c jpg\u060c jpeg.","ambulance":{"ambulance":"\u0633\u064a\u0627\u0631\u0629 \u0625\u0633\u0639\u0627\u0641","ambulance_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0633\u064a\u0627\u0631\u0629 \u0627\u0644\u0625\u0633\u0639\u0627\u0641","ambulances":"\u0633\u064a\u0627\u0631\u0627\u062a \u0627\u0644\u0625\u0633\u0639\u0627\u0641","driver_contact":"\u0627\u0644\u0627\u062a\u0635\u0627\u0644 \u0628\u0627\u0644\u0633\u0627\u0626\u0642","driver_license":"\u0631\u062e\u0635\u0629 \u0627\u0644\u0642\u064a\u0627\u062f\u0629","driver_name":"\u0627\u0633\u0645 \u0627\u0644\u0633\u0627\u0626\u0642","edit_ambulance":"\u062a\u062d\u0631\u064a\u0631 \u0633\u064a\u0627\u0631\u0629 \u0625\u0633\u0639\u0627\u0641","is_available":"\u0645\u062a\u0627\u062d","new_ambulance":"\u0633\u064a\u0627\u0631\u0629 \u0625\u0633\u0639\u0627\u0641 \u062c\u062f\u064a\u062f\u0629","note":"\u0645\u0630\u0643\u0631\u0629","vehicle_model":"\u0645\u0648\u062f\u064a\u0644 \u0627\u0644\u0645\u0631\u0643\u0628\u0629","vehicle_number":"\u0631\u0642\u0645 \u0627\u0644\u0645\u0631\u0643\u0628\u0629","vehicle_type":"\u0646\u0648\u0639 \u0627\u0644\u0645\u0631\u0643\u0628\u0629","year_made":"\u0633\u0646\u0629 \u0627\u0644\u0635\u0646\u0639"},"ambulance_call":{"ambulance_call":"\u0646\u062f\u0627\u0621 \u0625\u0633\u0639\u0627\u0641","ambulance_call_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0645\u0643\u0627\u0644\u0645\u0629 \u0633\u064a\u0627\u0631\u0629 \u0625\u0633\u0639\u0627\u0641","ambulance_calls":"\u0645\u0643\u0627\u0644\u0645\u0627\u062a \u0627\u0644\u0625\u0633\u0639\u0627\u0641","amount":"\u0643\u0645\u064a\u0629","date":"\u062a\u0627\u0631\u064a\u062e","driver_name":"\u0627\u0633\u0645 \u0627\u0644\u0633\u0627\u0626\u0642","edit_ambulance_call":"\u062a\u062d\u0631\u064a\u0631 \u0645\u0643\u0627\u0644\u0645\u0629 \u0627\u0644\u0625\u0633\u0639\u0627\u0641","new_ambulance_call":"\u0645\u0643\u0627\u0644\u0645\u0629 \u0625\u0633\u0639\u0627\u0641 \u062c\u062f\u064a\u062f\u0629","patient":"\u0635\u0628\u0648\u0631","vehicle_model":"\u0645\u0648\u062f\u064a\u0644 \u0627\u0644\u0645\u0631\u0643\u0628\u0629"},"ambulance_calls":"\u0645\u0643\u0627\u0644\u0645\u0627\u062a \u0627\u0644\u0625\u0633\u0639\u0627\u0641","ambulances":"\u0633\u064a\u0627\u0631\u0627\u062a \u0627\u0644\u0625\u0633\u0639\u0627\u0641","appointment":{"appointment_calendar":"\u062a\u0642\u0648\u064a\u0645 \u0627\u0644\u0645\u0648\u0627\u0639\u064a\u062f","appointment_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u0648\u0639\u062f","appointment_exists":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0644\u0644\u0645\u0631\u064a\u0636 \u0645\u0648\u062c\u0648\u062f \u0628\u0627\u0644\u0641\u0639\u0644","appointment_list":"\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u062a\u0639\u064a\u064a\u0646","are_you_sure_want_to_cancel":"\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u063a\u0627\u0621","are_you_sure_want_to_change":"\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0627\u0644\u062a\u063a\u064a\u064a\u0631","available_slot":"\u0627\u0644\u0641\u062a\u062d\u0629 \u0627\u0644\u0645\u062a\u0627\u062d\u0629","calendar_view":"\u0639\u0631\u0636 \u0627\u0644\u062a\u0642\u0648\u064a\u0645","change_status":"\u062a\u063a\u064a\u064a\u0631 \u0627\u0644\u0648\u0636\u0639","changed_appointment":"\u0645\u0648\u0639\u062f \u062a\u0645 \u062a\u063a\u064a\u064a\u0631\u0647","completed":"\u0645\u0646\u062c\u0632","date":"\u062a\u0627\u0631\u064a\u062e","day":"\u064a\u0648\u0645","department_name":"\u0627\u0633\u0645 \u0627\u0644\u0642\u0633\u0645","description":"\u0648\u0635\u0641","doctor":"\u0637\u0628\u064a\u0628","doctor_department":"\u0642\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","doctor_department_name":"\u0627\u0633\u0645 \u0642\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","doctor_name":"\u0627\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","doctor_schedule_not_available_on_this_date":"\u062c\u062f\u0648\u0644 \u0627\u0644\u0637\u0628\u064a\u0628 \u063a\u064a\u0631 \u0645\u062a\u0648\u0641\u0631 \u0647\u0630\u0627 \u0627\u0644\u062a\u0627\u0631\u064a\u062e.","edit_appointment":"\u062a\u062d\u0631\u064a\u0631 \u0645\u0648\u0639\u062f","has_been_cancelled":"\u062a\u0645 \u0625\u0644\u063a\u0627\u0621.","has_been_changed":"\u062a\u063a\u064a\u0631.","last_30_days":"\u0622\u062e\u0631 30 \u064a\u0648\u0645\u064b\u0627","last_7_days":"\u0627\u062e\u0631 7 \u0627\u064a\u0627\u0645","last_month":"\u0627\u0644\u0634\u0647\u0631 \u0627\u0644\u0645\u0627\u0636\u064a","month":"\u0634\u0647\u0631","new_appointment":"\u0645\u0648\u0639\u062f \u062c\u062f\u064a\u062f","no_available":"\u063a\u064a\u0631 \u0645\u062a\u0627\u062d","old_patient_email_exists":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0645\u0648\u062c\u0648\u062f \u0628\u0627\u0644\u0641\u0639\u0644 \u060c \u064a\u0631\u062c\u0649 \u062a\u062d\u062f\u064a\u062f \u0627\u0644\u0645\u0631\u064a\u0636 \u0627\u0644\u0642\u062f\u064a\u0645.","opd_date":"\u062a\u0627\u0631\u064a\u062e Opd","patient":"\u0635\u0628\u0648\u0631","patient_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u064a\u0636","patient_not_exists_or_status_is_not_active":"\u0627\u0644\u0645\u0631\u064a\u0636 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f \u0623\u0648 \u0627\u0644\u062d\u0627\u0644\u0629 \u063a\u064a\u0631 \u0646\u0634\u0637\u0629.","pending":"\u0642\u064a\u062f \u0627\u0644\u0627\u0646\u062a\u0638\u0627\u0631","please_select_appointment_time_slot":"\u0627\u0644\u0631\u062c\u0627\u0621 \u062a\u062d\u062f\u064a\u062f \u062e\u0627\u0646\u0629 \u0648\u0642\u062a \u0627\u0644\u0645\u0648\u0639\u062f","please_select_doctor":"\u0627\u0644\u0631\u062c\u0627\u0621 \u062a\u062d\u062f\u064a\u062f \u062f\u0643\u062a\u0648\u0631","please_select_doctor_department":"\u0627\u0644\u0631\u062c\u0627\u0621 \u062a\u062d\u062f\u064a\u062f \u0642\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","this_month":"\u0647\u0630\u0627 \u0627\u0644\u0634\u0647\u0631","this_week":"\u0647\u0630\u0627 \u0627\u0644\u0627\u0633\u0628\u0648\u0639","today":"\u0627\u0644\u064a\u0648\u0645","week":"\u0623\u0633\u0628\u0648\u0639","yesterday":"\u0641\u064a \u0627\u0644\u0627\u0645\u0633"},"appointment_calendar":"\u0639\u064a\u0651\u0646. \u0627\u0644\u062a\u0642\u0648\u064a\u0645","appointments":"\u062a\u0639\u064a\u064a\u0646\u0627\u062a","available_slot":"\u0627\u0644\u0641\u062a\u062d\u0629 \u0627\u0644\u0645\u062a\u0627\u062d\u0629","bed":{"add":"\u0623\u0636\u0641","available":"\u0645\u062a\u0627\u062d","bed":"\u0633\u0631\u064a\u0631 \u062c\u062f\u064a\u062f","bed_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0633\u0631\u064a\u0631","bed_id":"\u0645\u0639\u0631\u0641 \u0627\u0644\u0633\u0631\u064a\u0631","bed_type":"\u0646\u0648\u0639 \u0627\u0644\u0633\u0631\u064a\u0631","beds":"\u0633\u0631\u064a\u0631","charge":"\u0627\u0644\u0634\u062d\u0646\u0629","description":"\u0648\u0635\u0641","edit_bed":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0633\u0631\u064a\u0631","name":"\u0627\u0633\u0645","new_bed":"\u0633\u0631\u064a\u0631 \u062c\u062f\u064a\u062f","new_bulk_bed":"\u0633\u0631\u064a\u0631 \u0636\u062e\u0645 \u062c\u062f\u064a\u062f","not_available":"\u063a\u064a\u0631 \u0645\u062a\u0648\u0641\u0631"},"bed_assign":{"assign_date":"\u062a\u0639\u064a\u064a\u0646 \u0627\u0644\u062a\u0627\u0631\u064a\u062e","assign_date_should_not_be_smaller_than_patient_birth_date":"\u064a\u062c\u0628 \u0623\u0644\u0627 \u064a\u0643\u0648\u0646 \u062a\u0627\u0631\u064a\u062e \u0627\u0644\u062a\u0639\u064a\u064a\u0646 \u0623\u0635\u063a\u0631 \u0645\u0646 \u062a\u0627\u0631\u064a\u062e \u0645\u064a\u0644\u0627\u062f \u0627\u0644\u0645\u0631\u064a\u0636.","assigned":"\u062a\u0639\u064a\u064a\u0646","bed":"\u0627\u0644\u0633\u0631\u064a\u0631","bed_assign":"\u062a\u0639\u064a\u064a\u0646 \u0627\u0644\u0633\u0631\u064a\u0631","bed_assign_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u062a\u0639\u064a\u064a\u0646 \u0627\u0644\u0633\u0631\u064a\u0631","bed_assigns":"\u062a\u0639\u064a\u064a\u0646\u0627\u062a \u0627\u0644\u0633\u0631\u064a\u0631","bed_name":"\u0627\u0633\u0645 \u0627\u0644\u0633\u0631\u064a\u0631","case_id":"ID \u0627\u0644\u0642\u0636\u064a\u0629","description":"\u0648\u0635\u0641","discharge_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u062a\u0641\u0631\u064a\u063a","edit_bed_assign":"\u062a\u062d\u0631\u064a\u0631 \u062a\u0639\u064a\u064a\u0646 \u0627\u0644\u0633\u0631\u064a\u0631","ipd_patient_id":"\u0645\u0639\u0631\u0641 \u0627\u0644\u0645\u0631\u064a\u0636 IPD","new_bed_assign":"\u062a\u0639\u064a\u064a\u0646 \u0633\u0631\u064a\u0631 \u062c\u062f\u064a\u062f","not_assigned":"\u063a\u064a\u0631\u0645\u0639\u062a\u0645\u062f","patient_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u064a\u0636"},"bed_assigns":"\u062a\u0639\u064a\u064a\u0646\u0627\u062a \u0627\u0644\u0633\u0631\u064a\u0631","bed_management":"\u0625\u062f\u0627\u0631\u0629 \u0627\u0644\u0633\u0631\u064a\u0631","bed_mgt":"\u0625\u062f\u0627\u0631\u0629 \u0627\u0644\u0633\u0631\u064a\u0631","bed_status":{"admission_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0642\u0628\u0648\u0644","assigned_beds":"\u0623\u0633\u0631\u0629 \u0645\u062e\u0635\u0635\u0629","available_beds":"\u0627\u0644\u0623\u0633\u0631\u0629 \u0627\u0644\u0645\u062a\u0627\u062d\u0629","bed_name":"\u0627\u0633\u0645 \u0627\u0644\u0633\u0631\u064a\u0631","bed_status":"\u062d\u0627\u0644\u0629 \u0627\u0644\u0633\u0631\u064a\u0631","gender":"\u062c\u0646\u0633","patient_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u064a\u0636","phone":"\u0647\u0627\u062a\u0641"},"bed_type":{"bed_type":"\u0646\u0648\u0639 \u0627\u0644\u0633\u0631\u064a\u0631","bed_type_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0646\u0648\u0639 \u0627\u0644\u0633\u0631\u064a\u0631","bed_types":"\u0623\u0646\u0648\u0627\u0639 \u0627\u0644\u0633\u0631\u064a\u0631","description":"\u0648\u0635\u0641","edit_bed_type":"\u062a\u062d\u0631\u064a\u0631 \u0646\u0648\u0639 \u0627\u0644\u0633\u0631\u064a\u0631","new_bed_type":"\u0646\u0648\u0639 \u0633\u0631\u064a\u0631 \u062c\u062f\u064a\u062f","title":"\u0639\u0646\u0648\u0627\u0646"},"bed_types":"\u0623\u0646\u0648\u0627\u0639 \u0627\u0644\u0633\u0631\u064a\u0631","beds":"\u0633\u0631\u064a\u0631","bill":{"add":"\u0627\u0644\u0633\u0639\u0631","admission_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0642\u0628\u0648\u0644","admission_id":"\u0645\u0639\u0631\u0641 \u0627\u0644\u0642\u0628\u0648\u0644","amount":"\u0643\u0645\u064a\u0629","bill":"\u0645\u0634\u0631\u0648\u0639 \u0642\u0627\u0646\u0648\u0646","bill_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","bill_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","bill_id":"\u0645\u0639\u0631\u0641 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","bill_summary":"\u0645\u0644\u062e\u0635 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","bills":"\u0641\u0648\u0627\u062a\u064a\u0631","calculate":"\u0627\u062d\u0633\u0628","cell_no":"\u062e\u0644\u064a\u0629 \u0644\u0627","discharge_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u062a\u0641\u0631\u064a\u063a","doctor_name":"\u0627\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","edit":"\u062a\u0639\u062f\u064a\u0644","edit_bill":"\u062a\u062d\u0631\u064a\u0631 \u0628\u064a\u0644","generate_bill":"\u062a\u0648\u0644\u064a\u062f \u0628\u064a\u0644","insurance_name":"\u0627\u0633\u0645 \u0627\u0644\u062a\u0623\u0645\u064a\u0646","item_name":"\u0627\u0633\u0645 \u0627\u0644\u0639\u0646\u0635\u0631","new_bill":"\u0645\u0634\u0631\u0648\u0639 \u0642\u0627\u0646\u0648\u0646 \u062c\u062f\u064a\u062f","package_name":"\u0627\u0633\u0645 \u0627\u0644\u062d\u0632\u0645\u0629","patient":"\u0635\u0628\u0648\u0631","patient_cell_no":"\u0631\u0642\u0645 \u062e\u0644\u064a\u0629 \u0627\u0644\u0645\u0631\u064a\u0636","patient_dob":"\u0627\u0644\u0645\u0631\u064a\u0636 DOB","patient_email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0644\u0644\u0645\u0631\u064a\u0636","patient_gender":"\u062c\u0646\u0633 \u0627\u0644\u0645\u0631\u064a\u0636","patient_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u064a\u0636","policy_no":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0633\u064a\u0627\u0633\u0629","price":"\u0627\u0644\u0633\u0639\u0631","print_bill":"\u0637\u0628\u0627\u0639\u0629 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","qty":"\u0627\u0644\u0643\u0645\u064a\u0629","total_amount":"\u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a","total_days":"\u0645\u062c\u0645\u0648\u0639 \u0627\u0644\u0623\u064a\u0627\u0645","update_bill":"\u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629"},"billing":"\u0627\u0644\u0641\u0648\u0627\u062a\u064a\u0631","bills":"\u0641\u0648\u0627\u062a\u064a\u0631","birth_report":{"birth_report":"\u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u0645\u064a\u0644\u0627\u062f","birth_report_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u0648\u0644\u0627\u062f\u0629","birth_reports":"\u062a\u0642\u0627\u0631\u064a\u0631 \u0627\u0644\u0645\u064a\u0644\u0627\u062f","case_id":"ID \u0627\u0644\u0642\u0636\u064a\u0629","data_should_not_be_smaller_than_patient_birth_date":"\u064a\u062c\u0628 \u0623\u0644\u0627 \u064a\u0643\u0648\u0646 \u0627\u0644\u062a\u0627\u0631\u064a\u062e \u0623\u0635\u063a\u0631 \u0645\u0646 \u062a\u0627\u0631\u064a\u062e \u0645\u064a\u0644\u0627\u062f \u0627\u0644\u0645\u0631\u064a\u0636.","date":"\u062a\u0627\u0631\u064a\u062e","description":"\u0648\u0635\u0641","doctor_name":"\u0627\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","edit_birth_report":"\u062a\u062d\u0631\u064a\u0631 \u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u0645\u064a\u0644\u0627\u062f","new_birth_report":"\u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u0645\u064a\u0644\u0627\u062f \u0627\u0644\u062c\u062f\u064a\u062f","patient_birth_date_not_found":"\u062a\u0627\u0631\u064a\u062e \u0645\u064a\u0644\u0627\u062f \u0627\u0644\u0645\u0631\u064a\u0636 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f.","patient_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u064a\u0636"},"birth_reports":"\u062a\u0642\u0627\u0631\u064a\u0631 \u0627\u0644\u0645\u064a\u0644\u0627\u062f","blood_bank":"\u0628\u0646\u0643 \u0627\u0644\u062f\u0645","blood_banks":"\u0628\u0646\u0648\u0643 \u0627\u0644\u062f\u0645","blood_donation":{"bags":"\u0623\u0643\u064a\u0627\u0633","blood_donation":"\u062a\u0628\u0631\u0639 \u0628\u0627\u0644\u062f\u0645","donor_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u062a\u0628\u0631\u0639","edit_blood_donation":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062a\u0628\u0631\u0639 \u0628\u0627\u0644\u062f\u0645","last_donate_date":"\u062a\u0627\u0631\u064a\u062e \u0622\u062e\u0631 \u062a\u0628\u0631\u0639","new_blood_donation":"\u0627\u0644\u062a\u0628\u0631\u0639 \u0628\u0627\u0644\u062f\u0645 \u0627\u0644\u062c\u062f\u064a\u062f"},"blood_donations":"\u062a\u0628\u0631\u0639 \u0628\u0627\u0644\u062f\u0645","blood_donor":{"age":"\u0639\u0645\u0631","blood_donor":"\u0645\u062a\u0628\u0631\u0639 \u0628\u0627\u0644\u062f\u0645","blood_donor_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u062a\u0628\u0631\u0639\u064a\u0646 \u0628\u0627\u0644\u062f\u0645","blood_donors":"\u0627\u0644\u0645\u062a\u0628\u0631\u0639\u064a\u0646 \u0628\u0627\u0644\u062f\u0645","blood_group":"\u0641\u0635\u064a\u0644\u0629 \u0627\u0644\u062f\u0645","donation_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u062a\u0628\u0631\u0639","edit_blood_donor":"\u062a\u062d\u0631\u064a\u0631 \u0645\u062a\u0628\u0631\u0639 \u0628\u0627\u0644\u062f\u0645","gender":"\u062c\u0646\u0633","last_donation_date":"\u062a\u0627\u0631\u064a\u062e \u0622\u062e\u0631 \u062a\u0628\u0631\u0639","name":"\u0627\u0633\u0645","new_blood_donor":"\u0645\u062a\u0628\u0631\u0639 \u062c\u062f\u064a\u062f \u0628\u0627\u0644\u062f\u0645"},"blood_donors":"\u0627\u0644\u0645\u062a\u0628\u0631\u0639\u064a\u0646 \u0628\u0627\u0644\u062f\u0645","blood_issue":{"amount":"\u0643\u0645\u064a\u0629","blood_issue":"\u0645\u0634\u0643\u0644\u0629 \u0627\u0644\u062f\u0645","doctor_name":"\u0627\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","donor_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u062a\u0628\u0631\u0639","edit_blood_issue":"\u062a\u062d\u0631\u064a\u0631 \u0642\u0636\u064a\u0629 \u0627\u0644\u062f\u0645","issue_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0627\u0635\u062f\u0627\u0631","new_blood_issue":"\u0642\u0636\u064a\u0629 \u062f\u0645 \u062c\u062f\u064a\u062f\u0629","patient_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u064a\u0636","remarks":"\u0645\u0644\u0627\u062d\u0638\u0627\u062a"},"blood_issues":"\u0645\u0634\u0627\u0643\u0644 \u0627\u0644\u062f\u0645","call_log":{"call_log":"\u0633\u062c\u0644 \u0627\u0644\u0645\u0643\u0627\u0644\u0645\u0627\u062a","call_type":"\u0646\u0648\u0639 \u0627\u0644\u0627\u062a\u0635\u0627\u0644","description":"\u0648\u0635\u0641","edit":"\u062a\u062d\u0631\u064a\u0631 \u0633\u062c\u0644 \u0627\u0644\u0645\u0643\u0627\u0644\u0645\u0627\u062a","follow_up_date":"\u0645\u062a\u0627\u0628\u0639\u0629 \u0627\u0644\u062a\u0627\u0631\u064a\u062e","incoming":"\u0648\u0627\u0631\u062f\u0629","name":"\u0627\u0633\u0645","new":"\u0633\u062c\u0644 \u0627\u0644\u0645\u0643\u0627\u0644\u0645\u0627\u062a \u0627\u0644\u062c\u062f\u064a\u062f","note":"\u0645\u0644\u062d\u0648\u0638\u0629","outgoing":"\u0645\u0646\u0641\u062a\u062d","phone":"\u0647\u0627\u062a\u0641","received_on":"\u0648\u0631\u062f\u062a \u0641\u064a"},"call_logs":"\u0633\u062c\u0644\u0627\u062a \u0627\u0644\u0645\u0643\u0627\u0644\u0645\u0627\u062a","case":{"case":"\u0642\u0636\u064a\u0629","case_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0642\u0636\u064a\u0629","case_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u062d\u0627\u0644\u0629","case_id":"ID \u0627\u0644\u0642\u0636\u064a\u0629","date":"\u062a\u0627\u0631\u064a\u062e","description":"\u0648\u0635\u0641","doctor":"\u0637\u0628\u064a\u0628","edit_case":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062d\u0627\u0644\u0629","fee":"\u0627\u0644\u0631\u0633\u0648\u0645","new_case":"\u062d\u0627\u0644\u0629 \u062c\u062f\u064a\u062f\u0629","patient":"\u0635\u0628\u0648\u0631","phone":"\u0647\u0627\u062a\u0641"},"case_handler":{"case_handler":"\u0645\u0639\u0627\u0644\u062c \u0627\u0644\u062d\u0627\u0644\u0629","case_handler_detail":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0645\u0639\u0627\u0644\u062c \u0627\u0644\u062d\u0627\u0644\u0629","edit_case_handler":"\u062a\u062d\u0631\u064a\u0631 \u0645\u0639\u0627\u0644\u062c \u0627\u0644\u062d\u0627\u0644\u0629","new_case_handler":"\u0645\u0639\u0627\u0644\u062c \u0627\u0644\u062d\u0627\u0644\u0629 \u0627\u0644\u062c\u062f\u064a\u062f"},"case_handlers":"\u0645\u0639\u0627\u0644\u062c\u0627\u062a \u0627\u0644\u062d\u0627\u0644\u0629","case_manager":"\u0645\u062f\u064a\u0631 \u0627\u0644\u062d\u0627\u0644\u0629","cases":"\u0627\u0644\u062d\u0627\u0644\u0627\u062a","change_password":{"change_password":"\u062a\u063a\u064a\u064a\u0631 \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","confirm_password":"\u062a\u0623\u0643\u064a\u062f \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","current_password":"\u0643\u0644\u0645\u0629 \u0627\u0644\u0633\u0631 \u0627\u0644\u062d\u0627\u0644\u064a\u0629","new_password":"\u0643\u0644\u0645\u0629 \u0627\u0644\u0633\u0631 \u0627\u0644\u062c\u062f\u064a\u062f\u0629"},"charge":{"charge_category":"\u0641\u0626\u0629 \u0627\u0644\u0634\u062d\u0646","charge_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0631\u0633\u0648\u0645","code":"\u0627\u0644\u0634\u0641\u0631\u0629","edit_charge":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0645\u0633\u0624\u0648\u0644","new_charge":"\u062a\u0647\u0645\u0629 \u062c\u062f\u064a\u062f\u0629","standard_charge":"\u0627\u0644\u0645\u0633\u0624\u0648\u0644 \u0627\u0644\u0642\u064a\u0627\u0633\u064a"},"charge_categories":"\u0641\u0626\u0627\u062a \u0627\u0644\u0631\u0633\u0648\u0645","charge_category":{"charge_categories":"\u0641\u0626\u0627\u062a \u0627\u0644\u0631\u0633\u0648\u0645","charge_category_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0641\u0626\u0629 \u0627\u0644\u0634\u062d\u0646","charge_type":"\u0646\u0648\u0639 \u0627\u0644\u062a\u0647\u0645\u0629","edit_charge_category":"\u062a\u062d\u0631\u064a\u0631 \u0641\u0626\u0629 \u0627\u0644\u0631\u0633\u0648\u0645","new_charge_category":"\u0641\u0626\u0629 \u0627\u0644\u0634\u062d\u0646 \u0627\u0644\u062c\u062f\u064a\u062f\u0629"},"charges":"\u0634\u062d\u0646\u0629","cms":"CMS","common":{"action":"\u0639\u0645\u0644","actions":"\u0623\u062c\u0631\u0627\u0621\u0627\u062a","active":"\u0646\u0634\u064a\u0637","add":"\u0623\u0636\u0641","address":"\u0639\u0646\u0648\u0627\u0646","apply":"\u064a\u062a\u0642\u062f\u0645","are_you_sure_want_to_delete_this":"\u0647\u0644 \u062a\u0631\u064a\u062f \u0628\u0627\u0644\u062a\u0623\u0643\u064a\u062f \u062d\u0630\u0641 \u0647\u0630\u0627 ","back":"\u0639\u0648\u062f\u0629","cancel":"\u0625\u0644\u063a\u0627\u0621","canceled":"\u0625\u0644\u063a\u0627\u0621","cant_be_deleted":"\u0644\u0627 \u064a\u0645\u0643\u0646 \u062d\u0630\u0641\u0647\u0627","choose":"\u0623\u062e\u062a\u0631","confirm":"\u064a\u062a\u0623\u0643\u062f","created_at":"\u062a\u0645 \u0625\u0646\u0634\u0627\u0624\u0647\u0627 \u0639\u0644\u0649","created_on":"\u062a\u0645 \u0625\u0646\u0634\u0627\u0624\u0647\u0627 \u0639\u0644\u0649","custom":"\u0627\u0644\u0639\u0627\u062f\u0629","de_active":"\u063a\u064a\u0631 \u0646\u0634\u0637","delete":"\u062d\u0630\u0641","deleted":"\u062a\u0645 \u0627\u0644\u062d\u0630\u0641","deleted_successfully":"\u062d\u0630\u0641 \u0628\u0646\u062c\u0627\u062d","description":"\u0648\u0635\u0641","detail":"\u062a\u0641\u0627\u0635\u064a\u0644","edit":"\u062a\u0639\u062f\u064a\u0644","export_to_excel":"\u062a\u0635\u062f\u064a\u0631 \u0627\u0644\u0649 \u0627\u0643\u0633\u0644","filter_options":"\u062e\u064a\u0627\u0631\u0627\u062a \u0627\u0644\u062a\u0635\u0641\u064a\u0629","from":"\u0645\u0646","has_been_deleted":"\u0642\u062f \u062a\u0645 \u062d\u0630\u0641.","invalid_country_code":"\u0631\u0645\u0632 \u0627\u0644\u062f\u0648\u0644\u0629 \u063a\u064a\u0631 \u0635\u062d\u064a\u062d","invalid_number":"\u0631\u0642\u0645 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d","is_available":"\u0645\u062a\u0627\u062d","last_updated":"\u0622\u062e\u0631 \u062a\u062d\u062f\u064a\u062b","n\/a":"\u0644\u0627 \u064a\u0648\u062c\u062f","name":"\u0627\u0633\u0645","new":"\u062c\u062f\u064a\u062f","next":"\u0627\u0644\u062a\u0627\u0644\u064a","no":"\u0644\u0627","not_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649","ok":"\u0645\u0648\u0627\u0641\u0642","previous":"\u0633\u0627\u0628\u0642","profile":"\u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a","reset":"\u0625\u0639\u0627\u062f\u0629 \u0636\u0628\u0637","save":"\u062d\u0641\u0638","saved_successfully":"\u062d\u0641\u0638 \u0628\u0646\u062c\u0627\u062d.","search":"\u064a\u0628\u062d\u062b","status":"\u0627\u0644\u062d\u0627\u0644\u0629","status_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u062d\u0627\u0644\u0629 \u0628\u0646\u062c\u0627\u062d.","this_action_is_not_allowed_for_default_record":"\u0647\u0630\u0627 \u0627\u0644\u0625\u062c\u0631\u0627\u0621 \u063a\u064a\u0631 \u0645\u0633\u0645\u0648\u062d \u0628\u0647 \u0644\u0644\u0633\u062c\u0644 \u0627\u0644\u0627\u0641\u062a\u0631\u0627\u0636\u064a.","to":"\u0625\u0644\u0649","too_long":"\u0637\u0648\u064a\u0644 \u062c\u062f\u0627","too_short":"\u0642\u0635\u064a\u0631 \u062c\u062f\u0627","total":"\u0645\u062c\u0645\u0648\u0639","updated_at":"\u0622\u062e\u0631 \u062a\u062d\u062f\u064a\u062b","updated_successfully":"\u062a\u0645 \u0627\u0644\u062a\u062d\u062f\u064a\u062b \u0628\u0646\u062c\u0627\u062d","view":"\u0631\u0623\u064a","view_attachment":"\u0639\u0631\u0636 \u0627\u0644\u0645\u0631\u0641\u0642\u0627\u062a","yes":"\u0646\u0639\u0645"},"contact_us":"\u0627\u062a\u0635\u0644 \u0628\u0646\u0627","currency":{"add_currency_code_as_per_three_letter_iso_code":"\u0623\u0636\u0641 \u0631\u0645\u0632 \u0627\u0644\u0639\u0645\u0644\u0629 \u0648\u0641\u0642\u064b\u0627 \u0644\u0631\u0645\u0632 ISO \u0627\u0644\u0645\u0643\u0648\u0646 \u0645\u0646 \u062b\u0644\u0627\u062b\u0629 \u0623\u062d\u0631\u0641.","currency":"\u0639\u0645\u0644\u0629","currency_code":"\u0631\u0645\u0632 \u0627\u0644\u0639\u0645\u0644\u0629","currency_icon":"\u0631\u0645\u0632 \u0627\u0644\u0639\u0645\u0644\u0629","currency_name":"\u0627\u0633\u0645 \u0627\u0644\u0639\u0645\u0644\u0629","edit_currency":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0639\u0645\u0644\u0629","new_currency":"\u0639\u0645\u0644\u0629 \u062c\u062f\u064a\u062f\u0629","you_can_find_out_here":"\u064a\u0645\u0643\u0646\u0643 \u0627\u0646 \u062a\u062c\u062f \u0647\u0646\u0627"},"currency_setting":"\u0627\u0644\u0639\u0645\u0644\u0627\u062a","dashboard":{"available_beds":"\u0627\u0644\u0623\u0633\u0631\u0629 \u0627\u0644\u0645\u062a\u0627\u062d\u0629","dashboard":"\u0644\u0648\u062d\u0629 \u0627\u0644\u0642\u064a\u0627\u062f\u0629","doctors":"\u0627\u0644\u0623\u0637\u0628\u0627\u0621","income_and_expense_report":"\u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u062f\u062e\u0644 \u0648\u0627\u0644\u0645\u0635\u0631\u0648\u0641\u0627\u062a","income_and_expense_reports":"\u062a\u0642\u0627\u0631\u064a\u0631 \u0627\u0644\u062f\u062e\u0644 \u0648\u0627\u0644\u0645\u0635\u0631\u0648\u0641\u0627\u062a","no_enquiries_yet":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0627\u0633\u062a\u0641\u0633\u0627\u0631\u0627\u062a \u062d\u062a\u0649 \u0627\u0644\u0622\u0646","no_notice_yet":"\u0644\u0627 \u0625\u0634\u0639\u0627\u0631 \u062d\u062a\u0649 \u0627\u0644\u0622\u0646","notice_boards":"\u0644\u0627\u0641\u062a\u0627\u062a \u062a\u0646\u0628\u064a\u0647","patients":"\u0627\u0644\u0645\u0631\u0636\u0649","title":"\u0639\u0646\u0648\u0627\u0646","total_advance_payments":"\u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a \u0644\u0644\u062f\u0641\u0639 \u0627\u0644\u0645\u0633\u0628\u0642","total_bills":"\u0625\u062c\u0645\u0627\u0644\u064a \u0645\u0628\u0644\u063a \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","total_invoices":"\u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a \u0644\u0644\u0641\u0627\u062a\u0648\u0631\u0629","total_payments":"\u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a \u0644\u0644\u062f\u0641\u0639"},"death_report":{"case_id":"ID \u0627\u0644\u0642\u0636\u064a\u0629","date":"\u062a\u0627\u0631\u064a\u062e","death_report":"\u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u0648\u0641\u0627\u0629","death_report_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u0648\u0641\u0627\u0629","death_reports":"\u062a\u0642\u0627\u0631\u064a\u0631 \u0627\u0644\u0648\u0641\u0627\u0629","description":"\u0648\u0635\u0641","doctor_name":"\u0627\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","edit_death_report":"\u062a\u062d\u0631\u064a\u0631 \u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u0648\u0641\u0627\u0629","new_death_report":"\u062a\u0642\u0631\u064a\u0631 \u0648\u0641\u0627\u0629 \u062c\u062f\u064a\u062f","patient_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u064a\u0636"},"death_reports":"\u062a\u0642\u0627\u0631\u064a\u0631 \u0627\u0644\u0648\u0641\u0627\u0629","department":"\u0642\u0633\u0645","departments":"\u0627\u0644\u0623\u0642\u0633\u0627\u0645","diagnosis_category":{"category_name":"\u0627\u0633\u0645 \u0627\u0644\u062a\u0635\u0646\u064a\u0641","description":"\u0648\u0635\u0641","diagnosis_categories":"\u0641\u0626\u0629 \u0627\u0644\u062a\u0634\u062e\u064a\u0635","diagnosis_category":"\u0641\u0626\u0629 \u0627\u0644\u062a\u0634\u062e\u064a\u0635","diagnosis_category_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0641\u0626\u0629 \u0627\u0644\u062a\u0634\u062e\u064a\u0635","edit_diagnosis_category":"\u062a\u062d\u0631\u064a\u0631 \u0641\u0626\u0629 \u0627\u0644\u062a\u0634\u062e\u064a\u0635","new_diagnosis_category":"\u0641\u0626\u0629 \u0627\u0644\u062a\u0634\u062e\u064a\u0635 \u0627\u0644\u062c\u062f\u064a\u062f\u0629"},"doc_type":{"edit_doc_type":"\u062a\u062d\u0631\u064a\u0631 \u0646\u0648\u0639 \u0627\u0644\u0645\u0633\u062a\u0646\u062f","name":"\u0627\u0633\u0645","new_doc_type":"\u0646\u0648\u0639 \u0645\u0633\u062a\u0646\u062f \u062c\u062f\u064a\u062f"},"doctor":{"doctor_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0637\u0628\u064a\u0628","edit_doctor":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0637\u0628\u064a\u0628","new_doctor":"\u062f\u0643\u062a\u0648\u0631 \u062c\u062f\u064a\u062f","specialist":"\u0645\u062a\u062e\u0635\u0635"},"doctor_department":{"description":"\u0648\u0635\u0641","doctor_department":"\u0642\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","doctor_department_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0642\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","doctor_departments":"\u0623\u0642\u0633\u0627\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","edit_doctor_department":"\u062a\u0639\u062f\u064a\u0644 \u0642\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","new_doctor_department":"\u0642\u0633\u0645 \u0627\u0644\u0623\u0637\u0628\u0627\u0621 \u0627\u0644\u062c\u062f\u064a\u062f","title":"\u0639\u0646\u0648\u0627\u0646"},"doctor_departments":"\u0623\u0642\u0633\u0627\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","doctor_opd_charge":{"doctor":"\u0637\u0628\u064a\u0628","doctor_name":"\u0627\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","doctor_opd_charge":"\u0637\u0628\u064a\u0628 \u0627\u0644\u0639\u064a\u0627\u062f\u0627\u062a \u0627\u0644\u062e\u0627\u0631\u062c\u064a\u0629 \u0627\u0644\u0645\u0633\u0624\u0648\u0644","edit_doctor_opd_charge":"\u062a\u062d\u0631\u064a\u0631 \u062a\u0647\u0645\u0629 \u0637\u0628\u064a\u0628 OPD","new_doctor_opd_charge":"\u0637\u0628\u064a\u0628 \u062c\u062f\u064a\u062f \u0631\u0633\u0648\u0645 OPD","standard_charge":"\u0627\u0644\u0645\u0633\u0624\u0648\u0644 \u0627\u0644\u0642\u064a\u0627\u0633\u064a"},"doctor_opd_charges":"\u0631\u0633\u0648\u0645 \u0637\u0628\u064a\u0628 OPD","doctors":"\u0627\u0644\u0623\u0637\u0628\u0627\u0621","doctors_list":"\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u0623\u0637\u0628\u0627\u0621","document":{"attachment":"\u0627\u0644\u0645\u0631\u0641\u0642","document":"\u0627\u0644\u0645\u0633\u062a\u0646\u062f","document_detail":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0648\u062b\u064a\u0642\u0629","document_type":"\u0646\u0648\u0639 \u0627\u0644\u0648\u062b\u064a\u0642\u0629","document_type_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0646\u0648\u0639 \u0627\u0644\u0645\u0633\u062a\u0646\u062f","download":"\u062a\u062d\u0645\u064a\u0644","edit_document":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0645\u0633\u062a\u0646\u062f","new_document":"\u0645\u0633\u062a\u0646\u062f \u062c\u062f\u064a\u062f","notes":"\u0645\u0644\u0627\u062d\u0638\u0627\u062a","patient":"\u0635\u0628\u0648\u0631","select_document_type":"\u062d\u062f\u062f \u0646\u0648\u0639 \u0627\u0644\u0645\u0633\u062a\u0646\u062f","select_patient":"\u062d\u062f\u062f \u0627\u0644\u0645\u0631\u064a\u0636","title":"\u0639\u0646\u0648\u0627\u0646","uploaded_by":"\u062a\u0645 \u0627\u0644\u0631\u0641\u0639 \u0628\u0648\u0627\u0633\u0637\u0629"},"document_types":"\u0623\u0646\u0648\u0627\u0639 \u0627\u0644\u0645\u0633\u062a\u0646\u062f\u0627\u062a","documents":"\u0645\u0633\u062a\u0646\u062f\u0627\u062a","email":{"attachment":"\u0627\u0644\u0645\u0631\u0641\u0642\u0627\u062a","message":"\u0631\u0633\u0627\u0644\u0629","subject":"\u0645\u0648\u0636\u0648\u0639","to":"\u0625\u0644\u0649"},"employee_payroll":{"allowance":"\u0645\u062e\u0635\u0635","basic_salary":"\u0631\u0627\u062a\u0628 \u0627\u0633\u0627\u0633\u064a","deductions":"\u0627\u0644\u062e\u0635\u0648\u0645\u0627\u062a","edit_employee_payroll":"\u062a\u062d\u0631\u064a\u0631 \u0631\u0648\u0627\u062a\u0628 \u0627\u0644\u0645\u0648\u0638\u0641\u064a\u0646","employee":"\u0645\u0648\u0638\u0641","employee_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0648\u0638\u0641","employee_payroll":"\u0643\u0634\u0648\u0641 \u0645\u0631\u062a\u0628\u0627\u062a \u0627\u0644\u0645\u0648\u0638\u0641\u064a\u0646","employee_payroll_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0631\u0648\u0627\u062a\u0628 \u0627\u0644\u0645\u0648\u0638\u0641\u064a\u0646","employee_payrolls":"\u0643\u0634\u0648\u0641 \u0645\u0631\u062a\u0628\u0627\u062a \u0627\u0644\u0645\u0648\u0638\u0641\u064a\u0646","month":"\u0634\u0647\u0631","net_salary":"\u0635\u0627\u0641\u064a \u0627\u0644\u0631\u0627\u062a\u0628","new_employee_payroll":"\u0631\u0648\u0627\u062a\u0628 \u0627\u0644\u0645\u0648\u0638\u0641\u064a\u0646 \u0627\u0644\u062c\u062f\u062f","not_paid":"\u063a\u064a\u0631 \u0645\u062f\u0641\u0648\u0639","paid":"\u062f\u0641\u0639","payroll_id":"\u0645\u0639\u0631\u0641 \u0627\u0644\u0631\u0648\u0627\u062a\u0628","role":"\u0648\u0638\u064a\u0641\u0629","sr_no":"\u0627\u0644\u0623\u0628 \u0631\u0642\u0645","year":"\u0639\u0627\u0645"},"employee_payrolls":"\u0643\u0634\u0648\u0641 \u0645\u0631\u062a\u0628\u0627\u062a \u0627\u0644\u0645\u0648\u0638\u0641\u064a\u0646","enquiries":"\u0627\u0633\u062a\u0641\u0633\u0627\u0631\u0627\u062a","enquiry":{"contact":"\u0627\u062a\u0635\u0644","email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","enquiry_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0625\u0633\u062a\u0641\u0633\u0627\u0631","enquiry_send_successfully":"\u0623\u0631\u0633\u0644 \u0627\u0644\u0627\u0633\u062a\u0641\u0633\u0627\u0631 \u0628\u0646\u062c\u0627\u062d","message":"\u0631\u0633\u0627\u0644\u0629","name":"\u0627\u0633\u0645","not_viewed":"\u0644\u0645 \u064a\u0634\u0627\u0647\u062f","read":"\u0627\u0642\u0631\u0623","received_on":"\u0648\u0631\u062f\u062a \u0641\u064a","send_enquiry":"\u0623\u0631\u0633\u0644 \u0625\u0633\u062a\u0641\u0633\u0627\u0631","type":"\u0627\u0643\u062a\u0628","unread":"\u063a\u064a\u0631 \u0645\u0642\u0631\u0648\u0621","viewed_by":"\u062a\u0645 \u0639\u0631\u0636\u0647\u0627 \u0628\u0648\u0627\u0633\u0637\u0629"},"expense":{"amount":"\u0643\u0645\u064a\u0629","attachment":"\u0627\u0644\u0645\u0631\u0641\u0642","choose":"\u0623\u062e\u062a\u0631","date":"\u062a\u0627\u0631\u064a\u062e","description":"\u0648\u0635\u0641","document_error":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 \u0627\u0644\u0648\u062b\u064a\u0642\u0629 \u0645\u0646 \u0646\u0648\u0639: jpeg\u060c jpg\u060c png\u060c pdf\u060c doc\u060c docx.","download":"\u062a\u062d\u0645\u064a\u0644","edit_expense":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense":"\u0645\u0635\u0631\u0648\u0641","expense_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense_head":"\u0631\u0626\u064a\u0633 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","invoice_number":"\u0631\u0642\u0645 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","name":"\u0627\u0633\u0645","new_expense":"\u0646\u0641\u0642\u0629 \u062c\u062f\u064a\u062f\u0629","select_expense_head":"\u062d\u062f\u062f \u0631\u0623\u0633 \u0627\u0644\u0646\u0641\u0642\u0627\u062a"},"expenses":"\u0646\u0641\u0642\u0627\u062a","facebook_url":"URL \u0627\u0644\u0641\u064a\u0633\u0628\u0648\u0643","file_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0644\u0641","finance":"\u0627\u0644\u0645\u0627\u0644\u064a\u0629","front_cms":"\u0627\u0644\u062c\u0628\u0647\u0629 \u0633\u0645","front_cms_services":"\u062e\u062f\u0645\u0627\u062a Front CMS","front_office":"\u0645\u0643\u062a\u0628 \u0627\u0644\u0625\u0633\u062a\u0642\u0628\u0627\u0644","front_service":"\u0627\u0644\u062e\u062f\u0645\u0629 \u0627\u0644\u0623\u0645\u0627\u0645\u064a\u0629","front_setting":{"about_us_description":"\u0648\u0635\u0641","about_us_details":"\u0645\u0646 \u0646\u062d\u0646 \u0627\u0644\u062a\u0641\u0627\u0635\u064a\u0644","about_us_image":"\u0635\u0648\u0631\u0629","about_us_mission":"\u0645\u0647\u0645\u0629","about_us_title":"\u0644\u0642\u0628","appointment_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u0648\u0639\u062f","front_setting_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0625\u0639\u062f\u0627\u062f \u0627\u0644\u0623\u0645\u0627\u0645\u064a","home_page_box_description":"\u0648\u0635\u0641 \u0645\u0631\u0628\u0639 \u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629","home_page_box_title":"\u0639\u0646\u0648\u0627\u0646 \u0645\u0631\u0628\u0639 \u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629","home_page_certified_box_description":"\u0648\u0635\u0641 \u0645\u0631\u0628\u0639 \u0645\u0639\u062a\u0645\u062f \u0644\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629","home_page_certified_box_title":"\u0639\u0646\u0648\u0627\u0646 \u0645\u0631\u0628\u0639 \u0645\u0639\u062a\u0645\u062f \u0644\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629","home_page_certified_doctor_description":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0648\u0635\u0641 \u0637\u0628\u064a\u0628 \u0645\u0639\u062a\u0645\u062f","home_page_certified_doctor_image":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0635\u0648\u0631\u0629 \u0637\u0628\u064a\u0628 \u0645\u0639\u062a\u0645\u062f","home_page_certified_doctor_text":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0646\u0635 \u0637\u0628\u064a\u0628 \u0645\u0639\u062a\u0645\u062f","home_page_certified_doctor_title":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0644\u0642\u0628 \u0637\u0628\u064a\u0628 \u0645\u0639\u062a\u0645\u062f","home_page_description":"\u0648\u0635\u0641 \u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629","home_page_experience":"\u062a\u062c\u0631\u0628\u0629 \u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629","home_page_image":"\u0635\u0648\u0631\u0629 \u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629","home_page_step_1_description":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0627\u0644\u062e\u0637\u0648\u0629 1 \u0627\u0644\u0648\u0635\u0641","home_page_step_1_title":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0627\u0644\u062e\u0637\u0648\u0629 1 \u0627\u0644\u0639\u0646\u0648\u0627\u0646","home_page_step_2_description":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0627\u0644\u062e\u0637\u0648\u0629 2 \u0627\u0644\u0648\u0635\u0641","home_page_step_2_title":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0627\u0644\u062e\u0637\u0648\u0629 2 \u0627\u0644\u0639\u0646\u0648\u0627\u0646","home_page_step_3_description":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0627\u0644\u062e\u0637\u0648\u0629 3 \u0627\u0644\u0648\u0635\u0641","home_page_step_3_title":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0627\u0644\u062e\u0637\u0648\u0629 3 \u0627\u0644\u0639\u0646\u0648\u0627\u0646","home_page_step_4_description":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0627\u0644\u062e\u0637\u0648\u0629 4 \u0627\u0644\u0648\u0635\u0641","home_page_step_4_title":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0627\u0644\u062e\u0637\u0648\u0629 4 \u0627\u0644\u0639\u0646\u0648\u0627\u0646","home_page_title":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629 \u0639\u0646\u0648\u0627\u0646","privacy_policy":"\u0633\u064a\u0627\u0633\u0629 \u0627\u0644\u062e\u0635\u0648\u0635\u064a\u0629","terms_condition_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0634\u0631\u0648\u0637 \u0648\u0627\u0644\u0623\u062d\u0643\u0627\u0645","terms_conditions":"\u0627\u0644\u0628\u0646\u0648\u062f \u0648 \u0627\u0644\u0638\u0631\u0648\u0641"},"front_settings":"\u0627\u0644\u0625\u0639\u062f\u0627\u062f\u0627\u062a \u0627\u0644\u0623\u0645\u0627\u0645\u064a\u0629","general":"\u062c\u0646\u0631\u0627\u0644 \u0644\u0648\u0627\u0621","hospital_activities":"\u0623\u0646\u0634\u0637\u0629 \u0627\u0644\u0645\u0633\u062a\u0634\u0641\u0649","hospital_blood_bank":{"blood_bank":"\u0628\u0646\u0643 \u0627\u0644\u062f\u0645","blood_bank_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0628\u0646\u0643 \u0627\u0644\u062f\u0645","blood_banks":"\u0628\u0646\u0648\u0643 \u0627\u0644\u062f\u0645","blood_group":"\u0641\u0635\u064a\u0644\u0629 \u0627\u0644\u062f\u0645","edit_blood_group":"\u062a\u062d\u0631\u064a\u0631 \u0641\u0635\u064a\u0644\u0629 \u0627\u0644\u062f\u0645","new_blood_group":"\u0641\u0635\u064a\u0644\u0629 \u0627\u0644\u062f\u0645 \u0627\u0644\u062c\u062f\u064a\u062f\u0629","remained_bags":"\u0623\u0643\u064a\u0627\u0633 \u0645\u062a\u0628\u0642\u064a\u0629"},"hospital_charges":"\u0631\u0633\u0648\u0645 \u0627\u0644\u0645\u0633\u062a\u0634\u0641\u0649","hospital_schedule":"\u062c\u062f\u0648\u0644 \u0627\u0644\u0645\u0633\u062a\u0634\u0641\u0649","hospital_schedules":{"exists_doctor_schedule":"\u062d\u062f\u062f \u0628\u0639\u0636 \u0627\u0644\u0623\u0637\u0628\u0627\u0621 \u0645\u0648\u0627\u0639\u064a\u062f\u0647\u0645 \u0641\u064a \u0623\u064a\u0627\u0645 \u0645\u062d\u062f\u062f\u0629 \u060c \u0641\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0631\u063a\u0628\u062a\u0643 \u0641\u064a \u0625\u062c\u0631\u0627\u0621 \u0647\u0630\u0647 \u0627\u0644\u0639\u0645\u0644\u064a\u0629\u061f"},"icon":"\u0623\u064a\u0642\u0648\u0646\u0629","income":"\u0627\u0644\u0625\u064a\u0631\u0627\u062f\u0627\u062a","incomes":{"amount":"\u0643\u0645\u064a\u0629","attachment":"\u0627\u0644\u0645\u0631\u0641\u0642","choose":"\u0623\u062e\u062a\u0631","date":"\u062a\u0627\u0631\u064a\u062e","description":"\u0648\u0635\u0641","document_error":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 \u0627\u0644\u0648\u062b\u064a\u0642\u0629 \u0645\u0646 \u0646\u0648\u0639: jpeg\u060c jpg\u060c png\u060c pdf\u060c doc\u060c docx.","download":"\u062a\u062d\u0645\u064a\u0644","edit_income":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062f\u062e\u0644","income_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u062f\u062e\u0644","income_head":"\u0631\u0626\u064a\u0633 \u0627\u0644\u062f\u062e\u0644","incomes":"\u0627\u0644\u062f\u062e\u0644","invoice_number":"\u0631\u0642\u0645 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","name":"\u0627\u0633\u0645","new_income":"\u062f\u062e\u0644 \u062c\u062f\u064a\u062f","select_income_head":"\u062d\u062f\u062f \u0631\u0623\u0633 \u0627\u0644\u062f\u062e\u0644"},"instagram_url":"\u0631\u0627\u0628\u0637 \u0627\u0646\u0633\u062a\u063a\u0631\u0627\u0645","insurance":{"discount":"\u062e\u0635\u0645","disease_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u0631\u0636","diseases_charge":"\u0631\u0633\u0648\u0645 \u0627\u0644\u0623\u0645\u0631\u0627\u0636","diseases_name":"\u0627\u0633\u0645 \u0627\u0644\u0623\u0645\u0631\u0627\u0636","edit_insurance":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062a\u0623\u0645\u064a\u0646","hospital_rate":"\u0645\u0639\u062f\u0644 \u0627\u0644\u0645\u0633\u062a\u0634\u0641\u0649","insurance":"\u062a\u0623\u0645\u064a\u0646","insurance_code":"\u0642\u0627\u0646\u0648\u0646 \u0627\u0644\u062a\u0623\u0645\u064a\u0646","insurance_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u062a\u0623\u0645\u064a\u0646","insurance_no":"\u0631\u0642\u0645 \u0627\u0644\u062a\u0623\u0645\u064a\u0646","insurances":"\u062a\u0623\u0645\u064a\u0646","new_insurance":"\u062a\u0623\u0645\u064a\u0646 \u062c\u062f\u064a\u062f","remark":"\u0645\u0644\u0627\u062d\u0638\u0629","service_tax":"\u0636\u0631\u064a\u0628\u0629 \u0627\u0644\u062e\u062f\u0645\u0629","total_amount":"\u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a"},"insurances":"\u062a\u0623\u0645\u064a\u0646","inventory":"\u0627\u0644\u0645\u062e\u0632\u0648\u0646","investigation_report":{"attachment":"\u0627\u0644\u0645\u0631\u0641\u0642","birth_date_validation":"\u064a\u062c\u0628 \u0623\u0644\u0627 \u064a\u0643\u0648\u0646 \u062a\u0627\u0631\u064a\u062e \u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u062a\u062d\u0642\u064a\u0642 \u0623\u0635\u063a\u0631 \u0645\u0646 \u062a\u0627\u0631\u064a\u062e \u0645\u064a\u0644\u0627\u062f \u0627\u0644\u0645\u0631\u064a\u0636.","date":"\u062a\u0627\u0631\u064a\u062e","description":"\u0648\u0635\u0641","doctor":"\u0639\u0646\u0648\u0627\u0646","edit_investigation_report":"\u062a\u062d\u0631\u064a\u0631 \u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u062a\u062d\u0642\u064a\u0642","investigation_report":"\u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u062a\u062d\u0642\u064a\u0642","investigation_report_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u062a\u062d\u0642\u064a\u0642","investigation_reports":"\u062a\u0642\u0627\u0631\u064a\u0631 \u0627\u0644\u062a\u062d\u0642\u064a\u0642","new_investigation_report":"\u062a\u0642\u0631\u064a\u0631 \u062a\u062d\u0642\u064a\u0642 \u062c\u062f\u064a\u062f","patient":"\u0635\u0628\u0648\u0631","title":"\u0639\u0646\u0648\u0627\u0646"},"investigation_reports":"\u062a\u0642\u0627\u0631\u064a\u0631 \u0627\u0644\u062a\u062d\u0642\u064a\u0642","invoice":{"account_name":"\u0623\u0633\u0645 \u0627\u0644\u062d\u0633\u0627\u0628","add":"\u0623\u0636\u0641","amount":"\u0643\u0645\u064a\u0629","description":"\u0648\u0635\u0641","discount":"\u062e\u0635\u0645","edit":"\u062a\u0639\u062f\u064a\u0644","edit_invoice":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","hospital_address":"\u0639\u0646\u0648\u0627\u0646 \u0627\u0644\u0645\u0633\u062a\u0634\u0641\u0649","invoice":"\u0641\u0627\u062a\u0648\u0631\u0629","invoice_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","invoice_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","invoice_id":"\u0647\u0648\u064a\u0629 \u0635\u0648\u062a\u064a\u0629","invoices":"\u0641\u0648\u0627\u062a\u064a\u0631","new_invoice":"\u0641\u0627\u062a\u0648\u0631\u0629 \u062c\u062f\u064a\u062f\u0629","not_paid":"\u063a\u064a\u0631 \u0645\u062f\u0641\u0648\u0639","paid":"\u062f\u0641\u0639","patient":"\u0635\u0628\u0648\u0631","patient_id":"\u0631\u0642\u0645 \u0627\u0644\u0645\u0631\u064a\u0636","price":"\u0627\u0644\u0633\u0639\u0631","print_invoice":"\u0637\u0628\u0627\u0639\u0629 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","qty":"\u0627\u0644\u0643\u0645\u064a\u0629","sub_total":"\u0627\u0644\u0645\u062c\u0645\u0648\u0639 \u0627\u0644\u0641\u0631\u0639\u064a","total":"\u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a"},"invoices":"\u0641\u0648\u0627\u062a\u064a\u0631","ipd_bill":{"discount_in_number":"\u0627\u0644\u062e\u0635\u0645 \u0641\u064a \u0627\u0644\u0639\u062f\u062f","discount_in_percentage":"\u0646\u0633\u0628\u0629 \u0627\u0644\u062e\u0635\u0645","gross_total":"\u0627\u0644\u0645\u062c\u0645\u0648\u0639 \u0627\u0644\u0643\u0644\u064a","net_payable_amount":"\u0635\u0627\u0641\u064a \u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0645\u0633\u062a\u062d\u0642","other_charges":"\u0631\u0633\u0648\u0645 \u0623\u062e\u0631\u0649","paid_amount":"\u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0645\u062f\u0641\u0648\u0639","tax_in_number":"\u0631\u0642\u0645 \u0627\u0644\u0636\u0631\u064a\u0628\u0629","tax_in_percentage":"\u0627\u0644\u0636\u0631\u064a\u0628\u0629 \u0628\u0627\u0644\u0646\u0633\u0628\u0629 \u0627\u0644\u0645\u0626\u0648\u064a\u0629","total_charges":"\u0627\u0644\u0643\u0644\u0641\u0629 \u0627\u0644\u0627\u062c\u0645\u0627\u0644\u064a\u0647"},"ipd_charges":"\u0634\u062d\u0646\u0629","ipd_consultant_register":"\u062a\u0639\u0644\u064a\u0645\u0627\u062a \u0627\u0633\u062a\u0634\u0627\u0631\u064a","ipd_diagnosis":"\u0627\u0644\u062a\u0634\u062e\u064a\u0635","ipd_opd":"IPD \/ \u0627\u0644\u0639\u064a\u0627\u062f\u0627\u062a \u0627\u0644\u062e\u0627\u0631\u062c\u064a\u0629","ipd_patient":{"admission_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0642\u0628\u0648\u0644","bed_id":"\u0627\u0644\u0633\u0631\u064a\u0631","bed_type_id":"\u0646\u0648\u0639 \u0627\u0644\u0633\u0631\u064a\u0631","bill_status":"\u062d\u0627\u0644\u0629 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","bp":"\u0636\u063a\u0637 \u0627\u0644\u062f\u0645","case_id":"\u0642\u0636\u064a\u0629","doctor_id":"\u0637\u0628\u064a\u0628","edit_ipd_patient":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0645\u0631\u064a\u0636 IPD","height":"\u0627\u0631\u062a\u0641\u0627\u0639","ipd_number":"IPD \u0644\u0627","ipd_patient":"\u0645\u0631\u064a\u0636 IPD","ipd_patient_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u0631\u064a\u0636 IPD","ipd_patients":"\u0645\u0631\u0636\u0649 IPD","is_old_patient":"\u0645\u0631\u064a\u0636 \u0642\u062f\u064a\u0645","new_ipd_patient":"\u0645\u0631\u064a\u0636 IPD \u0627\u0644\u062c\u062f\u064a\u062f","notes":"\u0645\u0644\u0627\u062d\u0638\u0627\u062a","patient_id":"\u0635\u0628\u0648\u0631","symptoms":"\u0627\u0644\u0623\u0639\u0631\u0627\u0636","the_bed_field_is_required":"\u062d\u0642\u0644 \u0627\u0644\u0633\u0631\u064a\u0631 \u0645\u0637\u0644\u0648\u0628.","the_case_field_is_required":"\u062d\u0642\u0644 \u0627\u0644\u062d\u0627\u0644\u0629 \u0645\u0637\u0644\u0648\u0628.","weight":"\u0648\u0632\u0646"},"ipd_patient_charges":{"applied_charge":"\u0627\u0644\u0631\u0633\u0648\u0645 \u0627\u0644\u062a\u0637\u0628\u064a\u0642\u064a\u0629","charge_category_id":"\u0641\u0626\u0629 \u0627\u0644\u0634\u062d\u0646","charge_id":"\u0627\u0644\u0634\u0641\u0631\u0629","charge_type_id":"\u0646\u0648\u0639 \u0627\u0644\u062a\u0647\u0645\u0629","date":"\u062a\u0627\u0631\u064a\u062e","new_charge":"\u0623\u0636\u0641 \u0627\u0644\u0631\u0633\u0648\u0645","standard_charge":"\u0627\u0644\u0634\u062d\u0646 \u0627\u0644\u0642\u064a\u0627\u0633\u064a"},"ipd_patient_consultant_register":{"applied_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u062a\u0637\u0628\u064a\u0642","doctor_id":"\u0637\u0628\u064a\u0628","instruction":"\u062a\u0639\u0644\u064a\u0645\u0627\u062a","instruction_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u062a\u0639\u0644\u064a\u0645\u0627\u062a","new_consultant_register":"\u0623\u0636\u0641 \u062a\u0639\u0644\u064a\u0645\u0627\u062a \u0627\u0633\u062a\u0634\u0627\u0631\u064a"},"ipd_patient_diagnosis":{"description":"\u0648\u0635\u0641","document":"\u0648\u062b\u064a\u0642\u0629","edit_ipd_diagnosis":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062a\u0634\u062e\u064a\u0635","new_ipd_diagnosis":"\u0623\u0636\u0641 \u0627\u0644\u062a\u0634\u062e\u064a\u0635","report_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u062a\u0642\u0631\u064a\u0631","report_type":"\u0646\u0648\u0639 \u0627\u0644\u062a\u0642\u0631\u064a\u0631"},"ipd_patient_prescription":{"category_id":"\u0641\u0626\u0629 \u0627\u0644\u0637\u0628","dosage":"\u0627\u0644\u062c\u0631\u0639\u0629","edit_prescription":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0648\u0635\u0641\u0629 \u0627\u0644\u0637\u0628\u064a\u0629","footer_note":"\u0645\u0644\u0627\u062d\u0638\u0629 \u0627\u0644\u062a\u0630\u064a\u064a\u0644","header_note":"\u0645\u0644\u0627\u062d\u0638\u0629 \u0631\u0623\u0633","instruction":"\u062a\u0639\u0644\u064a\u0645\u0627\u062a","ipd_no":"IPD \u0644\u0627","medicine_id":"\u0627\u0644\u062f\u0648\u0627\u0621","new_prescription":"\u0625\u0636\u0627\u0641\u0629 \u0648\u0635\u0641\u0629 \u0637\u0628\u064a\u0629","prescription_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0648\u0635\u0641\u0629","print_prescription":"\u0648\u0635\u0641\u0629 \u0637\u0628\u064a\u0629 \u0645\u0637\u0628\u0648\u0639\u0629"},"ipd_patient_timeline":{"date":"\u062a\u0627\u0631\u064a\u062e","description":"\u0648\u0635\u0641","document":"\u0648\u062b\u064a\u0642\u0629","edit_ipd_timeline":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062c\u062f\u0648\u0644 \u0627\u0644\u0632\u0645\u0646\u064a","new_ipd_timeline":"\u0623\u0636\u0641 \u0627\u0644\u062c\u062f\u0648\u0644 \u0627\u0644\u0632\u0645\u0646\u064a","no_timeline_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u062e\u0637 \u0632\u0645\u0646\u064a","title":"\u0639\u0646\u0648\u0627\u0646","visible_to_person":"\u0645\u0631\u0626\u064a \u0644\u0644\u0634\u062e\u0635"},"ipd_patients":"\u0645\u0631\u0636\u0649 IPD","ipd_payment":"\u062f\u0641\u0639 IPD","ipd_payments":{"add_ipd_payment":"\u0625\u0636\u0627\u0641\u0629 \u062f\u0641\u0639 Ipd","edit_ipd_payment":"Edit IPD Payment","make_payment":"\u0642\u0645 \u0628\u0627\u0644\u062f\u0641\u0639","payment_mode":"\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u062f\u0641\u0639"},"ipd_prescription":"\u0627\u0644\u0648\u0635\u0641\u0627\u062a \u0627\u0644\u0637\u0628\u064a\u0629","ipd_timelines":"\u0627\u0644\u062c\u062f\u0627\u0648\u0644 \u0627\u0644\u0632\u0645\u0646\u064a\u0629","issued_item":{"are_you_sure_want_to_return_this_item":"\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0625\u0631\u062c\u0627\u0639 \u0647\u0630\u0627 \u0627\u0644\u0639\u0646\u0635\u0631","available_quantity":"\u0627\u0644\u0643\u0645\u064a\u0629 \u0627\u0644\u0645\u062a\u0648\u0641\u0631\u0629","department_id":"\u0646\u0648\u0639 \u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645","description":"\u0648\u0635\u0641","edit_issued_item":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0639\u0646\u0635\u0631 \u0627\u0644\u0630\u064a \u062a\u0645 \u0625\u0635\u062f\u0627\u0631\u0647","issued_by":"\u0625\u0635\u062f\u0627\u0631 \u0628\u0648\u0627\u0633\u0637\u0629","issued_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0627\u0635\u062f\u0627\u0631","issued_item":"\u0627\u0644\u0628\u0646\u062f \u0627\u0644\u0645\u0635\u062f\u0631","issued_item_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0623\u0635\u0646\u0627\u0641 \u0627\u0644\u0645\u0635\u062f\u0631\u0629","issued_items":"\u0627\u0644\u0639\u0646\u0627\u0635\u0631 \u0627\u0644\u0645\u0635\u062f\u0631\u0629","item":"\u0628\u0646\u062f","item_category":"\u0627\u0644\u0639\u0646\u0635\u0631 \u0641\u0626\u0629","item_return":"\u0625\u0631\u062c\u0627\u0639 \u0627\u0644\u0628\u0646\u062f","item_returned":"\u0639\u0627\u062f","new_issued_item":"\u0639\u0646\u0635\u0631 \u062c\u062f\u064a\u062f \u0635\u0627\u062f\u0631","quantity":"\u0643\u0645\u064a\u0629","return_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0639\u0648\u062f\u0629","user_id":"\u0625\u0635\u062f\u0627\u0631 \u0644"},"issued_items":"\u0627\u0644\u0639\u0646\u0627\u0635\u0631 \u0627\u0644\u0645\u0635\u062f\u0631\u0629","item":{"available_quantity":"\u0627\u0644\u0643\u0645\u064a\u0629 \u0627\u0644\u0645\u062a\u0648\u0641\u0631\u0629","description":"\u0648\u0635\u0641","edit_item":"\u062a\u0639\u062f\u064a\u0644 \u0639\u0646\u0635\u0631","item":"\u0628\u0646\u062f","item_category":"\u0627\u0644\u0639\u0646\u0635\u0631 \u0641\u0626\u0629","item_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0646\u0635\u0631","items":"\u0627\u0644\u0639\u0646\u0627\u0635\u0631","name":"\u0627\u0633\u0645","new_item":"\u0639\u0646\u0635\u0631 \u062c\u062f\u064a\u062f","unit":"\u0648\u062d\u062f\u0629"},"item_category":{"edit_item_category":"\u062a\u062d\u0631\u064a\u0631 \u0641\u0626\u0629 \u0627\u0644\u0639\u0646\u0635\u0631","item_categories":"\u0641\u0626\u0627\u062a \u0627\u0644\u0639\u0646\u0627\u0635\u0631","item_category":"\u0627\u0644\u0639\u0646\u0635\u0631 \u0641\u0626\u0629","name":"\u0627\u0633\u0645","new_item_category":"\u0641\u0626\u0629 \u0639\u0646\u0635\u0631 \u062c\u062f\u064a\u062f"},"item_stock":{"attachment":"\u0627\u0644\u0645\u0631\u0641\u0642","description":"\u0648\u0635\u0641","edit_item_stock":"\u062a\u062d\u0631\u064a\u0631 \u0645\u062e\u0632\u0648\u0646 \u0627\u0644\u0639\u0646\u0635\u0631","item":"\u0628\u0646\u062f","item_category":"\u0627\u0644\u0639\u0646\u0635\u0631 \u0641\u0626\u0629","item_stock":"\u0639\u0646\u0635\u0631 \u0627\u0644\u0645\u062e\u0632\u0648\u0646","item_stock_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0645\u062e\u0632\u0648\u0646 \u0627\u0644\u0639\u0646\u0635\u0631","item_stocks":"\u0645\u062e\u0632\u0648\u0646 \u0627\u0644\u0628\u0646\u062f","new_item_stock":"\u0645\u062e\u0632\u0648\u0646 \u0639\u0646\u0635\u0631 \u062c\u062f\u064a\u062f","purchase_price":"\u0633\u0639\u0631 \u0627\u0644\u0634\u0631\u0627\u0621","quantity":"\u0643\u0645\u064a\u0629","store_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u062a\u062c\u0631","supplier_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0648\u0631\u062f"},"items":"\u0627\u0644\u0639\u0646\u0627\u0635\u0631","items_categories":"\u0641\u0626\u0627\u062a \u0627\u0644\u0639\u0646\u0627\u0635\u0631","items_stocks":"\u0645\u062e\u0632\u0648\u0646 \u0627\u0644\u0628\u0646\u062f","lab_tech":{"edit_lab_tech":"\u062a\u062d\u0631\u064a\u0631 \u0641\u0646\u064a \u0645\u062e\u062a\u0628\u0631","lab_tech_detail":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0641\u0646\u064a \u0645\u062e\u062a\u0628\u0631","lab_technician":"\u0641\u0646\u064a \u0645\u062e\u062a\u0628\u0631","new_lab_tech":"\u0641\u0646\u064a \u0645\u062e\u062a\u0628\u0631 \u062c\u062f\u064a\u062f"},"lab_technicians":"\u0641\u0646\u064a\u0648 \u0627\u0644\u0645\u062e\u062a\u0628\u0631\u0627\u062a","language":{"Arabic":"\u0639\u0631\u0628\u064a","Chinese":"\u0635\u064a\u0646\u0649","English":"\u0625\u0646\u062c\u0644\u064a\u0632\u064a","French":"\u0641\u0631\u0646\u0633\u064a","German":"\u0623\u0644\u0645\u0627\u0646\u064a\u0629","Portuguese":"\u0627\u0644\u0628\u0631\u062a\u063a\u0627\u0644\u064a\u0629","Russian":"\u0627\u0644\u0631\u0648\u0633\u064a\u0629","Spanish":"\u0627\u0644\u0623\u0633\u0628\u0627\u0646\u064a\u0629","Turkish":"\u0627\u0644\u0644\u063a\u0629 \u0627\u0644\u062a\u0631\u0643\u064a\u0629"},"linkedIn_url":"\u0631\u0627\u0628\u0637 \u0631\u0627\u0628\u0637","live_consultation":{"add_credential":"\u0623\u0636\u0641 \u0628\u064a\u0627\u0646\u0627\u062a \u0627\u0644\u0627\u0639\u062a\u0645\u0627\u062f","client_video":"\u0641\u064a\u062f\u064a\u0648 \u0627\u0644\u0639\u0645\u064a\u0644","consultation_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0627\u0633\u062a\u0634\u0627\u0631\u0629","consultation_duration_minutes":"\u062f\u0642\u0627\u0626\u0642 \u0645\u062f\u0629 \u0627\u0644\u0627\u0633\u062a\u0634\u0627\u0631\u0629","consultation_title":"\u0639\u0646\u0648\u0627\u0646 \u0627\u0644\u0627\u0633\u062a\u0634\u0627\u0631\u0629","created_by":"\u0627\u0646\u0634\u0623 \u0645\u0646 \u0642\u0628\u0644","created_for":"\u062e\u0644\u0642\u062a \u0644","disabled":"\u0645\u0639\u0627\u0642","edit_live_consultation":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0633\u062a\u0634\u0627\u0631\u0629 \u0645\u0628\u0627\u0634\u0631\u0629","edit_live_meeting":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0627\u062c\u062a\u0645\u0627\u0639 \u0627\u0644\u0645\u0628\u0627\u0634\u0631","enable":"\u0645\u0645\u0643\u0646","host_video":"\u0627\u0633\u062a\u0636\u0627\u0641\u0629 \u0627\u0644\u0641\u064a\u062f\u064a\u0648","join_now":"\u0646\u0636\u0645 \u0627\u0644\u0627\u0646","live_consultation":"\u0627\u0644\u0627\u0633\u062a\u0634\u0627\u0631\u0627\u062a \u0627\u0644\u062d\u064a\u0629","new_live_consultation":"\u0627\u0633\u062a\u0634\u0627\u0631\u0629 \u0645\u0628\u0627\u0634\u0631\u0629 \u062c\u062f\u064a\u062f\u0629","new_live_meeting":"\u0627\u062c\u062a\u0645\u0627\u0639 \u062c\u062f\u064a\u062f \u0645\u0628\u0627\u0634\u0631","staff_list":"\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u0645\u0648\u0638\u0641\u064a\u0646","type":"\u0646\u0648\u0639","type_number":"\u0646\u0648\u0639 \u0627\u0644\u0631\u0642\u0645","zoom_api_key":"\u0645\u0641\u062a\u0627\u062d Zoom Api","zoom_api_secret":"Zoom API \u0627\u0644\u0633\u0631\u064a"},"live_consultations":"\u0627\u0633\u062a\u0634\u0627\u0631\u0627\u062a \u0645\u0628\u0627\u0634\u0631\u0629","live_meeting":"\u0644\u0642\u0627\u0621 \u0645\u0628\u0627\u0634\u0631","live_meetings":"\u0627\u062c\u062a\u0645\u0627\u0639\u0627\u062a \u0645\u0628\u0627\u0634\u0631\u0629","mail":"\u0628\u0631\u064a\u062f","make_an_appointment":"\u0625\u062d\u062c\u0632 \u0645\u0648\u0639\u062f","medicine":{"brand":"\u0627\u0644\u0639\u0644\u0627\u0645\u0629 \u0627\u0644\u062a\u062c\u0627\u0631\u064a\u0629","brand_name":"\u0627\u0633\u0645 \u0627\u0644\u0639\u0644\u0627\u0645\u0629 \u0627\u0644\u062a\u062c\u0627\u0631\u064a\u0629","buying_price":"\u0633\u0639\u0631 \u0627\u0644\u0634\u0631\u0627\u0621","category":"\u0641\u0626\u0629","category_id":"\u0645\u0639\u0631\u0641 \u0627\u0644\u0641\u0626\u0629","description":"\u0648\u0635\u0641","edit_medicine":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0637\u0628","edit_medicine_brand":"\u062a\u0639\u062f\u064a\u0644 \u0627\u0644\u0639\u0644\u0627\u0645\u0629 \u0627\u0644\u062a\u062c\u0627\u0631\u064a\u0629 \u0644\u0644\u0637\u0628","edit_medicine_category":"\u062a\u062d\u0631\u064a\u0631 \u0641\u0626\u0629 \u0627\u0644\u062f\u0648\u0627\u0621","medicine":"\u062f\u0648\u0627\u0621","medicine_brands":"\u0645\u0627\u0631\u0643\u0627\u062a \u0627\u0644\u0637\u0628","medicine_brands_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0644\u0627\u0645\u0629 \u0627\u0644\u062a\u062c\u0627\u0631\u064a\u0629 \u0644\u0644\u0623\u062f\u0648\u064a\u0629","medicine_category":"\u0641\u0626\u0629 \u0627\u0644\u0637\u0628","medicine_category_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0641\u0626\u0629 \u0627\u0644\u062f\u0648\u0627\u0621","medicine_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u062f\u0648\u0627\u0621","medicines":"\u0623\u062f\u0648\u064a\u0629","name":"\u0627\u0633\u0645","new_brand":"\u0627\u0644\u0639\u0644\u0627\u0645\u0629 \u0627\u0644\u062a\u062c\u0627\u0631\u064a\u0629 \u0627\u0644\u062c\u062f\u064a\u062f\u0629","new_medicine":"\u0627\u0644\u0637\u0628 \u0627\u0644\u062c\u062f\u064a\u062f","new_medicine_brand":"\u0627\u0644\u0639\u0644\u0627\u0645\u0629 \u0627\u0644\u062a\u062c\u0627\u0631\u064a\u0629 \u0644\u0644\u0637\u0628 \u0627\u0644\u062c\u062f\u064a\u062f","new_medicine_category":"\u0641\u0626\u0629 \u0627\u0644\u0637\u0628 \u0627\u0644\u062c\u062f\u064a\u062f","salt_composition":"\u062a\u0643\u0648\u064a\u0646 \u0627\u0644\u0645\u0644\u062d","selling_price":"\u0633\u0639\u0631 \u0627\u0644\u0628\u064a\u0639","side_effects":"\u0622\u062b\u0627\u0631 \u062c\u0627\u0646\u0628\u064a\u0629"},"medicine_brands":"\u0645\u0627\u0631\u0643\u0627\u062a \u0627\u0644\u0637\u0628","medicine_categories":"\u0641\u0626\u0627\u062a \u0627\u0644\u0637\u0628","medicines":"\u0623\u062f\u0648\u064a\u0629","message":{"date":"\u062a\u0627\u0631\u064a\u062e","message":"\u0631\u0633\u0627\u0644\u0629","messages":"\u0627\u0644\u0631\u0633\u0627\u0626\u0644","messages_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0631\u0633\u0627\u0644\u0629","new_message":"\u0631\u0633\u0627\u0644\u0629 \u062c\u062f\u064a\u062f\u0629","select_user":"\u0627\u062e\u062a\u0631 \u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645","send_to":"\u0627\u0631\u0633\u0644 \u0625\u0644\u0649","sender_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u0633\u0644","subject":"\u0645\u0648\u0636\u0648\u0639"},"months":{"apr":"\u0623\u0628\u0631\u064a\u0644","aug":"\u0623\u063a\u0633\u0637\u0633","dec":"\u062f\u064a\u0633\u0645\u0628\u0631","feb":"\u0634\u0647\u0631 \u0641\u0628\u0631\u0627\u064a\u0631","jan":"\u064a\u0646\u0627\u064a\u0631","july":"\u064a\u0648\u0644\u064a\u0648","jun":"\u064a\u0648\u0646\u064a\u0647","mar":"\u064a\u0645\u0634\u064a","may":"\u0645\u0627\u064a\u0648","nov":"\u0634\u0647\u0631 \u0646\u0648\u0641\u0645\u0628\u0631","oct":"\u0627\u0643\u062a\u0648\u0628\u0631","sep":"\u0633\u0628\u062a\u0645\u0628\u0631"},"my_payroll":{"allowance":"Allowance","basic_salary":"\u0631\u0627\u062a\u0628 \u0627\u0633\u0627\u0633\u064a","deductions":"\u0627\u0644\u062e\u0635\u0648\u0645\u0627\u062a","my_payrolls":"\u0631\u0648\u0627\u062a\u0628\u064a","net_salary":"\u0635\u0627\u0641\u064a \u0627\u0644\u0631\u0627\u062a\u0628"},"my_payrolls":"\u0631\u0648\u0627\u062a\u0628\u064a","new_patient":"\u0645\u0631\u064a\u0636 \u062c\u062f\u064a\u062f","no_data_available":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0628\u064a\u0627\u0646\u0627\u062a \u0645\u062a\u0648\u0641\u0631\u0629 \u0641\u064a \u0627\u0644\u062c\u062f\u0648\u0644","notice_board":{"created_at":"\u0623\u0646\u0634\u0626\u062a \u0641\u064a","description":"\u0648\u0635\u0641","details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0644\u0648\u062d\u0629 \u0627\u0644\u0625\u0639\u0644\u0627\u0646\u0627\u062a","edit":"\u062a\u062d\u0631\u064a\u0631 \u0644\u0648\u062d\u0629 \u0627\u0644\u0625\u0639\u0644\u0627\u0646\u0627\u062a","new":"\u0644\u0648\u062d\u0629 \u0627\u0644\u0625\u0639\u0644\u0627\u0646\u0627\u062a \u0627\u0644\u062c\u062f\u064a\u062f\u0629","notice_board":"\u0644\u0648\u062d \u0627\u0644\u0625\u0639\u0644\u0627\u0646\u0627\u062a","title":"\u0639\u0646\u0648\u0627\u0646"},"notice_boards":"\u0644\u0627\u0641\u062a\u0627\u062a \u062a\u0646\u0628\u064a\u0647","notification":{"mark_all_as_read":"\u0627\u0634\u0631 \u0639\u0644\u064a\u0647\u0627 \u0628\u0627\u0646\u0647\u0627 \u0642\u0631\u0627\u062a","notifications":"\u0625\u0634\u0639\u0627\u0631\u0627\u062a","you_don`t_have_any_new_notification":"\u0644\u064a\u0633 \u0644\u062f\u064a\u0643 \u0623\u064a \u0625\u062e\u0637\u0627\u0631 \u062c\u062f\u064a\u062f"},"nurse":{"birth_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0645\u064a\u0644\u0627\u062f","choose":"\u0623\u062e\u062a\u0631","edit_nurse":"\u062a\u062d\u0631\u064a\u0631 \u0645\u0645\u0631\u0636\u0629","new_nurse":"\u0645\u0645\u0631\u0636\u0629 \u062c\u062f\u064a\u062f\u0629","nurse":"\u0645\u0645\u0631\u0636\u0629","nurse_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u0645\u0631\u0636\u0629","phone_no":"\u0631\u0642\u0645 \u0627\u0644\u0647\u0627\u062a\u0641"},"nurses":"\u0627\u0644\u0645\u0645\u0631\u0636\u0627\u062a","old_patient":"\u0645\u0631\u064a\u0636 \u0642\u062f\u064a\u0645","opd_diagnosis":"\u062a\u0634\u062e\u064a\u0635 \u0627\u0644\u0639\u064a\u0627\u062f\u0627\u062a \u0627\u0644\u062e\u0627\u0631\u062c\u064a\u0629","opd_patient":{"appointment_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0645\u0648\u0639\u062f","edit_opd_patient":"\u062a\u062d\u0631\u064a\u0631 \u0645\u0631\u064a\u0636 \u0627\u0644\u0639\u064a\u0627\u062f\u0627\u062a \u0627\u0644\u062e\u0627\u0631\u062c\u064a\u0629","new_opd_patient":"\u0645\u0631\u064a\u0636 \u0627\u0644\u0639\u064a\u0627\u062f\u0627\u062a \u0627\u0644\u062e\u0627\u0631\u062c\u064a\u0629 \u0627\u0644\u062c\u062f\u064a\u062f","opd_number":"OPD \u0644\u0627","opd_patient":"\u0645\u0631\u064a\u0636 \u0627\u0644\u0639\u064a\u0627\u062f\u0627\u062a \u0627\u0644\u062e\u0627\u0631\u062c\u064a\u0629","opd_patient_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0645\u0631\u064a\u0636 \u0627\u0644\u0639\u064a\u0627\u062f\u0627\u062a \u0627\u0644\u062e\u0627\u0631\u062c\u064a\u0629","opd_patients":"\u0645\u0631\u0636\u0649 \u0627\u0644\u0639\u064a\u0627\u062f\u0627\u062a \u0627\u0644\u062e\u0627\u0631\u062c\u064a\u0629","revisits":"\u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u0646\u0638\u0631","total_visits":"\u0625\u062c\u0645\u0627\u0644\u064a \u0639\u062f\u062f \u0627\u0644\u0632\u064a\u0627\u0631\u0627\u062a","visits":"\u0627\u0644\u0632\u064a\u0627\u0631\u0627\u062a"},"opd_patients":"\u0645\u0631\u0636\u0649 \u0627\u0644\u0639\u064a\u0627\u062f\u0627\u062a \u0627\u0644\u062e\u0627\u0631\u062c\u064a\u0629","opd_payments":{"add_opd_payment":"\u0625\u0636\u0627\u0641\u0629 \u062f\u0641\u0639 Opd","edit_opd_payment":"\u062a\u062d\u0631\u064a\u0631 \u062f\u0641\u0639 Opd","make_payment":"\u0642\u0645 \u0628\u0627\u0644\u062f\u0641\u0639","payment_mode":"\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u062f\u0641\u0639"},"opd_timeline":"\u0627\u0644\u062c\u062f\u0648\u0644 \u0627\u0644\u0632\u0645\u0646\u064a \u0644\u0644\u0639\u064a\u0627\u062f\u0627\u062a \u0627\u0644\u062e\u0627\u0631\u062c\u064a\u0629","operation_report":{"case_id":"ID \u0627\u0644\u0642\u0636\u064a\u0629","date":"\u062a\u0627\u0631\u064a\u062e","description":"\u0648\u0635\u0641","doctor_name":"\u0627\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","edit_operation_report":"\u062a\u062d\u0631\u064a\u0631 \u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u0639\u0645\u0644\u064a\u0629","new_operation_report":"\u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u0639\u0645\u0644\u064a\u0629 \u0627\u0644\u062c\u062f\u064a\u062f","operation_report":"\u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u0639\u0645\u0644\u064a\u0629","operation_report_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u062a\u0642\u0631\u064a\u0631 \u0627\u0644\u0639\u0645\u0644\u064a\u0629","operation_reports":"\u062a\u0642\u0627\u0631\u064a\u0631 \u0627\u0644\u062a\u0634\u063a\u064a\u0644","patient_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u064a\u0636"},"operation_reports":"\u062a\u0642\u0627\u0631\u064a\u0631 \u0627\u0644\u062a\u0634\u063a\u064a\u0644","overview":"\u0645\u0644\u062e\u0635","package":{"amount":"\u0643\u0645\u064a\u0629","description":"\u0648\u0635\u0641","discount":"\u062e\u0635\u0645","edit_package":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062d\u0632\u0645\u0629","name":"\u0627\u0633\u0645","new_package":"\u062d\u0632\u0645\u0629 \u062c\u062f\u064a\u062f\u0629","package":"\u0635\u0641\u0642\u0629","package_details":"\u062d\u0632\u0645\u0629 \u0645\u0646 \u0627\u0644\u062a\u0641\u0627\u0635\u064a\u0644","packages":"\u0627\u0644\u062d\u0632\u0645","qty":"\u0627\u0644\u0643\u0645\u064a\u0629","rate":"\u0645\u0639\u062f\u0644","select_service":"\u062d\u062f\u062f \u0627\u0644\u062e\u062f\u0645\u0629","service":"\u0627\u0644\u062e\u062f\u0645\u0627\u062a","total_amount":"\u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a"},"packages":"\u0627\u0644\u062d\u0632\u0645","pathologies":"\u0639\u0644\u0645 \u0627\u0644\u0623\u0645\u0631\u0627\u0636","pathology_categories":"\u0641\u0626\u0629 \u0639\u0644\u0645 \u0627\u0644\u0623\u0645\u0631\u0627\u0636","pathology_category":{"edit_pathology_category":"\u062a\u062d\u0631\u064a\u0631 \u0641\u0626\u0629 \u0639\u0644\u0645 \u0627\u0644\u0623\u0645\u0631\u0627\u0636","name":"\u0627\u0633\u0645","new_pathology_category":"\u0641\u0626\u0629 \u0639\u0644\u0645 \u0627\u0644\u0623\u0645\u0631\u0627\u0636 \u0627\u0644\u062c\u062f\u064a\u062f\u0629","pathology_categories":"\u0641\u0626\u0627\u062a \u0639\u0644\u0645 \u0627\u0644\u0623\u0645\u0631\u0627\u0636"},"pathology_test":{"category_name":"\u0627\u0633\u0645 \u0627\u0644\u062a\u0635\u0646\u064a\u0641","charge_category":"\u0641\u0626\u0629 \u0627\u0644\u0634\u062d\u0646","edit_pathology_test":"\u062a\u062d\u0631\u064a\u0631 \u0627\u062e\u062a\u0628\u0627\u0631 \u0639\u0644\u0645 \u0627\u0644\u0623\u0645\u0631\u0627\u0636","method":"\u0637\u0631\u064a\u0642\u0629","new_pathology_test":"\u0627\u062e\u062a\u0628\u0627\u0631 \u0628\u0627\u062b\u0648\u0644\u0648\u062c\u064a \u062c\u062f\u064a\u062f","pathology_test_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u062e\u062a\u0628\u0627\u0631 \u0639\u0644\u0645 \u0627\u0644\u0623\u0645\u0631\u0627\u0636","pathology_tests":"\u0627\u062e\u062a\u0628\u0627\u0631\u0627\u062a \u0639\u0644\u0645 \u0627\u0644\u0623\u0645\u0631\u0627\u0636","report_days":"\u0623\u064a\u0627\u0645 \u0627\u0644\u062a\u0642\u0631\u064a\u0631","short_name":"\u0627\u0633\u0645 \u0642\u0635\u064a\u0631","standard_charge":"\u0627\u0644\u0645\u0633\u0624\u0648\u0644 \u0627\u0644\u0642\u064a\u0627\u0633\u064a","subcategory":"\u062a\u0635\u0646\u064a\u0641 \u0641\u0631\u0639\u064a","test_name":"\u0627\u0633\u0645 \u0627\u0644\u0627\u062e\u062a\u0628\u0627\u0631","test_type":"\u0646\u0648\u0639 \u0627\u0644\u0627\u062e\u062a\u0628\u0627\u0631","unit":"\u0648\u062d\u062f\u0629"},"pathology_tests":"\u0627\u062e\u062a\u0628\u0627\u0631\u0627\u062a \u0639\u0644\u0645 \u0627\u0644\u0623\u0645\u0631\u0627\u0636","patient":{"edit_patient":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0645\u0631\u064a\u0636","new_patient":"\u0645\u0631\u064a\u0636 \u062c\u062f\u064a\u062f","patient_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u0631\u064a\u0636","total_admissions":"\u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u0642\u0628\u0648\u0644","total_appointments":"\u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u0645\u0648\u0627\u0639\u064a\u062f","total_cases":"\u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u062d\u0627\u0644\u0627\u062a"},"patient_admission":{"admission_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0642\u0628\u0648\u0644","agent_name":"\u0627\u0633\u0645 \u0627\u0644\u0639\u0645\u064a\u0644","bed":"\u0627\u0644\u0633\u0631\u064a\u0631","details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0642\u0628\u0648\u0644 \u0627\u0644\u0645\u0631\u064a\u0636","discharge_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u062a\u0641\u0631\u064a\u063a","doctor":"\u0637\u0628\u064a\u0628","doctor_name":"\u0627\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","edit_patient_admission":"\u062a\u062d\u0631\u064a\u0631 \u0642\u0628\u0648\u0644 \u0627\u0644\u0645\u0631\u064a\u0636","guardian_address":"\u0639\u0646\u0648\u0627\u0646 \u0648\u0644\u064a \u0627\u0644\u0623\u0645\u0631","guardian_contact":"\u062c\u0647\u0629 \u0627\u062a\u0635\u0627\u0644 \u0627\u0644\u0648\u0635\u064a","guardian_name":"\u0627\u0633\u0645 \u0627\u0644\u0648\u0635\u064a","guardian_relation":"\u0639\u0644\u0627\u0642\u0629 \u0627\u0644\u0648\u0635\u064a","insurance":"\u062a\u0623\u0645\u064a\u0646","insurance_name":"\u0627\u0633\u0645 \u0627\u0644\u062a\u0623\u0645\u064a\u0646","new_patient_admission":"\u0642\u0628\u0648\u0644 \u0627\u0644\u0645\u0631\u064a\u0636 \u0627\u0644\u062c\u062f\u064a\u062f","package":"\u0635\u0641\u0642\u0629","package_name":"\u0627\u0633\u0645 \u0627\u0644\u062d\u0632\u0645\u0629","patient":"\u0635\u0628\u0648\u0631","patient_admission":"\u0642\u0628\u0648\u0644 \u0627\u0644\u0645\u0631\u064a\u0636","patient_admission_id":"\u0645\u0639\u0631\u0641 \u0642\u0628\u0648\u0644 \u0627\u0644\u0645\u0631\u064a\u0636","patient_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u064a\u0636","policy_no":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0633\u064a\u0627\u0633\u0629"},"patient_admissions":"\u0642\u0628\u0648\u0644 \u0627\u0644\u0645\u0631\u0636\u0649","patient_appointment":"\u0645\u0648\u0639\u062f \u0627\u0644\u0645\u0631\u064a\u0636","patient_diagnosis_test":{"action":"\u0639\u0645\u0644","add_other_diagnosis_property":"\u0623\u0636\u0641 \u062e\u0627\u0635\u064a\u0629 \u062a\u0634\u062e\u064a\u0635 \u0623\u062e\u0631\u0649","age":"\u0633\u0646","average_glucose":"\u0645\u062a\u0648\u0633\u0637 \u0627\u0644\u062c\u0644\u0648\u0643\u0648\u0632","blood_pressure":"\u0636\u063a\u0637 \u0627\u0644\u062f\u0645","cholesterol":"\u0627\u0644\u0643\u0648\u0644\u064a\u0633\u062a\u0631\u0648\u0644","create_patient_diagnosis_test":"\u0625\u0646\u0634\u0627\u0621 \u0627\u062e\u062a\u0628\u0627\u0631 \u062a\u0634\u062e\u064a\u0635 \u0627\u0644\u0645\u0631\u064a\u0636","created_at":"\u0623\u0646\u0634\u0626\u062a \u0641\u064a","diabetes":"\u0627\u0644\u0633\u0643\u0631\u064a","diagnosis":"\u0627\u0644\u062a\u0634\u062e\u064a\u0635","diagnosis_category":"\u0641\u0626\u0629 \u0627\u0644\u062a\u0634\u062e\u064a\u0635","diagnosis_property_name":"\u0627\u0633\u0645 \u062e\u0627\u0635\u064a\u0629 \u0627\u0644\u062a\u0634\u062e\u064a\u0635","diagnosis_property_value":"\u062a\u0634\u062e\u064a\u0635 \u0642\u064a\u0645\u0629 \u0627\u0644\u0639\u0642\u0627\u0631","diagnosis_test":"\u0627\u062e\u062a\u0628\u0627\u0631\u0627\u062a \u0627\u0644\u062a\u0634\u062e\u064a\u0635","doctor":"\u0637\u0628\u064a\u0628","doctor_name":"\u0627\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","edit_patient_diagnosis_test":"\u062a\u062d\u0631\u064a\u0631 \u0627\u062e\u062a\u0628\u0627\u0631 \u062a\u0634\u062e\u064a\u0635 \u0627\u0644\u0645\u0631\u064a\u0636","fasting_blood_sugar":"\u0633\u0643\u0631 \u0627\u0644\u062f\u0645 \u0627\u0644\u0635\u0627\u0626\u0645","height":"\u0627\u0631\u062a\u0641\u0627\u0639","new_patient_diagnosis_test":"\u0627\u062e\u062a\u0628\u0627\u0631 \u062a\u0634\u062e\u064a\u0635 \u0627\u0644\u0645\u0631\u064a\u0636 \u0627\u0644\u062c\u062f\u064a\u062f","other_diagnosis_property":"\u062e\u0627\u0635\u064a\u0629 \u0627\u0644\u062a\u0634\u062e\u064a\u0635 \u0627\u0644\u0623\u062e\u0631\u0649","patient":"\u0635\u0628\u0648\u0631","patient_diagnosis_test":"\u0627\u062e\u062a\u0628\u0627\u0631\u0627\u062a \u062a\u0634\u062e\u064a\u0635 \u0627\u0644\u0645\u0631\u0636\u0649","patient_diagnosis_test_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u062e\u062a\u0628\u0627\u0631 \u062a\u0634\u062e\u064a\u0635 \u0627\u0644\u0645\u0631\u064a\u0636","patient_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0631\u064a\u0636","print_diagnosis_test":"\u0627\u062e\u062a\u0628\u0627\u0631 \u062a\u0634\u062e\u064a\u0635 \u0627\u0644\u0637\u0628\u0627\u0639\u0629","report_number":"\u0631\u0642\u0645 \u0627\u0644\u062a\u0642\u0631\u064a\u0631","urine_sugar":"\u0633\u0643\u0631 \u0627\u0644\u0628\u0648\u0644","weight":"\u0648\u0632\u0646"},"patients":"\u0627\u0644\u0645\u0631\u0636\u0649","patients_case_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u062d\u0627\u0644\u0629 \u0627\u0644\u0645\u0631\u0636\u0649","patients_cases":"\u062d\u0627\u0644\u0627\u062a \u0627\u0644\u0645\u0631\u0636\u0649","payment":{"account":"\u0627\u0644\u062d\u0633\u0627\u0628","account_name":"\u0623\u0633\u0645 \u0627\u0644\u062d\u0633\u0627\u0628","amount":"\u0643\u0645\u064a\u0629","description":"\u0648\u0635\u0641","edit_payment":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062f\u0641\u0639","new_payment":"\u062f\u0641\u0639 \u062c\u062f\u064a\u062f","pay_to":"\u062f\u0641\u0639 \u0644","payment":"\u062f\u0641\u0639","payment_date":"\u0645\u0648\u0639\u062f \u0627\u0644\u062f\u0641\u0639","payment_details":"\u0628\u064a\u0627\u0646\u0627\u062a \u0627\u0644\u062f\u0641\u0639","payment_reports":"\u062a\u0642\u0627\u0631\u064a\u0631 \u0627\u0644\u062f\u0641\u0639","payments":"\u0627\u0644\u0645\u062f\u0641\u0648\u0639\u0627\u062a"},"payments":"\u0627\u0644\u0645\u062f\u0641\u0648\u0639\u0627\u062a","pharmacist":{"edit_pharmacist":"\u062a\u062d\u0631\u064a\u0631 \u0635\u064a\u062f\u0644\u064a","new_pharmacist":"\u0635\u064a\u062f\u0644\u064a \u062c\u062f\u064a\u062f","pharmacist_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0635\u064a\u062f\u0644\u064a","pharmacists":"\u0627\u0644\u0635\u064a\u0627\u062f\u0644\u0629"},"pharmacists":"\u0627\u0644\u0635\u064a\u0627\u062f\u0644\u0629","postal":{"address":"\u0639\u0646\u0648\u0627\u0646","date":"\u062a\u0627\u0631\u064a\u062e","dispatch":"\u0625\u064a\u0641\u0627\u062f","edit_dispatch":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0625\u0631\u0633\u0627\u0644","edit_receive":"\u062a\u062d\u0631\u064a\u0631 \u062a\u0644\u0642\u064a","from_title":"\u0645\u0646 \u0627\u0644\u0639\u0646\u0648\u0627\u0646","new_dispatch":"\u062f\u064a\u0633\u0628\u0627\u062a\u0634 \u062c\u062f\u064a\u062f","new_receive":"\u0627\u0633\u062a\u0644\u0627\u0645 \u062c\u062f\u064a\u062f","postal":"\u0628\u0631\u064a\u062f\u064a","receive":"\u062a\u0633\u0644\u0645","reference_no":"\u0631\u0642\u0645 \u0627\u0644\u0645\u0631\u062c\u0639","to_title":"\u0625\u0644\u0649 \u0627\u0644\u0639\u0646\u0648\u0627\u0646"},"postal_dispatch":"\u0627\u0644\u0625\u0631\u0633\u0627\u0644 \u0627\u0644\u0628\u0631\u064a\u062f\u064a","postal_receive":"\u0627\u0633\u062a\u0644\u0627\u0645 \u0628\u0631\u064a\u062f\u064a","prescription":{"accident":"\u062d\u0627\u062f\u062b","advice":"\u0627\u0644\u0646\u0635\u064a\u062d\u0629","after_meal":"\u0628\u0639\u062f \u0627\u0644\u0648\u062c\u0628\u0629","before_meal":"\u0642\u0628\u0644 \u0627\u0644\u0648\u062c\u0628\u0629","breast_feeding":"\u0627\u0644\u0631\u0636\u0627\u0639\u0629 \u0627\u0644\u0637\u0628\u064a\u0639\u064a\u0629","comment":"\u062a\u0639\u0644\u064a\u0642","current_medication":"\u0627\u0644\u062f\u0648\u0627\u0621 \u0627\u0644\u062d\u0627\u0644\u064a","diabetic":"\u0645\u0631\u064a\u0636 \u0628\u0627\u0644\u0633\u0643\u0631","duration":"\u0645\u062f\u0629","edit_prescription":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0648\u0635\u0641\u0629 \u0627\u0644\u0637\u0628\u064a\u0629","female_pregnancy":"\u0627\u0644\u062d\u0645\u0644 \u0627\u0644\u0623\u0646\u062b\u0648\u064a","food_allergies":"\u062d\u0633\u0627\u0633\u064a\u0629 \u0627\u0644\u0637\u0639\u0627\u0645","health_insurance":"\u062a\u0623\u0645\u064a\u0646 \u0635\u062d\u064a","heart_disease":"\u0645\u0631\u0636 \u0627\u0644\u0642\u0644\u0628","high_blood_pressure":"\u0636\u063a\u0637 \u062f\u0645 \u0645\u0631\u062a\u0641\u0639","low_income":"\u062f\u062e\u0644 \u0645\u0646\u062e\u0641\u0636","medical_history":"\u062a\u0627\u0631\u064a\u062e \u0637\u0628\u0649","medicine_name":"\u0627\u0633\u0645_\u0627\u0644\u0637\u0628","month":"\u0634\u0647\u0631","new_medicine":"\u0627\u0644\u0637\u0628 \u0627\u0644\u062c\u062f\u064a\u062f","new_prescription":"\u0648\u0635\u0641\u0629 \u0637\u0628\u064a\u0629 \u062c\u062f\u064a\u062f\u0629","next_visit":"\u0641\u064a \u0627\u0644\u0645\u0631\u0629 \u0627\u0644\u0642\u0627\u062f\u0645\u0629","no_data_available":"\u0644\u0627\u062a\u0648\u062c\u062f \u0628\u064a\u0627\u0646\u0627\u062a","others":"\u0627\u0644\u0622\u062e\u0631\u064a\u0646","patient":"\u0635\u0628\u0648\u0631","physical_information":"\u0627\u0644\u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0627\u0644\u0645\u0627\u062f\u064a\u0629","plus_rate":"\u0645\u0639\u062f\u0644 \u0646\u0628\u0636","prescription":"\u0648\u0635\u0641\u0629 \u0637\u0628\u064a\u0629","prescription_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0648\u0635\u0641\u0629 \u0627\u0644\u0637\u0628\u064a\u0629","prescriptions":"\u0627\u0644\u0648\u0635\u0641\u0627\u062a \u0627\u0644\u0637\u0628\u064a\u0629","problem":"\u0645\u0634\u0643\u0644\u0629","problem_description":"\u0648\u0635\u0641 \u0627\u0644\u0645\u0634\u0643\u0644\u0629","reference":"\u0645\u0631\u062c\u0639","rx":"\u0622\u0631 \u0625\u0643\u0633","surgery":"\u0627\u0644\u062c\u0631\u0627\u062d\u0629","temperature":"\u062f\u0631\u062c\u0629 \u0627\u0644\u062d\u0631\u0627\u0631\u0629","tendency_bleed":"\u062a\u064a\u0627\u0631 \u0627\u0644\u0646\u0632\u0641","test":"\u0627\u062e\u062a\u0628\u0627\u0631","time":"\u0632\u0645\u0646","year":"\u0639\u0627\u0645"},"prescriptions":"\u0627\u0644\u0648\u0635\u0641\u0627\u062a \u0627\u0644\u0637\u0628\u064a\u0629","profile":{"change_language":"\u062a\u063a\u064a\u064a\u0631 \u0627\u0644\u0644\u063a\u0629","edit_profile":"\u062a\u0639\u062f\u064a\u0644 \u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a","email":"\u0628\u0631\u064a\u062f \u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","first_name":"\u0627\u0644\u0627\u0633\u0645 \u0627\u0644\u0623\u0648\u0644","language":"\u0644\u063a\u0629","last_name":"\u0627\u0644\u0643\u0646\u064a\u0629","phone":"\u0647\u0627\u062a\u0641","profile":"\u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a"},"radiologies":"\u0627\u0644\u0623\u0634\u0639\u0629","radiology_categories":"\u0641\u0626\u0629 \u0627\u0644\u0623\u0634\u0639\u0629","radiology_category":{"edit_radiology_category":"\u062a\u062d\u0631\u064a\u0631 \u0641\u0626\u0629 \u0627\u0644\u0623\u0634\u0639\u0629","name":"\u0627\u0633\u0645","new_radiology_category":"\u0641\u0626\u0629 \u0627\u0644\u0623\u0634\u0639\u0629 \u0627\u0644\u062c\u062f\u064a\u062f\u0629","radiology_categories":"\u0641\u0626\u0627\u062a \u0627\u0644\u0623\u0634\u0639\u0629"},"radiology_test":{"category_name":"\u0627\u0633\u0645 \u0627\u0644\u062a\u0635\u0646\u064a\u0641","charge_category":"\u0641\u0626\u0629 \u0627\u0644\u0634\u062d\u0646","edit_radiology_test":"\u062a\u062d\u0631\u064a\u0631 \u0627\u062e\u062a\u0628\u0627\u0631 \u0627\u0644\u0623\u0634\u0639\u0629","new_radiology_test":"\u0627\u062e\u062a\u0628\u0627\u0631 \u0623\u0634\u0639\u0629 \u062c\u062f\u064a\u062f","radiology_test_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u062e\u062a\u0628\u0627\u0631 \u0627\u0644\u0623\u0634\u0639\u0629","radiology_tests":"\u0627\u062e\u062a\u0628\u0627\u0631\u0627\u062a \u0627\u0644\u0623\u0634\u0639\u0629","report_days":"\u0623\u064a\u0627\u0645 \u0627\u0644\u062a\u0642\u0631\u064a\u0631","short_name":"\u0627\u0633\u0645 \u0642\u0635\u064a\u0631","standard_charge":"\u0627\u0644\u0645\u0633\u0624\u0648\u0644 \u0627\u0644\u0642\u064a\u0627\u0633\u064a","subcategory":"\u062a\u0635\u0646\u064a\u0641 \u0641\u0631\u0639\u064a","test_name":"\u0627\u0633\u0645 \u0627\u0644\u0627\u062e\u062a\u0628\u0627\u0631","test_type":"\u0646\u0648\u0639 \u0627\u0644\u0627\u062e\u062a\u0628\u0627\u0631"},"radiology_tests":"\u0627\u062e\u062a\u0628\u0627\u0631\u0627\u062a \u0627\u0644\u0623\u0634\u0639\u0629","receptionist":{"edit_receptionist":"\u062a\u062d\u0631\u064a\u0631 \u0645\u0648\u0638\u0641 \u0627\u0633\u062a\u0642\u0628\u0627\u0644","new_receptionist":"\u0645\u0648\u0638\u0641 \u0627\u0633\u062a\u0642\u0628\u0627\u0644 \u062c\u062f\u064a\u062f","receptionist":"\u0645\u0648\u0638\u0641 \u0627\u0644\u0625\u0633\u062a\u0642\u0628\u0627\u0644","receptionist_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0645\u0648\u0638\u0641 \u0627\u0644\u0627\u0633\u062a\u0642\u0628\u0627\u0644","receptionists":"\u0645\u0648\u0638\u0641 \u0627\u0644\u0625\u0633\u062a\u0642\u0628\u0627\u0644"},"receptionists":"\u0627\u0644\u0627\u0633\u062a\u0642\u0628\u0627\u0644","reports":"\u0627\u0644\u062a\u0642\u0627\u0631\u064a\u0631","role":{"edit_role":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062f\u0648\u0631","new_role":"\u062f\u0648\u0631 \u062c\u062f\u064a\u062f"},"roles":"\u0627\u0644\u0623\u062f\u0648\u0627\u0631","schedule":{"available_from":"\u0645\u062a\u0627\u062d \u0645\u0646","available_on":"\u0645\u062a\u0627\u062d \u0639\u0644\u0649","available_to":"\u0645\u062a\u0627\u062d\u0629 \u0644\u0644","details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u062c\u062f\u0648\u0644","doctor_name":"\u0627\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","edit":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062c\u062f\u0648\u0644","new":"\u062c\u062f\u0648\u0644 \u062c\u062f\u064a\u062f","per_patient_time":"\u0644\u0643\u0644 \u0645\u0631\u064a\u0636","select_doctor_name":"\u062d\u062f\u062f \u0627\u0633\u0645 \u0627\u0644\u0637\u0628\u064a\u0628","select_serial_visibility":"\u062d\u062f\u062f \u0627\u0644\u0631\u0624\u064a\u0629 \u0627\u0644\u062a\u0633\u0644\u0633\u0644\u064a\u0629","sequential":"\u062a\u0633\u0644\u0633\u0644\u064a","serial_visibility":"\u0627\u0644\u0631\u0624\u064a\u0629 \u0627\u0644\u062a\u0633\u0644\u0633\u0644\u064a\u0629","timestamp":"\u0627\u0644\u0637\u0627\u0628\u0639 \u0627\u0644\u0632\u0645\u0646\u064a"},"schedule_label":"\u062c\u062f\u0648\u0644","schedules":"\u062c\u062f\u0627\u0648\u0644","service":{"edit_service":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062e\u062f\u0645\u0629","given":"\u0645\u0639\u0637\u0649","new_service":"\u062e\u062f\u0645\u0629 \u062c\u062f\u064a\u062f\u0629","not_given":"\u063a\u064a\u0631 \u0645\u0639\u0637\u0649","quantity":"\u0643\u0645\u064a\u0629","rate":"\u0645\u0639\u062f\u0644","service_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u062e\u062f\u0645\u0629"},"services":"\u062e\u062f\u0645\u0627\u062a","setting":{"address":"\u0639\u0646\u0648\u0627\u0646 \u0627\u0644\u0645\u0633\u062a\u0634\u0641\u0649","app_logo":"\u0634\u0639\u0627\u0631 \u0627\u0644\u062a\u0637\u0628\u064a\u0642","app_name":"\u0627\u0633\u0645 \u0627\u0644\u062a\u0637\u0628\u064a\u0642","company_name":"\u0627\u0633\u0645 \u0627\u0644\u0634\u0631\u0643\u0629","country_code":"\u0643\u0648\u062f \u0627\u0644\u062f\u0648\u0644\u0629","currency":"\u0627\u0644\u0639\u0645\u0644\u0629 \u0627\u0644\u062d\u0627\u0644\u064a\u0629","hospital_email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0644\u0644\u0645\u0633\u062a\u0634\u0641\u0649","hospital_from_day":"\u0645\u0633\u062a\u0634\u0641\u0649 \u0645\u0646 \u064a\u0648\u0645","hospital_from_time":"\u0645\u0633\u062a\u0634\u0641\u0649 \u0645\u0646 \u0648\u0642\u062a","hospital_phone":"\u0647\u0627\u062a\u0641 \u0627\u0644\u0645\u0633\u062a\u0634\u0641\u0649","image_validation":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 \u0627\u0644\u0635\u0648\u0631\u0629 90 \u00d7 60 \u0628\u0643\u0633\u0644.","social_details":"\u0627\u0644\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0627\u062c\u062a\u0645\u0627\u0639\u064a\u0629"},"settings":"\u0627\u0644\u0625\u0639\u062f\u0627\u062f\u0627\u062a","short_description":"\u0648\u0635\u0641 \u0642\u0635\u064a\u0631","sidebar_setting":"\u0625\u0639\u062f\u0627\u062f\u0627\u062a \u0627\u0644\u0648\u062d\u062f\u0627\u062a","sms":{"date":"\u062a\u0627\u0631\u064a\u062e","message":"\u0631\u0633\u0627\u0644\u0629","new_sms":"\u0631\u0633\u0627\u0626\u0644 \u062c\u062f\u064a\u062f\u0629","only_user_with_registered_phone_will_display":"(\u0633\u064a\u062a\u0645 \u0639\u0631\u0636 \u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645\u064a\u0646 \u0627\u0644\u0630\u064a\u0646 \u0644\u062f\u064a\u0647\u0645 \u0647\u0627\u062a\u0641 \u0645\u0633\u062c\u0644 \u0641\u0642\u0637.)","phone_number":"\u0631\u0642\u0645 \u0627\u0644\u0647\u0627\u062a\u0641","role":"\u0648\u0638\u064a\u0641\u0629","send":"\u0625\u0631\u0633\u0627\u0644","send_by":"\u0623\u0631\u0633\u0644 \u0628\u0648\u0627\u0633\u0637\u0629","send_sms_by_number_directly":"\u0625\u0631\u0633\u0627\u0644 \u0627\u0644\u0631\u0633\u0627\u0626\u0644 \u0627\u0644\u0642\u0635\u064a\u0631\u0629 \u0628\u0627\u0644\u0631\u0642\u0645 \u0645\u0628\u0627\u0634\u0631\u0629","send_to":"\u0627\u0631\u0633\u0644 \u0625\u0644\u0649","sms":"\u0633\u0627\u0645\u0633","sms_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0631\u0633\u0627\u0626\u0644 \u0627\u0644\u0642\u0635\u064a\u0631\u0629"},"testimonial":{"description":"\u0648\u0635\u0641","edit_testimonial":"\u062a\u062d\u0631\u064a\u0631 \u0634\u0647\u0627\u062f\u0629","name":"\u0627\u0633\u0645","new_testimonial":"\u0634\u0647\u0627\u062f\u0629 \u062c\u062f\u064a\u062f\u0629","profile_error":"\u064a\u062c\u0628 \u0623\u0646 \u064a\u0643\u0648\u0646 \u0627\u0644\u0645\u0644\u0641 \u0645\u0646 \u0627\u0644\u0646\u0648\u0639: jpg\u060c jpeg\u060c png.","testimonial":"\u0634\u0647\u0627\u062f\u0629","testimonial_detail":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0634\u0647\u0627\u062f\u0629"},"testimonials":"\u0627\u0644\u0634\u0647\u0627\u062f\u0627\u062a - \u0627\u0644\u062a\u0648\u0635\u064a\u0627\u062a","twitter_url":"\u0631\u0627\u0628\u0637 \u062a\u0648\u064a\u062a\u0631","user":{"address1":"\u0627\u0644\u0639\u0646\u0648\u0627\u0646 1","address2":"\u0627\u0644\u0639\u0646\u0648\u0627\u0646 2","address_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0646\u0648\u0627\u0646","address_not_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0646\u0648\u0627\u0646","blood_group":"\u0641\u0635\u064a\u0644\u0629 \u0627\u0644\u062f\u0645","change_password":"\u062a\u063a\u064a\u064a\u0631 \u0643\u0644\u0645\u0629 \u0627\u0644\u0633\u0631","city":"\u0645\u062f\u064a\u0646\u0629","designation":"\u062a\u0639\u064a\u064a\u0646","dob":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0648\u0644\u0627\u062f\u0629","edit_profile":"\u062a\u0639\u062f\u064a\u0644 \u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a","edit_user":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0639\u0636\u0648","education":"\u0627\u0644\u062a\u0639\u0644\u064a\u0645","email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","email_verified_successfully":"\u062a\u0645 \u0627\u0644\u062a\u062d\u0642\u0642 \u0645\u0646 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0628\u0646\u062c\u0627\u062d.","female":"\u0623\u0646\u062b\u0649","first_name":"\u0627\u0644\u0627\u0633\u0645 \u0627\u0644\u0627\u0648\u0644","gender":"\u062c\u0646\u0633","invalid_password":"\u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631 \u0627\u0644\u062d\u0627\u0644\u064a\u0629 \u063a\u064a\u0631 \u0635\u062d\u064a\u062d\u0629.","last_name":"\u0627\u0644\u0643\u0646\u064a\u0629","logout":"\u062a\u0633\u062c\u064a\u0644 \u062e\u0631\u0648\u062c","male":"\u0627\u0644\u0630\u0643\u0631","name":"\u0627\u0633\u0645","new_user":"\u0645\u0633\u062a\u062e\u062f\u0645 \u062c\u062f\u064a\u062f","password":"\u0643\u0644\u0645\u0647 \u0627\u0644\u0633\u0631","password_confirmation":"\u062a\u0623\u0643\u064a\u062f \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","phone":"\u0647\u0627\u062a\u0641","qualification":"\u0627\u0644\u0645\u0624\u0647\u0644","select_blood_group":"\u062d\u062f\u062f \u0641\u0635\u064a\u0644\u0629 \u0627\u0644\u062f\u0645","status":"\u0627\u0644\u062d\u0627\u0644\u0629","user_details":"\u0628\u064a\u0627\u0646\u0627\u062a \u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645","usrs":"\u0627\u0644\u0645\u0633\u062a\u0639\u0645\u0644","validate_confirm_password":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u062a\u0637\u0627\u0628\u0642 \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631 \u0645\u0639 \u062a\u0623\u0643\u064a\u062f \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631.","validate_min_character_password":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u062d\u062a\u0648\u064a \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631 \u0639\u0644\u0649 6 \u0623\u062d\u0631\u0641 \u0639\u0644\u0649 \u0627\u0644\u0623\u0642\u0644.","zip":"\u0627\u0644\u0631\u0645\u0632 \u0627\u0644\u0628\u0631\u064a\u062f\u064a"},"users":"\u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645\u0648\u0646","vaccinated_patient":{"add_vaccinate_patient":"\u0627\u0636\u0627\u0641\u0629 \u0644\u0642\u0627\u062d \u0644\u0644\u0645\u0631\u064a\u0636","description":"\u0648\u0635\u0641","does_no":"\u062c\u0631\u0639\u0629 \u0644\u0627","dose_given_date":"\u062a\u0627\u0631\u064a\u062e \u0625\u0639\u0637\u0627\u0621 \u0627\u0644\u062c\u0631\u0639\u0629","edit_vaccinate_patient":"\u062a\u062d\u0631\u064a\u0631 \u0644\u0642\u0627\u062d \u0627\u0644\u0645\u0631\u064a\u0636","new_vaccinate_patient":"\u0644\u0642\u0627\u062d \u062c\u062f\u064a\u062f \u0644\u0644\u0645\u0631\u064a\u0636","patient":"\u0645\u0631\u064a\u0636","serial_no":"\u0627\u0644\u0631\u0642\u0645 \u0627\u0644\u062a\u0633\u0644\u0633\u0644\u064a","vaccinate_patient":"\u062a\u0637\u0639\u064a\u0645 \u0627\u0644\u0645\u0631\u064a\u0636","vaccinated_patient":"\u062a\u0645 \u062a\u0637\u0639\u064a\u0645 \u0627\u0644\u0645\u0631\u064a\u0636","vaccination":"\u062a\u0644\u0642\u064a\u062d","vaccine":"\u0645\u0635\u0644"},"vaccinated_patients":"\u0627\u0644\u0645\u0631\u0636\u0649 \u0627\u0644\u0630\u064a\u0646 \u062a\u0645 \u062a\u0637\u0639\u064a\u0645\u0647\u0645","vaccination":{"brand":"\u0645\u0627\u0631\u0643\u0629","edit_vaccination":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062a\u0637\u0639\u064a\u0645","manufactured_by":"\u0635\u0646\u0639 \u0628\u0648\u0627\u0633\u0637\u0629","name":"\u0627\u0633\u0645","new_vaccination":"\u062a\u0637\u0639\u064a\u0645 \u062c\u062f\u064a\u062f","vaccinated":"\u062a\u0644\u0642\u064a\u062d","vaccinations":"\u0627\u0644\u062a\u0637\u0639\u064a\u0645\u0627\u062a"},"vaccinations":"\u0627\u0644\u062a\u0637\u0639\u064a\u0645\u0627\u062a","valid":"\u0635\u0627\u0644\u062d","verification":{"another_verify_request":"\u0627\u0646\u0642\u0631 \u0647\u0646\u0627 \u0644\u0637\u0644\u0628 \u0622\u062e\u0631","verify_message":"\u0642\u0628\u0644 \u0627\u0644\u0645\u062a\u0627\u0628\u0639\u0629 \u060c \u064a\u0631\u062c\u0649 \u0627\u0644\u062a\u062d\u0642\u0642 \u0645\u0646 \u0628\u0631\u064a\u062f\u0643 \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0628\u062d\u062b\u064b\u0627 \u0639\u0646 \u0631\u0627\u0628\u0637 \u0627\u0644\u062a\u062d\u0642\u0642. \u0625\u0630\u0627 \u0644\u0645 \u062a\u0633\u062a\u0644\u0645 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u060c","verify_your_email_address":"\u062a\u062d\u0642\u0642 \u0645\u0646 \u0639\u0646\u0648\u0627\u0646 \u0628\u0631\u064a\u062f\u0643 \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a."},"visitor":{"date":"\u062a\u0627\u0631\u064a\u062e","edit":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0632\u0627\u0626\u0631","id_card":"\u0628\u0637\u0627\u0642\u0629 \u0627\u0644\u062a\u0639\u0631\u064a\u0641","in_time":"\u0641\u064a \u0627\u0644\u0648\u0642\u062a \u0627\u0644\u0645\u0646\u0627\u0633\u0628","name":"\u0627\u0633\u0645","new":"\u0632\u0627\u0626\u0631 \u062c\u062f\u064a\u062f","note":"\u0645\u0644\u062d\u0648\u0638\u0629","number_of_person":"\u0639\u062f\u062f \u0627\u0644\u0623\u0634\u062e\u0627\u0635","out_time":"\u0648\u0642\u062a \u062e\u0631\u0648\u062c","phone":"\u0647\u0627\u062a\u0641","purpose":"\u063a\u0631\u0636","visitor":"\u0632\u0627\u0626\u0631"},"visitors":"\u0627\u0644\u0632\u0627\u0626\u0631\u064a\u0646","web_appointment":{"call_now_and_get_a_free_consulting":"\u0627\u062a\u0635\u0644 \u0627\u0644\u0622\u0646 \u0648\u0627\u062d\u0635\u0644 \u0639\u0644\u0649 \u0627\u0633\u062a\u0634\u0627\u0631\u0629 \u0645\u062c\u0627\u0646\u064a\u0629","enter_confirm_password":"\u0623\u062f\u062e\u0644 \u062a\u0623\u0643\u064a\u062f \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","enter_description":"\u0623\u062f\u062e\u0644 \u0627\u0644\u0648\u0635\u0641","enter_your_first_name":"\u0623\u062f\u062e\u0644 \u0627\u0633\u0645\u0643 \u0627\u0644\u0623\u0648\u0644","enter_your_last_name":"\u0623\u062f\u062e\u0644 \u0627\u0633\u0645\u0643 \u0627\u0644\u0623\u062e\u064a\u0631","enter_your_password":"\u0627\u062f\u062e\u0644 \u0631\u0642\u0645\u0643 \u0627\u0644\u0633\u0631\u064a","make_an_appointment":"\u0625\u062d\u062c\u0632 \u0645\u0648\u0639\u062f","select_department":"\u062d\u062f\u062f \u0627\u0644\u0642\u0633\u0645","select_doctor":"\u0627\u062e\u062a\u0631 \u062f\u0643\u062a\u0648\u0631","select_time":"\u062d\u062f\u062f \u0627\u0644\u0648\u0642\u062a"},"web_contact":{"call_today":"\u0627\u0644\u062f\u0639\u0648\u0629 \u0627\u0644\u064a\u0648\u0645","contact_no":"\u0631\u0642\u0645 \u0627\u0644\u0627\u062a\u0635\u0627\u0644","enter_your_email":"\u0623\u062f\u062e\u0644 \u0628\u0631\u064a\u062f\u0643 \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","enter_your_name":"\u0623\u062f\u062e\u0644 \u0623\u0633\u0645\u0643","open_hours":"\u0633\u0627\u0639\u0627\u062a \u0645\u0641\u062a\u0648\u062d\u0629","our_location":"\u0645\u0648\u0642\u0639\u0646\u0627","phone_number":"\u0631\u0642\u0645 \u0627\u0644\u0647\u0627\u062a\u0641","please_enter_your_phone_number":"\u064a\u0631\u062c\u0649 \u0625\u062f\u062e\u0627\u0644 \u0631\u0642\u0645 \u0627\u0644\u0647\u0627\u062a\u0641 \u0627\u0644\u062e\u0627\u0635 \u0628\u0643","select_enquiry":"\u062d\u062f\u062f \u0627\u0644\u0627\u0633\u062a\u0641\u0633\u0627\u0631","send_message":"\u0623\u0631\u0633\u0644 \u0631\u0633\u0627\u0644\u0629","send_us_a_message":"\u0623\u0631\u0633\u0644 \u0644\u0646\u0627 \u0631\u0633\u0627\u0644\u0629","type_your_message":"\u0627\u0643\u062a\u0628 \u0631\u0633\u0627\u0644\u062a\u0643","write_your_message":"\u0627\u0643\u062a\u0628 \u0631\u0633\u0627\u0644\u062a\u0643","your_email":"\u0628\u0631\u064a\u062f\u0643 \u0627\u0644\u0627\u0644\u0643\u062a\u0631\u0648\u0646\u064a","your_message":"\u0631\u0633\u0627\u0644\u062a\u0643","your_name":"\u0627\u0633\u0645\u0643"},"web_home":{"4_easy_step_and_get_the_world_best_treatment":"4 \u062e\u0637\u0648\u0627\u062a \u0633\u0647\u0644\u0629 \u0648\u0627\u062d\u0635\u0644 \u0639\u0644\u0649 \u0623\u0641\u0636\u0644 \u0639\u0644\u0627\u062c \u0641\u064a \u0627\u0644\u0639\u0627\u0644\u0645","about_us":"\u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0639\u0646\u0627","available_doctors":"\u0627\u0644\u0623\u0637\u0628\u0627\u0621 \u0627\u0644\u0645\u062a\u0627\u062d\u0648\u0646","book_an_appointment":"\u0627\u062d\u062c\u0632 \u0645\u0648\u0639\u062f\u064b\u0627","book_appointment":"\u0645\u0648\u0639\u062f \u0627\u0644\u0643\u062a\u0627\u0628","book_now":"\u0627\u062d\u062c\u0632 \u0627\u0644\u0622\u0646","contact":"\u0627\u062a\u0635\u0644","contact_doctors":"\u0627\u062a\u0635\u0644 \u0628\u0627\u0644\u0637\u0628\u064a\u0628","contact_hospital":"\u0627\u062a\u0635\u0644 \u0628\u0627\u0644\u0645\u0633\u062a\u0634\u0641\u0649","doctors":"\u0627\u0644\u0623\u0637\u0628\u0627\u0621","doctors_nurses":"\u0623\u0637\u0628\u0627\u0621 \u0648\u0645\u0645\u0631\u0636\u0627\u062a","easy_solutions":"\u062d\u0644\u0648\u0644 \u0633\u0647\u0644\u0629","happy_patients":"\u0645\u0631\u0636\u0649 \u0633\u0639\u062f\u0627\u0621","home":"\u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629","make_appointment":"\u062d\u062f\u062f \u0645\u0648\u0639\u062f\u0627","our_services":"\u062e\u062f\u0645\u0627\u062a\u0646\u0627","our_testimonials":"\u0634\u0647\u0627\u062f\u0627\u062a\u0646\u0627","patients":"\u0645\u0631\u0636\u0649","patients_beds":"\u0623\u0633\u0631\u0629 \u0627\u0644\u0645\u0631\u0636\u0649","privacy_policy":"\u0633\u064a\u0627\u0633\u0629 \u062e\u0627\u0635\u0629","professional_doctors":"\u0623\u0637\u0628\u0627\u0621 \u0645\u062a\u062e\u0635\u0635\u0648\u0646","select_doctor":"\u0627\u062e\u062a\u0631 \u062f\u0643\u062a\u0648\u0631","select_doctors":"\u062d\u062f\u062f \u0627\u0644\u0623\u0637\u0628\u0627\u0621","services":"\u062e\u062f\u0645\u0627\u062a","sign_up":"\u0627\u0634\u062a\u0631\u0627\u0643","terms_of_service":"\u0634\u0631\u0648\u0637 \u0627\u0644\u062e\u062f\u0645\u0629","testimonials":"\u0627\u0644\u0634\u0647\u0627\u062f\u0627\u062a - \u0627\u0644\u062a\u0648\u0635\u064a\u0627\u062a","we_are_experienced_healthcare_professionals":"\u0646\u062d\u0646 \u0645\u062a\u062e\u0635\u0635\u0648\u0646 \u0641\u064a \u0645\u062c\u0627\u0644 \u0627\u0644\u0631\u0639\u0627\u064a\u0629 \u0627\u0644\u0635\u062d\u064a\u0629 \u0645\u0646 \u0630\u0648\u064a \u0627\u0644\u062e\u0628\u0631\u0629","we_offer_different_services_to_improve_your_health":"\u0646\u062d\u0646 \u0646\u0642\u062f\u0645 \u062e\u062f\u0645\u0627\u062a \u0645\u062e\u062a\u0644\u0641\u0629 \u0644\u062a\u062d\u0633\u064a\u0646 \u0635\u062d\u062a\u0643","what_our_patient_say_about_medical_treatments":"\u0645\u0627\u0630\u0627 \u064a\u0642\u0648\u0644 \u0645\u0631\u0636\u0627\u0646\u0627 \u0639\u0646 \u0639\u0644\u0627\u062c\u0627\u062a\u0646\u0627 \u0627\u0644\u0637\u0628\u064a\u0629","working_hours":"\u0633\u0627\u0639\u0627\u062a \u0627\u0644\u0639\u0645\u0644","years_experience":"\u0633\u0646\u0648\u0627\u062a \u062e\u0628\u0631\u0629"},"web_menu":{"about":"\u0639\u0646","all_rights_reserved_by":"\u062c\u0645\u064a\u0639 \u0627\u0644\u062d\u0642\u0648\u0642 \u0645\u062d\u0641\u0648\u0638\u0629","appointment":"\u0645\u064a\u0639\u0627\u062f","contact_information":"\u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0644\u0644\u062a\u0648\u0627\u0635\u0644","copyright":"\u062d\u0642\u0648\u0642 \u0627\u0644\u0646\u0634\u0631","login":"\u062a\u0633\u062c\u064a\u0644 \u0627\u0644\u062f\u062e\u0648\u0644","our_features":"\u0645\u064a\u0632\u0627\u062a\u0646\u0627","useful_link":"\u0631\u0627\u0628\u0637 \u0645\u0641\u064a\u062f","working_hours":"\u0633\u0627\u0639\u0627\u062a \u0627\u0644\u0639\u0645\u0644"},"web_password":{"password_and_confirm_password_not_match":"\u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631 \u0648\u062a\u0623\u0643\u064a\u062f \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631 \u063a\u064a\u0631 \u0645\u062a\u0637\u0627\u0628\u0642\u064a\u0646.","please_fill_all_the_required_fields":"\u064a\u0631\u062c\u0649 \u0645\u0644\u0621 \u062c\u0645\u064a\u0639 \u0627\u0644\u062d\u0642\u0648\u0644 \u0627\u0644\u0645\u0637\u0644\u0648\u0628\u0629."},"web_working_hours":{"no_yet_opening_hours":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0633\u0627\u0639\u0627\u062a \u0639\u0645\u0644 \u0628\u0639\u062f","opening_hours":"\u0633\u0627\u0639\u0627\u062a \u0627\u0644\u0639\u0645\u0644"},"weekdays":{"fri":"\u062c\u0645\u0647\u0648\u0631\u064a\u0629 \u0645\u0642\u062f\u0648\u0646\u064a\u0627","mon":"\u0627\u0644\u0639\u0627\u0644\u0645\u064a\u0629","sat":"\u062c\u0644\u0633","sun":"\u0627\u0644\u0634\u0645\u0633","thu":"\u0627\u0644\u062e\u0645\u064a\u0633","tue":"\u0627\u0644\u062b\u0644\u0627\u062b\u0627\u0621","wed":"\u0627\u0644\u0623\u0631\u0628\u0639\u0627\u0621"}},"de.messages":{"about_us":"\u00dcber uns","account":{"account":"Konto","account_details":"Kontodetails","accounts":"Konten","credit":"Anerkennung","debit":"Lastschrift","description":"Beschreibung","edit_account":"Konto bearbeiten","name":"Name","new_account":"Neues Konto","payments":"Zahlungen","status":"Status","type":"Art"},"account_manager":"Buchhalter","accountant":{"accountant_details":"Buchhalter Details","accountants":"Buchhalterinnen","edit_accountant":"Buchhalter bearbeiten","new_accountant":"Neuer Buchhalter"},"accountants":"Buchhalterinnen","accounts":"Konten","admin":"Admins","admins":"Administratorin","advanced_payment":{"advanced_payment":"Vorauszahlung","advanced_payment_details":"Vorauszahlungsdetails","advanced_payments":"Vorauszahlungen","amount":"Menge","date":"Datum","edit_advanced_payment":"Vorauszahlung bearbeiten","new_advanced_payment":"Neue Vorauszahlung","patient":"Geduldig","patient_name":"Patientenname","receipt_no":"Quittungsnr"},"advanced_payments":"Vorauszahlungen","allow_file_type":"Erlaubte Dateitypen: png, jpg, jpeg.","ambulance":{"ambulance":"Krankenwagen","ambulance_details":"Krankenwagen Details","ambulances":"Ambulanzen","driver_contact":"Fahrerkontakt","driver_license":"F\u00fchrerschein","driver_name":"Fahrername","edit_ambulance":"Krankenwagen bearbeiten","is_available":"Ist verf\u00fcgbar","new_ambulance":"Neuer Krankenwagen","note":"Note","vehicle_model":"Fahrzeugmodell","vehicle_number":"Fahrzeugnummer","vehicle_type":"Fahrzeugtyp","year_made":"Jahr gemacht"},"ambulance_call":{"ambulance_call":"Krankenwagenanruf","ambulance_call_details":"Details zum Krankenwagenanruf","ambulance_calls":"Krankenwagenanrufe","amount":"Menge","date":"Datum","driver_name":"Fahrername","edit_ambulance_call":"Krankenwagenanruf bearbeiten","new_ambulance_call":"Neuer Krankenwagenanruf","patient":"Geduldig","vehicle_model":"Fahrzeugmodell"},"ambulance_calls":"Krankenwagenanrufe","ambulances":"Ambulanzen","appointment":{"appointment_calendar":"Terminkalender","appointment_details":"Termindetails","appointment_exists":"Patienten-E-Mail existiert bereits","appointment_list":"Terminliste","are_you_sure_want_to_cancel":"Sind Sie sicher, dass sie abbrechen wollen","are_you_sure_want_to_change":"M\u00f6chten Sie wirklich wechseln?","available_slot":"Verf\u00fcgbarer Slot","calendar_view":"Kalenderansicht","change_status":"Status \u00e4ndern","changed_appointment":"Termin ge\u00e4ndert","completed":"Abgeschlossen","date":"Datum","day":"Tag","department_name":"Abteilungsname","description":"Beschreibung","doctor":"\u00c4rztin","doctor_department":"Arztabteilung","doctor_department_name":"Name der Arztabteilung","doctor_name":"Name des Arztes","doctor_schedule_not_available_on_this_date":"Arztplan an diesem Datum nicht verf\u00fcgbar.","edit_appointment":"Termin bearbeiten","has_been_cancelled":"wurde abgebrochen.","has_been_changed":"wurde ge\u00e4ndert.","last_30_days":"Letzte 30 Tage","last_7_days":"Letzten 7 Tage","last_month":"Im vergangenen Monat","month":"Monat","new_appointment":"Neuer Termin","no_available":"Nicht verf\u00fcgbar","old_patient_email_exists":"E-Mail existiert bereits, bitte alten Patienten ausw\u00e4hlen.","opd_date":"Opd-Datum","patient":"Geduldig","patient_name":"Patientenname","patient_not_exists_or_status_is_not_active":"Patient not exists or status is not active.","pending":"steht aus","please_select_appointment_time_slot":"Bitte w\u00e4hlen Sie das Zeitfenster f\u00fcr den Termin aus","please_select_doctor":"Bitte Arzt ausw\u00e4hlen","please_select_doctor_department":"Bitte w\u00e4hlen Sie die Arztabteilung aus","this_month":"Diesen Monat","this_week":"In dieser Woche","today":"Heute","week":"Woche","yesterday":"Gestern"},"appointment_calendar":"Ernennen. Kalender","appointments":"Termine","available_slot":"Verf\u00fcgbarer Slot","bed":{"add":"Hinzuf\u00fcgen","available":"Verf\u00fcgbar","bed":"Neues Bett","bed_details":"Bettdetails","bed_id":"Bett Id","bed_type":"Betttyp","beds":"Betten","charge":"Aufladen","description":"Beschreibung","edit_bed":"Bett bearbeiten","name":"Name","new_bed":"Neues Bett","new_bulk_bed":"Neues Gro\u00dfbett","not_available":"Nicht verf\u00fcgbar"},"bed_assign":{"assign_date":"Datum zuweisen","assign_date_should_not_be_smaller_than_patient_birth_date":"Das Zuweisungsdatum sollte nicht kleiner als das Geburtsdatum des Patienten sein.","assigned":"Zugewiesen","bed":"Bett","bed_assign":"Bett zuweisen","bed_assign_details":"Bed Assign Details","bed_assigns":"Bett weist zu","bed_name":"Bettname","case_id":"Fall-ID","description":"Beschreibung","discharge_date":"Entlassungsdatum","edit_bed_assign":"Bett zuweisen zuweisen","ipd_patient_id":"IPD-Patienten-ID","new_bed_assign":"Neues Bett zuweisen","not_assigned":"Nicht zugeordnet","patient_name":"Patientenname"},"bed_assigns":"Bett weist zu","bed_management":"Bettenverwaltung","bed_mgt":"Bettmanagement","bed_status":{"admission_date":"Aufnahmedatum","assigned_beds":"Zugewiesene Betten","available_beds":"Verf\u00fcgbare Betten","bed_name":"Bettname","bed_status":"Bettstatus","gender":"Geschlecht","patient_name":"Patienten name","phone":"Telefon"},"bed_type":{"bed_type":"Betttyp","bed_type_details":"Betttyp Details","bed_types":"Betttypen","description":"Beschreibung","edit_bed_type":"Betttyp bearbeiten","new_bed_type":"Neuer Betttyp","title":"Titel"},"bed_types":"Betttypen","beds":"Betten","bill":{"add":"Hinzuf\u00fcgen","admission_date":"Aufnahmedatum","admission_id":"Zulassungsausweis","amount":"Menge","bill":"Rechnung","bill_date":"Rechnungsdatum","bill_details":"Rechnungsdetails","bill_id":"Regnings id","bill_summary":"Rechnungszusammenfassung","bills":"Rechnungen","calculate":"Berechnung","cell_no":"Zelle Nr","discharge_date":"Entlassungsdatum","doctor_name":"Name des Arztes","edit":"Bearbeiten","edit_bill":"Rechnung bearbeiten","generate_bill":"Rechnung erstellen","insurance_name":"Versicherungsname","item_name":"Artikelname","new_bill":"Neue Rechnung","package_name":"Paketnamen","patient":"Geduldig","patient_cell_no":"Patientenzelle Nr","patient_dob":"Patienten DOB","patient_email":"Patienten-E-Mail","patient_gender":"Geschlecht des Patienten","patient_name":"Patientenname","policy_no":"Richtlinie Nr","price":"Preis","print_bill":"Rechnung drucken","qty":"Menge","total_amount":"Gesamtmenge","total_days":"Die Summe an Tagen","update_bill":"Rechnung aktualisieren"},"billing":"Abrechnung","bills":"Rechnungen","birth_report":{"birth_report":"Geburtsbericht","birth_report_details":"Geburtsbericht Details","birth_reports":"Geburtsberichte","case_id":"Fall-ID","data_should_not_be_smaller_than_patient_birth_date":"Das Datum sollte nicht kleiner als das Geburtsdatum des Patienten sein.","date":"Datum","description":"Beschreibung","doctor_name":"Name des Arztes","edit_birth_report":"Geburtsbericht bearbeiten","new_birth_report":"Neuer Geburtsbericht","patient_birth_date_not_found":"Geburtsdatum des Patienten nicht gefunden.","patient_name":"Patientenname"},"birth_reports":"Geburtsberichte","blood_bank":"Blutbank","blood_banks":"Blutbanken","blood_donation":{"bags":"Taschen","blood_donation":"Blutspende","donor_name":"Name des Spenders","edit_blood_donation":"Blutspende bearbeiten","last_donate_date":"Letztes Spendendatum","new_blood_donation":"Neue Blutspende"},"blood_donations":"Blutspenden","blood_donor":{"age":"Alter","blood_donor":"Blutspender","blood_donor_details":"Blutspender Details","blood_donors":"Blutspender","blood_group":"Blutgruppe","donation_date":"Spendendatum","edit_blood_donor":"Blutspender bearbeiten","gender":"Geschlecht","last_donation_date":"Letztes Spendendatum","name":"Name","new_blood_donor":"Neuer Blutspender"},"blood_donors":"Blutspender","blood_issue":{"amount":"Menge","blood_issue":"Blutproblem","doctor_name":"Name des Arztes","donor_name":"Name des Spenders","edit_blood_issue":"Blutproblem bearbeiten","issue_date":"Ausgabedatum","new_blood_issue":"Neues Blutproblem","patient_name":"Patientenname","remarks":"Bemerkungen"},"blood_issues":"Blutprobleme","call_log":{"call_log":"Anrufliste","call_type":"Anrufart","edit":"Anrufliste bearbeiten","follow_up_date":"Follow-up-Termin","incoming":"Eingehend","name":"Name","new":"Neues Anrufprotokoll","note":"Hinweis","outgoing":"Ausgehend","phone":"Telefon","received_on":"Eingegangen am"},"call_logs":"Anruflisten","case":{"case":"Fall","case_date":"Falldatum","case_details":"Falldetails","case_id":"Fall-ID","date":"Datum","description":"Beschreibung","doctor":"\u00c4rztin","edit_case":"Fall bearbeiten","fee":"Geb\u00fchr","new_case":"Neuer Fall","patient":"Geduldig","phone":"Telefon"},"case_handler":{"case_handler":"Fallbearbeiter","case_handler_detail":"Details zur Fallbearbeitung","edit_case_handler":"Fallbearbeiter bearbeiten","new_case_handler":"Neuer Case Handler"},"case_handlers":"Fallbearbeiter","case_manager":"Fallmanager","cases":"F\u00e4lle","change_password":{"change_password":"Kennwort \u00e4ndern","confirm_password":"Kennwort best\u00e4tigen","current_password":"Jetziges Passwort","new_password":"Neues Kennwort"},"charge":{"charge_category":"Geb\u00fchrenkategorie","charge_details":"Geb\u00fchrendetails","code":"Code","edit_charge":"Geb\u00fchr bearbeiten","new_charge":"Neue Geb\u00fchr","standard_charge":"Normaltarif"},"charge_categories":"Geb\u00fchrenkategorien","charge_category":{"charge_categories":"Geb\u00fchrenkategorien","charge_category_details":"Details zur Geb\u00fchrenkategorie","charge_type":"Ladungsart","edit_charge_category":"Geb\u00fchrenkategorie bearbeiten","new_charge_category":"Neue Geb\u00fchrenkategorie"},"charges":"Geb\u00fchren","cms":"CMS","common":{"action":"Aktion","actions":"Aktionen","active":"Aktiv","add":"Hinzuf\u00fcgen","address":"Adresse","apply":"anwenden","are_you_sure_want_to_delete_this":"M\u00f6chten Sie dies wirklich l\u00f6schen? ","back":"Zur\u00fcck","cancel":"Stornieren","canceled":"Stornierened","cant_be_deleted":"kann nicht gel\u00f6scht werden","choose":"W\u00e4hlen","confirm":"Best\u00e4tigen Sie","created_at":"Erstellt am","created_on":"Erstellt am","custom":"Brauch","de_active":"Deaktivieren","delete":"L\u00f6schen","deleted":"Gel\u00f6scht","deleted_successfully":"Erfolgreich gel\u00f6scht","description":"Beschreibung","detail":"Einzelheiten","edit":"Bearbeiten","export_to_excel":"Nach Excel exportieren","filter_options":"Filteroptionen","from":"aus","has_been_deleted":"wurde gel\u00f6scht.","invalid_country_code":"Ung\u00fcltiger L\u00e4ndercode","invalid_number":"Ung\u00fcltige Nummer","is_available":"Ist verf\u00fcgbar","last_updated":"Zuletzt aktualisiert","n\/a":"N \/ A","name":"Name","new":"Neu","next":"N\u00e4chste","no":"Nein","not_found":"nicht gefunden","ok":"OK","previous":"Vorherige","profile":"Profil","reset":"Zur\u00fccksetzen","save":"speichern","saved_successfully":"Erfolgreich gespeichert.","search":"Suche","status":"Status","status_updated_successfully":"Status erfolgreich aktualisiert.","this_action_is_not_allowed_for_default_record":"Diese Aktion ist f\u00fcr den Standarddatensatz nicht zul\u00e4ssig.","to":"Zu","too_long":"Zu lang","too_short":"Zu kurz","total":"Gesamt","updated_at":"Zuletzt aktualisiert","updated_successfully":"Erfolgreich geupdated","view":"Aussicht","view_attachment":"Anhang ansehen","yes":"Ja"},"contact_us":"Kontaktieren Sie uns","currency":{"add_currency_code_as_per_three_letter_iso_code":"F\u00fcgen Sie den W\u00e4hrungscode gem\u00e4\u00df dem dreistelligen ISO-Code hinzu","currency":"W\u00e4hrung","currency_code":"W\u00e4hrungscode","currency_icon":"W\u00e4hrungssymbol","currency_name":"W\u00e4hrungsname","edit_currency":"W\u00e4hrung bearbeiten","new_currency":"Neue W\u00e4hrung","you_can_find_out_here":"das erf\u00e4hrst du hier"},"currency_setting":"W\u00e4hrungen","dashboard":{"available_beds":"Verf\u00fcgbare Betten","dashboard":"Instrumententafel","doctors":"\u00c4rztinnen","income_and_expense_report":"Einnahmen- und Ausgabenbericht","income_and_expense_reports":"Einnahmen- und Ausgabenberichte","no_enquiries_yet":"Noch keine Anfragen","no_notice_yet":"Noch keine Ank\u00fcndigung","notice_boards":"Notiz Bretter","patients":"Patientinnen","title":"Titel","total_advance_payments":"Vorauszahlungsbetrag","total_bills":"Rechnungsbetrag","total_invoices":"Rechnungsbetrag","total_payments":"Zahlungsbetrag"},"death_report":{"case_id":"Fall-ID","date":"Datum","death_report":"Todesbericht","death_report_details":"Details zum Todesbericht","death_reports":"Todesberichte","description":"Beschreibung","doctor_name":"Name des Arztes","edit_death_report":"Todesbericht bearbeiten","new_death_report":"Neuer Todesbericht","patient_name":"Patientenname"},"death_reports":"Todesberichte","department":"Abteilung","departments":"Abteilungen","diagnosis_category":{"category_name":"Kategoriename","description":"Beschreibung","diagnosis_categories":"Diagnosekategorie","diagnosis_category":"Diagnosekategorie","diagnosis_category_details":"Details zur Diagnosekategorie","edit_diagnosis_category":"Diagnosekategorie bearbeiten","new_diagnosis_category":"Neue Diagnosekategorie"},"doc_type":{"edit_doc_type":"Dokumenttyp bearbeiten","name":"Name","new_doc_type":"Neuer Dokumenttyp"},"doctor":{"doctor_details":"Arzt Details","edit_doctor":"Doktor bearbeiten","new_doctor":"Neuer Doktor","specialist":"Spezialistin"},"doctor_department":{"description":"Beschreibung","doctor_department":"Arztabteilung","doctor_department_details":"Details der Arztabteilung","doctor_departments":"Arztabteilungen","edit_doctor_department":"Arztabteilung bearbeiten","new_doctor_department":"Neue Arztabteilung","title":"Titel"},"doctor_departments":"Arztabteilungen","doctor_opd_charge":{"doctor":"Arzt","doctor_name":"Name des Arztes","doctor_opd_charge":"OPD-Geb\u00fchr des Arztes","edit_doctor_opd_charge":"Bearbeiten Sie die OPD-Geb\u00fchr f\u00fcr den Arzt","new_doctor_opd_charge":"Neue Doktor-OPD-Geb\u00fchr","new_opd_charge":"Neue OPD Geb\u00fchr","standard_charge":"Normaltarif"},"doctor_opd_charges":"Arzt OPD Geb\u00fchren","doctors":"\u00c4rztinnen","doctors_list":"\u00c4rzte-Liste","document":{"attachment":"Anhang","document":"Dokumentieren","document_detail":"Dokumentdetails","document_type":"Dokumentenart","document_type_details":"Dokumenttypdetails","download":"Herunterladen","edit_document":"Dokument bearbeiten","new_document":"Neues Dokument","notes":"Anmerkungen","patient":"Geduldig","select_document_type":"W\u00e4hlen Sie Dokumenttyp","select_patient":"W\u00e4hlen Sie Patient","title":"Titel","uploaded_by":"Hochgeladen von"},"document_types":"Dokumenttypen","documents":"Unterlagen","email":{"attachment":"Anh\u00e4nge","message":"Botschaft","subject":"Gegenstand","to":"Zu"},"employee_payroll":{"allowance":"Beihilfe","basic_salary":"Grundgehalt","deductions":"Abz\u00fcge","edit_employee_payroll":"Mitarbeiterabrechnung bearbeiten","employee":"Mitarbeiterin","employee_name":"Mitarbeitername","employee_payroll":"Mitarbeiterabrechnung","employee_payroll_details":"Angaben zur Mitarbeiterabrechnung","employee_payrolls":"Mitarbeiterabrechnungen","month":"Monat","net_salary":"Nettogehalt","new_employee_payroll":"Neue Mitarbeiterabrechnung","not_paid":"Nicht bezahlt","paid":"Bezahlt","payroll_id":"Gehaltsabrechnungs-ID","role":"Rolle","sr_no":"Sr. Nr","year":"Jahr"},"employee_payrolls":"Mitarbeiterabrechnungen","enquiries":"Anfragen","enquiry":{"contact":"Kontakt","email":"Email","enquiry_details":"Anfragedetails","enquiry_send_successfully":"Anfrage erfolgreich gesendet","message":"Botschaft","name":"Name","not_viewed":"Nicht angezeigt","read":"Lesen","received_on":"Eingegangen am","send_enquiry":"Anfrage absenden","type":"Art","unread":"Ungelesen","viewed_by":"Gesehen von"},"expense":{"amount":"Menge","attachment":"Anhang","choose":"W\u00e4hlen","date":"Datum","description":"Beschreibung","document_error":"Das Dokument muss eine Dateityp sein: jpeg, jpg, png, pdf, doc, docx.","download":"Herunterladen","edit_expense":"Kosten bearbeiten","expense":"Aufwand","expense_details":"Aufwandsdetails","expense_head":"Kosten Kopf","invoice_number":"Rechnungsnummer","name":"Name","new_expense":"Neue Ausgaben","select_expense_head":"W\u00e4hlen Sie Expense Head"},"expenses":"Kosten","facebook_url":"Facebook URL","file_name":"Dateiname","finance":"Finanzen","front_cms":"Front cms","front_cms_services":"Front-CMS-Dienste","front_office":"Postversand","front_service":"Frontdienst","front_setting":{"about_us_description":"Beschreibung","about_us_details":"\u00dcber uns Details","about_us_image":"Bild","about_us_mission":"Mission","about_us_title":"Titel","appointment_details":"Termindetails","front_setting_details":"Fronteinstellungsdetail","home_page_box_description":"Beschreibung des Startseitenfelds","home_page_box_title":"Titel der Homepage-Box","home_page_certified_box_description":"Startseite Zertifizierte Box Beschreibung","home_page_certified_box_title":"Homepage Zertifizierte Box Titlen","home_page_certified_doctor_description":"Startseite Zertifizierter Arzt Beschreibung","home_page_certified_doctor_image":"Startseite Zertifizierter Arzt Bild","home_page_certified_doctor_text":"Homepage Zertifizierter Arzt Text","home_page_certified_doctor_title":"Homepage Zertifizierter Arzt Titel","home_page_description":"Homepage-Beschreibung","home_page_experience":"Homepage-Erfahrung","home_page_image":"Startseitenbild","home_page_step_1_description":"Startseite Schritt 1 Beschreibung","home_page_step_1_title":"Startseite Schritt 1 Titel","home_page_step_2_description":"Startseite Schritt 2 Beschreibung","home_page_step_2_title":"Startseite Schritt 2 Titel","home_page_step_3_description":"Startseite Schritt 3 Beschreibung","home_page_step_3_title":"Startseite Schritt 3 Titel","home_page_step_4_description":"Startseite Schritt 4 Beschreibung","home_page_step_4_title":"Startseite Schritt 4 Titel","home_page_title":"Titel der Homepage","privacy_policy":"Datenschutz-Bestimmungen","terms_condition_details":"AGB-Details","terms_conditions":"Terms & Bedingungen"},"front_settings":"Fronteinstellungen","general":"Allgemeines","hospital_activities":"Krankenhausaktivit\u00e4ten","hospital_blood_bank":{"blood_bank":"Blutbank","blood_bank_details":"Details zur Blutbank","blood_banks":"Blutbanken","blood_group":"Blutgruppe","edit_blood_group":"Blutgruppe bearbeiten","new_blood_group":"Neue Blutgruppe","remained_bags":"Verbleibende Taschen"},"hospital_charges":"Krankenhauskosten","hospital_schedule":"Krankenhausplan","hospital_schedules":{"exists_doctor_schedule":"Einige \u00c4rzte haben ihre Tage in bestimmten ungepr\u00fcften Tagen geplant, also sind Sie sicher, dass Sie diese Operation durchf\u00fchren m\u00f6chten?"},"icon":"Symbol","income":"Einkommen","incomes":{"amount":"Menge","attachment":"Anhang","choose":"W\u00e4hlen","date":"Datum","description":"Beschreibung","document_error":"Das Dokument muss eine Dateityp sein: jpeg, jpg, png, pdf, doc, docx.","download":"Herunterladen","edit_income":"Einkommen bearbeiten","income_details":"Einkommensdetails","income_head":"Einkommensleiter","incomes":"Einkommen","invoice_number":"Rechnungsnummer","name":"Name","new_income":"Neues Einkommen","select_income_head":"W\u00e4hlen Sie Income Head"},"instagram_url":"Instagram-URL","insurance":{"discount":"Rabatt","disease_details":"Krankheitsdetails","diseases_charge":"Krankheitsgeb\u00fchr","diseases_name":"Name der Krankheit","edit_insurance":"Versicherung bearbeiten","hospital_rate":"Krankenhauspreis","insurance":"Versicherung","insurance_code":"Versicherungscode","insurance_details":"Versicherungsdetails","insurance_no":"Versicherung Nr","insurances":"Versicherungen","new_insurance":"Neue Versicherung","remark":"Anmerkung","service_tax":"Servicesteuer","total_amount":"Gesamtmenge"},"insurances":"Versicherungen","inventory":"Inventar","investigation_report":{"attachment":"Anhang","birth_date_validation":"Das Datum des Untersuchungsberichts sollte nicht kleiner sein als das Geburtsdatum des Patienten.","date":"Datum","description":"Beschreibung","doctor":"\u00c4rztin","edit_investigation_report":"Untersuchungsbericht bearbeiten","investigation_report":"Untersuchungsbericht","investigation_report_details":"Untersuchungsbericht Details","investigation_reports":"Untersuchungsberichte","new_investigation_report":"Neuer Untersuchungsbericht","patient":"Geduldig","title":"Titel"},"investigation_reports":"Untersuchungsberichte","invoice":{"account_name":"Kontobezeichnung","add":"Hinzuf\u00fcgen","amount":"Menge","description":"Beschreibung","discount":"Rabatt","edit":"Bearbeiten","edit_invoice":"Rechnung bearbeiten","hospital_address":"Krankenhausadresse","invoice":"Rechnung","invoice_date":"Rechnungsdatum","invoice_details":"Rechnungs-Details","invoice_id":"Rechnungs-ID","invoices":"Rechnungen","new_invoice":"Neue Rechnung","not_paid":"Nicht bezahlt","paid":"Bezahlt","patient":"Geduldig","patient_id":"Patienten ID","price":"Preis","print_invoice":"Rechnung drucken","qty":"Menge","sub_total":"Zwischensumme","total":"Gesamtmenge"},"invoices":"Rechnungen","ipd_bill":{"discount_in_number":"Discount In Number","discount_in_percentage":"Rabatt in Prozent","gross_total":"Bruttosumme","net_payable_amount":"Nettobetrag","other_charges":"Zusatzgeb\u00fchren","paid_amount":"Bezahlte Menge","tax_in_number":"Steuernummer","tax_in_percentage":"Steuer in Prozent","total_charges":"Gesamte Geb\u00fchren"},"ipd_charges":"Geb\u00fchren","ipd_consultant_register":"Anleitung des Beraters","ipd_diagnosis":"Diagnose","ipd_opd":"IPD\/OPD","ipd_patient":{"admission_date":"Aufnahmedatum","bed_id":"Bett","bed_type_id":"Betttyp","bill_status":"Rechnungsstatus","bp":"Blutdruck","case_id":"Fall","doctor_id":"Arzt","edit_ipd_patient":"IPD-Patienten bearbeiten","height":"H\u00f6he","ipd_number":"IPD Nr","ipd_patient":"IPD Patient","ipd_patient_details":"IPD Patient Einzelheiten","ipd_patients":"IPD Patients","is_old_patient":"Ist alter Patient","new_ipd_patient":"Neuer IPD Patient","notes":"Anmerkungen","patient_id":"Geduldig","symptoms":"Symptome","the_bed_field_is_required":"Das Bettfeld ist erforderlich.","the_case_field_is_required":"Das Fallfeld ist erforderlich.","weight":"Gewicht"},"ipd_patient_charges":{"applied_charge":"Angewandte Geb\u00fchr","charge_category_id":"Geb\u00fchrenkategorie","charge_id":"Code","charge_type_id":"Ladungsart","date":"Datum","new_charge":"Geb\u00fchren hinzuf\u00fcgen","standard_charge":"Standardgeb\u00fchr"},"ipd_patient_consultant_register":{"applied_date":"Angewandtes Datum","doctor_id":"Arzt","instruction":"Anweisung","instruction_date":"Anweisungsdatum","new_consultant_register":"Berateranweisung hinzuf\u00fcgen"},"ipd_patient_diagnosis":{"description":"Beschreibung","document":"Dokument","edit_ipd_diagnosis":"Diagnose bearbeiten","new_ipd_diagnosis":"Diagnose hinzuf\u00fcgen","report_date":"Berichtsdatum","report_type":"Berichtstyp"},"ipd_patient_prescription":{"category_id":"Medizin Kategorie","dosage":"Dosierung","edit_prescription":"Rezept bearbeiten","footer_note":"Fu\u00dfzeile Hinweis","header_note":"Header Hinweis","instruction":"Anweisung","ipd_no":"IPD Nr","medicine_id":"Medizin","new_prescription":"Rezept hinzuf\u00fcgen","prescription_details":"Rezeptdetails","print_prescription":"Rezept drucken"},"ipd_patient_timeline":{"date":"Datum","description":"Beschreibung","document":"Dokument","edit_ipd_timeline":"Timeline bearbeiten","new_ipd_timeline":"Timeline hinzuf\u00fcgen","no_timeline_found":"Keine Zeitleiste gefunden","title":"Titel","visible_to_person":"F\u00fcr die Person sichtbar"},"ipd_patients":"IPD-Patienten","ipd_payment":"IPD-Zahlung","ipd_payments":{"add_ipd_payment":"Ipd-Zahlung hinzuf\u00fcgen","edit_ipd_payment":"IPD-Zahlung bearbeiten","make_payment":"Zahlung leisten","payment_mode":"Zahlungsart"},"ipd_prescription":"Rezepte","ipd_timelines":"Zeitleisten","issued_item":{"are_you_sure_want_to_return_this_item":"M\u00f6chten Sie diesen Artikel wirklich zur\u00fcckgeben?","available_quantity":"verf\u00fcgbare Anzahl","department_id":"Benutzertyp","description":"Beschreibung","edit_issued_item":"Ausgestelltes Element bearbeiten","issued_by":"Problem durch","issued_date":"Ausgabedatum","issued_item":"Ausgestelltes Objekt","issued_item_details":"Details zu ausgegebenen Artikeln","issued_items":"Ausgestellte Artikel","item":"Artikel","item_category":"Artikelkategorie","item_return":"Artikel zur\u00fcckgeben","item_returned":"Ist zur\u00fcckgekommen","new_issued_item":"Neu ausgegebener Artikel","quantity":"Menge","return_date":"R\u00fcckflugdatum","user_id":"Ausgabe an"},"issued_items":"Ausgestellte Artikel","item":{"available_quantity":"Verf\u00fcgbar Menge","description":"Beschreibung","edit_item":"Bearbeiten Artikel","item":"Artikel","item_category":"Artikel Kategorie","item_details":"Artikel Einzelheiten","items":"Artikel","name":"Name","new_item":"Neu Artikel","unit":"Einheit"},"item_category":{"edit_item_category":"Artikel kategorie bearbeiten","item_categories":"Artikel kategorien","item_category":"Artikel kategorie","name":"Name","new_item_category":"Neue Artikel kategorie"},"item_stock":{"attachment":"Anhang","description":"Beschreibung","edit_item_stock":"Bearbeiten Artikel Lager","item":"Artikel","item_category":"Artikel Kategorie","item_stock":"Artikel Lager","item_stock_details":"Artikel Lager Details","item_stocks":"Artikel Best\u00e4nde","new_item_stock":"Neu Artikel Lager","purchase_price":"Kaufpreis","quantity":"Menge","store_name":"Gesch\u00e4ft Name","supplier_name":"Lieferant Name"},"items":"Artikel","items_categories":"Artikel Kategorien","items_stocks":"Artikel Best\u00e4nde","lab_tech":{"edit_lab_tech":"Labortechniker bearbeiten","lab_tech_detail":"Details zum Labortechniker","lab_technician":"Labortechniker","new_lab_tech":"Neuer Labortechniker"},"lab_technicians":"Labortechniker","language":{"Arabic":"Arabisch","Chinese":"Chinesisch","English":"Englisch","French":"Franz\u00f6sisch","German":"Deutsch","Portuguese":"Portugiesisch","Russian":"Russisch","Spanish":"Spanisch","Turkish":"T\u00fcrkisch"},"linkedIn_url":"linkedIn-URL","live_consultation":{"Type":"Art","add_credential":"Anmeldedaten hinzuf\u00fcgen","client_video":"Client Video","consultation_date":"Konsultationsdatum","consultation_duration_minutes":"Konsultationsdauer Minuten","consultation_title":"Konsultationstitel","created_by":"Erstellt von","created_for":"Hergestellt f\u00fcr","disabled":"Behindert","edit_live_consultation":"Live-Beratung bearbeiten","edit_live_meeting":"Live-Meeting bearbeiten","enable":"aktivieren","host_video":"Host-Video","join_now":"Jetzt beitreten","live_consultation":"Live-Beratung","new_live_consultation":"Neue Live-Beratung","new_live_meeting":"Neues Live-Meeting","staff_list":"Mitarbeiterliste","type_number":"Nummer eingeben","zoom_api_key":"Zoom-API-Schl\u00fcssel","zoom_api_secret":"Zoom-API-Geheimnis"},"live_consultations":"Live-Konsultationen","live_meeting":"Live-Meeting","live_meetings":"Live-Meetings","mail":"Mail","make_an_appointment":"Termin vereinbaren","medicine":{"brand":"Marke","brand_name":"Markenname","buying_price":"Kaufpreis","category":"Kategorie","category_id":"Kategorie ID","description":"Beschreibung","edit_medicine":"Medizin bearbeiten","edit_medicine_brand":"Medizinmarke bearbeiten","edit_medicine_category":"Kategorie Medizin bearbeiten","medicine":"Medizin","medicine_brands":"Arzneimittelmarken","medicine_brands_details":"Details zur Medizinmarke","medicine_category":"Medizin Kategorie","medicine_category_details":"Details zur Medikamentenkategorie","medicine_details":"Medizin Details","medicines":"Medikamente","name":"Name","new_brand":"Neue Marke","new_medicine":"Neue Medizin","new_medicine_brand":"Neue Medizinmarke","new_medicine_category":"Neue Medizin Kategorie","salt_composition":"Salzzusammensetzung","selling_price":"Verkaufspreis","side_effects":"Nebenwirkungen"},"medicine_brands":"Medizinmarken","medicine_categories":"Medizin Kategorien","medicines":"Medikamente","message":{"date":"Datum","message":"Botschaft","messages":"Mitteilungen","messages_details":"Nachrichtendetails","new_message":"Neue Nachricht","select_user":"W\u00e4hle den Benutzer","send_to":"Senden an","sender_name":"Absender","subject":"Gegenstand"},"months":{"apr":"April","aug":"August","dec":"Dezember","feb":"Februar","jan":"Januar","july":"Juli","jun":"Juni","mar":"Marsch","may":"Kann","nov":"November","oct":"Oktober","sep":"September"},"my_payroll":{"allowance":"Beihilfe","basic_salary":"Grundgehalt","deductions":"Abz\u00fcge","my_payrolls":"Meine Gehaltsabrechnungen","net_salary":"Nettogehalt"},"my_payrolls":"Meine Gehaltsabrechnungen","new_patient":"Neuer Patient","no_data_available":"Keine Daten in der Tabelle verf\u00fcgbar","notice_board":{"created_at":"hergestellt in","description":"Beschreibung","details":"Anschlagtafel Details","edit":"Anschlagtafel bearbeiten","new":"Neues Schwarzes Brett","notice_board":"Schild","title":"Titel"},"notice_boards":"Notiz Bretter","notification":{"mark_all_as_read":"Markiere alle als gelesen","notifications":"Benachrichtigungen","you_don`t_have_any_new_notification":"Sie haben keine neue Benachrichtigung"},"nurse":{"birth_date":"Geburtsdatum","choose":"W\u00e4hlen","edit_nurse":"Krankenschwester bearbeiten","new_nurse":"Neue Krankenschwester","nurse":"Krankenschwester","nurse_details":"Krankenschwester Details","phone_no":"Telefonnummer"},"nurses":"Krankenschwestern","old_patient":"Alter Patient","opd_diagnosis":"OPD-Diagnose","opd_patient":{"appointment_date":"Termin","edit_opd_patient":"Bearbeiten OPD Patient","new_opd_patient":"Neu OPD Patient","opd_number":"OPD Nein","opd_patient":"OPD Patient","opd_patient_details":"OPD Patienten details","opd_patients":"OPD Patients","revisits":"Wiederholen","total_visits":"Gesamtzahl der Besuche","visits":"Besuche"},"opd_patients":"OPD-Patienten","opd_payments":{"add_opd_payment":"Opd Payment hinzuf\u00fcgen","edit_opd_payment":"Opd Payment bearbeiten","make_payment":"Zahlung leisten","payment_mode":"Zahlungsart"},"opd_timeline":"OPD-Zeitleiste","operation_report":{"case_id":"Fall-ID","date":"Datum","description":"Beschreibung","doctor_name":"Name des Arztes","edit_operation_report":"Betriebsbericht bearbeiten","new_operation_report":"Neuer Betriebsbericht","operation_report":"Betriebsbericht","operation_report_details":"Details zum Betriebsbericht","operation_reports":"Betriebsberichte","patient_name":"Patientenname"},"operation_reports":"Betriebsberichte","overview":"\u00dcberblick","package":{"amount":"Menge","description":"Beschreibung","discount":"Rabatt","edit_package":"Paket bearbeiten","name":"Name","new_package":"Neues Paket","package":"Paket","package_details":"Paketdetails","packages":"Pakete","qty":"Menge","rate":"Bewertung","select_service":"W\u00e4hlen Sie Service","service":"Bedienung","total_amount":"Gesamtmenge"},"packages":"Pakete","pathologies":"Pathologie","pathology_categories":"Pathologie-Kategorie","pathology_category":{"edit_pathology_category":"Pathologiekategorie bearbeiten","name":"Name","new_pathology_category":"Neue Pathologiekategorie","pathology_categories":"Pathologiekategorien"},"pathology_test":{"category_name":"Kategorie Name","charge_category":"Geb\u00fchrenkategorie","edit_pathology_test":"Bearbeiten Pathologie Pr\u00fcfung","method":"Methode","new_pathology_test":"Neu Pathologie Pr\u00fcfung","pathology_test_details":"Pathologie Pr\u00fcfung Details","pathology_tests":"Pathologie Tests","report_days":"Tage melden","short_name":"Kurz Name","standard_charge":"Normaltarif","subcategory":"Unterkategorie","test_name":"Pr\u00fcfung Name","test_type":"Pr\u00fcfung Art","unit":"Einheit"},"pathology_tests":"Pathologie Tests","patient":{"edit_patient":"Patient bearbeiten","new_patient":"Neuer Patient","patient_details":"Patientendetails","total_admissions":"Gesamtzulassungen","total_appointments":"Termine insgesamt","total_cases":"F\u00e4lle insgesamt"},"patient_admission":{"admission_date":"Aufnahmedatum","agent_name":"Agentenname","bed":"Bett","details":"Details zur Patientenaufnahme","discharge_date":"Entlassungsdatum","doctor":"\u00c4rztin","doctor_name":"Name des Arztes","edit_patient_admission":"Patientenaufnahme bearbeiten","guardian_address":"W\u00e4chteradresse","guardian_contact":"Guardian Kontakt","guardian_name":"Name des W\u00e4chters","guardian_relation":"W\u00e4chterbeziehung","insurance":"Versicherung","insurance_name":"Versicherungsname","new_patient_admission":"Neue Patientenaufnahme","package":"Paket","package_name":"Paketnamen","patient":"Geduldig","patient_admission":"Patientenaufnahme","patient_admission_id":"ID der Patientenaufnahme","patient_name":"Patientenname","policy_no":"Richtlinie Nr"},"patient_admissions":"Patientenaufnahmen","patient_appointment":"Patiententermin","patient_diagnosis_test":{"action":"Aktion","add_other_diagnosis_property":"F\u00fcgen Sie eine andere Diagnoseeigenschaft hinzu","age":"Alter","average_glucose":"Durchschnittliche Glukose","blood_pressure":"Blutdruck","cholesterol":"Cholesterin","create_patient_diagnosis_test":"Erstellen Sie einen Patientendiagnosetest","created_at":"Hergestellt in","diabetes":"Diabetes","diagnosis":"Diagnose","diagnosis_category":"Diagnosekategorie","diagnosis_property_name":"Name der Diagnoseeigenschaft","diagnosis_property_value":"Diagnoseeigenschaftswert","diagnosis_test":"Diagnosetests","doctor":"Arzt","doctor_name":"Name des Arztes","edit_patient_diagnosis_test":"Patientendiagnosetest bearbeiten","fasting_blood_sugar":"Blutzucker n\u00fcchtern","height":"H\u00f6he","new_patient_diagnosis_test":"Neuer Patientendiagnosetest","other_diagnosis_property":"Andere Diagnoseeigenschaft","patient":"Geduldig","patient_diagnosis_test":"Patientendiagnosetests","patient_diagnosis_test_details":"Details zum Patientendiagnosetest","patient_name":"Patientenname","print_diagnosis_test":"Diagnosetest drucken","report_number":"Berichtsnummer","urine_sugar":"Urin Zucker","weight":"Gewicht"},"patients":"Patientinnen","patients_case_details":"Details zum Patientenfall","patients_cases":"Patientenf\u00e4lle","payment":{"account":"Konto","account_name":"Kontobezeichnung","amount":"Menge","description":"Beschreibung","edit_payment":"Zahlung bearbeiten","new_payment":"Neue Zahlung","pay_to":"Zahlen an","payment":"Zahlung","payment_date":"Zahlungsdatum","payment_details":"Zahlungsdetails","payment_reports":"Zahlungsberichte","payments":"Zahlungen"},"payments":"Zahlungen","pharmacist":{"edit_pharmacist":"Apotheker bearbeiten","new_pharmacist":"Neuer Apotheker","pharmacist_details":"Apotheker Details","pharmacists":"Apothekerinnen"},"pharmacists":"Apothekerinnen","postal":{"address":"Adresse","date":"Datum","dispatch":"Versand","edit_dispatch":"Versand bearbeiten","edit_receive":"Empfangen bearbeiten","from_title":"Aus dem Titel","new_dispatch":"Neuer Versand","new_receive":"Neu empfangen","postal":"Post","receive":"Erhalten","reference_no":"Referenznummer","to_title":"Zum Titel"},"postal_dispatch":"Postversand","postal_receive":"Postempfang","prescription":{"accident":"Unfall","advice":"Rat","after_meal":"nach dem Essen","before_meal":"vor dem Essen","breast_feeding":"Stillen","comment":"Kommentar","current_medication":"Derzeitige Medikamente","diabetic":"Diabetikerin","duration":"Dauer","edit_prescription":"Rezept bearbeiten","female_pregnancy":"Weibliche Schwangerschaft","food_allergies":"Essensallergien","health_insurance":"Krankenversicherung","heart_disease":"Herzkrankheit","high_blood_pressure":"Bluthochdruck","low_income":"Niedriges Einkommen","medical_history":"Krankengeschichte","medicine_name":"Medizinname","month":"Monat","new_medicine":"neue Medizin","new_prescription":"Neues Rezept","next_visit":"n\u00e4chster Besuch","no_data_available":"keine Daten gefunden","others":"Andere","patient":"Geduldig","physical_information":"physikalische Informationen","plus_rate":"Impuls Tarif","prescription":"Rezept","prescription_details":"Rezeptdetails","prescriptions":"Rezepte","problem":"Problem","problem_description":"Problembeschreibung","reference":"Referenz","rx":"Empfang","surgery":"Chirurgie","temperature":"Temperatur","tendency_bleed":"Tendenz bluten","test":"Pr\u00fcfung","time":"Zeit","year":"Jahr"},"prescriptions":"Rezepte","profile":{"change_language":"Sprache \u00e4ndern","edit_profile":"Profil bearbeiten","email":"Email","first_name":"Vorname","language":"Sprache","last_name":"Nachname","phone":"Telefon","profile":"Profil"},"radiologies":"Radiologie","radiology_categories":"Radiologie Kategorie","radiology_category":{"edit_radiology_category":"Bearbeiten Radiologie Kategorie","name":"Name","new_radiology_category":"Neu Radiologie Kategorie","radiology_categories":"Neu"},"radiology_test":{"category_name":"Kategoriename","charge_category":"Geb\u00fchrenkategorie","edit_radiology_test":"Radiologie-Test bearbeiten","new_radiology_test":"Neuer Radiologietest","radiology_test_details":"Details zum Radiologietest","radiology_tests":"Radiologische Tests","report_days":"Tage melden","short_name":"Kurz Name","standard_charge":"Normaltarif","subcategory":"Unterkategorie","test_name":"Pr\u00fcfung Name","test_type":"Pr\u00fcfung Art"},"radiology_tests":"Radiologische Tests","receptionist":{"edit_receptionist":"Empfangsdame bearbeiten","new_receptionist":"Neue Rezeptionistin","receptionist":"Rezeptionistin","receptionist_details":"Details zur Rezeption","receptionists":"Rezeptionistinnen"},"receptionists":"Rezeptionistinnen","reports":"Berichte","role":{"edit_role":"Rolle bearbeiten","new_role":"Neue Rolle"},"roles":"Rollen","schedule":{"available_from":"Verf\u00fcgbar ab","available_on":"Verf\u00fcgbar auf","available_to":"Verf\u00fcgbar f\u00fcr","details":"Zeitplandetails","doctor_name":"Name des Arztes","edit":"Zeitplan bearbeiten","new":"Neue Terminplanung","per_patient_time":"Pro Patientenzeit","select_doctor_name":"W\u00e4hlen Sie den Namen des Arztes","select_serial_visibility":"W\u00e4hlen Sie Serielle Sichtbarkeit","sequential":"Sequentiell","serial_visibility":"Serielle Sichtbarkeit","timestamp":"Zeitstempel"},"schedule_label":"Zeitplan","schedules":"Zeitpl\u00e4ne","service":{"edit_service":"Service bearbeiten","given":"Gegeben","new_service":"Neuer Service","not_given":"Nicht angegeben","quantity":"Menge","rate":"Bewertung","service_details":"Servicedetails"},"services":"Dienstleistungen","setting":{"address":"Krankenhausadresse","app_logo":"App-Logo","app_name":"App Name","company_name":"Name der Firma","country_code":"L\u00e4ndercode","currency":"Aktuelle W\u00e4hrung","hospital_email":"Krankenhaus-E-Mail","hospital_from_day":"Krankenhaus vom Tag","hospital_from_time":"Krankenhaus aus der Zeit","hospital_phone":"Krankenhaustelefon","image_validation":"Das Bild muss 90 x 60 Pixel gro\u00df sein.","social_details":"Soziale Details"},"settings":"die Einstellungen","short_description":"kurze Beschreibung","sidebar_setting":"Moduleinstellungen","sms":{"date":"Datum","message":"Botschaft","new_sms":"Neue SMS","only_user_with_registered_phone_will_display":"(Es werden nur Benutzer mit einem registrierten Telefon angezeigt.)","phone_number":"Telefonnummer","role":"Rolle","send":"Senden","send_by":"Gesendet von","send_sms_by_number_directly":"Senden Sie SMS direkt nach Nummer","send_to":"Senden an","sms":"SMS","sms_details":"SMS-Details"},"testimonial":{"description":"Beschreibung","edit_testimonial":"Testimonial bearbeiten","name":"Name","new_testimonial":"Neu Zeugnis","profile_error":"Das Dokument muss eine Datei vom Typ sein: jpeg, jpg, png.","testimonial":"Zeugnis","testimonial_detail":"Testimonial-Details"},"testimonials":"Referenzen","twitter_url":"Twitter-URL","user":{"address1":"Adresse 1","address2":"Adresse 2","address_details":"Adressen Details","address_not_found":"Keine Adressdaten gefunden","blood_group":"Blutgruppe","change_password":"Passwort \u00e4ndern","city":"Stadt","designation":"Bezeichnung","dob":"Geburtsdatum","edit_profile":"Profil bearbeiten","edit_user":"Benutzer bearbeiten","education":"Bildung","email":"Email","email_verified_successfully":"E-Mail erfolgreich verifiziert.","female":"Weiblich","first_name":"Vorname","gender":"Geschlecht","invalid_password":"Aktuelles Passwort ist ung\u00fcltig.","last_name":"Nachname","logout":"Ausloggen","male":"M\u00e4nnlich","name":"Name","new_user":"Neuer Benutzer","password":"Passwort","password_confirmation":"Kennwort best\u00e4tigen","phone":"Telefon","qualification":"Qualifikation","select_blood_group":"W\u00e4hlen Sie Blutgruppe","status":"Status","user_details":"Nutzerdetails","usrs":"Benutzer","validate_confirm_password":"Das Passwort und das Best\u00e4tigungspasswort m\u00fcssen \u00fcbereinstimmen.","validate_min_character_password":"Das Passwort muss mindestens 6 Zeichen enthalten.","zip":"Postleitzahl"},"users":"Benutzer","vaccinated_patient":{"add_vaccinate_patient":"Impfpatienten hinzuf\u00fcgen","description":"Beschreibung","does_no":"Dosis Nr","dose_given_date":"Dosis gegebenes Datum","edit_vaccinate_patient":"Impfpatienten bearbeiten","new_vaccinate_patient":"Neuer Impfpatient","patient":"Geduldig","serial_no":"Seriennummer","vaccinate_patient":"Patienten impfen","vaccinated_patient":"Geimpfter Patient","vaccination":"Impfung","vaccine":"Impfstoff"},"vaccinated_patients":"Geimpfte Patienten","vaccination":{"brand":"Marke","edit_vaccination":"Impfung bearbeiten","manufactured_by":"Hergestellt von","name":"Name","new_vaccination":"Neue Impfung","vaccinated":"Geimpft","vaccinations":"Impfungen"},"vaccinations":"Impfungen","valid":"G\u00fcltig","verification":{"another_verify_request":"Klicken Sie hier, um eine weitere anzufordern","verify_message":"Bevor Sie fortfahren, \u00fcberpr\u00fcfen Sie bitte Ihre E-Mail auf einen Best\u00e4tigungslink. Wenn Sie die E-Mail nicht erhalten haben,","verify_your_email_address":"Best\u00e4tige deine Email-Adresse."},"visitor":{"date":"Datum","edit":"Besucher bearbeiten","id_card":"Ausweis","in_time":"Rechtzeitig","name":"Name","new":"Neuer Besucher","note":"Hinweis","number_of_person":"Anzahl von Personen","out_time":"aus der Zeit","phone":"Telefon","purpose":"Zweck","visitor":"Besucherin"},"visitors":"Besucherinnen","web_appointment":{"call_now_and_get_a_free_consulting":"Rufen Sie jetzt an und lassen Sie sich kostenlos beraten","enter_confirm_password":"Geben Sie das Kennwort zur Best\u00e4tigung ein","enter_description":"Beschreibung eingeben","enter_your_first_name":"Geben Sie Ihren Vornamen ein","enter_your_last_name":"Geben Sie Ihren Nachnamen ein","enter_your_password":"Geben Sie Ihr Passwort ein","make_an_appointment":"Einen Termin machen","select_department":"Abteilung ausw\u00e4hlen","select_doctor":"Arzt ausw\u00e4hlen","select_time":"W\u00e4hlen Sie Zeit"},"web_contact":{"call_today":"Ruf heute an","contact_no":"Kontakt Nr","enter_your_email":"Geben sie ihre E-Mail Adresse ein","enter_your_name":"Gib deinen Namen ein","open_hours":"\u00d6ffnungszeiten","our_location":"unsere Position","phone_number":"Telefonnummer","please_enter_your_phone_number":"Bitte geben sie ihre Telefonnummer ein","select_enquiry":"Anfrage ausw\u00e4hlen","send_message":"Nachricht senden","send_us_a_message":"Schick uns eine Nachricht","type_your_message":"Geben Sie Ihre Nachricht ein","write_your_message":"Schreibe deine Nachricht","your_email":"Deine E-Mail","your_message":"Ihre Nachricht","your_name":"Dein Name"},"web_home":{"4_easy_step_and_get_the_world_best_treatment":"4 einfache Schritte und erhalten Sie die beste Behandlung der Welt","about_us":"\u00dcber uns","available_doctors":"Verf\u00fcgbare \u00c4rzte","book_an_appointment":"Vereinbare einen Termin","book_appointment":"Einen Termin verabreden","book_now":"buchen Sie jetzt","contact":"Kontakt","contact_doctors":"Arzt kontaktieren","contact_hospital":"Krankenhaus kontaktieren","doctors":"\u00c4rztinnen","doctors_nurses":"\u00c4rzte & Krankenschwestern","easy_solutions":"Einfache L\u00f6sungen","happy_patients":"Gl\u00fcckliche Patienten","home":"Heim","make_appointment":"Einen Termin machen","our_services":"Unsere Dienstleistungen","our_testimonials":"Unsere Erfahrungsberichte","patients":"Patientinnen","patients_beds":"Patientenbetten","privacy_policy":"Datenschutz-Bestimmungen","professional_doctors":"Professionelle \u00c4rzte","select_doctor":"Arzt ausw\u00e4hlen","select_doctors":"\u00c4rzte ausw\u00e4hlen","services":"Dienstleistungen","sign_up":"Anmeldung","terms_of_service":"Nutzungsbedingungen","testimonials":"Referenzen","we_are_experienced_healthcare_professionals":"Wir sind erfahrene Gesundheitsexperten","we_offer_different_services_to_improve_your_health":"Wir bieten verschiedene Dienstleistungen an, um Ihre Gesundheit zu verbessern","what_our_patient_say_about_medical_treatments":"Was unsere Patienten \u00fcber unsere medizinischen Behandlungen sagen","working_hours":"Arbeitszeit","years_experience":"Jahre Erfahrung"},"web_menu":{"about":"\u00dcber","all_rights_reserved_by":"Alle Rechte vorbehalten von","appointment":"Termin","contact_information":"Kontaktinformationen","copyright":"Urheberrechte \u00a9","login":"Anmeldung","our_features":"Unsere Funktionen","useful_link":"N\u00fctzlicher Link","working_hours":"Arbeitszeit"},"web_password":{"password_and_confirm_password_not_match":"Passwort und Passwort best\u00e4tigen stimmen nicht \u00fcberein.","please_fill_all_the_required_fields":"Bitte f\u00fcllen Sie alle Pflichtfelder aus."},"web_working_hours":{"no_yet_opening_hours":"Noch keine \u00d6ffnungszeiten","opening_hours":"\u00d6ffnungszeiten"},"weekdays":{"fri":"FR","mon":"MO","sat":"SA","sun":"SONNE","thu":"DO","tue":"DI","wed":"HEIRATEN"}},"en.messages":{"about_us":"About Us","account":{"account":"Account","account_details":"Account Details","accounts":"Accounts","credit":"Credit","debit":"Debit","description":"Description","edit_account":"Edit Account","name":"Name","new_account":"New Account","payments":"Payments","status":"Status","type":"Type"},"account_manager":"Account Manager","accountant":{"accountant":"Accountant","accountant_details":"Accountant Details","accountants":"Accountants","edit_accountant":"Edit Accountant","new_accountant":"New Accountant"},"accountants":"Accountants","admin":"Admins","admins":"Admin","advanced_payment":{"advanced_payment":"Advance Payment","advanced_payment_details":"Advance Payment Details","advanced_payments":"Advance Payments","amount":"Amount","date":"Date","edit_advanced_payment":"Edit Advance Payment","new_advanced_payment":"New Advance Payment","patient":"Patient","patient_name":"Patient Name","receipt_no":"Receipt No"},"advanced_payments":"Advance Payments","allow_file_type":"Allowed file types: png, jpg, jpeg.","ambulance":{"ambulance":"Ambulance","ambulance_details":"Ambulance Details","ambulances":"Ambulances","driver_contact":"Driver Contact","driver_license":"Driver License","driver_name":"Driver Name","edit_ambulance":"Edit Ambulance","is_available":"Is Available","new_ambulance":"New Ambulance","note":"Note","vehicle_model":"Vehicle Model","vehicle_number":"Vehicle Number","vehicle_type":"Vehicle Type","year_made":"Year Made"},"ambulance_call":{"ambulance_call":"Ambulance Call","ambulance_call_details":"Ambulance Call Details","ambulance_calls":"Ambulance Calls","amount":"Amount","date":"Date","driver_name":"Driver Name","edit_ambulance_call":"Edit Ambulance Call","new_ambulance_call":"New Ambulance Call","patient":"Patient","vehicle_model":"Vehicle Model"},"ambulance_calls":"Ambulance Calls","ambulances":"Ambulances","appointment":{"appointment_calendar":"Appointment Calendar","appointment_details":"Appointment Details","appointment_exists":"Appointment already exists","appointment_list":"Appointment List","are_you_sure_want_to_cancel":"Are you sure want to cancel","are_you_sure_want_to_change":"Are you sure want to change ","available_slot":"Available Slot","calendar_view":"Calendar View","change_status":"Change status","changed_appointment":"Changed Appointment","completed":"Completed","date":"Date","day":"Day","department_name":"Department Name","description":"Description","doctor":"Doctor","doctor_department":"Doctor Department","doctor_department_name":"Doctor Department Name","doctor_name":"Doctor Name","doctor_schedule_not_available_on_this_date":"Doctor Schedule not available this date.","edit_appointment":"Edit Appointment","has_been_cancelled":"has been Cancelled.","has_been_changed":"has been Changed.","last_30_days":"Last 30 days","last_7_days":"Last 7 days","last_month":"Last month","month":"Month","new_appointment":"New Appointment","no_available":"Not Available","old_patient_email_exists":"Email already exists, please select old patient.","opd_date":"Opd Date","patient":"Patient","patient_name":"Patient Name","patient_not_exists_or_status_is_not_active":"Patient not exists or status is not active.","pending":"Pending","please_select_appointment_time_slot":"Please select appointment time slot","please_select_doctor":"Please select Doctor","please_select_doctor_department":"Please select Doctor Department","this_month":"This month","this_week":"This Week","today":"Today","week":"Week","yesterday":"Yesterday"},"appointment_calendar":"Appoint. Calendar","appointments":"Appointments","available_slot":"Available Slot","available_slots":"Available Slots","bed":{"add":"Add","available":"Available","bed":"New Bed","bed_details":"Bed Details","bed_id":"Bed Id","bed_type":"Bed Type","beds":"Beds","charge":"Charge","description":"Description","edit_bed":"Edit Bed","name":"Name","new_bed":"New Bed","new_bulk_bed":"New Bulk Bed","not_available":"Not Available"},"bed_assign":{"assign_date":"Assign Date","assign_date_should_not_be_smaller_than_patient_birth_date":"Assign date should not be smaller than patient birth date.","assigned":"Assigned","bed":"Bed","bed_assign":"Bed Assign","bed_assign_details":"Bed Assign Details","bed_assigns":"Bed Assigns","bed_name":"Bed Name","case_id":"Case Id","description":"Description","discharge_date":"Discharge Date","edit_bed_assign":"Edit Bed Assign","ipd_patient_id":"IPD Patient Id","new_bed_assign":"New Bed Assign","not_assigned":"Not Assigned","patient_name":"Patient Name"},"bed_assigns":"Bed Assigns","bed_management":"Bed Management","bed_mgt":"Bed Management","bed_status":{"admission_date":"Admission Date","assigned_beds":"Assigned Beds","available_beds":"Available Beds","bed_name":"Bed Name","bed_status":"Bed Status","gender":"Gender","patient_name":"Patient Name","phone":"Phone"},"bed_type":{"bed_type":"Bed Type","bed_type_details":"Bed Type Details","bed_types":"Bed Types","description":"Description","edit_bed_type":"Edit Bed Type","new_bed_type":"New Bed Type","title":"Title"},"bed_types":"Bed Types","beds":"Beds","bill":{"add":"Add","admission_date":"Admission Date","admission_id":"Admission Id","amount":"Amount","bill":"Bill","bill_date":"Bill Date","bill_details":"Bill Details","bill_id":"Bill Id","bill_summary":"Bill Summary","bills":"Bills","calculate":"Calculate","cell_no":"Cell No","discharge_date":"Discharge Date","doctor_name":"Doctor Name","edit":"Edit","edit_bill":"Edit Bill","generate_bill":"Generate Bill","insurance_name":"Insurance Name","item_name":"Item Name","new_bill":"New Bill","package_name":"Package Name","patient":"Patient","patient_cell_no":"Patient Cell No","patient_dob":"Patient DOB","patient_email":"Patient Email","patient_gender":"Patient Gender","patient_name":"Patient Name","policy_no":"Policy No","price":"Price","print_bill":"Print Bill","qty":"Qty","total_amount":"Total Amount","total_days":"Total Days","update_bill":"Update Bill"},"billing":"Billings","bills":"Bills","birth_report":{"birth_report":"Birth Report","birth_report_details":"Birth Report Details","birth_reports":"Birth Reports","case_id":"Case Id","data_should_not_be_smaller_than_patient_birth_date":"Date should not be smaller than patient birth date.","date":"Date","description":"Description","doctor_name":"Doctor Name","edit_birth_report":"Edit Birth Report","new_birth_report":"New Birth Report","patient_birth_date_not_found":"Patient Birth Date not found.","patient_name":"Patient Name"},"birth_reports":"Birth Reports","blood_bank":"Blood Banks","blood_banks":"Blood Banks","blood_donation":{"bags":"Bags","blood_donation":"Blood Donation","donor_name":"Donor Name","edit_blood_donation":"Edit Blood Donation","last_donate_date":"Last donate date","new_blood_donation":"New Blood Donation"},"blood_donations":"Blood Donations","blood_donor":{"age":"Age","blood_donor":"Blood Donor","blood_donor_details":"Blood Donor Details","blood_donors":"Blood Donors","blood_group":"Blood Group","donation_date":"Donation Date","edit_blood_donor":"Edit Blood Donor","gender":"Gender","last_donation_date":"Last Donation Date","name":"Name","new_blood_donor":"New Blood Donor"},"blood_donors":"Blood Donors","blood_issue":{"amount":"Amount","blood_issue":"Blood Issue","doctor_name":"Doctor Name","donor_name":"Donor Name","edit_blood_issue":"Edit Blood Issue","issue_date":"Issue Date","new_blood_issue":"New Blood Issue","patient_name":"Patient Name","remarks":"Remarks"},"blood_issues":"Blood Issues","call_log":{"call_log":"Call Log","call_type":"Call Type","edit":"Edit Call Log","follow_up_date":"Follow-Up Date","incoming":"Incoming","name":"Name","new":"New Call Log","note":"Note","outgoing":"Outgoing","phone":"Phone","received_on":"Received On"},"call_logs":"Call Logs","case":{"case":"Case","case_date":"Case Date","case_details":"Case Details","case_id":"Case Id","date":"Date","description":"Description","doctor":"Doctor","edit_case":"Edit Case","fee":"Fee","new_case":"New Case","patient":"Patient","phone":"Phone"},"case_handler":{"case_handler":"Case Handler","case_handler_detail":"Case Handler Details","edit_case_handler":"Edit Case Handler","new_case_handler":"New Case Handler"},"case_handlers":"Case Handlers","case_manager":"Case Manager","cases":"Cases","change_password":{"change_password":"Change Password","confirm_password":"Confirm Password","current_password":"Current Password","new_password":"New Password"},"charge":{"charge_category":"Charge Category","charge_details":"Charge Details","code":"Code","edit_charge":"Edit Charge","new_charge":"New Charge","standard_charge":"Standard Charge"},"charge_categories":"Charge Categories","charge_category":{"charge_categories":"Charge Categories","charge_category_details":"Charge Category Details","charge_type":"Charge Type","edit_charge_category":"Edit Charge Category","new_charge_category":"New Charge Category"},"charges":"Charges","cms":"CMS","common":{"action":"Action","actions":"Actions","active":"Active","add":"Add","address":"Address","apply":"apply","are_you_sure_want_to_delete_this":"Are you sure want to delete this ","back":"Back","cancel":"Cancel","canceled":"Canceled","cant_be_deleted":"can't be deleted","choose":"Choose","confirm":"Confirm","created_at":"Created On","created_on":"Created On","custom":"Custom","de_active":"Deactive","delete":"Delete","deleted":"Deleted","deleted_successfully":"deleted successfully","description":"Description","detail":"Details","edit":"Edit","export_to_excel":"Export to Excel","filter":"Filter","filter_options":"Filter Options","from":"from","has_been_deleted":"has been deleted.","invalid_country_code":"Invalid country code","invalid_number":"Invalid number","is_available":"Is Available","last_updated":"Last Updated","n\/a":"N\/A","name":"Name","new":"New","next":"Next","no":"No","no data available in table":"No data available in table","no_data_available":"No data available in table","not_found":"not found","ok":"Ok","previous":"Previous","profile":"Profile","reset":"Reset","save":"Save","saved_successfully":"saved successfully","search":"Search","status":"Status","status_updated_successfully":"Status updated successfully.","this_action_is_not_allowed_for_default_record":"This action is not allowed for default record.","to":"To","too_long":"Too long","too_short":"Too short","total":"Total","updated_at":"Last Updated","updated_successfully":"updated successfully","user_details":"User","view":"View","view_attachment":"View Attachment","yes":"Yes"},"contact_us":"Contact Us","currency":{"add_currency_code_as_per_three_letter_iso_code":"Add currency code as per three-letter ISO code","currency":"Currency","currency_code":"Currency Code","currency_icon":"Currency Icon","currency_name":"Currency Name","edit_currency":"Edit Currency","new_currency":"New Currency","you_can_find_out_here":"you can find out here"},"currency_setting":"Currencies","dashboard":{"available_beds":"Available Beds","dashboard":"Dashboard","doctors":"Doctors","income_and_expense_report":"Income and Expense Report","income_and_expense_reports":"Income and Expense Reports","no_enquiries_yet":"No Enquiries Yet","no_notice_yet":"No Notice Yet","notice_boards":"Notice Boards","patients":"Patients","title":"Title","total_advance_payments":"Advance Payment Amount","total_bills":"Bill Amount","total_invoices":"Invoice Amount","total_payments":"Payment Amount"},"death_report":{"case_id":"Case Id","date":"Date","death_report":"Death Report","death_report_details":"Death Report Details","death_reports":"Death Reports","description":"Description","doctor_name":"Doctor Name","edit_death_report":"Edit Death Report","new_death_report":"New Death Report","patient_name":"Patient Name"},"death_reports":"Death Reports","department":"Department","departments":"Departments","diagnosis_category":{"category_name":"Category name","description":"Description","diagnosis_categories":"Diagnosis Categories","diagnosis_category":"Diagnosis Category","diagnosis_category_details":"Diagnosis Category Details","edit_diagnosis_category":"Edit Diagnosis Category","new_diagnosis_category":"New Diagnosis Category"},"doc_type":{"edit_doc_type":"Edit Document Type","name":"Name","new_doc_type":"New Document Type"},"doctor":{"doctor_details":"Doctor Details","edit_doctor":"Edit Doctor","name":"Name","new_doctor":"New Doctor","specialist":"Specialist"},"doctor_department":{"description":"Description","doctor_department":"Doctor Department","doctor_department_details":"Doctor Department Details","doctor_departments":"Doctor Departments","edit_doctor_department":"Edit Doctor Department","new_doctor_department":"New Doctor Department","title":"Title"},"doctor_departments":"Doctor Departments","doctor_opd_charge":{"doctor":"Doctor","doctor_name":"Doctor Name","doctor_opd_charge":"Doctor OPD Charge","edit_doctor_opd_charge":"Edit Doctor OPD Charge","new_doctor_opd_charge":"New Doctor OPD Charge","standard_charge":"Standard Charge"},"doctor_opd_charges":"Doctor OPD Charges","doctors":"Doctors","doctors_list":"Doctors List","document":{"attachment":"Attachment","document":"Document","document_detail":"Document Details","document_type":"Document Type","document_type_details":"Document Type Details","documents":"Documents","download":"Download","edit_document":"Edit Document","new_document":"New Document","notes":"Notes","patient":"Patient","select_document_type":"Select Document Type","select_patient":"Select Patient","title":"Title","uploaded_by":"Uploaded By","view":"View"},"document_types":"Document Types","documents":"Documents","email":{"attachment":"Attachment","message":"Message","subject":"Subject","to":"To"},"employee_payroll":{"allowance":"Allowance","basic_salary":"Basic Salary","deductions":"Deductions","edit_employee_payroll":"Edit Employee Payroll","employee":"Employee","employee_name":"Employee Name","employee_payroll":"Employee Payroll","employee_payroll_details":"Employee Payroll Details","employee_payrolls":"Employee Payrolls","month":"Month","net_salary":"Net Salary","new_employee_payroll":"New Employee Payroll","not_paid":"Not Paid","paid":"Paid","payroll_id":"Payroll Id","role":"Role","sr_no":"Sr No","year":"Year"},"employee_payrolls":"Employee Payrolls","enquiries":"Enquiries","enquiry":{"contact":"Contact","email":"Email","enquiry_details":"Enquiry Details","enquiry_send_successfully":"Enquiry send successfully","message":"Message","name":"Name","not_viewed":"Not Viewed","read":"Read","received_on":"Received On","send_enquiry":"Send Enquiry","type":"Type","unread":"Unread","viewed_by":"Viewed By"},"expense":{"amount":"Amount","attachment":"Attachment","choose":"Choose","date":"Date","description":"Description","document_error":"The document must be a file of type: jpeg, jpg, png, pdf, doc, docx.","download":"Download","edit_expense":"Edit Expense","expense":"Expense","expense_details":"Expense Details","expense_head":"Expense Head","invoice_number":"Invoice Number","name":"Name","new_expense":"New Expense","select_expense_head":"Select Expense Head"},"expenses":"Expenses","facebook_url":"Facebook URL","file_name":"File Name","finance":"Finances","front_cms":"Front CMS","front_cms_services":"Front CMS Services","front_office":"Front Office","front_service":"Front Service","front_services":{"edit_service":"Edit Service","new_service":"New Service"},"front_setting":{"about_us_description":"Description","about_us_details":"About Us Details","about_us_image":"Image","about_us_mission":"Mission","about_us_title":"Title","appointment_details":"Appointment Details","front_setting_details":"Front Setting Details","home_page_box_description":"Home Page Box Description","home_page_box_title":"Home Page Box Title","home_page_certified_box_description":"Home Page Certified Box Description","home_page_certified_box_title":"Home Page Certified Box Title","home_page_certified_doctor_description":"Home Page Certified Doctor Description","home_page_certified_doctor_image":"Home Page Certified Doctor Image","home_page_certified_doctor_text":"Home Page Certified Doctor Text","home_page_certified_doctor_title":"Home Page Certified Doctor Title","home_page_description":"Home Page Description","home_page_experience":"Home Page Experience","home_page_image":"Home Page Image","home_page_step_1_description":"Home Page Step 1 Description","home_page_step_1_title":"Home Page Step 1 Title","home_page_step_2_description":"Home Page Step 2 Description","home_page_step_2_title":"Home Page Step 2 Title","home_page_step_3_description":"Home Page Step 3 Description","home_page_step_3_title":"Home Page Step 3 Title","home_page_step_4_description":"Home Page Step 4 Description","home_page_step_4_title":"Home Page Step 4 Title","home_page_title":"Home Page Title","privacy_policy":"Privacy Policy","terms_condition_details":"T&C Details","terms_conditions":"Terms & Conditions"},"front_settings":"Front Settings","general":"General","hospital_activities":"Hospital Activities","hospital_blood_bank":{"blood_bank":"Blood Bank","blood_bank_details":"Blood Bank Details","blood_banks":"Blood Banks","blood_group":"Blood Group","edit_blood_group":"Edit Blood Group","new_blood_group":"New Blood Group","remained_bags":"Remained Bags"},"hospital_charges":"Hospital Charges","hospital_schedule":"Hospital Schedule","hospital_schedules":{"exists_doctor_schedule":"Some doctors have scheduled their days in given unchecked days, so are you sure you want to perform this operation?"},"icon":"Icon","income":"Income","incomes":{"amount":"Amount","attachment":"Attachment","choose":"Choose","date":"Date","description":"Description","document_error":"The document must be a file of type: jpeg, jpg, png, pdf, doc, docx.","download":"Download","edit_income":"Edit Income","income_details":"Income Details","income_head":"Income Head","incomes":"Incomes","invoice_number":"Invoice Number","name":"Name","new_income":"New Income","select_income_head":"Select Income Head"},"instagram_url":"Instagram URL","insurance":{"discount":"Discount","disease_details":"Disease Details","diseases_charge":"Diseases charge","diseases_name":"Diseases Name","edit_insurance":"Edit Insurance","hospital_rate":"Hospital Rate","insurance":"Insurance","insurance_code":"Insurance Code","insurance_details":"Insurance Details","insurance_no":"Insurance No","insurances":"Insurances","new_insurance":"New Insurance","remark":"Remark","service_tax":"Service Tax","total_amount":"Total Amount"},"insurances":"Insurances","inventory":"Inventories","investigation_report":{"attachment":"Attachment","birth_date_validation":"Investigation report date should not be smaller than patient birth date.","date":"Date","description":"Description","doctor":"Doctor","edit_investigation_report":"Edit Investigation Report","investigation_report":"Investigation Report","investigation_report_details":"Investigation Report Details","investigation_reports":"Investigation Reports","new_investigation_report":"New Investigation Report","patient":"Patient","title":"Title"},"investigation_reports":"Investigation Reports","invoice":{"account_name":"Account Name","add":"Add","amount":"Amount","description":"Description","discount":"Discount","edit":"Edit","edit_invoice":"Edit Invoice","hospital_address":"Hospital Address","invoice":"Invoice","invoice_date":"Invoice Date","invoice_details":"Invoice Details","invoice_id":"Invoice Id","invoices":"Invoices","new_invoice":"New Invoice","not_paid":"Not Paid","paid":"Paid","patient":"Patient","patient_id":"Patient Id","price":"Price","print_invoice":"Print Invoice","qty":"Qty","sub_total":"Sub Total","total":"Total Amount"},"invoices":"Invoices","ipd_bill":{"discharge_patient":"Discharge Patient","discount_in_number":"Discount In Number","discount_in_percentage":"Discount In Percentage","gross_total":"Gross Total","net_payable_amount":"Net Payable Amount","other_charges":"Other Charges","paid_amount":"Paid Amount","tax_in_number":"Tax In Number","tax_in_percentage":"Tax In Percentage","total_charges":"Total Charges"},"ipd_charges":"Charges","ipd_consultant_register":"Consultant Instruction","ipd_diagnosis":"Diagnosis","ipd_opd":"IPD\/OPD","ipd_patient":{"admission_date":"Admission Date","bed_id":"Bed","bed_type_id":"Bed Type","bill_status":"Bill Status","bp":"Blood Pressure","case_id":"Case","doctor_id":"Doctor","edit_ipd_patient":"Edit IPD Patient","height":"Height","ipd_number":"IPD No","ipd_patient":"IPD Patient","ipd_patient_details":"IPD Patient Details","ipd_patients":"IPD Patients","is_old_patient":"Is Old Patient","new_ipd_patient":"New IPD Patient","notes":"Notes","patient_id":"Patient","symptoms":"Symptoms","the_bed_field_is_required":"The bed field is required.","the_case_field_is_required":"The case field is required.","weight":"Weight"},"ipd_patient_charges":{"applied_charge":"Applied Charge","charge_category_id":"Charge Category","charge_id":"Code","charge_type_id":"Charge Type","date":"Date","edit_charge":"Edit Charges","new_charge":"Add Charges","standard_charge":"Standard Charge"},"ipd_patient_consultant_register":{"applied_date":"Applied Date","doctor_id":"Doctor","edit_consultant_register":"Edit Consultant Instruction","instruction":"Instruction","instruction_date":"Instruction Date","new_consultant_register":"Add Consultant Instruction"},"ipd_patient_diagnosis":{"description":"Description","document":"Document","edit_ipd_diagnosis":"Edit Diagnosis","new_ipd_diagnosis":"Add Diagnosis","report_date":"Report Date","report_type":"Report Type"},"ipd_patient_prescription":{"category_id":"Medicine Category","dosage":"Dosage","edit_prescription":"Edit Prescription","footer_note":"Footer Note","header_note":"Header Note","instruction":"Instruction","ipd_no":"IPD No","medicine_id":"Medicine","new_prescription":"Add Prescription","prescription_details":"Prescription Details","print_prescription":"Print Prescription"},"ipd_patient_timeline":{"date":"Date","description":"Description","document":"Document","edit_ipd_timeline":"Edit Timeline","new_ipd_timeline":"Add Timeline","no_timeline_found":"No TimeLine Found","title":"Title","visible_to_person":"Visible To Person"},"ipd_patients":"IPD Patients","ipd_payment":"IPD Payment","ipd_payments":{"add_ipd_payment":"Add IPD Payment","edit_ipd_payment":"Edit IPD Payment","make_payment":"Make Payment","payment_mode":"Payment Mode"},"ipd_prescription":"Prescriptions","ipd_timelines":"Timelines","issued_item":{"are_you_sure_want_to_return_this_item":"Are you sure want to return this item","available_quantity":"Available Quantity","department_id":"User Type","description":"Description","edit_issued_item":"Edit Issued Item","issued_by":"Issue By","issued_date":"Issue Date","issued_item":"Issued Item","issued_item_details":"Issued Items Details","issued_items":"Issued Items","item":"Item","item_category":"Item Category","item_return":"Return Item","item_returned":"Returned","new_issued_item":"New Issued Item","quantity":"Quantity","return_date":"Return Date","user_id":"Issue To"},"issued_items":"Issued Items","item":{"available_quantity":"Available Quantity","description":"Description","edit_item":"Edit Item","item":"Item","item_category":"Item Category","item_details":"Item Details","items":"Items","name":"Name","new_item":"New Item","unit":"Unit"},"item_category":{"edit_item_category":"Edit Item Category","item_categories":"Item Categories","item_category":"Item Category","name":"Name","new_item_category":"New Item Category"},"item_stock":{"attachment":"Attachment","description":"Description","edit_item_stock":"Edit Item Stock","item":"Item Name","item_category":"Item Category","item_stock":"Item Stock","item_stock_details":"Item Stock Details","item_stocks":"Item Stocks","new_item_stock":"New Item Stock","purchase_price":"Purchase Price","quantity":"Quantity","store_name":"Store Name","supplier_name":"Supplier Name"},"items":"Items","items_categories":"Items Categories","items_stocks":"Item Stocks","lab_tech":{"edit_lab_tech":"Edit Lab Technician","lab_tech_detail":"Lab Technician Details","lab_technician":"Lab Technician","new_lab_tech":"New Lab Technician"},"lab_technicians":"Lab Technicians","language":{"Arabic":"Arabic","Chinese":"Chinese","English":"English","French":"French","German":"German","Portuguese":"Portuguese","Russian":"Russian","Spanish":"Spanish","Turkish":"Spanish"},"linkedIn_url":"LinkedIn URL","live_consultation":{"add_credential":"Add Credential","client_video":"Client Video","consultation_date":"Consultation Date","consultation_duration_minutes":"Consultation Duration Minutes","consultation_title":"Consultation Title","created_by":"Created By","created_for":"Created For","disabled":"Disabled","duration":"Duration (in minutes)","edit_live_consultation":"Edit Live Consultation","edit_live_meeting":"Edit Live Meeting","enable":"Enable","host_video":"Host Video","join_now":"Join Now","live_consultation":"Live Consultancy","new_live_consultation":"New Live Consultation","new_live_meeting":"New Live Meeting","staff_list":"Staff List","start_now":"Start Now","type":"Type","type_number":"Type Number","zoom_api_key":"Zoom Api Key","zoom_api_secret":"Zoom API Secret"},"live_consultations":"Live Consultations","live_meeting":"Live Meeting","live_meetings":"Live Meetings","mail":"Mail","make_an_appointment":"Make An Appointment","medicine":{"brand":"Brand","brand_name":"Brand Name","buying_price":"Buying Price","category":"Category","category_id":"Category Id","description":"Description","dosage":"Dosage","duration":"Duration","edit_medicine":"Edit Medicine","edit_medicine_brand":"Edit Medicine Brand","edit_medicine_category":"Edit Medicine Category","medicine":"Medicine","medicine_brands":"Medicine Brands","medicine_brands_details":"Medicine Brand Details","medicine_category":"Medicine Category","medicine_category_details":"Medicine Category Details","medicine_details":"Medicine Details","medicine_name":"Medicine Name","medicines":"Medicines","name":"Name","new_brand":"New Brand","new_medicine":"New Medicine","new_medicine_brand":"New Medicine Brand","new_medicine_category":"New Medicine Category","salt_composition":"Salt Composition","selling_price":"Selling Price","side_effects":"Side Effects"},"medicine_brands":"Medicine Brands","medicine_categories":"Medicine Categories","medicines":"Medicines","message":{"date":"Date","message":"Message","messages":"Messages","messages_details":"Message Details","new_message":"New Message","select_user":"Select User","send_to":"Send To","sender_name":"Sender Name","subject":"Subject"},"months":{"apr":"April","aug":"August","dec":"December","feb":"February","jan":"January","july":"July","jun":"June","mar":"March","may":"May","nov":"November","oct":"October","sep":"September"},"my_payroll":{"allowance":"Allowance","basic_salary":"Basic Salary","deductions":"Deductions","my_payrolls":"My Payrolls","net_salary":"Net Salary"},"my_payrolls":"My Payrolls","new_patient":"New Patient","no_data_available":"No data available in table","notice_board":{"created_at":"Created At","description":"Description","details":"Notice Board Details","edit":"Edit Notice Board","new":"New Notice Board","notice_board":"Notice Board","title":"Title"},"notice_boards":"Notice Boards","notification":{"mark_all_as_read":"Mark All As Read","notifications":"Notifications","you_don`t_have_any_new_notification":"You don't have any new notification"},"nurse":{"birth_date":"Birth Date","choose":"Choose","edit_nurse":"Edit Nurse","new_nurse":"New Nurse","nurse":"Nurse","nurse_details":"Nurse Details","phone_no":"Phone No"},"nurses":"Nurses","old_patient":"Old Patient","opd_diagnosis":"OPD Diagnosis","opd_patient":{"appointment_date":"Appointment Date","edit_opd_patient":"Edit OPD Patient","new_opd_patient":"New OPD Patient","opd_number":"OPD No","opd_patient":"OPD Patient","opd_patient_details":"OPD Patient Details","opd_patients":"OPD Patients","revisits":"Revisit","total_visits":"Total Visits","visits":"Visits"},"opd_patients":"OPD Patients","opd_payments":{"add_opd_payment":"Add Opd Payment","edit_opd_payment":"Edit Opd Payment","make_payment":"Make Payment","payment_mode":"Payment Mode"},"opd_timeline":"OPD Timeline","operation_report":{"case_id":"Case Id","date":"Date","description":"Description","doctor_name":"Doctor Name","edit_operation_report":"Edit Operation Report","new_operation_report":"New Operation Report","operation_report":"Operation Report","operation_report_details":"Operation Report Details","operation_reports":"Operation Reports","patient_name":"Patient Name"},"operation_reports":"Operation Reports","overview":"Overview","package":{"amount":"Amount","description":"Description","discount":"Discount","edit_package":"Edit Package","name":"Name","new_package":"New Package","package":"Package","package_details":"Package Details","packages":"Packages","qty":"Qty","rate":"Rate","select_service":"Select Service","service":"Service","total_amount":"Total Amount"},"packages":"Packages","pathologies":"Pathology","pathology_categories":"Pathology Category","pathology_category":{"edit_pathology_category":"Edit Pathology Category","name":"Name","new_pathology_category":"New Pathology Category","pathology_categories":"Pathology Categories"},"pathology_test":{"category_name":"Category Name","charge_category":"Charge Category","edit_pathology_test":"Edit Pathology Test","method":"Method","new_pathology_test":"New Pathology Test","pathology_test_details":"Pathology Test Details","pathology_tests":"Pathology Test","report_days":"Report Days","short_name":"Short Name","standard_charge":"Standard Charge","subcategory":"Sub Category","test_name":"Test Name","test_type":"Test Type","unit":"Unit"},"pathology_tests":"Pathology Tests","patient":{"edit_patient":"Edit Patient","new_patient":"New Patient","patient_details":"Patient Details","total_admissions":"Total Admissions","total_appointments":"Total Appointments","total_cases":"Total Cases"},"patient_admission":{"admission_date":"Admission Date","agent_name":"Agent Name","bed":"Bed","details":"Patient Admission Details","discharge_date":"Discharge Date","doctor":"Doctor","doctor_name":"Doctor Name","edit_patient_admission":"Edit Patient Admission","guardian_address":"Guardian Address","guardian_contact":"Guardian Contact","guardian_name":"Guardian Name","guardian_relation":"Guardian Relation","insurance":"Insurance","insurance_name":"Insurance Name","new_patient_admission":"New Patient Admission","package":"Package","package_name":"Package Name","patient":"Patient","patient_admission":"Patient Admission","patient_admission_id":"Patient Admission Id","patient_name":"Patient Name","policy_no":"Policy No"},"patient_admissions":"Patient Admissions","patient_appointment":"Patient Appointment","patient_diagnosis_test":{"action":"Action","add_other_diagnosis_property":"Add other diagnosis property","age":"Age","average_glucose":"Average glucose","blood_pressure":"Blood Pressure","cholesterol":"Cholesterol","create_patient_diagnosis_test":"Create Patient Diagnosis Test","created_at":"Created at","diabetes":"Diabetes","diagnosis":"Diagnosis","diagnosis_category":"Diagnosis Category","diagnosis_property_name":"Diagnosis Property Name","diagnosis_property_value":"Diagnosis Property Value","diagnosis_test":"Diagnosis Tests","doctor":"Doctor","doctor_name":"Doctor name","edit_patient_diagnosis_test":"Edit Patient Diagnosis Test","fasting_blood_sugar":"Fasting Blood Sugar","height":"Height","new_patient_diagnosis_test":"New Patient Diagnosis Test","other_diagnosis_property":"Other diagnosis property","patient":"Patient","patient_diagnosis_test":"Patient Diagnosis Tests","patient_diagnosis_test_details":"Patient Diagnosis Test Details","patient_name":"Patient name","print_diagnosis_test":"Print Diagnosis Test","report_number":"Report number","urine_sugar":"Urine Sugar","weight":"Weight"},"patients":"Patients","patients_case_details":"Patients Case Details","patients_cases":"Patients Cases","payment":{"account":"Account","account_name":"Account Name","amount":"Amount","description":"Description","edit_payment":"Edit Payment","new_payment":"New Payment","pay_to":"Pay To","payment":"Payment","payment_date":"Payment Date","payment_details":"Payment Details","payment_reports":"Payment Reports","payments":"Payments"},"payments":"Payments","pharmacist":{"edit_pharmacist":"Edit Pharmacist","new_pharmacist":"New Pharmacist","pharmacist_details":"Pharmacist Details","pharmacists":"Pharmacist"},"pharmacists":"Pharmacists","postal":{"address":"Address","date":"Date","dispatch":"Dispatch","edit_dispatch":"Edit Dispatch","edit_receive":"Edit Receive","from_title":"From Title","new_dispatch":"New Dispatch","new_receive":"New Receive","postal":"Postal","receive":"Receive","reference_no":"Reference Number","to_title":"To Title"},"postal_dispatch":"Postal Dispatch","postal_receive":"Postal Receive","prescription":{"accident":"Accident","advice":"Advice","after_meal":"After Meal","before_meal":"Before Meal","breast_feeding":"Breast Feeding","comment":"Comment","current_medication":"Current Medication","days":"Days","diabetic":"Diabetic","duration":"Duration","edit_prescription":"Edit Prescription","female_pregnancy":"Female Pregnancy","food_allergies":"Food Allergies","health_insurance":"Health Insurance","heart_disease":"Heart Disease","high_blood_pressure":"High Blood Pressure","low_income":"Low Income","medical_history":"Medical History","medicine_name":"Medicine Name","month":"Month","new_medicine":"New Medicine","new_prescription":"New Prescription","next_visit":"Next Visit","no_data_available":"No Data Available","others":"Others","patient":"Patient","physical_information":"Physical Information","plus_rate":"Pulse Rate","prescription":"Prescription","prescription_details":"Prescription Details","prescriptions":"Prescriptions","problem":"Problem","problem_description":"Problem Description","reference":"Reference","rx":"Rx","surgery":"Surgery","temperature":"Temperature","tendency_bleed":"Tendency Bleed","test":"Test","time":"Time","year":"Year"},"prescriptions":"Prescriptions","profile":{"change_language":"Change Language","edit_profile":"Edit Profile","email":"Email","first_name":"First Name","language":"Language","last_name":"Last Name","phone":"Phone","profile":"Profile"},"radiologies":"Radiology","radiology_categories":"Radiology Category","radiology_category":{"edit_radiology_category":"Edit Radiology Category","name":"Name","new_radiology_category":"New Radiology Category","radiology_categories":"Radiology Categories"},"radiology_test":{"category_name":"Category Name","charge_category":"Charge Category","edit_radiology_test":"Edit Radiology Test","new_radiology_test":"New Radiology Test","radiology_test_details":"Radiology Test Details","radiology_tests":"Radiology Test","report_days":"Report Days","short_name":"Short Name","standard_charge":"Standard Charge","subcategory":"Sub Category","test_name":"Test Name","test_type":"Test Type"},"radiology_tests":"Radiology Tests","receptionist":{"edit_receptionist":"Edit Receptionist","new_receptionist":"New Receptionist","receptionist":"Receptionist","receptionist_details":"Receptionist Details","receptionists":"Receptionists"},"receptionists":"Receptionists","reports":"Reports","role":{"edit_role":"Edit Role","new_role":"New Role"},"roles":"Roles","schedule":{"available_from":"Available From","available_on":"Available On","available_to":"Available To","details":"Schedule Details","doctor_name":"Doctor Name","edit":"Edit Schedule","new":"New Schedule","per_patient_time":"Per Patient Time","select_doctor_name":"Select Doctor Name","select_serial_visibility":"Select Serial Visibility","sequential":"Sequential","serial_visibility":"Serial Visibility","timestamp":"Timestamp"},"schedule_label":"Schedule","schedules":"Schedules","service":{"edit_service":"Edit Service","given":"Given","new_service":"New Service","not_given":"Not Given","quantity":"Quantity","rate":"Rate","service_details":"Service Details"},"services":"Services","setting":{"about_us":"About Us","address":"Hospital Address","app_logo":"App Logo","app_name":"App Name","company_name":"Company Name","country_code":"Country Code","currency":"Current Currency","favicon":"Favicon","favicon_validation":"The image must be of pixel 34 x 34.","hospital_email":"Hospital Email","hospital_from_day":"Hospital From Day","hospital_from_time":"Hospital From Time","hospital_phone":"Hospital Phone","image_validation":"The image must be of pixel 90 x 60.","social_details":"Social Details"},"settings":"Settings","short_description":"Short Description","sidebar_setting":"Modules Setting","sms":{"date":"Date","message":"Message","new_sms":"New SMS","only_user_with_registered_phone_will_display":"(Only Users with a registered phone will display.)","phone_number":"Phone Number","role":"Role","send":"Send","send_by":"Send By","send_sms_by_number_directly":"Send SMS by number directly","send_to":"Send To","sms":"SMS","sms_details":"SMS Details"},"testimonial":{"description":"Description","edit_testimonial":"Edit Testimonial","name":"Name","new_testimonial":"New Testimonial","profile_error":"The document must be a file of type: jpeg, jpg, png.","testimonial":"Testimonial","testimonial_detail":"Testimonial Detail"},"testimonials":"Testimonials","twitter_url":"Twitter URL","user":{"address1":"Address 1","address2":"Address 2","address_details":"Address Details","address_not_found":"No Address details found","blood_group":"Blood Group","change_password":"Change Password","city":"City","designation":"Designation","dob":"Date Of Birth","edit_profile":"Edit Profile","edit_user":"Edit User","education":"Education","email":"Email","email_verified_successfully":"Email Verified successfully.","female":"Female","first_name":"First Name","gender":"Gender","invalid_password":"Current password is invalid.","last_name":"Last Name","logout":"Logout","male":"Male","name":"Name","new_user":"New User","password":"Password","password_confirmation":"Confirm Password","phone":"Phone","qualification":"Qualification","select_blood_group":"Select Blood Group","status":"Status","user_details":"User Details","usrs":"User","validate_confirm_password":"The password and confirm password must be matched.","validate_min_character_password":"Password must contain at least 6 characters.","zip":"Zip"},"users":"Users","vaccinated_patient":{"add_vaccinate_patient":"Add Vaccinated Patient","description":"Description","does_no":"Dose No","dose_given_date":"Dose Given Date","edit_vaccinate_patient":"Edit Vaccinated Patient","new_vaccinate_patient":"New Vaccinated Patient","patient":"Patient","serial_no":"Serial No","vaccinate_patient":"Vaccinate Patient","vaccinated_patient":"Vaccinated Patient","vaccination":"Vaccination","vaccination_name":"Vaccination Name","vaccine":"Vaccine"},"vaccinated_patients":"Vaccinated Patients","vaccination":{"brand":"Brand","edit_vaccination":"Edit Vaccination","manufactured_by":"Manufactured By","name":"Name","new_vaccination":"New Vaccination","vaccinated":"Vaccinated","vaccinations":"Vaccination"},"vaccinations":"Vaccinations","valid":"Valid","verification":{"another_verify_request":"click here to request another","verify_message":"Before proceeding, please check your email for a verification link.If you did not receive the email,","verify_your_email_address":"Verify Your Email Address"},"visitor":{"date":"Date","edit":"Edit Visitor","id_card":"ID Card","in_time":"In Time","name":"Name","new":"New Visitor","note":"Note","number_of_person":"Number Of Person","out_time":"Out Time","phone":"Phone","purpose":"Purpose","visitor":"Visitor"},"visitors":"Visitors","web_appointment":{"call_now_and_get_a_free_consulting":"Call Now and Get a Free Consulting","enter_confirm_password":"Enter Confirm Password","enter_description":"Enter Description","enter_your_first_name":"Enter your First Name","enter_your_last_name":"Enter your Last Name","enter_your_password":"Enter your Password","make_an_appointment":"Make an Appointment","select_department":"Select Department","select_doctor":"Select Doctor","select_time":"Select Date"},"web_contact":{"call_today":"Call Today","contact_no":"Contact No","enter_your_email":"Enter your email","enter_your_name":"Enter your name","open_hours":"Open Hours","our_location":"Our Location","phone_number":"Phone Number","please_enter_your_phone_number":"Please enter your phone number","select_enquiry":"Select Enquiry","send_message":"Send Message","send_us_a_message":"Send Us a Message","type_your_message":"Type your message","write_your_message":"Write your message","your_email":"Your Email","your_message":"Your Message","your_name":"Your Name"},"web_home":{"4_easy_step_and_get_the_world_best_treatment":"4 Easy Step and Get the World Best Treatment","about_us":"About Us","available_doctors":"Available Doctors","book_an_appointment":"Book an Appointment","book_appointment":"Book Appointment","book_now":"Book Now","contact":"Contact","contact_doctors":"Contact Doctor","contact_hospital":"Contact Hospital","doctors":"Doctors","doctors_nurses":"Doctors & Nurses","easy_solutions":"Easy Solutions","happy_patients":"Happy Patients","home":"Home","make_appointment":"Make Appointment","our_services":"Our Services","our_testimonials":"Our Testimonials","patients":"Patients","patients_beds":"Patients Beds","privacy_policy":"Privacy Policy","professional_doctors":"Professional Doctors","select_doctor":"Select Doctor","select_doctors":"Select Doctors","services":"Services","sign_up":"Sign Up","terms_of_service":"Terms of Service","testimonials":"Testimonials","we_are_experienced_healthcare_professionals":"We are Experienced Healthcare Professionals","we_offer_different_services_to_improve_your_health":"We Offer Different Services To Improve Your Health","what_our_patient_say_about_medical_treatments":"What Our Patients Say About Our Medical Treatments","working_hours":"Working Hours","years_experience":"Years Experience"},"web_menu":{"about":"About","all_rights_reserved_by":"All Rights Reserved by","appointment":"Appointment","contact_information":"Contact Information","copyright":"Copyright","login":"Login","our_features":"Our Features","useful_link":"Useful Link","working_hours":"Working Hours"},"web_password":{"password_and_confirm_password_not_match":"Password and Confirm password not match.","please_fill_all_the_required_fields":"Please fill all the required fields."},"web_working_hours":{"no_yet_opening_hours":"No yet Opening Hours","opening_hours":"Opening Hours"},"weekdays":{"fri":"FRI","mon":"MON","sat":"SAT","sun":"SUN","thu":"THU","tue":"TUE","wed":"WED"}},"es.messages":{"about_us":"Acerca de nosotros","account":{"account":"Cuenta","account_details":"Detalles de la cuenta","accounts":"Cuentas","credit":"Cr\u00e9dito","debit":"D\u00e9bito","description":"Descripci\u00f3n","edit_account":"Editar cuenta","name":"Nombre","new_account":"Nueva cuenta","payments":"Pagos","status":"Estado","type":"Tipo"},"account_manager":"Administrador de cuenta","accountant":{"accountant_details":"Detalles del contador","accountants":"Contador","edit_accountant":"Editar contador","new_accountant":"Nuevo contador"},"accountants":"Contador","accounts":"Cuentas","admin":"Administradoras","admins":"Administradora","advanced_payment":{"advanced_payment":"Pago por adelantado","advanced_payment_details":"Detalles de pago anticipado","advanced_payments":"Pagos anticipados","amount":"Cantidad","date":"Fecha","edit_advanced_payment":"Editar pago anticipado","new_advanced_payment":"Nuevo anticipo","patient":"Paciente","patient_name":"Nombre del paciente","receipt_no":"Recibo No"},"advanced_payments":"Pagos anticipados","allow_file_type":"Tipos de archivos permitidos: png, jpg, jpeg.","ambulance":{"ambulance":"ambulancia","ambulance_details":"Detalles de ambulancia","ambulances":"ambulancias","driver_contact":"Contacto del conductor","driver_license":"Licencia de conducir","driver_name":"Nombre del conductor","edit_ambulance":"Editar ambulancia","is_available":"Est\u00e1 disponible","new_ambulance":"Nueva ambulancia","note":"nota","vehicle_model":"Modelo de veh\u00edculo","vehicle_number":"Numero de Veh\u00edculo","vehicle_type":"tipo de vehiculo","year_made":"A\u00f1o hecho"},"ambulance_call":{"ambulance_call":"Llamada de ambulancia","ambulance_call_details":"Detalles de la llamada de ambulancia","ambulance_calls":"Llamadas de ambulancia","amount":"Cantidad","date":"Fecha","driver_name":"Nombre del conductor","edit_ambulance_call":"Editar llamada de ambulancia","new_ambulance_call":"Nueva llamada de ambulancia","patient":"Paciente","vehicle_model":"Modelo de veh\u00edculo"},"ambulance_calls":"Llamadas de ambulancia","ambulances":"ambulancias","appointment":{"appointment_calendar":"Calendario de citas","appointment_details":"Detalles de la cita","appointment_exists":"El correo electr\u00f3nico del paciente ya existe","appointment_list":"Lista de citas","are_you_sure_want_to_cancel":"Seguro que quieres cancelar","are_you_sure_want_to_change":"Estas segura de querer cambiar","available_slot":"Espacio disponible","calendar_view":"Vista de calendario","change_status":"Cambiar Estado","changed_appointment":"Cita cambiada","completed":"Terminado","date":"Fecha","day":"D\u00eda","department_name":"Nombre del departamento","description":"Descripci\u00f3n","doctor":"M\u00e9dica","doctor_department":"Departamento m\u00e9dico","doctor_department_name":"Nombre del departamento m\u00e9dico","doctor_name":"Nombre del doctor","doctor_schedule_not_available_on_this_date":"Horario m\u00e9dico no disponible esta fecha.","edit_appointment":"Editar cita","has_been_cancelled":"ha sido cancelado.","has_been_changed":"Ha sido cambiada.","last_30_days":"\u00faltimos 30 d\u00edas","last_7_days":"Los \u00faltimos 7 d\u00edas","last_month":"El mes pasado","month":"Mes","new_appointment":"Nueva cita","no_available":"No disponible","old_patient_email_exists":"El correo electr\u00f3nico ya existe, seleccione paciente antiguo.","opd_date":"Fecha de opd","patient":"Paciente","patient_name":"Nombre del paciente","patient_not_exists_or_status_is_not_active":"La paciente no existe o el estado no est\u00e1 activo.","pending":"Pendiente","please_select_appointment_time_slot":"Seleccione la franja horaria de la cita","please_select_doctor":"Por favor seleccione doctora","please_select_doctor_department":"Por favor seleccione Departamento M\u00e9dico","this_month":"Este mes","this_week":"Esta semana","today":"Hoy","week":"Semana","yesterday":"El dia de ayer"},"appointment_calendar":"Nombrar. Calendario","appointments":"Citas","available_slot":"Espacio disponible","bed":{"add":"Agregar","available":"Disponible","bed":"Nueva cama","bed_details":"Detalles de la cama","bed_id":"ID de la cama","bed_type":"Tipo de cama","beds":"Camas","charge":"Cargo","description":"Descripci\u00f3n","edit_bed":"Editar cama","name":"Nombre","new_bed":"Nueva cama","new_bulk_bed":"Nueva cama masiva","not_available":"No disponible"},"bed_assign":{"assign_date":"Asignar fecha","assign_date_should_not_be_smaller_than_patient_birth_date":"La fecha de asignaci\u00f3n no debe ser menor que la fecha de nacimiento del paciente.","assigned":"Asignada","bed":"Cama","bed_assign":"Asignaci\u00f3n de cama","bed_assign_details":"Detalles de asignaci\u00f3n de cama","bed_assigns":"Asignaciones de cama","bed_name":"Nombre de cama","case_id":"ID del caso","description":"Descripci\u00f3n","discharge_date":"Fecha de alta","edit_bed_assign":"Editar asignaci\u00f3n de cama","ipd_patient_id":"ID de paciente de IPD","new_bed_assign":"Nueva asignaci\u00f3n de cama","not_assigned":"No asignado","patient_name":"Nombre del paciente"},"bed_assigns":"Asignaciones de cama","bed_management":"Gesti\u00f3n de camas","bed_mgt":"Administraci\u00f3n de la cama","bed_status":{"admission_date":"Fecha de admisi\u00f3n","assigned_beds":"Camas asignadas","available_beds":"Camas disponibles","bed_name":"Nombre de cama","bed_status":"Estado de la cama","gender":"G\u00e9nero","patient_name":"Nombre del paciente","phone":"Tel\u00e9fono"},"bed_type":{"bed_type":"Tipo de cama","bed_type_details":"Detalles del tipo de cama","bed_types":"Tipos de cama","description":"Descripci\u00f3n","edit_bed_type":"Editar tipo de cama","new_bed_type":"Nuevo tipo de cama","title":"T\u00edtulo"},"bed_types":"Tipos de cama","beds":"Camas","bill":{"add":"Agregar","admission_date":"Fecha de admisi\u00f3n","admission_id":"ID de admisi\u00f3n","amount":"Cantidad","bill":"Factura","bill_date":"Fecha de factura","bill_details":"Detalles de la factura","bill_id":"ID de factura","bill_summary":"Resumen de la factura","bills":"Facturas","calculate":"Calcular","cell_no":"Celda no","discharge_date":"Fecha de alta","doctor_name":"Nombre del doctor","edit":"Editar","edit_bill":"Editar factura","generate_bill":"Generar factura","insurance_name":"Nombre del seguro","item_name":"Nombre del elemento","new_bill":"Nueva factura","package_name":"Nombre del paquete","patient":"Paciente","patient_cell_no":"N\u00famero de celda del paciente","patient_dob":"DOB del paciente","patient_email":"Correo electr\u00f3nico del paciente","patient_gender":"Sexo del paciente","patient_name":"Nombre del paciente","policy_no":"No pol\u00edtica","price":"Precio","print_bill":"Imprimir factura","qty":"Cantidad","total_amount":"Cantidad total","total_days":"Total de d\u00edas","update_bill":"Actualizar factura"},"billing":"Facturaci\u00f3n","bills":"Facturas","birth_report":{"birth_report":"Informe de nacimiento","birth_report_details":"Detalles del informe de nacimiento","birth_reports":"Informes de nacimiento","case_id":"ID del caso","data_should_not_be_smaller_than_patient_birth_date":"La fecha no debe ser menor que la fecha de nacimiento del paciente.","date":"Fecha","description":"Descripci\u00f3n","doctor_name":"Nombre del doctor","edit_birth_report":"Editar informe de nacimiento","new_birth_report":"Nuevo informe de nacimiento","patient_birth_date_not_found":"Fecha de nacimiento del paciente no encontrada.","patient_name":"Nombre del paciente"},"birth_reports":"Informes de nacimiento","blood_bank":"Banco de sangre","blood_banks":"Bancos de sangre","blood_donation":{"bags":"Pantal\u00f3n","blood_donation":"Donaci\u00f3n de sangre","donor_name":"Nombre del donante","edit_blood_donation":"Editar donaci\u00f3n de sangre","last_donate_date":"\u00faltima fecha de donaci\u00f3n","new_blood_donation":"Nueva donaci\u00f3n de sangre"},"blood_donations":"Donaciones de sangre","blood_donor":{"age":"Edad","blood_donor":"Donante de sangre","blood_donor_details":"Detalles del donante de sangre","blood_donors":"Donantes de sangre","blood_group":"Grupo sangu\u00edneo","donation_date":"Fecha de donaci\u00f3n","edit_blood_donor":"Editar donante de sangre","gender":"G\u00e9nero","last_donation_date":"\u00daltima fecha de donaci\u00f3n","name":"Nombre","new_blood_donor":"Nuevo donante de sangre"},"blood_donors":"Donantes de sangre","blood_issue":{"amount":"Cantidad","blood_issue":"Problema de sangre","doctor_name":"Nombre del doctor","donor_name":"Nombre del donante","edit_blood_issue":"Editar problema de sangre","issue_date":"Fecha de asunto","new_blood_issue":"Nueva emisi\u00f3n de sangre","patient_name":"Nombre del paciente","remarks":"Observaciones"},"blood_issues":"Problemas de sangre","call_log":{"call_log":"Registro de llamadas","call_type":"Tipo de llamada","edit":"Editar registro de llamadas","follow_up_date":"Fecha de seguimiento","incoming":"Entrante","name":"Nombre","new":"Nuevo registro de llamadas","note":"Nota","outgoing":"Saliente","phone":"Tel\u00e9fono","received_on":"Recibido el"},"call_logs":"Registros de llamadas","case":{"case":"Caso","case_date":"Fecha del caso","case_details":"Detalles del caso","case_id":"ID del caso","date":"Fecha","description":"Descripci\u00f3n","doctor":"M\u00e9dico","edit_case":"Editar caso","fee":"Tarifa","new_case":"Nuevo caso","patient":"Paciente","phone":"Tel\u00e9fono"},"case_handler":{"case_handler":"Manejador de casos","case_handler_detail":"Detalles del manejador de casos","edit_case_handler":"Editar manejador de casos","new_case_handler":"Nuevo manejador de casos"},"case_handlers":"Manejadores de caso","case_manager":"Administrador de casos","cases":"Casos","change_password":{"change_password":"Cambiar la contrase\u00f1a","confirm_password":"confirmar Contrase\u00f1a","current_password":"Contrase\u00f1a actual","new_password":"Nueva contrase\u00f1a"},"charge":{"charge_category":"Cargo est\u00e1ndar","charge_details":"Detalles de carga","code":"C\u00f3digo","edit_charge":"Editar carga","new_charge":"Nueva carga","standard_charge":"Standard Charge"},"charge_categories":"Categor\u00edas de carga","charge_category":{"charge_categories":"Categor\u00edas de carga","charge_category_details":"Detalles de la categor\u00eda de carga","charge_type":"Tipo de carga","edit_charge_category":"Editar categor\u00eda de carga","new_charge_category":"Nueva categor\u00eda de carga"},"charges":"Cargos","cms":"CMS","common":{"action":"Acci\u00f3n","actions":"Comportamiento","active":"Activo","add":"Agregar","address":"Habla a","apply":"aplicar","are_you_sure_want_to_delete_this":"\u00bfEst\u00e1s segura de que quieres eliminar esto?( ","back":"Atr\u00e1s","cancel":"Cancelar","canceled":"Cancelada","cant_be_deleted":"no se puede borrar","choose":"Escoger","confirm":"Confirmar","created_at":"Creado el","created_on":"Creado el","custom":"Disfraz","de_active":"Inactivo","delete":"Eliminar","deleted":"Eliminada","deleted_successfully":"borrado exitosamente","description":"Descripci\u00f3n","detail":"detalles","edit":"Editar","export_to_excel":"Exportar a Excel","filter_options":"Opciones de filtro","from":"de","has_been_deleted":"ha sido eliminado.","invalid_country_code":"C\u00f3digo de pa\u00eds no v\u00e1lido","invalid_number":"N\u00famero invalido","is_available":"Est\u00e1 disponible","last_updated":"\u00daltima actualizaci\u00f3n","n\/a":"N \/ A","name":"Nombre","new":"Nuevo","next":"Nest","no":"No","not_found":"extraviado","ok":"OK","previous":"Previous","profile":"Perfil","reset":"Reiniciar","save":"Guardar","saved_successfully":"Guardado exitosamente.","search":"B\u00fasqueda","status":"Estado","status_updated_successfully":"Estado actualizado correctamente.","this_action_is_not_allowed_for_default_record":"Esta acci\u00f3n no est\u00e1 permitida para el registro predeterminado.","to":"A","too_long":"Demasiado larga","too_short":"Demasiado corta","total":"Total","updated_at":"\u00daltima actualizaci\u00f3n","updated_successfully":"actualizado con \u00e9xito","view":"Ver","view_attachment":"Vea el archivo adjunto","yes":"Si"},"contact_us":"Cont\u00e1ctenos","currency":{"add_currency_code_as_per_three_letter_iso_code":"Agregue el c\u00f3digo de moneda seg\u00fan el c\u00f3digo ISO de tres letras","currency":"Divisa","currency_code":"C\u00f3digo de moneda","currency_icon":"Icono de moneda","currency_name":"Nombre de moneda","edit_currency":"Editar moneda","new_currency":"Nueva moneda","you_can_find_out_here":"puedes averiguarlo aqu\u00ed"},"currency_setting":"Monedas","dashboard":{"available_beds":"Camas disponibles","dashboard":"Tablero","doctors":"Doctoras","income_and_expense_report":"Informe de ingresos y gastos","income_and_expense_reports":"Informes de ingresos y gastos","no_enquiries_yet":"A\u00fan no hay consultas","no_notice_yet":"Sin aviso todav\u00eda","notice_boards":"Tablones de anuncios","patients":"Pacientes","title":"T\u00edtulo","total_advance_payments":"Monto de anticipo","total_bills":"Total de la factura","total_invoices":"Monto de la factura","total_payments":"Monto del pago"},"death_report":{"case_id":"ID del caso","date":"Fecha","death_report":"Informe de defunci\u00f3n","death_report_details":"Detalles del informe de defunci\u00f3n","death_reports":"Informes de defunci\u00f3n","description":"Descripci\u00f3n","doctor_name":"Nombre del doctor","edit_death_report":"Editar informe de defunci\u00f3n","new_death_report":"Nuevo informe de defunci\u00f3n","patient_name":"Nombre del paciente"},"death_reports":"Informes de defunci\u00f3n","department":"Departamento","departments":"Departamentos","diagnosis_category":{"category_name":"Nombre de la categor\u00eda","description":"Descripci\u00f3n","diagnosis_categories":"Categor\u00eda de diagn\u00f3stico","diagnosis_category":"Categor\u00eda de diagn\u00f3stico","diagnosis_category_details":"Detalles de la categor\u00eda de diagn\u00f3stico","edit_diagnosis_category":"Editar categor\u00eda de diagn\u00f3stico","new_diagnosis_category":"Nueva categor\u00eda de diagn\u00f3stico"},"doc_type":{"edit_doc_type":"Editar tipo de documento","name":"Nombre","new_doc_type":"Nuevo tipo de documento"},"doctor":{"doctor_details":"Detalles del m\u00e9dico","edit_doctor":"Editar Doctor","new_doctor":"Nuevo doctor","specialist":"Especialista"},"doctor_department":{"description":"Descripci\u00f3n","doctor_department":"Departamento m\u00e9dico","doctor_department_details":"Detalles del departamento m\u00e9dico","doctor_departments":"Departamentos m\u00e9dicos","edit_doctor_department":"Editar departamento m\u00e9dico","new_doctor_department":"Nuevo departamento m\u00e9dico","title":"T\u00edtulo"},"doctor_departments":"Departamentos m\u00e9dicos","doctor_opd_charge":{"doctor":"M\u00e9dico","doctor_name":"Nombre Del Doctor","doctor_opd_charge":"Doctora OPD Cargo","edit_doctor_opd_charge":"Editar Doctor OPD Cargo","new_doctor_opd_charge":"Nuevo Doctor Cargo OPD","standard_charge":"Cargo Est\u00e1ndar"},"doctor_opd_charges":"Doctor OPD Cargos","doctors":"Doctores","doctors_list":"Lista de m\u00e9dicos","document":{"attachment":"Adjunto archivo","document":"Documento","document_detail":"Detalles del Documento","document_type":"Tipo de documento","document_type_details":"Detalles del tipo de documento","download":"Descargar","edit_document":"Editar documento","new_document":"Nuevo documento","notes":"Notas","patient":"Paciente","select_document_type":"Seleccionar tipo de documento","select_patient":"Seleccionar paciente","title":"T\u00edtulo","uploaded_by":"Subido por"},"document_types":"Tipos de documento","documents":"Documentos","email":{"attachment":"Archivos adjuntos","message":"Mensaje","subject":"Sujeta","to":"A"},"employee_payroll":{"allowance":"Permiso","basic_salary":"Salario b\u00e1sico","deductions":"Deducciones","edit_employee_payroll":"Editar n\u00f3mina de empleados","employee":"Empleado","employee_name":"Nombre de empleado","employee_payroll":"N\u00f3mina de empleados","employee_payroll_details":"Detalles de la n\u00f3mina del empleado","employee_payrolls":"N\u00f3minas de empleados","month":"Mes","net_salary":"Salario neto","new_employee_payroll":"Nueva n\u00f3mina de empleados","not_paid":"No pagada","paid":"Pagada","payroll_id":"Id. de n\u00f3mina","role":"Papel","sr_no":"No Se\u00f1or","year":"A\u00f1o"},"employee_payrolls":"N\u00f3minas de empleados","enquiries":"Consultas","enquiry":{"contact":"Contacto","email":"Email","enquiry_details":"Detalles de la consulta","enquiry_send_successfully":"Consulta enviada con \u00e9xito","message":"Mensaje","name":"Nombre","not_viewed":"No vista","read":"Leer","received_on":"Recibido el","send_enquiry":"Enviar consulta","type":"Tipo","unread":"No le\u00edda","viewed_by":"Visto por"},"expense":{"amount":"Cantidad","attachment":"Adjunto Archivo","choose":"Escoger","date":"Fecha","description":"descripci\u00f3n","document_error":"Das Dokument muss eine Dateityp sein: jpeg, jpg, png, pdf, doc, docx.","download":"Descargar","edit_expense":"Editar Gasto","expense":"Gastos","expense_details":"Detalles de Gastos","expense_head":"Jefe de Gastos","invoice_number":"Numero de Factura","name":"Nombre","new_expense":"Nuevo Gasto","select_expense_head":"Seleccionar Cabeza de Gastos"},"expenses":"Gastos","facebook_url":"Facebook URL","file_name":"Nombre del archivo","finance":"Finanzas","front_cms":"cm delantero","front_cms_services":"Servicios frontales de CMS","front_office":"Oficina frontal","front_service":"Servicio frontal","front_setting":{"about_us_description":"Descripci\u00f3n","about_us_details":"Sobre nosotros detalles","about_us_image":"Imagen","about_us_mission":"Misi\u00f3n","about_us_title":"T\u00edtulo","appointment_details":"Detalles de la cita","front_setting_details":"Front Setting Details","home_page_box_description":"Descripci\u00f3n del cuadro de la p\u00e1gina de inicio","home_page_box_title":"T\u00edtulo del cuadro de la p\u00e1gina de inicio","home_page_certified_box_description":"P\u00e1gina de inicio Caja certificada Descripci\u00f3n","home_page_certified_box_title":"T\u00edtulo del cuadro certificado de la p\u00e1gina de inicio","home_page_certified_doctor_description":"P\u00e1gina de Inicio M\u00e9dico Certificado Descripci\u00f3n","home_page_certified_doctor_image":"P\u00e1gina de inicio Imagen de m\u00e9dico certificado","home_page_certified_doctor_text":"Texto de m\u00e9dico certificado de la p\u00e1gina de inicio","home_page_certified_doctor_title":"T\u00edtulo de m\u00e9dico certificado de la p\u00e1gina de inicio","home_page_description":"Descripci\u00f3n de la p\u00e1gina de inicio","home_page_experience":"Experiencia en la p\u00e1gina de inicio","home_page_image":"Imagen de la p\u00e1gina de inicio","home_page_step_1_description":"P\u00e1gina de inicio Paso 1 Descripci\u00f3n","home_page_step_1_title":"P\u00e1gina de inicio Paso 1 T\u00edtulo","home_page_step_2_description":"P\u00e1gina de inicio Paso 2 Descripci\u00f3n","home_page_step_2_title":"P\u00e1gina de inicio Paso 2 T\u00edtulo","home_page_step_3_description":"P\u00e1gina de inicio Paso 3 Descripci\u00f3n","home_page_step_3_title":"P\u00e1gina de inicio Paso 3 T\u00edtulo","home_page_step_4_description":"P\u00e1gina de inicio Paso 4 Descripci\u00f3n","home_page_step_4_title":"P\u00e1gina de inicio Paso 4 T\u00edtulo","home_page_title":"T\u00edtulo de la p\u00e1gina de inicio","privacy_policy":"Pol\u00edtica de privacidad","terms_condition_details":"Detalles de t\u00e9rminos y condiciones","terms_conditions":"T\u00e9rminos y condiciones"},"front_settings":"Configuraci\u00f3n frontal","general":"General","hospital_activities":"Actividades hospitalarias","hospital_blood_bank":{"blood_bank":"Banco de sangre","blood_bank_details":"Detalles del banco de sangre","blood_banks":"Bancos de sangre","blood_group":"Grupo sangu\u00edneo","edit_blood_group":"Editar grupo sangu\u00edneo","new_blood_group":"Nuevo grupo sangu\u00edneo","remained_bags":"Bolsas restantes"},"hospital_charges":"Cargos Hospitalarios","hospital_schedule":"Horario del hospital","hospital_schedules":{"exists_doctor_schedule":"Algunos m\u00e9dicos han programado sus d\u00edas en d\u00edas no marcados, \u00bfest\u00e1 seguro de que desea realizar esta operaci\u00f3n?"},"icon":"Icono","income":"Ingresos","incomes":{"amount":"Cantidad","attachment":"Adjunto Archivo","choose":"Escoger","date":"Fecha","description":"descripci\u00f3n","document_error":"Das Dokument muss eine Dateityp sein: jpeg, jpg, png, pdf, doc, docx.","download":"Descargar","edit_income":"Einkommen bearbeiten","income_details":"Detalles de Ingresos","income_head":"Einkommensleiter","incomes":"Ingresos","invoice_number":"Numero de Factura","name":"Nombre","new_income":"Neues Einkommen","select_income_head":"W\u00e4hlen Sie Income Head"},"instagram_url":"URL de Instagram","insurance":{"discount":"Descuento","disease_details":"Detalles de la enfermedad","diseases_charge":"Carga de enfermedades","diseases_name":"Nombre de enfermedades","edit_insurance":"Editar seguro","hospital_rate":"Tarifa hospitalaria","insurance":"Seguro","insurance_code":"C\u00f3digo de seguro","insurance_details":"Detalles del seguro","insurance_no":"Seguro no","insurances":"Seguros","new_insurance":"Nuevo seguro","remark":"Observaci\u00f3n","service_tax":"Impuesto de servicio","total_amount":"Cantidad total"},"insurances":"Seguros","inventory":"Inventario","investigation_report":{"attachment":"Adjunto","birth_date_validation":"La fecha del informe de la investigaci\u00f3n no debe ser menor que la fecha de nacimiento del paciente.","date":"Fecha","description":"Descripci\u00f3n","doctor":"M\u00e9dica","edit_investigation_report":"Editar informe de investigaci\u00f3n","investigation_report":"Informe de investigaci\u00f3n","investigation_report_details":"Detalles del informe de investigaci\u00f3n","investigation_reports":"Informes de investigaci\u00f3n","new_investigation_report":"Nuevo informe de investigaci\u00f3n","patient":"Paciente","title":"T\u00edtulo"},"investigation_reports":"Informes de investigaci\u00f3n","invoice":{"account_name":"Nombre de cuenta","add":"Agregar","amount":"Cantidad","description":"Descripci\u00f3n","discount":"Descuento","edit":"Editar","edit_invoice":"Editar factura","hospital_address":"Direcci\u00f3n del hospital","invoice":"Factura","invoice_date":"Fecha de factura","invoice_details":"Detalles de la factura","invoice_id":"ID de factura","invoices":"Facturas","new_invoice":"Nueva factura","not_paid":"No pagada","paid":"Pagada","patient":"Paciente","patient_id":"Id. del paciente","price":"Precio","print_invoice":"Imprimir factura","qty":"Cantidad","sub_total":"Subtotal","total":"Cantidad total"},"invoices":"Facturas","ipd_bill":{"discount_in_number":"Descuento en n\u00famero","discount_in_percentage":"Descuento en porcentaje","gross_total":"Total bruto","net_payable_amount":"Importe neto a pagar","other_charges":"Otros cargos","paid_amount":"Monto de pago","tax_in_number":"N\u00famero de impuestos","tax_in_percentage":"Impuesto en porcentaje","total_charges":"Cargos totales"},"ipd_charges":"Cargos","ipd_consultant_register":"Instrucci\u00f3n del consultor","ipd_diagnosis":"Diagn\u00f3stico","ipd_opd":"IPD \/ OPD","ipd_patient":{"admission_date":"Fecha de admisi\u00f3n","bed_id":"Cama","bed_type_id":"Tipo de cama","bill_status":"Estado de la factura","bp":"Presi\u00f3n arterial","case_id":"Caso","doctor_id":"M\u00e9dico","edit_ipd_patient":"Editar paciente de DPI","height":"Altura","ipd_number":"IPD No","ipd_patient":"Paciente con DPI","ipd_patient_details":"Detalles del paciente IPD","ipd_patients":"Pacientes con ENI","is_old_patient":"Es viejo paciente","new_ipd_patient":"Nuevo paciente IPD","notes":"Notas","patient_id":"Paciente","symptoms":"S\u00edntomas","the_bed_field_is_required":"El campo de la cama es obligatorio.","the_case_field_is_required":"El campo del caso es obligatorio.","weight":"Peso"},"ipd_patient_charges":{"applied_charge":"Carga aplicada","charge_category_id":"Categor\u00eda de carga","charge_id":"C\u00f3digo","charge_type_id":"Tipo de carga","date":"Fecha","new_charge":"Agregar cargos","standard_charge":"Cargo est\u00e1ndar"},"ipd_patient_consultant_register":{"applied_date":"Fecha de aplicaci\u00f3n","doctor_id":"M\u00e9dico","instruction":"Instrucci\u00f3n","instruction_date":"Fecha de instrucci\u00f3n","new_consultant_register":"Agregar instrucci\u00f3n de consultor"},"ipd_patient_diagnosis":{"description":"Descripci\u00f3n","document":"Documento","edit_ipd_diagnosis":"Editar diagn\u00f3stico","new_ipd_diagnosis":"Agregar diagn\u00f3stico","report_date":"Fecha del informe","report_type":"Tipo de informe"},"ipd_patient_prescription":{"category_id":"Categor\u00eda de medicina","dosage":"Dosis","edit_prescription":"Editar prescripci\u00f3n","footer_note":"Nota de pie de p\u00e1gina","header_note":"Nota de encabezado","instruction":"Instrucci\u00f3n","ipd_no":"IPD No","medicine_id":"Medicamento","new_prescription":"Agregar receta","prescription_details":"Detalles de la prescripci\u00f3n","print_prescription":"Receta de impresi\u00f3n"},"ipd_patient_timeline":{"date":"Fecha","description":"Descripci\u00f3n","document":"Documento","edit_ipd_timeline":"Editar l\u00ednea de tiempo","new_ipd_timeline":"Agregar cronolog\u00eda","no_timeline_found":"No se encontr\u00f3 TimeLine","title":"T\u00edtulo","visible_to_person":"Visible para la persona"},"ipd_patients":"Pacientes con ENI","ipd_payment":"Pago IPD","ipd_payments":{"add_ipd_payment":"Agregar pago de Ipd","edit_ipd_payment":"Edit IPD Payment","make_payment":"Hacer el pago","payment_mode":"Modo de pago"},"ipd_prescription":"Prescripciones","ipd_timelines":"Cronolog\u00edas","issued_item":{"are_you_sure_want_to_return_this_item":"\u00bfEst\u00e1s segura de que quieres devolver este art\u00edculo?","available_quantity":"Cantidad disponible","department_id":"Tipo de usuario","description":"Descripci\u00f3n","edit_issued_item":"Editar art\u00edculo emitido","issued_by":"Problema por","issued_date":"Fecha de asunto","issued_item":"Art\u00edculo emitido","issued_item_details":"Detalles de art\u00edculos emitidos","issued_items":"Art\u00edculos emitidos","item":"Articulo","item_category":"Categor\u00eda de art\u00edculo","item_return":"Devolver objeto","item_returned":"Devuelto","new_issued_item":"Nuevo art\u00edculo emitido","quantity":"Cantidad","return_date":"Fecha de regreso","user_id":"Emitido a"},"issued_items":"Art\u00edculos emitidos","item":{"available_quantity":"Cantidad disponible","description":"Descripci\u00f3n","edit_item":"Editar art\u00edculo","item":"Articulo","item_category":"Categor\u00eda de art\u00edculo","item_details":"detalles del art\u00edculo","items":"Art\u00edculos","name":"Nombre","new_item":"Nuevo art\u00edculo","unit":"Unidad"},"item_category":{"edit_item_category":"Editar Categor\u00eda de art\u00edculo","item_categories":"Categor\u00edas de art\u00edculos","item_category":"Categor\u00eda de art\u00edculo","name":"Nombre","new_item_category":"Nueva Categor\u00eda de art\u00edculo"},"item_stock":{"attachment":"Adjunto archivo","description":"Descripci\u00f3n","edit_item_stock":"Editar stock de art\u00edculos","item":"Articulo","item_category":"Categor\u00eda de art\u00edculo","item_stock":"Stock del art\u00edculo","item_stock_details":"Detalles de stock del art\u00edculo","item_stocks":"Existencias de art\u00edculos","new_item_stock":"Stock de art\u00edculos nuevos","purchase_price":"Precio de compra","quantity":"Cantidad","store_name":"Nombre de la tienda","supplier_name":"Nombre del proveedor"},"items":"Art\u00edculos","items_categories":"Categor\u00edas de art\u00edculos","items_stocks":"Existencias de art\u00edculos","lab_tech":{"edit_lab_tech":"Editar t\u00e9cnico de laboratorio","lab_tech_detail":"Detalles del t\u00e9cnico de laboratorio","lab_technician":"T\u00e9cnica de laboratorio","new_lab_tech":"Nuevo t\u00e9cnico de laboratorio"},"lab_technicians":"T\u00e9cnicos de laboratorio","language":{"Arabic":"Ar\u00e1bica","Chinese":"Chino","English":"ingl\u00e9s","French":"Franc\u00e9s","German":"Alem\u00e1n","Portuguese":"portugu\u00e9s","Russian":"ruso","Spanish":"espa\u00f1ol","Turkish":"turco"},"linkedIn_url":"vinculado en_url","live_consultation":{"add_credential":"Agregar credencial","client_video":"Video del cliente","consultation_date":"Fecha de consulta","consultation_duration_minutes":"Minutos de duraci\u00f3n de la consulta","consultation_title":"T\u00edtulo de la consulta","created_by":"Creado por","created_for":"Creado para","disabled":"Disabled","edit_live_consultation":"Editar consulta en vivo","edit_live_meeting":"Editar Live Meeting","enable":"Habilitar","host_video":"Video anfitri\u00f3n","join_now":"\u00danete ahora","live_consultation":"Consultor\u00eda en vivo","new_live_consultation":"Nueva consulta en vivo","new_live_meeting":"Nueva reuni\u00f3n en vivo","staff_list":"Lista de personal","type":"Tipo","type_number":"N\u00famero de tipo","zoom_api_key":"Chave da API de zoom","zoom_api_secret":"Segredo da API do Zoom"},"live_consultations":"Consultas en vivo","live_meeting":"Reuni\u00f3n en vivo","live_meetings":"Reuniones en vivo","mail":"Correo","make_an_appointment":"Concierte una cita","medicine":{"brand":"Marca","brand_name":"Nombre de la marca","buying_price":"Precio de compra","category":"Categor\u00eda","category_id":"Id. de categor\u00eda","description":"Descripci\u00f3n","edit_medicine":"Editar medicina","edit_medicine_brand":"Editar marca de medicina","edit_medicine_category":"Editar categor\u00eda de medicina","medicine":"Medicina","medicine_brands":"Marcas de medicamentos","medicine_brands_details":"Detalles de la marca de medicina","medicine_category":"Categor\u00eda de medicina","medicine_category_details":"Detalles de la categor\u00eda de medicina","medicine_details":"Detalles de la medicina","medicines":"Medicamentos","name":"Nombre","new_brand":"Marca nueva","new_medicine":"Nueva medicina","new_medicine_brand":"Nueva marca de medicina","new_medicine_category":"Nueva categor\u00eda de medicina","salt_composition":"Composici\u00f3n de sal","selling_price":"Precio de venta","side_effects":"Efectos secundarios"},"medicine_brands":"Marcas de medicina","medicine_categories":"Categor\u00edas de medicina","medicines":"Medicamentos","message":{"date":"Fecha","message":"Mensaje","messages":"Mensajes","messages_details":"Detalles del mensaje","new_message":"Nuevo mensaje","select_user":"Seleccionar usuario","send_to":"Enviar a","sender_name":"Nombre del remitente","subject":"Sujeto"},"months":{"apr":"Abril","aug":"Agosto","dec":"Diciembre","feb":"Febrero","jan":"enero","july":"Julio","jun":"Junio","mar":"Marzo","may":"Mayo","nov":"Noviembre","oct":"Octubre","sep":"Septiembre"},"my_payroll":{"allowance":"Permiso","basic_salary":"Salario b\u00e1sico","deductions":"Deducciones","my_payrolls":"Mis n\u00f3minas","net_salary":"Salario neto"},"my_payrolls":"Mis n\u00f3minas","new_patient":"Paciente nuevo","no_data_available":"No hay datos disponibles en la tabla","notice_board":{"created_at":"Creado en","description":"Descripci\u00f3n","details":"Detalles del tabl\u00f3n de anuncios","edit":"Editar tabl\u00f3n de anuncios","new":"Nuevo tabl\u00f3n de anuncios","notice_board":"Tabl\u00f3n de anuncios","title":"T\u00edtulo"},"notice_boards":"Tabl\u00f3n de anuncios","notification":{"mark_all_as_read":"Marcar todo como leido","notifications":"Notificaciones","you_don`t_have_any_new_notification":"No tienes ninguna notificaci\u00f3n nueva"},"nurse":{"birth_date":"Fecha de nacimiento","choose":"Escoger","edit_nurse":"Editar enfermera","new_nurse":"Nueva enfermera","nurse":"Enfermera","nurse_details":"Detalles de la enfermera","phone_no":"N\u00famero de tel\u00e9fono"},"nurses":"Enfermeras","old_patient":"Paciente anciano","opd_diagnosis":"Diagn\u00f3stico de OPD","opd_patient":{"appointment_date":"D\u00eda de la cita","edit_opd_patient":"Editar paciente OPD","new_opd_patient":"Nuevo paciente OPD","opd_number":"OPD No","opd_patient":"Paciente OPD","opd_patient_details":"Detalles del paciente OPD","opd_patients":"Pacientes OPD","revisits":"Volver a visitar","total_visits":"Visitas totales","visits":"Visitas"},"opd_patients":"Pacientes OPD","opd_payments":{"add_opd_payment":"Agregar pago de Opd","edit_opd_payment":"Editar pago de Opd","make_payment":"Hacer el pago","payment_mode":"Modo de pago"},"opd_timeline":"Cronolog\u00eda de OPD","operation_report":{"case_id":"ID del caso","date":"Fecha","description":"Descripci\u00f3n","doctor_name":"Nombre del doctor","edit_operation_report":"Editar informe de operaci\u00f3n","new_operation_report":"Nuevo informe de operaci\u00f3n","operation_report":"Informe de operaci\u00f3n","operation_report_details":"Detalles del informe de operaci\u00f3n","operation_reports":"Informes de operaciones","patient_name":"Nombre del paciente"},"operation_reports":"Informes de operaciones","overview":"Visi\u00f3n general","package":{"amount":"Cantidad","description":"Descripci\u00f3n","discount":"Descuento","edit_package":"Editar paquete","name":"Nombre","new_package":"Nuevo paquete","package":"Paquete","package_details":"Detalles del paquete","packages":"Paquetes","qty":"Cantidad","rate":"Velocidad","select_service":"Seleccionar servicio","service":"Servicio","total_amount":"Cantidad total"},"packages":"Paquetes","pathologies":"Patolog\u00eda","pathology_categories":"Categor\u00eda de patolog\u00eda","pathology_category":{"edit_pathology_category":"Editar Patolog\u00eda Categor\u00eda","name":"Nombre","new_pathology_category":"Nueva Patolog\u00eda Categor\u00eda","pathology_categories":"Categor\u00edas de patolog\u00eda"},"pathology_test":{"category_name":"Categor\u00eda Nombre","charge_category":"Categor\u00eda de carga","edit_pathology_test":"Editar Patolog\u00eda Prueba","method":"M\u00e9todo","new_pathology_test":"Nueva Patolog\u00eda Prueba","pathology_test_details":"Patolog\u00eda Prueba Detalles","pathology_tests":"Patolog\u00eda Pruebas","report_days":"Informar d\u00edas","short_name":"Corto Nombre","standard_charge":"Cargo est\u00e1ndar","subcategory":"Subcategor\u00eda","test_name":"Prueba Nombre","test_type":"Prueba Type","unit":"Unidad"},"pathology_tests":"Patolog\u00eda Pruebas","patient":{"edit_patient":"Editar paciente","new_patient":"Nuevo paciente","patient_details":"Detalles del paciente","total_admissions":"Admisiones totales","total_appointments":"Citas totales","total_cases":"Casos Totales"},"patient_admission":{"admission_date":"Fecha de admisi\u00f3n","agent_name":"Nombre del agente","bed":"Cama","details":"Detalles de admisi\u00f3n del paciente","discharge_date":"Fecha de alta","doctor":"M\u00e9dica","doctor_name":"Nombre del doctor","edit_patient_admission":"Editar admisi\u00f3n del paciente","guardian_address":"Direcci\u00f3n del tutor","guardian_contact":"Contacto de tutor","guardian_name":"Nombre del guardi\u00e1n","guardian_relation":"Relaci\u00f3n de tutor","insurance":"Seguro","insurance_name":"Nombre del seguro","new_patient_admission":"Admisi\u00f3n de pacientes nuevos","package":"Paquete","package_name":"Nombre del paquete","patient":"Paciente","patient_admission":"Admisi\u00f3n de pacientes","patient_admission_id":"ID de admisi\u00f3n del paciente","patient_name":"Nombre del paciente","policy_no":"No pol\u00edtica"},"patient_admissions":"Admisiones de pacientes","patient_appointment":"Cita del paciente","patient_diagnosis_test":{"action":"Acci\u00f3n","add_other_diagnosis_property":"Agregar otra propiedad de diagn\u00f3stico","age":"Alter","average_glucose":"Durchschnittliche Glukose","blood_pressure":"Blutdruck","cholesterol":"Cholesterin","create_patient_diagnosis_test":"Crear prueba de diagn\u00f3stico del paciente","created_at":"Creado en","diabetes":"Diabetes","diagnosis":"Diagn\u00f3stico","diagnosis_category":"Categor\u00eda de diagn\u00f3stico","diagnosis_property_name":"Nombre de la propiedad de diagn\u00f3stico","diagnosis_property_value":"Valor de la propiedad de diagn\u00f3stico","diagnosis_test":"Pruebas de diagn\u00f3stico","doctor":"M\u00e9dico","doctor_name":"Nombre del doctor","edit_patient_diagnosis_test":"Editar prueba de diagn\u00f3stico del paciente","fasting_blood_sugar":"Blutzucker n\u00fcchtern","height":"H\u00f6he","new_patient_diagnosis_test":"Nueva prueba de diagn\u00f3stico del paciente","other_diagnosis_property":"Otra propiedad de diagn\u00f3stico","patient":"Paciente","patient_diagnosis_test":"Pruebas de diagn\u00f3stico del paciente","patient_diagnosis_test_details":"Detalles de la prueba de diagn\u00f3stico del paciente","patient_name":"Nombre del paciente","print_diagnosis_test":"Prueba de diagn\u00f3stico de impresi\u00f3n","report_number":"Numero de reporte","urine_sugar":"Urin Zucker","weight":"Gewicht"},"patients":"Pacientes","patients_case_details":"Detalles del caso de las pacientes","patients_cases":"Casos de pacientes","payment":{"account":"Cuenta","account_name":"Nombre de cuenta","amount":"Cantidad","description":"Descripci\u00f3n","edit_payment":"Editar pago","new_payment":"Nuevo pago","pay_to":"Pagar a","payment":"Pago","payment_date":"Fecha de pago","payment_details":"Detalles de pago","payment_reports":"Informes de pago","payments":"Pagos"},"payments":"Pagos","pharmacist":{"edit_pharmacist":"Editar farmac\u00e9utico","new_pharmacist":"Nuevo farmac\u00e9utico","pharmacist_details":"Detalles del farmac\u00e9utico","pharmacists":"Farmac\u00e9uticos"},"pharmacists":"Farmac\u00e9uticos","postal":{"address":"Habla a","date":"Fecha","dispatch":"Env\u00edo","edit_dispatch":"Editar env\u00edo","edit_receive":"Editar Recibir","from_title":"Desde el t\u00edtulo","new_dispatch":"Nuevo env\u00edo","new_receive":"Nueva recepci\u00f3n","postal":"Postal","receive":"Recibir","reference_no":"N\u00famero de referencia","to_title":"Al t\u00edtulo"},"postal_dispatch":"Despacho postal","postal_receive":"Recepci\u00f3n postal","prescription":{"accident":"Accidente","advice":"consejo","after_meal":"despu\u00e9s de comer","before_meal":"Antes de la comida","breast_feeding":"Lactancia materna","comment":"comentario","current_medication":"Medicaci\u00f3n actual","days":"d\u00edas","diabetic":"Diab\u00e9tica","duration":"Duraci\u00f3n","edit_prescription":"Editar receta","female_pregnancy":"Embarazo femenino","food_allergies":"Alergias a los alimentos","health_insurance":"Seguro de salud","heart_disease":"Enfermedad del coraz\u00f3n","high_blood_pressure":"Alta presi\u00f3n sangu\u00ednea","low_income":"De bajos ingresos","medical_history":"Historial m\u00e9dico","medicine_name":"nombre_medicamento","month":"Mes","new_medicine":"nueva medicina","new_prescription":"Nueva receta","next_visit":"siguiente visita","no_data_available":"datos no encontrados","others":"Otras","patient":"Paciente","physical_information":"Informaci\u00f3n F\u00edsica","plus_rate":"Legumbres adicional","prescription":"Prescripci\u00f3n","prescription_details":"Detalles de prescripci\u00f3n","prescriptions":"Recetas","problem":"problema","problem_description":"Descripci\u00f3n del problema","reference":"Referencia","rx":"Rx","surgery":"Cirug\u00eda","temperature":"la temperatura","tendency_bleed":"Sangrado de tendencia","test":"prueba","time":"tiempo","year":"A\u00c3\u00b1o"},"prescriptions":"Recetas","profile":{"change_language":"Cambiar idioma","edit_profile":"Editar perfil","email":"Correo electr\u00f3nico","first_name":"Primer nombre","language":"Idioma","last_name":"Apellido","phone":"Tel\u00e9fono","profile":"Perfil"},"radiologies":"Radiolog\u00eda","radiology_categories":"Radiolog\u00eda Categor\u00eda","radiology_category":{"edit_radiology_category":"Editar Radiolog\u00eda Categor\u00eda","name":"Nombre","new_radiology_category":"Nueva Radiolog\u00eda Categor\u00eda","radiology_categories":"Radiolog\u00eda Categorias"},"radiology_test":{"category_name":"Categor\u00eda Nombre","charge_category":"Cargar Categor\u00eda","edit_radiology_test":"Editar Radiolog\u00eda Prueba","new_radiology_test":"Nueva Radiolog\u00eda Prueba","radiology_test_details":"Radiolog\u00eda Prueba Detalles","radiology_tests":"Radiolog\u00eda Pruebas","report_days":"Reporte Dias","short_name":"Corta Nombre","standard_charge":"Est\u00e1ndar Cargar","subcategory":"Sub Categor\u00eda","test_name":"Prueba Nombre","test_type":"Prueba Tipo"},"radiology_tests":"Radiolog\u00eda Pruebas","receptionist":{"edit_receptionist":"Editar recepcionista","new_receptionist":"Nueva recepcionista","receptionist":"Recepcionista","receptionist_details":"Detalles del recepcionista","receptionists":"Recepcionistas"},"receptionists":"Recepcionistas","reports":"Informes","role":{"edit_role":"Editar rol","new_role":"Nuevo rol"},"roles":"Roles","schedule":{"available_from":"Disponible desde","available_on":"Disponible el","available_to":"Disponible para","details":"Detalles de programaci\u00f3n","doctor_name":"Nombre del doctor","edit":"Editar horario","new":"Nuevo horario","per_patient_time":"Tiempo por paciente","select_doctor_name":"Seleccionar nombre del m\u00e9dico","select_serial_visibility":"Seleccionar visibilidad en serie","sequential":"Secuencial","serial_visibility":"Visibilidad en serie","timestamp":"Marca de tiempo"},"schedule_label":"Calendario","schedules":"Horarios","service":{"edit_service":"Editar servicio","given":"Dada","new_service":"Nuevo servicio","not_given":"No dado","quantity":"Cantidad","rate":"Velocidad","service_details":"Detalles del servicio"},"services":"Servicios","setting":{"address":"Direcci\u00f3n del hospital","app_logo":"Logotipo de la aplicaci\u00f3n","app_name":"Nombre de la aplicaci\u00f3n","company_name":"Nombre de la empresa","country_code":"C\u00f3digo de pa\u00eds","currency":"Moneda actual","hospital_email":"Correo electr\u00f3nico del hospital","hospital_from_day":"Hospital de d\u00eda","hospital_from_time":"Hospital de tiempo","hospital_phone":"Tel\u00e9fono del hospital","image_validation":"La imagen debe tener un p\u00edxel de 90 x 60.","social_details":"Detalles sociales"},"settings":"Configuraci\u00f3n","short_description":"Breve descripci\u00f3n","sidebar_setting":"Configuraci\u00f3n de m\u00f3dulos","sms":{"date":"Fecha","message":"Mensaje","new_sms":"SMS nuevo","only_user_with_registered_phone_will_display":"(Solo se mostrar\u00e1n los usuarios con un tel\u00e9fono registrado).","phone_number":"N\u00famero de Tel\u00e9fono","role":"Papel","send":"Enviar","send_by":"Enviado Por","send_sms_by_number_directly":"Env\u00eda SMS por n\u00famero directamente","send_to":"Enviar a","sms":"SMS","sms_details":"Detalles de SMS"},"testimonial":{"description":"Descripci\u00f3n","edit_testimonial":"Editar testimonio","name":"Nombre","new_testimonial":"Nuevo testimonio","profile_error":"El documento debe ser un archivo del tipo: jpeg, jpg, png.","testimonial":"Testimonial","testimonial_detail":"Detalle del testimonio"},"testimonials":"Testimonios","twitter_url":"URL de twitter","user":{"address1":"Direcci\u00f3n  1","address2":"Direcci\u00f3n  2","address_details":"Detalles de la direcci\u00f3n","address_not_found":"No se encontraron detalles de la direcci\u00f3n","blood_group":"Grupo sangu\u00edneo","change_password":"Cambia la contrase\u00f1a","city":"Ciudad","designation":"Designaci\u00f3n","dob":"Fecha de nacimiento","edit_profile":"Editar perfil","edit_user":"Editar usuario","education":"Educaci\u00f3n","email":"Correo electr\u00f3nico","email_verified_successfully":"Correo electr\u00f3nico verificado con \u00e9xito.","female":"Hembra","first_name":"Nombre","gender":"G\u00e9nero","invalid_password":"La contrase\u00f1a actual no es v\u00e1lida.","last_name":"Apellido","logout":"Cerrar sesi\u00f3n","male":"Masculino","name":"Nombre","new_user":"Nuevo usuario","password":"Contrase\u00f1a","password_confirmation":"Confirmar contrase\u00f1a","phone":"Tel\u00e9fono","qualification":"Calificaci\u00f3n","select_blood_group":"Seleccionar grupo sangu\u00edneo","status":"Estado","user_details":"Detalles de usuario","usrs":"Usuaria","validate_confirm_password":"La contrase\u00f1a y la contrase\u00f1a de confirmaci\u00f3n deben coincidir.","validate_min_character_password":"La contrase\u00f1a debe contener al menos 6 caracteres.","zip":"C\u00f3digo Postal"},"users":"Usuarios","vaccinated_patient":{"add_vaccinate_patient":"Agregar paciente vacunar","description":"Descripci\u00f3n","does_no":"Dosis No","dose_given_date":"Fecha de administraci\u00f3n de la dosis","edit_vaccinate_patient":"Editar Vacunar Paciente","new_vaccinate_patient":"Nuevo paciente vacunado","patient":"Paciente","serial_no":"N\u00famero de serie","vaccinate_patient":"Vacunar Paciente","vaccinated_patient":"Paciente vacunada","vaccination":"Vacunaci\u00f3n","vaccine":"Vacuna"},"vaccinated_patients":"Pacientes vacunados","vaccination":{"brand":"Marca","edit_vaccination":"Editar vacunaci\u00f3n","manufactured_by":"Fabricado por","name":"Nombre","new_vaccination":"Nueva vacunaci\u00f3n","vaccinated":"Vacunado","vaccinations":"Vacunas"},"vaccinations":"Vacunas","valid":"V\u00e1lida","verification":{"another_verify_request":"haga clic aqu\u00ed para solicitar otro","verify_message":"Antes de continuar, verifique su correo electr\u00f3nico para obtener un enlace de verificaci\u00f3n. Si no recibi\u00f3 el correo electr\u00f3nico,","verify_your_email_address":"Verifique su direcci\u00f3n de correo electr\u00f3nico."},"visitor":{"date":"Fecha","edit":"Editar visitante","id_card":"Tarjeta de identificaci\u00f3n","in_time":"A tiempo","name":"Nombre","new":"Nueva visitante","note":"Nota","number_of_person":"Numero de personas","out_time":"Fuera de tiempo","phone":"Tel\u00e9fono","purpose":"Prop\u00f3sito","visitor":"Visitante"},"visitors":"Visitantes","web_appointment":{"call_now_and_get_a_free_consulting":"Llame ahora y obtenga una consultor\u00eda gratuita","enter_confirm_password":"Ingrese Confirmar Contrase\u00f1a","enter_description":"Ingrese descripci\u00f3n","enter_your_first_name":"Ponga su primer nombre","enter_your_last_name":"Ingrese su apellido","enter_your_password":"Ingresa tu contrase\u00f1a","make_an_appointment":"Haga una cita","select_department":"Seleccionar departamento","select_doctor":"Seleccionar doctora","select_time":"Seleccionar hora"},"web_contact":{"call_today":"Llama hoy","contact_no":"Contacto No","enter_your_email":"Introduce tu correo electr\u00f3nico","enter_your_name":"Introduzca su nombre","open_hours":"Horarios de apertura","our_location":"nuestra ubicaci\u00f3n","phone_number":"N\u00famero de tel\u00e9fono","please_enter_your_phone_number":"Por favor, introduzca su n\u00famero de tel\u00e9fono","select_enquiry":"Seleccionar consulta","send_message":"Enviar mensaje","send_us_a_message":"Mandanos un mensaje","type_your_message":"Escribe tu mensaje","write_your_message":"escribe tu mensaje","your_email":"Tu correo electr\u00f3nico","your_message":"Tu mensaje","your_name":"Tu nombre"},"web_home":{"4_easy_step_and_get_the_world_best_treatment":"4 pasos sencillos y obtenga el mejor tratamiento del mundo","about_us":"Sobre nosotras","available_doctors":"Doctores Disponibles","book_an_appointment":"Reservar una cita","book_appointment":"Reservar una cita","book_now":"Reservar ahora","contact":"Contacto","contact_doctors":"Doctora de contacto","contact_hospital":"P\u00f3ngase en contacto con el hospital","doctors":"Doctoras","doctors_nurses":"Doctores y enfermeras","easy_solutions":"Soluciones f\u00e1ciles","happy_patients":"Pacientes felices","home":"Hogar","make_appointment":"Concertar cita","our_services":"Nuestros servicios","our_testimonials":"Nuestras Testimonios","patients":"Pacientes","patients_beds":"Camas de pacientes","privacy_policy":"Pol\u00edtica de privacidad","professional_doctors":"Doctores Profesionales","select_doctor":"Seleccionar doctora","select_doctors":"Seleccionar m\u00e9dicos","services":"Servicios","sign_up":"Inscribirse","terms_of_service":"T\u00e9rminos de servicio","testimonials":"Testimonios","we_are_experienced_healthcare_professionals":"Somos profesionales sanitarios experimentados","we_offer_different_services_to_improve_your_health":"Ofrecemos diferentes servicios para mejorar su salud","what_our_patient_say_about_medical_treatments":"Lo que dicen nuestros pacientes sobre nuestros tratamientos m\u00e9dicos","working_hours":"Horas Laborales","years_experience":"A\u00f1os de experiencia"},"web_menu":{"about":"Sobre","all_rights_reserved_by":"Todos los derechos reservados por","appointment":"Cita","contact_information":"Informaci\u00f3n del contacto","copyright":"Derechos de autor","login":"Acceso","our_features":"Nuestras caracteristicas","useful_link":"Enlace \u00fatil","working_hours":"Horas Laborales"},"web_password":{"password_and_confirm_password_not_match":"Contrase\u00f1a y Confirmar contrase\u00f1a no coinciden.","please_fill_all_the_required_fields":"Por favor complete todos los campos requeridos."},"web_working_hours":{"no_yet_opening_hours":"A\u00fan no hay horario de apertura","opening_hours":"Horario de apertura"},"weekdays":{"fri":"VIE","mon":"LUN","sat":"SE SENT\u00d3","sun":"SOL","thu":"JUE","tue":"MAR","wed":"CASARSE"}},"fr.messages":{"about_us":"\u00c0 propos de nous","account":{"account":"Compte","account_details":"D\u00e9tails du compte","accounts":"Comptes","credit":"Le cr\u00e9dit","debit":"D\u00e9bit","description":"La description","edit_account":"Modifier le compte","name":"Nom","new_account":"Nouveau compte","payments":"Paiements","status":"Statut","type":"Type"},"account_manager":"Gestionnaire de compte","accountant":{"accountant_details":"D\u00e9tails du comptable","accountants":"Comptables","edit_accountant":"Modifier le comptable","new_accountant":"Nouveau comptable"},"accountants":"Comptables","accounts":"Comptes","admin":"Administratrices","admins":"Administratrice","advanced_payment":{"advanced_payment":"Acompte","advanced_payment_details":"D\u00e9tails du paiement anticip\u00e9","advanced_payments":"Paiements avanc\u00e9s","amount":"Montante","date":"Date","edit_advanced_payment":"Modifier le paiement anticip\u00e9","new_advanced_payment":"Nouveau paiement anticip\u00e9","patient":"Patiente","patient_name":"Nom du patient","receipt_no":"Aucun re\u00e7u"},"advanced_payments":"Paiements avanc\u00e9s","allow_file_type":"Types de fichiers autoris\u00e9s : png, jpg, jpeg.","ambulance":{"ambulance":"ambulance","ambulance_details":"D\u00e9tails de l'ambulance","ambulances":"ambulances","driver_contact":"Contact conducteur","driver_license":"Permis de conduire","driver_name":"Nom du conducteur","edit_ambulance":"Modifier l'ambulance","is_available":"Est disponible","new_ambulance":"Nouvelle ambulance","note":"note","vehicle_model":"Mod\u00e8le de v\u00e9hicule","vehicle_number":"Num\u00e9ro de v\u00e9hicule","vehicle_type":"Type de v\u00e9hicule","year_made":"Ann\u00e9e de fabrication"},"ambulance_call":{"ambulance_call":"Appel d'ambulance","ambulance_call_details":"D\u00e9tails de l'appel d'ambulance","ambulance_calls":"Appels d'ambulance","amount":"Montante","date":"Date","driver_name":"Nom du conducteur","edit_ambulance_call":"Modifier l'appel d'ambulance","new_ambulance_call":"Nouvel appel d'ambulance","patient":"Patiente","vehicle_model":"Mod\u00e8le de v\u00e9hicule"},"ambulance_calls":"Appels d'ambulance","ambulances":"ambulances","appointment":{"appointment_calendar":"Calendrier des rendez-vous","appointment_details":"D\u00e9tails du rendez-vous","appointment_exists":"L'e-mail du patient existe d\u00e9j\u00e0","appointment_list":"Liste de rendez-vous","are_you_sure_want_to_cancel":"\u00cates-vous s\u00fbr de vouloir annuler","are_you_sure_want_to_change":"\u00cates-vous s\u00fbr de vouloir changer","available_slot":"Emplacement disponible","calendar_view":"Affichage du calendrier","change_status":"Changer de statut","changed_appointment":"Rendez-vous modifi\u00e9","completed":"Termin\u00e9","date":"Date","day":"Jour","department_name":"Nom du d\u00e9partement","description":"La description","doctor":"M\u00e9decin","doctor_department":"D\u00e9partement de docteur","doctor_department_name":"Nom du d\u00e9partement de m\u00e9decin","doctor_name":"Nom du docteur","doctor_schedule_not_available_on_this_date":"Horaire des m\u00e9decins non disponible \u00e0 cette date.","edit_appointment":"Modifier le rendez-vous","has_been_cancelled":"a \u00e9t\u00e9 annul\u00e9.","has_been_changed":"a \u00e9t\u00e9 modifi\u00e9.","last_30_days":"Les 30 derniers jours","last_7_days":"Les 7 derniers jours","last_month":"Le mois dernier","month":"Mois","new_appointment":"Nouveau rendez-vous","no_available":"Indisponible","old_patient_email_exists":"L'e-mail existe d\u00e9j\u00e0, veuillez s\u00e9lectionner l'ancien patient.\n","opd_date":"Date de l'opd","patient":"Patiente","patient_name":"Nom du patient","patient_not_exists_or_status_is_not_active":"Le patient n'existe pas ou le statut n'est pas actif.","pending":"En attente","please_select_appointment_time_slot":"Veuillez s\u00e9lectionner le cr\u00e9neau horaire du rendez-vous","please_select_doctor":"Veuillez s\u00e9lectionner un m\u00e9decin","please_select_doctor_department":"Veuillez s\u00e9lectionner le d\u00e9partement du m\u00e9decin","this_month":"Ce mois-ci","this_week":"Cette semaine","today":"Aujourd'hui","week":"Semaine","yesterday":"Hier"},"appointment_calendar":"Nommer. Calendrier","appointments":"Rendez-vous","available_slot":"Slot disponible","bed":{"add":"Ajouter","available":"Disponible","bed":"Nouveau lit","bed_details":"D\u00e9tails du lit","bed_id":"Identifiant du lit","bed_type":"Type de lit","beds":"Des lits","charge":"Charger","description":"La description","edit_bed":"Modifier le lit","name":"Nom","new_bed":"Nouveau lit","new_bulk_bed":"Nouveau lit en vrac","not_available":"Indisponible"},"bed_assign":{"assign_date":"Attribuer une date","assign_date_should_not_be_smaller_than_patient_birth_date":"La date d'attribution ne doit pas \u00eatre inf\u00e9rieure \u00e0 la date de naissance du patient.","assigned":"Attribu\u00e9","bed":"Lit","bed_assign":"Affectation de lit","bed_assign_details":"D\u00e9tails d'attribution de lit","bed_assigns":"Attributions de lit","bed_name":"Nom du lit","case_id":"Identifiant de cas","description":"La description","discharge_date":"Date de sortie","edit_bed_assign":"Modifier l'attribution de lit","ipd_patient_id":"IPD Patiente Identifiant","new_bed_assign":"Nouvelle affectation de lit","not_assigned":"Non attribu\u00e9","patient_name":"Nom du patient"},"bed_assigns":"Attributions de lit","bed_management":"Gestion des lits","bed_mgt":"Bed Management","bed_status":{"admission_date":"Date d'admission","assigned_beds":"Lits attribu\u00e9s","available_beds":"Lits disponibles","bed_name":"Nom du lit","bed_status":"Statut du lit","gender":"Le genre","patient_name":"Nom du patient","phone":"T\u00e9l\u00e9phone"},"bed_type":{"bed_type":"Type de lit","bed_type_details":"D\u00e9tails sur le type de lit","bed_types":"Types de lits","description":"La description","edit_bed_type":"Modifier le type de lit","new_bed_type":"Nouveau type de lit","title":"Titre"},"bed_types":"Types de lits","beds":"Des lits","bill":{"add":"Ajouter","admission_date":"Date d'admission","admission_id":"ID d'admission","amount":"Montant","bill":"Facture","bill_date":"Date de facturation","bill_details":"D\u00e9tails de la facture","bill_id":"Id de facture","bill_summary":"R\u00e9sum\u00e9 de la facture","bills":"Factures","calculate":"Calculer","cell_no":"No de cellule","discharge_date":"Date de sortie","doctor_name":"Nom du docteur","edit":"Modifier","edit_bill":"Modifier la facture","generate_bill":"G\u00e9n\u00e9rer la facture","insurance_name":"Nom de l'assurance","item_name":"Nom de l'article","new_bill":"Nouveau projet de loi","package_name":"Nom du paquet","patient":"Patiente","patient_cell_no":"No de cellule patient","patient_dob":"Patient DOB","patient_email":"Courriel du patient","patient_gender":"Sexe du patient","patient_name":"Nom du patient","policy_no":"No de politique","price":"Prix","print_bill":"Imprimer la facture","qty":"Qt\u00e9","total_amount":"Montant total","total_days":"Nombre total de jours","update_bill":"Mettre \u00e0 jour la facture"},"billing":"Facturation","bills":"Factures","birth_report":{"birth_report":"Rapport de naissance","birth_report_details":"D\u00e9tails du rapport de naissance","birth_reports":"Rapports de naissance","case_id":"Identifiant de cas","data_should_not_be_smaller_than_patient_birth_date":"La date ne doit pas \u00eatre inf\u00e9rieure \u00e0 la date de naissance du patient.","date":"Date","description":"La description","doctor_name":"Nom du docteur","edit_birth_report":"Modifier le rapport de naissance","new_birth_report":"Nouveau rapport de naissance","patient_birth_date_not_found":"Date de naissance du patient introuvable.","patient_name":"Nom du patient"},"birth_reports":"Rapports de naissance","blood_bank":"Banque du sang","blood_banks":"Banques de sang","blood_donation":{"bags":"Sacs","blood_donation":"Don de sang","donor_name":"Nom du donateur","edit_blood_donation":"Modifier le don de sang","last_donate_date":"Date du dernier don","new_blood_donation":"Nouveau don de sang"},"blood_donations":"Don de sang","blood_donor":{"age":"\u00c2ge","blood_donor":"Donateur de sang","blood_donor_details":"D\u00e9tails sur le donneur de sang","blood_donors":"Donateurs de sang","blood_group":"Groupe sanguin","donation_date":"Date de don","edit_blood_donor":"Modifier le donneur de sang","gender":"Le sexe","last_donation_date":"Derni\u00e8re date de don","name":"Nom","new_blood_donor":"Nouveau donneur de sang"},"blood_donors":"Donneurs de sang","blood_issue":{"amount":"Montante","blood_issue":"Probl\u00e8me de sang","doctor_name":"Nom du m\u00e9decin","donor_name":"Nom du donateur","edit_blood_issue":"Modifier le probl\u00e8me de sang","issue_date":"Date d`\u00e9mission","new_blood_issue":"Nouveau probl\u00e8me de sang","patient_name":"Nom du patient","remarks":"Remarques"},"blood_issues":"Probl\u00e8mes de sang","call_log":{"call_log":"Journal d'appel","call_type":"Type d'appel","edit":"Modifier le journal des appels","follow_up_date":"Date de suivi","incoming":"Entrante","name":"Nom","new":"Nouveau journal d`appels","note":"Remarque","outgoing":"Sortante","phone":"T\u00e9l\u00e9phone","received_on":"Re\u00e7u le"},"call_logs":"Journaux d appels","case":{"case":"Cas","case_date":"Date du cas","case_details":"D\u00e9tails du cas","case_id":"Identifiant de cas","date":"Date","description":"La description","doctor":"M\u00e9decin","edit_case":"Modifier le cas","fee":"Taxe","new_case":"Nouveau cas","patient":"Patiente","phone":"T\u00e9l\u00e9phone"},"case_handler":{"case_handler":"Gestionnaire de cas","case_handler_detail":"D\u00e9tails du gestionnaire de cas","edit_case_handler":"Modifier le gestionnaire de cas","new_case_handler":"Nouveau gestionnaire de cas"},"case_handlers":"Gestionnaires de cas","case_manager":"Charg\u00e9 de dossiers","cases":"\u00c9tuis","change_password":{"change_password":"Changer le mot de passe","confirm_password":"Confirmez le mot de passe","current_password":"Mot de passe actuel","new_password":"nouveau mot de passe"},"charge":{"charge_category":"Cat\u00e9gorie de charge","charge_details":"D\u00e9tails des frais","code":"Code","edit_charge":"Modifier la charge","new_charge":"Nouvelle charge","standard_charge":"frais standards"},"charge_categories":"Cat\u00e9gories de frais","charge_category":{"charge_categories":"Cat\u00e9gories de frais","charge_category_details":"D\u00e9tails sur la cat\u00e9gorie de facturation","charge_type":"Type de charge","edit_charge_category":"Modifier la cat\u00e9gorie de frais","new_charge_category":"Nouvelle cat\u00e9gorie de frais"},"charges":"Des charges","cms":"CMS","common":{"action":"action","actions":"Actions","active":"Active","add":"Ajouter","address":"Adresse","apply":"appliquer","are_you_sure_want_to_delete_this":"Voulez-vous vraiment supprimer ce ","back":"Retour","cancel":"Annuler","canceled":"annul\u00e9","cant_be_deleted":"ne peut pas \u00eatre supprim\u00e9","choose":"Choisir","confirm":"Confirmer","created_at":"Cr\u00e9\u00e9 sur","created_on":"Cr\u00e9\u00e9 sur","custom":"Personnalis\u00e9","de_active":"D\u00e9sactiv\u00e9","delete":"Supprimer","deleted":"Supprim\u00e9","deleted_successfully":"Supprim\u00e9 avec succ\u00e8s","description":"La description","detail":"d\u00e9tails","edit":"\u00c9diter","export_to_excel":"Exporter vers Excel","filter_options":"Options de filtrage","from":"de","has_been_deleted":"a \u00e9t\u00e9 supprim\u00e9.","invalid_country_code":"Code pays invalide","invalid_number":"Num\u00e9ro invalide","is_available":"Est disponible","last_updated":"Derni\u00e8re mise \u00e0 jour","n\/a":"N \/ A","name":"Nom","new":"Nouvelle","next":"Prochain","no":"Non","not_found":"pas trouv\u00e9","ok":"D'accord","previous":"Pr\u00e9c\u00e9dent","profile":"Profil","reset":"R\u00e9initialiser","save":"sauvegarder","saved_successfully":"enregistr\u00e9 avec succ\u00e8s.","search":"Chercher","status":"Statut","status_updated_successfully":"Statut mis \u00e0 jour avec succ\u00e8s.","this_action_is_not_allowed_for_default_record":"Cette action n'est pas autoris\u00e9e pour l'enregistrement par d\u00e9faut.","to":"\u00c0","too_long":"Trop long","too_short":"Trop court","total":"Totale","updated_at":"Derni\u00e8re mise \u00e0 jour","updated_successfully":"Mis \u00e0 jour avec succ\u00e9s","view":"Vue","view_attachment":"Afficher la pi\u00e8ce jointe","yes":"Oui"},"contact_us":"Contactez-nous","currency":{"add_currency_code_as_per_three_letter_iso_code":"Ajoutez le code de devise selon le code ISO \u00e0 trois lettres","currency":"Devise","currency_code":"Code de devise","currency_icon":"Ic\u00f4ne de devise","currency_name":"Nom de la devise","edit_currency":"Modifier la devise","new_currency":"Nouvelle devise","you_can_find_out_here":"vous pouvez d\u00e9couvrir ici"},"currency_setting":"Devises","dashboard":{"available_beds":"Lits disponibles","dashboard":"Tableau de bord","doctors":"M\u00e9decins","income_and_expense_report":"Rapport de revenus et d\u00e9penses","income_and_expense_reports":"Rapports de revenus et de d\u00e9penses","no_enquiries_yet":"Aucune demande pour le moment","no_notice_yet":"Pas encore d'avis","notice_boards":"Tableaux d'affichage","patients":"Les patients","title":"Titre","total_advance_payments":"Montant du paiement anticip\u00e9","total_bills":"Montant de la facture","total_invoices":"Montant de la facture","total_payments":"Montant du paiement"},"death_report":{"case_id":"Identifiant de cas","date":"Date","death_report":"Rapport de d\u00e9c\u00e8s","death_report_details":"D\u00e9tails du rapport de d\u00e9c\u00e8s","death_reports":"Rapports de d\u00e9c\u00e8s","description":"La description","doctor_name":"Nom du docteur","edit_death_report":"Modifier le rapport de d\u00e9c\u00e8s","new_death_report":"Nouveau rapport de d\u00e9c\u00e8s","patient_name":"Nom du patient"},"death_reports":"Rapports de d\u00e9c\u00e8s","department":"d\u00e9partement","departments":"D\u00e9partements","diagnosis_category":{"category_name":"Nom de cat\u00e9gorie","description":"La description","diagnosis_categories":"Cat\u00e9gorie de diagnostic","diagnosis_category":"Cat\u00e9gorie de diagnostic","diagnosis_category_details":"D\u00e9tails de la cat\u00e9gorie de diagnostic","edit_diagnosis_category":"Modifier la cat\u00e9gorie de diagnostic","new_diagnosis_category":"Nouvelle cat\u00e9gorie de diagnostic"},"doc_type":{"edit_doc_type":"Modifier le type de document","name":"Nom","new_doc_type":"Nouveau type de document"},"doctor":{"doctor_details":"D\u00e9tails du m\u00e9decin","edit_doctor":"Modifier le docteur","new_doctor":"Nouveau docteur","specialist":"Sp\u00e9cialiste"},"doctor_department":{"description":"La description","doctor_department":"D\u00e9partement de docteur","doctor_department_details":"D\u00e9tails du service de m\u00e9decin","doctor_departments":"D\u00e9partements de m\u00e9decins","edit_doctor_department":"Modifier le d\u00e9partement de m\u00e9decin","new_doctor_department":"Nouveau d\u00e9partement de docteur","title":"Titre"},"doctor_departments":"D\u00e9partements de m\u00e9decins","doctor_opd_charge":{"doctor":"M\u00e9decin","doctor_name":"Nom du Socteur","doctor_opd_charge":"Charge du m\u00e9decin OPD","edit_doctor_opd_charge":"Modifier la charge Doctor OPD","new_doctor_opd_charge":"Nouveau Doctor OPD Charge","standard_charge":"Charge Standard"},"doctor_opd_charges":"Frais du m\u00e9decin OPD","doctors":"M\u00e9decins","doctors_list":"Liste des m\u00e9decins","document":{"attachment":"Attachement","document":"Document","document_detail":"D\u00e9tails du Document","document_type":"Type de document","document_type_details":"D\u00e9tails du type de document","download":"T\u00e9l\u00e9charger","edit_document":"Modifier le document","new_document":"Nouveau document","notes":"Remarques","patient":"Patiente","select_document_type":"Select Document Type","select_patient":"S\u00e9lectionner un patient","title":"Titre","uploaded_by":"Telecharg\u00e9 par"},"document_types":"Types de documents","documents":"Les documents","email":{"attachment":"Pi\u00e8ces jointes","message":"Un message","subject":"Mati\u00e8re","to":"\u00c0"},"employee_payroll":{"allowance":"Allocation","basic_salary":"Salaire de base","deductions":"D\u00e9ductions","edit_employee_payroll":"Modifier la paie des employ\u00e9s","employee":"Employ\u00e9e","employee_name":"Nom de l'employ\u00e9","employee_payroll":"Paie des employ\u00e9s","employee_payroll_details":"D\u00e9tails de la paie des employ\u00e9s","employee_payrolls":"Paie des employ\u00e9s","month":"Mois","net_salary":"Salaire net","new_employee_payroll":"Paie des nouveaux employ\u00e9s","not_paid":"Impay\u00e9","paid":"Pay\u00e9","payroll_id":"Identifiant de paie","role":"R\u00f4le","sr_no":"Sr Non","year":"Ann\u00e9e"},"employee_payrolls":"Paie des employ\u00e9s","enquiries":"Demandes","enquiry":{"contact":"Contact","email":"Email","enquiry_details":"D\u00e9tails de l'enqu\u00eate","enquiry_send_successfully":"Demande envoy\u00e9e avec succ\u00e8s","message":"Message","name":"Nom","not_viewed":"Pas vu","read":"Lis","received_on":"Re\u00e7u le","send_enquiry":"Envoyer une demande","type":"taper","unread":"Non lu","viewed_by":"Vu par"},"expense":{"amount":"Montant","attachment":"Attachement","choose":"Choisir","date":"Date","description":"La description","document_error":"Le document doit \u00eatre un fichier de type: jpeg, jpg, png, pdf, doc, docx.","download":"T\u00e9l\u00e9charger","edit_expense":"Modifier les D\u00e9penses","expense":"Frais","expense_details":"D\u00e9tails des D\u00e9penses","expense_head":"Responsable des D\u00e9penses","invoice_number":"Num\u00e9ro de Facture","name":"Nom","new_expense":"Nouvelle D\u00e9pense","select_expense_head":"S\u00e9lectionner la T\u00eate de D\u00e9pense"},"expenses":"D\u00e9penses","facebook_url":"L'adresse URL de Facebook","file_name":"Nom de fichier","finance":"La finance","front_cms":"Cm avant","front_cms_services":"Services CMS avant","front_office":"Bureau d`accueil","front_service":"Service avant","front_setting":{"about_us_description":"Description","about_us_details":"\u00c0 propos de nous D\u00e9tails","about_us_image":"Image","about_us_mission":"Mission","about_us_title":"Titre","appointment_details":"D\u00e9tails du rendez-vous","front_setting_details":"d\u00e9tail de r\u00e9glage avant","home_page_box_description":"Description de la bo\u00eete de la page d'accueil","home_page_box_title":"Titre de la bo\u00eete de la page d'accueil","home_page_certified_box_description":"Page d'accueil Description de la bo\u00eete certifi\u00e9e","home_page_certified_box_title":"Titre de la bo\u00eete certifi\u00e9e de la page d'accueil","home_page_certified_doctor_description":"Page d'accueil M\u00e9decin certifi\u00e9 Description","home_page_certified_doctor_image":"Page d'accueil Image de m\u00e9decin certifi\u00e9","home_page_certified_doctor_text":"Page d'accueil Texte du m\u00e9decin certifi\u00e9","home_page_certified_doctor_title":"Page d'accueil Titre de docteur certifi\u00e9","home_page_description":"Description de la page d'accueil","home_page_experience":"Exp\u00e9rience de la page d'accueil","home_page_image":"Image de la page d'accueil","home_page_step_1_description":"Page d'accueil \u00c9tape 1 Description","home_page_step_1_title":"Page d'accueil \u00c9tape 1 Titre","home_page_step_2_description":"Page d'accueil \u00c9tape 2 Description","home_page_step_2_title":"Page d'accueil \u00c9tape 2 Titlen","home_page_step_3_description":"Page d'accueil \u00c9tape 3 Description","home_page_step_3_title":"Page d'accueil \u00c9tape 3 Titre","home_page_step_4_description":"Page d'accueil \u00c9tape 4 Description","home_page_step_4_title":"Page d'accueil \u00c9tape 4 Titre","home_page_title":"Titre de la page d'accueil","privacy_policy":"Politique de confidentialit\u00e9","terms_condition_details":"D\u00e9tails des conditions g\u00e9n\u00e9rales","terms_conditions":"termes et conditions"},"front_settings":"Param\u00e8tres avant","general":"G\u00e9n\u00e9rale","hospital_activities":"Activit\u00e9s hospitali\u00e8res","hospital_blood_bank":{"blood_bank":"Banque du sang","blood_bank_details":"D\u00e9tails de la banque de sang","blood_banks":"Banques de sang","blood_group":"Groupe sanguin","edit_blood_group":"Modifier le groupe sanguin","new_blood_group":"Nouveau groupe sanguin","remained_bags":"Sacs restant"},"hospital_charges":"Frais d'hospitalisation","hospital_schedule":"Horaire de l'h\u00f4pital","hospital_schedules":{"exists_doctor_schedule":"Certains m\u00e9decins ont programm\u00e9 leurs journ\u00e9es en jours donn\u00e9s non coch\u00e9s, alors \u00eates-vous s\u00fbr de vouloir effectuer cette op\u00e9ration ?"},"icon":"Ic\u00f4ne","income":"Le revenu","incomes":{"amount":"Montant","attachment":"Attachement","choose":"Choisir","date":"Date","description":"La description","document_error":"Le document doit \u00eatre un fichier de type: jpeg, jpg, png, pdf, doc, docx.","download":"T\u00e9l\u00e9charger","edit_income":"Modifier le revenu","income_details":"D\u00e9tails sur le Revenu","income_head":"Responsable du revenu","incomes":"Revenus","invoice_number":"Num\u00e9ro de Facture","name":"Nom","new_income":"Nouveau revenu","select_income_head":"S\u00e9lectionner le responsable du revenu"},"instagram_url":"URL Instagram","insurance":{"discount":"Remise","disease_details":"D\u00e9tails de la maladie","diseases_charge":"Maladie facturer","diseases_name":"Maladies Nom","edit_insurance":"Modifier l'assurance","hospital_rate":"Taux d'hospitalisation","insurance":"Assurance","insurance_code":"Code d'assurance","insurance_details":"D\u00e9tails de l'assurance","insurance_no":"Num\u00e9ro d'assurance","insurances":"Assurances","new_insurance":"Nouvelle assurance","remark":"Remarque","service_tax":"Taxe de service","total_amount":"Montant total"},"insurances":"Assurances","inventory":"Inventaire","investigation_report":{"attachment":"Attachement","birth_date_validation":"La date du rapport d'investigation ne doit pas \u00eatre inf\u00e9rieure \u00e0 la date de naissance du patient.","date":"Date","description":"La description","doctor":"M\u00e9decin","edit_investigation_report":"Modifier le rapport d'enqu\u00eate","investigation_report":"Rapport d'investigation","investigation_report_details":"D\u00e9tails du rapport d'enqu\u00eate","investigation_reports":"Rapports d'enqu\u00eate","new_investigation_report":"Nouveau rapport d'enqu\u00eate","patient":"Patiente","title":"Titre"},"investigation_reports":"Rapports d'enqu\u00eate","invoice":{"account_name":"Nom du compte","add":"Ajouter","amount":"Montante","description":"La description","discount":"Remise","edit":"\u00c9diter","edit_invoice":"Modifier la facture","hospital_address":"Adresse de l'h\u00f4pital","invoice":"Facture d'achat","invoice_date":"Date de facturation","invoice_details":"D\u00e9tails de la facture","invoice_id":"Identifiant de facture","invoices":"Factures","new_invoice":"Nouvelle facture","not_paid":"Impay\u00e9","paid":"Pay\u00e9","patient":"Patiente","patient_id":"ID patient","price":"Prix","print_invoice":"Imprimer la facture","qty":"Qt\u00e9","sub_total":"Sous-total","total":"Montant total"},"invoices":"Factures","ipd_bill":{"discount_in_number":"Remise en nombre","discount_in_percentage":"Remise en pourcentage","gross_total":"Total brut","net_payable_amount":"Montant net \u00e0 payer","other_charges":"Autres frais","paid_amount":"Montant pay\u00e9","tax_in_number":"Num\u00e9ro de taxe","tax_in_percentage":"Taxe en pourcentage","total_charges":"Total Charges"},"ipd_charges":"Des charges","ipd_consultant_register":"Instruction du consultant","ipd_diagnosis":"Diagnostic","ipd_opd":"IPD\/OPD","ipd_patient":{"admission_date":"Date d'admission","bed_id":"Lit","bed_type_id":"Type de lit","bill_status":"Statut de la facture","bp":"Pression art\u00e9rielle","case_id":"Cas","doctor_id":"Docteur","edit_ipd_patient":"Modifier le patient IPD","height":"la taille","ipd_number":"IPD Non","ipd_patient":"Patient IPD","ipd_patient_details":"D\u00e9tails du patient IPD","ipd_patients":"Patients IPD","is_old_patient":"Est un vieux patient","new_ipd_patient":"Nouveau patient IPD","notes":"Remarques","patient_id":"Patient","symptoms":"Sympt\u00f4mes","the_bed_field_is_required":"Le champ lit est obligatoire.","the_case_field_is_required":"Le champ cas est obligatoire.","weight":"Poids"},"ipd_patient_charges":{"applied_charge":"Charge appliqu\u00e9e","charge_category_id":"Cat\u00e9gorie de charge","charge_id":"Code","charge_type_id":"Type de charge","date":"Date","new_charge":"Ajouter des frais","standard_charge":"Charge standard"},"ipd_patient_consultant_register":{"applied_date":"Date d'application","doctor_id":"Docteur","instruction":"Instruction","instruction_date":"Date de l'instruction","new_consultant_register":"Ajouter une instruction de consultant"},"ipd_patient_diagnosis":{"description":"La description","document":"Document","edit_ipd_diagnosis":"Modifier le diagnostic","new_ipd_diagnosis":"Ajouter un diagnostic","report_date":"Date du compte rendu","report_type":"Type de rapport"},"ipd_patient_prescription":{"category_id":"Cat\u00e9gorie de m\u00e9decine","dosage":"Dosage","edit_prescription":"Modifier la prescription","footer_note":"Note de pied de page","header_note":"Note d'en-t\u00eate","instruction":"Instruction","ipd_no":"IPD Non","medicine_id":"M\u00e9dicament","new_prescription":"Ajouter une ordonnance","prescription_details":"D\u00e9tails de la prescription","print_prescription":"Prescription d'impression"},"ipd_patient_timeline":{"date":"Date","description":"La description","document":"Document","edit_ipd_timeline":"Modifier la chronologie","new_ipd_timeline":"Ajouter une chronologie","no_timeline_found":"Aucune ligne de temps trouv\u00e9e","title":"Titre","visible_to_person":"Visible \u00e0 la personne"},"ipd_patients":"Patients IPD","ipd_payment":"Paiement IPD","ipd_payments":{"add_ipd_payment":"Ajouter un paiement IPD","edit_ipd_payment":"Edit IPD Payment","make_payment":"Effectuer le paiement","payment_mode":"Mode de paiement"},"ipd_prescription":"Les ordonnances","ipd_timelines":"D\u00e9lais","issued_item":{"are_you_sure_want_to_return_this_item":"\u00cates-vous s\u00fbr de vouloir retourner cet article","available_quantity":"quantit\u00e9 disponible","department_id":"Type d'utilisateur","description":"La description","edit_issued_item":"Modifier l'\u00e9l\u00e9ment \u00e9mis","issued_by":"Issue By","issued_date":"Date d'\u00e9mission","issued_item":"Article \u00e9mis","issued_item_details":"D\u00e9tails des articles \u00e9mis","issued_items":"Articles \u00e9mis","item":"Article","item_category":"Cat\u00e9gorie d'article","item_return":"Retourner l'objet","item_returned":"Revenu","new_issued_item":"Nouvel \u00e9l\u00e9ment \u00e9mis","quantity":"Quantit\u00e9","return_date":"Date de retour","user_id":"\u00c9mettre \u00e0"},"issued_items":"Articles \u00e9mis","item":{"available_quantity":"quantit\u00e9 disponible","description":"La description","edit_item":"\u00c9diter Item","item":"Item","item_category":"Item Cat\u00e9gorie","item_details":"Item D\u00e9tails","items":"Items","name":"Nom","new_item":"Nouvelle Item","unit":"Unit\u00e9"},"item_category":{"edit_item_category":"\u00c9diter Cat\u00e9gorie d'article","item_categories":"Cat\u00e9gories d'articles","item_category":"Cat\u00e9gorie d'article","name":"Nom","new_item_category":"Nouvelle Cat\u00e9gorie d'article"},"item_stock":{"attachment":"Attachement","description":"La description","edit_item_stock":"Modifier le stock d'articles","item":"Item","item_category":"Cat\u00e9gorie d'article","item_stock":"Stock d'article","item_stock_details":"D\u00e9tails du stock d'article","item_stocks":"Stocks d'articles","new_item_stock":"Nouveau stock d'article","purchase_price":"Prix d'achat","quantity":"Quantit\u00e9","store_name":"Nom du magasin","supplier_name":"Nom du fournisseur"},"items":"Items","items_categories":"Cat\u00e9gories d'articles","items_stocks":"Stocks d'articles","lab_tech":{"edit_lab_tech":"Modifier le technicien de laboratoire","lab_tech_detail":"D\u00e9tails du technicien de laboratoire","lab_technician":"Un technicien de laboratoire","new_lab_tech":"Nouveau technicien de laboratoire"},"lab_technicians":"Techniciens de laboratoire","language":{"Arabic":"arabe","Chinese":"Chinois","English":"Anglais","French":"Fran\u00e7ais","German":"Allemand","Portuguese":"Portugais","Russian":"russe","Spanish":"Espagnol","Turkish":"turc"},"linkedIn_url":"URL Linkedin","live_consultation":{"add_credential":"Ajouter des informations d'identification","client_video":"Vid\u00e9o client","consultation_date":"Date de consultation","consultation_duration_minutes":"Dur\u00e9e de la consultation Minutes","consultation_title":"Titre de la consultation","created_by":"Cr\u00e9\u00e9 par","created_for":"Cr\u00e9\u00e9 pour","disabled":"D\u00e9sactiv\u00e9","edit_live_consultation":"Modifier la consultation en direct","edit_live_meeting":"Modifier la r\u00e9union en direct","enable":"Activer","host_video":"H\u00e9berger la vid\u00e9o","join_now":"Adh\u00e9rer maintenant","live_consultation":"Consultation en direct","new_live_consultation":"Nouvelle consultation en direct","new_live_meeting":"Nouvelle r\u00e9union en direct","staff_list":"Liste du personnel","type":"Type","type_number":"Num\u00e9ro de type","zoom_api_key":"Zoom cl\u00e9 API","zoom_api_secret":"Secret API Zoom"},"live_consultations":"Consultations en direct","live_meeting":"R\u00e9union en direct","live_meetings":"R\u00e9unions en direct","mail":"Courrier","make_an_appointment":"Prendre rendez-vous","medicine":{"brand":"Marque","brand_name":"Marque","buying_price":"Prix d'achat","category":"Cat\u00e9gorie","category_id":"Identifiant de cat\u00e9gorie","description":"La description","edit_medicine":"Modifier la m\u00e9decine","edit_medicine_brand":"Modifier la marque de m\u00e9decine","edit_medicine_category":"Modifier la cat\u00e9gorie des m\u00e9dicaments","medicine":"M\u00e9decine","medicine_brands":"Marques de m\u00e9dicaments","medicine_brands_details":"D\u00e9tails sur la marque de m\u00e9dicaments","medicine_category":"Cat\u00e9gorie de m\u00e9decine'","medicine_category_details":"D\u00e9tails de la cat\u00e9gorie M\u00e9decine","medicine_details":"D\u00e9tails du m\u00e9dicament","medicines":"M\u00e9dicaments","name":"Nom","new_brand":"Nouvelle marque","new_medicine":"Nouvelle m\u00e9decine","new_medicine_brand":"Nouvelle marque de m\u00e9decine","new_medicine_category":"Nouvelle cat\u00e9gorie de m\u00e9dicaments","salt_composition":"Composition du sel","selling_price":"Prix de vente","side_effects":"Effets secondaires"},"medicine_brands":"Marques de m\u00e9dicaments","medicine_categories":"Cat\u00e9gories de m\u00e9decine","medicines":"M\u00e9dicaments","message":{"date":"Date","message":"Message","messages":"Messages","messages_details":"D\u00e9tails du Message","new_message":"Nouveau Message","select_user":"S\u00e9lectionnez un Utilisateur","send_to":"Envoyer \u00e0","sender_name":"Nom de l'exp\u00e9diteur","subject":"Mati\u00e8re"},"months":{"apr":"Avril","aug":"Ao\u00fbt","dec":"D\u00e9cembre","feb":"F\u00e9vrier","jan":"Janvier","july":"Juillet","jun":"Juin","mar":"Mars","may":"Peut","nov":"Novembre","oct":"Octobre","sep":"Septembre"},"my_payroll":{"allowance":"Allocation","basic_salary":"Salaire de base","deductions":"D\u00e9ductions","my_payrolls":"Mes livres de paie","net_salary":"Salaire net"},"my_payrolls":"Mes livres de paie","new_patient":"Nouveau Patient","no_data_available":"aucune donn\u00e9e disponible","notice_board":{"created_at":"cr\u00e9\u00e9 \u00e0","description":"La description","details":"D\u00e9tails du tableau d'affichage","edit":"Modifier le tableau d'affichage","new":"Nouveau tableau d'affichage","notice_board":"Tableau d'affichage","title":"Titre"},"notice_boards":"Tableaux d'affichage","notification":{"mark_all_as_read":"Tout marquer comme lu","notifications":"Notifications","you_don`t_have_any_new_notification":"Vous n`avez aucune nouvelle notification"},"nurse":{"birth_date":"Date de naissance","choose":"Choisir","edit_nurse":"Modifier l'infirmi\u00e8re","new_nurse":"Nouvelle infirmi\u00e8re","nurse":"Infirmi\u00e8re","nurse_details":"D\u00e9tails sur l'infirmi\u00e8re","phone_no":"Pas de t\u00e9l\u00e9phone"},"nurses":"Infirmi\u00e8res","old_patient":"Ancien patient","opd_diagnosis":"Diagnostic OPD","opd_patient":{"appointment_date":"Date de rendez-vous","edit_opd_patient":"Modifier le patient OPD","new_opd_patient":"Nouveau patient OPD","opd_number":"OPD Non","opd_patient":"OPD Patient","opd_patient_details":"D\u00e9tails du patient OPD","opd_patients":"OPD Patients","revisits":"Revisiter","total_visits":"Total des visites","visits":"Visites"},"opd_patients":"OPD Patients","opd_payments":{"add_opd_payment":"Ajouter un paiement Opd","edit_opd_payment":"Modifier le paiement Opd","make_payment":"Effectuer le paiement","payment_mode":"Mode de paiement"},"opd_timeline":"Chronologie OPD","operation_report":{"case_id":"Identifiant de cas","date":"Date","description":"La description","doctor_name":"Nom du docteur","edit_operation_report":"Modifier le rapport d'op\u00e9ration","new_operation_report":"Nouveau rapport d'op\u00e9ration","operation_report":"Rapport d'op\u00e9ration","operation_report_details":"D\u00e9tails du rapport d'op\u00e9ration","operation_reports":"Rapports d'op\u00e9ration","patient_name":"Nom du patient"},"operation_reports":"Rapports d'op\u00e9ration","overview":"Aper\u00e7u","package":{"amount":"Montante","description":"La description","discount":"Remise","edit_package":"Modifier le package","name":"Nom","new_package":"Nouveau package","package":"Paquet","package_details":"D\u00e9tails du paquet","packages":"Paquets","qty":"Qt\u00e9","rate":"Taux","select_service":"S\u00e9lectionnez le service","service":"Un service","total_amount":"Montant total"},"packages":"Paquets","pathologies":"Pathologie","pathology_categories":"Pathologie Cat\u00e9gorie","pathology_category":{"edit_pathology_category":"\u00c9diter Pathologie Cat\u00e9gorie","name":"Nom","new_pathology_category":"Nouvelle Pathologie Cat\u00e9gorie","pathology_categories":"Pathologie Les cat\u00e9gories"},"pathology_test":{"category_name":"Cat\u00e9gorie Nom","charge_category":"Charge Cat\u00e9gorie","edit_pathology_test":"\u00c9diter Pathologie Tester","method":"M\u00e9thode","new_pathology_test":"Nouvelle Pathologie Tester","pathology_test_details":"Pathologie Tester D\u00e9tails","pathology_tests":"Pathologie Les tests","report_days":"rapport Journ\u00e9es","short_name":"Courte Nom","standard_charge":"la norme Charge","subcategory":"Sous Cat\u00e9gorie","test_name":"Tester Nom","test_type":"Tester Type","unit":"Unit\u00e9"},"pathology_tests":"Pathologie Les tests","patient":{"edit_patient":"Modifier le patient","new_patient":"Nouveau patient","patient_details":"D\u00e9tails du patient","total_admissions":"Admissions totales","total_appointments":"Nombre total de rendez-vous","total_cases":"Nombre total de cas"},"patient_admission":{"admission_date":"Date d'admission","agent_name":"Nom d'agent","bed":"Lit","details":"D\u00e9tails sur l'admission des patients","discharge_date":"Date de sortie","doctor":"M\u00e9decin","doctor_name":"Doctor Name","edit_patient_admission":"Modifier l'admission des patients","guardian_address":"Adresse du gardien","guardian_contact":"Contact gardien","guardian_name":"Nom du gardien","guardian_relation":"Relation de gardien","insurance":"Assurance","insurance_name":"Nom de l'assurance","new_patient_admission":"Nouvelle admission de patient","package":"Paquet","package_name":"Nom du paquet","patient":"Patiente","patient_admission":"Admission des patients","patient_admission_id":"ID d'admission du patient","patient_name":"Nom du patient","policy_no":"Politique Non"},"patient_admissions":"Admissions des patients","patient_appointment":"Rendez-vous patient","patient_diagnosis_test":{"action":"action","add_other_diagnosis_property":"Ajouter une autre propri\u00e9t\u00e9 de diagnostic","age":"\u00c2ge","average_glucose":"Glyc\u00e9mie moyenne","blood_pressure":"Pression art\u00e9rielle","cholesterol":"Cholest\u00e9rol","create_patient_diagnosis_test":"Cr\u00e9er un test de diagnostic patient","created_at":"Cr\u00e9\u00e9 \u00e0","diabetes":"Diab\u00e8te","diagnosis":"Diagnostic","diagnosis_category":"Cat\u00e9gorie de diagnostic","diagnosis_property_name":"Nom de la propri\u00e9t\u00e9 de diagnostic","diagnosis_property_value":"Valeur de propri\u00e9t\u00e9 de diagnostic","diagnosis_test":"Tests de diagnostic","doctor":"Docteur","doctor_name":"Nom du docteur","edit_patient_diagnosis_test":"Modifier le test de diagnostic du patient","fasting_blood_sugar":"Glyc\u00e9mie \u00e0 jeun","height":"Hauteur","new_patient_diagnosis_test":"Nouveau test de diagnostic pour les patients","other_diagnosis_property":"Autre propri\u00e9t\u00e9 de diagnostic","patient":"Patient","patient_diagnosis_test":"Tests de diagnostic des patients","patient_diagnosis_test_details":"D\u00e9tails du test de diagnostic du patient","patient_name":"Nom du patient","print_diagnosis_test":"Test de diagnostic d'impression","report_number":"Signaler le num\u00e9ro","urine_sugar":"Urine Sucre","weight":"Poids"},"patients":"Les patients","patients_case_details":"D\u00e9tails du cas des patients","patients_cases":"Cas de patients","payment":{"account":"Compte","account_name":"Nom du compte","amount":"Montante","description":"La description","edit_payment":"Modifier le paiement","new_payment":"Nouveau paiement","pay_to":"Payer pour","payment":"Paiement","payment_date":"Date de paiement","payment_details":"D\u00e9tails de paiement","payment_reports":"Rapports de paiement","payments":"Paiements"},"payments":"Paiements","pharmacist":{"edit_pharmacist":"Modifier le pharmacien","new_pharmacist":"Nouveau pharmacien","pharmacist_details":"D\u00e9tails du pharmacien","pharmacists":"Pharmaciennes"},"pharmacists":"Pharmaciennes","postal":{"address":"Adresse","date":"Date","dispatch":"Envoi","edit_dispatch":"Modifier l`envoi","edit_receive":"Modifier la r\u00e9ception","from_title":"\u00c0 partir du titre","new_dispatch":"Nouvel envoi","new_receive":"Nouvelle r\u00e9ception","postal":"Carte postale","receive":"Recevoir","reference_no":"Num\u00e9ro de r\u00e9ference","to_title":"Au titre"},"postal_dispatch":"Envoi postal","postal_receive":"R\u00e9ception postale","prescription":{"Rx":"Rx","accident":"Accident","advice":"conseils","after_meal":"apr\u00e8s manger","before_meal":"Avant le repas","breast_feeding":"Allaitement maternel","comment":"commentaire","current_medication":"M\u00e9dicament actuel","days":"journ\u00e9es","diabetic":"Diab\u00e9tique","duration":"Dur\u00e9e","edit_prescription":"Modifier la prescription","female_pregnancy":"Grossesse f\u00e9minine","food_allergies":"Allergies alimentaires","health_insurance":"Assurance sant\u00e9","heart_disease":"Maladie cardiaque","high_blood_pressure":"Hypertension art\u00e9rielle","low_income":"Faible revenu","medical_history":"Ant\u00e9c\u00e9dents m\u00e9dicaux","medicine_name":"nom_du_medicament","month":"Mois","new_medicine":"nouveau m\u00e9dicament","new_prescription":"Nouvelle ordonnance","next_visit":"prochaine visite","no_data_available":"Aucune donn\u00e9e disponible","others":"Autres","patient":"Patiente","physical_information":"informations physiques","plus_rate":"Impulsion major\u00e9","prescription":"Prescription","prescription_details":"D\u00e9tails de la prescription","prescriptions":"Prescriptions","problem":"probl\u00e8me","problem_description":"Description du probl\u00e8me","reference":"R\u00e9f\u00e9rence","surgery":"Chirurgie","temperature":"temperature","tendency_bleed":"Saignement de tendance","test":"test","time":"temps","year":"Ann\u00e9e"},"prescriptions":"Prescriptions","profile":{"change_language":"Changer la langue","edit_profile":"Editer le profil","email":"E-mail","first_name":"Pr\u00e9nom","language":"Langue","last_name":"Nom de famille","phone":"T\u00e9l\u00e9phoner","profile":"Profil"},"radiologies":"Radiologie","radiology_categories":"Radiologie Cat\u00e9gorie","radiology_category":{"edit_radiology_category":"\u00c9diter Radiologie Cat\u00e9gorie","name":"Nom","new_radiology_category":"Nouvelle Radiologie Cat\u00e9gorie","radiology_categories":"Radiologie Les cat\u00e9gories"},"radiology_test":{"category_name":"Nom de cat\u00e9gorie","charge_category":"Cat\u00e9gorie de charge","edit_radiology_test":"\u00c9diter Radiologie Tester","new_radiology_test":"Nouvelle Radiologie Tester","radiology_test_details":"Radiologie Tester D\u00e9tails","radiology_tests":"Radiologie Les tests","report_days":"Journ\u00e9es du rapport","short_name":"Nom court","standard_charge":"la norme Charge","subcategory":"Sous-cat\u00e9gorie","test_name":"Nom du test","test_type":"Type de test"},"radiology_tests":"Radiologie Les tests","receptionist":{"edit_receptionist":"Modifier la r\u00e9ceptionniste","new_receptionist":"Nouveau r\u00e9ceptionniste","receptionist":"R\u00e9ceptionniste","receptionist_details":"D\u00e9tails de la r\u00e9ceptionniste","receptionists":"R\u00e9ceptionnistes"},"receptionists":"R\u00e9ceptionnistes","reports":"Rapports","role":{"edit_role":"Modifier le r\u00f4le","new_role":"Nouveau r\u00f4le"},"roles":"R\u00f4les","schedule":{"available_from":"Disponible \u00e0 partir de","available_on":"Disponible le","available_to":"Disponible pour","details":"D\u00e9tails du programme","doctor_name":"Nom du docteur","edit":"Modifier le calendrier","new":"Nouvelle programmation","per_patient_time":"Temps par patient","select_doctor_name":"S\u00e9lectionnez le nom du m\u00e9decin","select_serial_visibility":"S\u00e9lectionnez la visibilit\u00e9 s\u00e9rie","sequential":"S\u00e9quentielle","serial_visibility":"Visibilit\u00e9 s\u00e9rie","timestamp":"Horodatage"},"schedule_label":"Horaire","schedules":"Des horaires","service":{"edit_service":"Modifier le service","given":"Donn\u00e9e","new_service":"Nouveau service","not_given":"Non donn\u00e9","quantity":"Quantit\u00e9","rate":"Taux","service_details":"D\u00e9tails du service"},"services":"Prestations de service","setting":{"address":"Adresse de l'h\u00f4pital","app_logo":"Logo de l'application","app_name":"Nom de l'application","company_name":"Nom de la compagnie","country_code":"Indicatif du pays","currency":"Devise actuelle","hospital_email":"Courriel de l'h\u00f4pital","hospital_from_day":"H\u00f4pital de jour","hospital_from_time":"H\u00f4pital depuis le temps","hospital_phone":"T\u00e9l\u00e9phone de l'h\u00f4pital","image_validation":"L`image doit \u00eatre de 90 x 60 pixels.","social_details":"D\u00e9tails sociaux"},"settings":"R\u00e9glages","short_description":"br\u00e8ve description","sidebar_setting":"Param\u00e8tres des modules","sms":{"date":"Date","message":"Message","new_sms":"Nouveau SMS","only_user_with_registered_phone_will_display":"(Seuls les utilisateurs avec un t\u00e9l\u00e9phone enregistr\u00e9 s`afficheront.)","phone_number":"Num\u00e9ro de T\u00e9l\u00e9phone","role":"R\u00f4le","send":"Envoyer","send_by":"Envoy\u00e9 par","send_sms_by_number_directly":"Envoyez directement des SMS par num\u00e9ro","send_to":"Envoyer \u00e0","sms":"SMS","sms_details":"D\u00e9tails SMS"},"testimonial":{"description":"Description","edit_testimonial":"T\u00e9moignage bearbeiten","name":"Nom","new_testimonial":"Nouveau t\u00e9moignage","profile_error":"Das Dokument muss eine Datei vom Typ sein: jpeg, jpg, png.","testimonial":"T\u00e9moignage","testimonial_detail":"D\u00e9tail du t\u00e9moignage"},"testimonials":"T\u00e9moignages","twitter_url":"URL Twitter","user":{"address1":"Adresse 1","address2":"Adresse 2","address_details":"D\u00e9tails de l'adresse","address_not_found":"Aucune adresse n'a \u00e9t\u00e9 trouv\u00e9e","blood_group":"Groupe sanguin","change_password":"Changer le mot de passe","city":"Ville","designation":"La d\u00e9signation","dob":"Date de naissance","edit_profile":"Editer le profil","edit_user":"Modifier l`utilisateur","education":"\u00c9ducation","email":"E-mail","email_verified_successfully":"Courriel v\u00e9rifi\u00e9 avec succ\u00e8s.","female":"Femme","first_name":"Pr\u00e9nom","gender":"Le sexe","invalid_password":"Le mot de passe actuel est invalide.","last_name":"Nom de famille","logout":"Se d\u00e9connecter","male":"M\u00e2le","name":"Nom","new_user":"Nouvel utilisateur","password":"Mot de passe","password_confirmation":"Confirmez le mot de passe","phone":"T\u00e9l\u00e9phone","qualification":"Qualification","select_blood_group":"S\u00e9lectionnez le groupe sanguin","status":"Statut","user_details":"D\u00e9tails de l'utilisateur","usrs":"Utilisatrice","validate_confirm_password":"Le mot de passe et le mot de passe de confirmation doivent correspondre.","validate_min_character_password":"Le mot de passe doit contenir au moins 6 caract\u00e8res.","zip":"Zip *: fran\u00e7ais"},"users":"Utilisateurs","vaccinated_patient":{"add_vaccinate_patient":"Ajouter un patient vaccin\u00e9","description":"Description","does_no":"Dose Non","dose_given_date":"Dose donn\u00e9e Date","edit_vaccinate_patient":"Modifier le patient vaccin\u00e9","new_vaccinate_patient":"Nouveau patient vaccin\u00e9","patient":"Patient","serial_no":"Num\u00e9ro de s\u00e9rie","vaccinate_patient":"Vacciner le patient","vaccinated_patient":"Patient vaccin\u00e9","vaccination":"Vaccination","vaccine":"Vaccin"},"vaccinated_patients":"Patients vaccin\u00e9s","vaccination":{"brand":"Marque","edit_vaccination":"Modifier la vaccination","manufactured_by":"Fabriqu\u00e9 par","name":"Nom","new_vaccination":"Nouvelle vaccination","vaccinated":"Vaccin\u00e9","vaccinations":"Les vaccinations"},"vaccinations":"Les vaccinations","valid":"Valide","verification":{"another_verify_request":"cliquez ici pour en demander un autre","verify_message":"Avant de continuer, veuillez v\u00e9rifier votre e-mail pour un lien de v\u00e9rification. Si vous n'avez pas re\u00e7u l'e-mail,","verify_your_email_address":"V\u00e9rifiez votre adresse e-mail."},"visitor":{"date":"Date","edit":"Modifier le visiteur","id_card":"Carte d`identit\u00e9","in_time":"\u00c0 l`heure","name":"Nom","new":"Nouveau visiteur","note":"Remarque","number_of_person":"Nombre de personne","out_time":"Temps de sortie","phone":"T\u00e9l\u00e9phone","purpose":"Objectif","visitor":"Visiteuse"},"visitors":"Visiteuses","web_appointment":{"call_now_and_get_a_free_consulting":"Appelez maintenant et obtenez une consultation gratuite","enter_confirm_password":"Entrez Confirmer le mot de passe","enter_description":"Entrez la description","enter_your_first_name":"Entrez votre pr\u00e9nom","enter_your_last_name":"Entrez votre nom de famille","enter_your_password":"Tapez votre mot de passe","make_an_appointment":"Prendre rendez-vous","select_department":"S\u00e9lectionnez le d\u00e9partement","select_doctor":"S\u00e9lectionnez un m\u00e9decin","select_time":"S\u00e9lectionnez l'heure"},"web_contact":{"call_today":"Appelez aujourd'hui","contact_no":"N\u00b0 de contact","enter_your_email":"Entrer votre Email","enter_your_name":"Entrez votre nom","open_hours":"Heures d'ouverture","our_location":"Notre emplacement","phone_number":"Num\u00e9ro de t\u00e9l\u00e9phone","please_enter_your_phone_number":"Veuillez entrer votre num\u00e9ro de t\u00e9l\u00e9phone","select_enquiry":"S\u00e9lectionnez l'enqu\u00eate","send_message":"Envoyer le message","send_us_a_message":"Envoie-nous un message","type_your_message":"Tapez votre message","write_your_message":"\u00c9crivez votre message","your_email":"Votre e-mail","your_message":"Votre message","your_name":"votre nom"},"web_home":{"4_easy_step_and_get_the_world_best_treatment":"4 \u00e9tapes faciles et obtenez le meilleur traitement au monde","about_us":"\u00c0 propos de nous","available_doctors":"M\u00e9decins disponibles","book_an_appointment":"Prenez rendez-vous","book_appointment":"Prendre rendez-vous","book_now":"Reserve maintenant","contact":"Contact","contact_doctors":"Contacter le m\u00e9decin","contact_hospital":"Contacter l'h\u00f4pital","doctors":"M\u00e9decins","doctors_nurses":"M\u00e9decins et infirmi\u00e8res","easy_solutions":"Solutions faciles","happy_patients":"Patients heureux","home":"Accueil","make_appointment":"Prendre un rendez-vous","our_services":"Nos services","our_testimonials":"Nos t\u00e9moignages","patients":"Les patients","patients_beds":"Lits de patients","privacy_policy":"Politique de confidentialit\u00e9","professional_doctors":"M\u00e9decins professionnels","select_doctor":"S\u00e9lectionnez un m\u00e9decin","select_doctors":"S\u00e9lectionnez les m\u00e9decins","services":"Prestations de service","sign_up":"S'inscrire","terms_of_service":"Conditions d'utilisation","testimonials":"T\u00e9moignages","we_are_experienced_healthcare_professionals":"Nous sommes des professionnels de la sant\u00e9 exp\u00e9riment\u00e9s","we_offer_different_services_to_improve_your_health":"Nous offrons diff\u00e9rents services pour am\u00e9liorer votre sant\u00e9","what_our_patient_say_about_medical_treatments":"Ce que nos patients disent de nos traitements m\u00e9dicaux","working_hours":"Heures d'ouverture","years_experience":"Ann\u00e9es d'exp\u00e9rience"},"web_menu":{"about":"Sur","all_rights_reserved_by":"Tous droits r\u00e9serv\u00e9s par","appointment":"Rendez-vous","contact_information":"Coordonn\u00e9es","copyright":"droits d'auteur","login":"Connexion","our_features":"Nos fonctionnalit\u00e9s","useful_link":"Lien utile","working_hours":"Heures d'ouverture"},"web_password":{"password_and_confirm_password_not_match":"Le mot de passe et la confirmation du mot de passe ne correspondent pas.","please_fill_all_the_required_fields":"Veuillez remplir tous les champs obligatoires."},"web_working_hours":{"no_yet_opening_hours":"Pas encore d'heures d'ouverture","opening_hours":"Horaires d'ouvertures"},"weekdays":{"fri":"VEN","mon":"LUN","sat":"ASSISE","sun":"SOLEIL","thu":"JEU","tue":"MAR","wed":"\u00c9POUSER"}},"pt.messages":{"Users":"Usu\u00e1rios","about_us":"Sobre n\u00f3s","account":{"account":"Conta","account_details":"Detalhes da conta","accounts":"Contas","credit":"Cr\u00e9dito","debit":"D\u00e9bito","description":"Descri\u00e7\u00e3o","edit_account":"Editar conta","name":"Nome","new_account":"Nova conta","payments":"Pagamentos","status":"Status","type":"Modelo"},"account_manager":"Gerente de contas","accountant":{"accountant_details":"Detalhes do contador","accountants":"contabilistas","edit_accountant":"Editar contador","new_accountant":"Novo contador"},"accountants":"contabilistas","accounts":"Contas","admin":"Administradores","admins":"Administrador","advanced_payment":{"advanced_payment":"Adiantamento","advanced_payment_details":"Detalhes do pagamento antecipado","advanced_payments":"Adiantamentos","amount":"Montante","date":"Data","edit_advanced_payment":"Editar adiantamento","new_advanced_payment":"Novo adiantamento","patient":"paciente","patient_name":"Nome do paciente","receipt_no":"recibo n\u00e3o"},"advanced_payments":"Adiantamentos","allow_file_type":"Tipos de arquivo permitidos: png, jpg, jpeg.","ambulance":{"ambulance":"Ambul\u00e2ncia","ambulance_details":"Detalhes da ambul\u00e2ncia","ambulances":"Ambul\u00e2ncias","driver_contact":"Contato com o motorista","driver_license":"Carteira de motorista","driver_name":"Nome do motorista","edit_ambulance":"Editar Ambul\u00e2ncia","is_available":"Est\u00e1 dispon\u00edvel","new_ambulance":"Nova Ambul\u00e2ncia","note":"Nota","vehicle_model":"Modelo do ve\u00edculo","vehicle_number":"N\u00famero do ve\u00edculo","vehicle_type":"Tipo de Ve\u00edculo","year_made":"Ano de fabrica\u00e7\u00e3o"},"ambulance_call":{"ambulance_call":"Chamada de ambul\u00e2ncia","ambulance_call_details":"Detalhes da chamada de ambul\u00e2ncia","ambulance_calls":"Chamadas de ambul\u00e2ncia","amount":"Montante","date":"Encontro","driver_name":"Nome do motorista","edit_ambulance_call":"Editar chamada de ambul\u00e2ncia","new_ambulance_call":"Nova chamada de ambul\u00e2ncia","patient":"Paciente","vehicle_model":"Modelo do ve\u00edculo"},"ambulance_calls":"Chamadas de ambul\u00e2ncia","ambulances":"Ambul\u00e2ncias","appointment":{"appointment_calendar":"Calend\u00e1rio de compromissos","appointment_details":"Detalhes do compromisso","appointment_exists":"O e-mail do paciente j\u00e1 existe","appointment_list":"Lista de compromissos","are_you_sure_want_to_cancel":"Tem certeza que deseja cancelar","are_you_sure_want_to_change":"Tem certeza que deseja mudar","available_slot":"Slot Dispon\u00edvel","calendar_view":"Visualiza\u00e7\u00e3o da agenda","change_status":"Alterar status","changed_appointment":"Compromisso alterado","completed":"Conclu\u00eddo","date":"Data","day":"Dia","department_name":"Nome do departamento","description":"Descri\u00e7\u00e3o","doctor":"m\u00e9dico","doctor_department":"Departamento M\u00e9dico","doctor_department_name":"Nome do departamento m\u00e9dico","doctor_name":"Nome do M\u00e9dico","doctor_schedule_not_available_on_this_date":"Agenda do m\u00e9dico n\u00e3o dispon\u00edvel nesta data.","edit_appointment":"Editar compromisso","has_been_cancelled":"foi cancelado.","has_been_changed":"foi mudado.","last_30_days":"\u00daltimos 30 dias","last_7_days":"\u00daltimos 7 dias","last_month":"M\u00eas passado","month":"M\u00eas","new_appointment":"Novo compromisso","no_available":"N\u00e3o dispon\u00edvel","old_patient_email_exists":"O e-mail j\u00e1 existe, selecione paciente antigo.","opd_date":"Data da Opd","patient":"paciente","patient_name":"Nome do paciente","patient_not_exists_or_status_is_not_active":"O paciente n\u00e3o existe ou o status n\u00e3o est\u00e1 ativo.","pending":"Pendente","please_select_appointment_time_slot":"Por favor, selecione o hor\u00e1rio do compromisso","please_select_doctor":"Por favor selecione Doutor","please_select_doctor_department":"Por favor selecione Departamento M\u00e9dico","this_month":"Este m\u00eas","this_week":"Essa semana","today":"Hoje","week":"Semana","yesterday":"Ontem"},"appointment_calendar":"Compromisso. Calend\u00e1rio","appointments":"Compromissos","available_slot":"Slot dispon\u00edvel","bed":{"add":"Adicionar","available":"Dispon\u00edvel","bed":"Cama nova","bed_details":"Detalhes da cama","bed_id":"ID da cama","bed_type":"Tipo de cama","beds":"camas","charge":"Cobrar","description":"Descri\u00e7\u00e3o","edit_bed":"Editar cama","name":"Nome","new_bed":"Cama nova","new_bulk_bed":"Nova cama em massa","not_available":"N\u00e3o dispon\u00edvel"},"bed_assign":{"assign_date":"Atribuir data","assign_date_should_not_be_smaller_than_patient_birth_date":"A data de atribui\u00e7\u00e3o n\u00e3o deve ser menor que a data de nascimento do paciente.","assigned":"Atribu\u00eddo","bed":"cama","bed_assign":"Cama atribuir","bed_assign_details":"Detalhes da atribui\u00e7\u00e3o da cama","bed_assigns":"Cama atribui","bed_name":"Nome da cama","case_id":"ID do caso","description":"Descri\u00e7\u00e3o","discharge_date":"Data da descarga","edit_bed_assign":"Editar atribui\u00e7\u00e3o de cama","ipd_patient_id":"Id do paciente IPD","new_bed_assign":"Nova atribui\u00e7\u00e3o de cama","not_assigned":"N\u00e3o atribu\u00eddo","patient_name":"Nome do paciente"},"bed_assigns":"Cama atribui","bed_management":"Gest\u00e3o da cama","bed_mgt":"Gerenciamento de camas","bed_status":{"admission_date":"Data de admiss\u00e3o","assigned_beds":"Camas atribu\u00eddas","available_beds":"Camas Dispon\u00edveis","bed_name":"Nome da cama","bed_status":"Status da cama","gender":"G\u00eanero","patient_name":"Nome do paciente","phone":"Telefone"},"bed_type":{"bed_type":"Tipo de cama","bed_type_details":"Detalhes do tipo de cama","bed_types":"Tipos de cama","description":"Descri\u00e7\u00e3o","edit_bed_type":"Editar tipo de cama","new_bed_type":"Novo tipo de cama","title":"T\u00edtulo"},"bed_types":"Tipos de cama","beds":"Camas","bill":{"add":"Adicionar","admission_date":"Data da admiss\u00e3o","admission_id":"ID da admiss\u00e3o","amount":"Montante","bill":"Conta","bill_date":"Data da cobran\u00e7a","bill_details":"Detalhes da fatura","bill_id":"ID da fatura","bill_summary":"Resumo da conta","bills":"Contas","calculate":"Calcular","cell_no":"C\u00e9lula","discharge_date":"Data da descarga","doctor_name":"Doctor Name","edit":"Editar","edit_bill":"Editar fatura","generate_bill":"Gerar conta","insurance_name":"Nome do seguro","item_name":"Nome do item","new_bill":"Nova conta","package_name":"Nome do pacote","patient":"paciente","patient_cell_no":"N\u00ba da c\u00e9lula do paciente","patient_dob":"DOB do paciente","patient_email":"E-mail do paciente","patient_gender":"Sexo do paciente","patient_name":"Nome do paciente","policy_no":"Pol\u00edtica n\u00ba","price":"Pre\u00e7o","print_bill":"Imprimir fatura","qty":"Qty","total_amount":"Valor total","total_days":"Total de dias","update_bill":"Atualizar Bill"},"billing":"Faturamento","bills":"Contas","birth_report":{"birth_report":"Relat\u00f3rio de Nascimento","birth_report_details":"Detalhes do relat\u00f3rio de nascimento","birth_reports":"Relat\u00f3rios de Nascimento","case_id":"ID do caso","data_should_not_be_smaller_than_patient_birth_date":"A data n\u00e3o deve ser menor que a data de nascimento do paciente.","date":"Data","description":"Descri\u00e7\u00e3o","doctor_name":"Nome do M\u00e9dico","edit_birth_report":"Editar relat\u00f3rio de nascimento","new_birth_report":"Novo relat\u00f3rio de nascimento","patient_birth_date_not_found":"Data de nascimento do paciente n\u00e3o encontrada.","patient_name":"Nome do paciente"},"birth_reports":"Relat\u00f3rios de Nascimento","blood_bank":"Banco de sangue","blood_banks":"Bancos de sangue","blood_donation":{"bags":"Bolsas","blood_donation":"Doa\u00e7\u00e3o de sangue","donor_name":"Nome do Doador","edit_blood_donation":"Editar Doa\u00e7\u00e3o de Sangue","last_donate_date":"Data da \u00faltima doa\u00e7\u00e3o","new_blood_donation":"Nova Doa\u00e7\u00e3o de Sangue"},"blood_donations":"Doa\u00e7\u00f5es de sangue","blood_donor":{"age":"Idade ","blood_donor":"Doador de Sangue","blood_donor_details":"Detalhes dos doadores de sangue","blood_donors":"Doadores de sangue","blood_group":"Grupo sangu\u00edneo","donation_date":"Data da doa\u00e7\u00e3o","edit_blood_donor":"Editar doador de sangue","gender":"G\u00eanero","last_donation_date":"Data da \u00faltima doa\u00e7\u00e3o","name":"Nome","new_blood_donor":"Novo doador de sangue"},"blood_donors":"Doadores de sangue","blood_issue":{"amount":"Montante","blood_issue":"Emiss\u00e3o de Sangue","doctor_name":"Nome do M\u00e9dico","donor_name":"Donor Name","edit_blood_issue":"Editar sangue","issue_date":"Data de emiss\u00e3o","new_blood_issue":"Nova Quest\u00e3o de Sangue","patient_name":"Nome do paciente","remarks":"Observa\u00e7\u00f5es"},"blood_issues":"Problemas de sangue","call_log":{"call_log":"Registro de chamadas","call_type":"Tipo de Chamada","edit":"Editar registro de chamadas","follow_up_date":"Data de Acompanhamento","incoming":"Entrada","name":"Nome","new":"Novo registro de chamadas","note":"Nota","outgoing":"Extrovertida","phone":"telefone","received_on":"Recebido em"},"call_logs":"Registro de chamadas","case":{"case":"Caso","case_date":"Data do Caso","case_details":"Detalhes do caso","case_id":"ID do caso","date":"Data","description":"Descri\u00e7\u00e3o","doctor":"m\u00e9dico","edit_case":"Editar caso","fee":"Taxa","new_case":"Novo caso","patient":"paciente","phone":"Telefone"},"case_handler":{"case_handler":"Manipulador de casos","case_handler_detail":"Detalhes do manipulador de caso","edit_case_handler":"Editar manipulador de caso","new_case_handler":"Novo manipulador de casos"},"case_handlers":"Manipuladores de casos","case_manager":"Gerente de caso","cases":"Estojos","change_password":{"change_password":"Alterar a senha","confirm_password":"Confirme a Senha","current_password":"Senha atual","new_password":"Nova Senha"},"charge":{"charge_category":"Categoria de cobran\u00e7a","charge_details":"Detalhes da cobran\u00e7a","code":"C\u00f3digo","edit_charge":"Editar cobran\u00e7a","new_charge":"Nova cobran\u00e7a","standard_charge":"Carga padr\u00e3o"},"charge_categories":"Categorias de cobran\u00e7a","charge_category":{"charge_categories":"Categorias de cobran\u00e7a","charge_category_details":"Detalhes da categoria de cobran\u00e7a","charge_type":"Tipo de cobran\u00e7a","edit_charge_category":"Editar categoria de cobran\u00e7a","new_charge_category":"Nova categoria de cobran\u00e7a"},"charges":"Cobran\u00e7as","cms":"CMS","common":{"action":"A\u00e7\u00e3o","actions":"A\u00e7\u00f5es","active":"Ativo","add":"Adicionar","address":"Endere\u00e7o","apply":"Aplique","are_you_sure_want_to_delete_this":"Tem certeza de que deseja excluir isso ","back":"Voltar","cancel":"Cancelar","canceled":"cancelada","cant_be_deleted":"n\u00e3o pode ser deletado","choose":"Escolha","confirm":"confirme","created_at":"Criado em","created_on":"Criado em","custom":"Personalizada","de_active":"Desativado","delete":"Excluir","deleted":"Exclu\u00edda","deleted_successfully":"Apagado com sucesso","description":"Descri\u00e7\u00e3o","detail":"detalhes","edit":"Editar","export_to_excel":"Exportar para Excel","filter_options":"Op\u00e7\u00f5es de filtro","from":"a partir de","has_been_deleted":"foi deletado.","invalid_country_code":"C\u00f3digo de pa\u00eds inv\u00e1lido","invalid_number":"N\u00famero inv\u00e1lido","is_available":"Est\u00e1 dispon\u00edvel","last_updated":"\u00daltima atualiza\u00e7\u00e3o","n\/a":"N\/A","name":"Nome","new":"novo","next":"Pr\u00f3ximo","no":"N\u00e3o","not_found":"n\u00e3o encontrado","ok":"OK","previous":"Anterior","profile":"Perfil","reset":"Redefinir","save":"Salvar","saved_successfully":"Salvo com sucesso.","search":"Procurar","status":"Status","status_updated_successfully":"Status atualizado com sucesso.","this_action_is_not_allowed_for_default_record":"Esta a\u00e7\u00e3o n\u00e3o \u00e9 permitida para registro padr\u00e3o.","to":"Para","too_long":"Demasiado longo","too_short":"Curto demais","total":"Total","updated_at":"\u00daltima atualiza\u00e7\u00e3o","updated_successfully":"Atualizado com sucesso","view":"Visualizar","view_attachment":"Ver anexo","yes":"sim"},"contact_us":"Entre em contato","currency":{"add_currency_code_as_per_three_letter_iso_code":"Adicione o c\u00f3digo da moeda de acordo com o c\u00f3digo ISO de tr\u00eas letras","currency":"Moeda","currency_code":"C\u00f3digo da moeda","currency_icon":"\u00cdcone de moeda","currency_name":"Nome da moeda","edit_currency":"Editar moeda","new_currency":"Nova moeda","you_can_find_out_here":"Voc\u00ea pode descobrir aqui"},"currency_setting":"Moedas","dashboard":{"available_beds":"Camas Dispon\u00edveis","dashboard":"painel de controle","doctors":"Doutoras","income_and_expense_report":"Relat\u00f3rio de receitas e despesas","income_and_expense_reports":"Relat\u00f3rios de receitas e despesas","no_enquiries_yet":"Ainda n\u00e3o h\u00e1 perguntas","no_notice_yet":"Ainda sem aviso","notice_boards":"Quadros de aviso","patients":"Pacientes","title":"T\u00edtulo","total_advance_payments":"Valor do pagamento antecipado","total_bills":"Montante de dinheiro","total_invoices":"Valor da fatura","total_payments":"Valor do pagamento"},"death_report":{"case_id":"ID do caso","date":"Data","death_report":"Relat\u00f3rio da morte","death_report_details":"Detalhes do relat\u00f3rio de \u00f3bito","death_reports":"Relat\u00f3rios de \u00f3bito","description":"Descri\u00e7\u00e3o","doctor_name":"Nome do M\u00e9dico","edit_death_report":"Editar relat\u00f3rio de morte","new_death_report":"Novo relat\u00f3rio de \u00f3bito","patient_name":"Nome do paciente"},"death_reports":"Relat\u00f3rios de \u00f3bito","department":"departamento","departments":"departamentos","diagnosis_category":{"category_name":"Nome da Categoria","description":"Descri\u00e7\u00e3o","diagnosis_categories":"Categoria de diagn\u00f3stico","diagnosis_category":"Categoria de diagn\u00f3stico","diagnosis_category_details":"Detalhes da categoria de diagn\u00f3stico","edit_diagnosis_category":"Editar categoria de diagn\u00f3stico","new_diagnosis_category":"Nova categoria de diagn\u00f3stico"},"doc_type":{"edit_doc_type":"Editar tipo de documento","name":"Nome","new_doc_type":"Novo tipo de documento"},"doctor":{"doctor_details":"Editar m\u00e9dico","edit_doctor":"Editar m\u00e9dico","new_doctor":"Novo m\u00e9dico","specialist":"Especialista"},"doctor_department":{"description":"Descri\u00e7\u00e3o","doctor_department":"Departamento M\u00e9dico","doctor_department_details":"Detalhes do departamento m\u00e9dico","doctor_departments":"Departamentos m\u00e9dicos","edit_doctor_department":"Editar departamento m\u00e9dico","new_doctor_department":"Novo departamento m\u00e9dico","title":"T\u00edtulo"},"doctor_departments":"Departamento M\u00e9dico","doctor_opd_charge":{"doctor":"M\u00e9dico","doctor_name":"Nome do M\u00e9dico","doctor_opd_charge":"Taxa de OPD do m\u00e9dico","edit_doctor_opd_charge":"Editar Carga do M\u00e9dico OPD","new_doctor_opd_charge":"Nouveau Doctor OPD Charge","standard_charge":"Cobran\u00e7a Padr\u00e3o"},"doctor_opd_charges":"M\u00e9dico OPD Encargos","doctors":"Doutoras","doctors_list":"Lista de m\u00e9dicos","document":{"attachment":"Anexo","document":"Documento","document_detail":"Detalhes do Documento","document_type":"Tipo de documento","document_type_details":"Detalhes do tipo de documento","download":"Download","edit_document":"Editar documento","new_document":"Novo documento","notes":"Notas","patient":"paciente","select_document_type":"Selecionar tipo de documento","select_patient":"Selecionar paciente","title":"T\u00edtulo","uploaded_by":"Enviado por"},"document_types":"Tipos de documento","documents":"Documentos","email":{"attachment":"Anexos","message":"mensagem","subject":"Sujeita","to":"Para"},"employee_payroll":{"allowance":"subs\u00eddio","basic_salary":"Sal\u00e1rio b\u00e1sico","deductions":"dedu\u00e7\u00f5es","edit_employee_payroll":"Editar folha de pagamento dos funcion\u00e1rios","employee":"Empregado","employee_name":"Nome do empregado","employee_payroll":"Folha de pagamento dos funcion\u00e1rios","employee_payroll_details":"Detalhes da folha de pagamento dos funcion\u00e1rios","employee_payrolls":"Folha de pagamento dos funcion\u00e1rios","month":"M\u00eas","net_salary":"Sal\u00e1rio l\u00edquido","new_employee_payroll":"Nova folha de pagamento dos funcion\u00e1rios","not_paid":"N\u00e3o pago","paid":"Pago","payroll_id":"ID da folha de pagamento","role":"Fun\u00e7\u00e3o","sr_no":"Sr No","year":"Ano"},"employee_payrolls":"Folha de pagamento dos funcion\u00e1rios","enquiries":"Inqu\u00e9ritos","enquiry":{"contact":"Contato","email":"O email","enquiry_details":"Detalhes da consulta","enquiry_send_successfully":"Consulta enviada com sucesso","message":"mensagem","name":"Nome","not_viewed":"N\u00e3o visto","read":"Ler","received_on":"Recebido em","send_enquiry":"Enviar inqu\u00e9rito","type":"Tipo","unread":"N\u00e3o lida","viewed_by":"Visualizado por"},"expense":{"amount":"Montante","attachment":"Anexo","choose":"Escolher","date":"Encontro","description":"Descri\u00e7\u00e3o","document_error":"O documento deve ser um arquivo do tipo: jpeg, jpg, png, pdf, doc, docx.","download":"Baixar","edit_expense":"Editar Despesa","expense":"Despesa","expense_details":"Detalhes da Despesa","expense_head":"Cabe\u00e7a de Despesa","invoice_number":"N\u00famero da Fatura","name":"Nome","new_expense":"Nova Despesa","select_expense_head":"Selecione Cabe\u00e7a de Despesa"},"expenses":"Despesas","facebook_url":"URL Facebook","file_name":"Nome do arquivo","finance":"Finan\u00e7a","front_cms":"Cms frontais","front_cms_services":"Servi\u00e7os CMS frontais","front_office":"Front Office","front_service":"Servi\u00e7o Frontal","front_setting":{"about_us_description":"Descri\u00e7\u00e3o","about_us_details":"Sobre n\u00f3s detalhes","about_us_image":"Imagem","about_us_mission":"Miss\u00e3o","about_us_title":"T\u00edtulo","appointment_details":"Detalhes do compromisso","front_setting_details":"detalhe de ajuste frontal","home_page_box_description":"Descri\u00e7\u00e3o da caixa da p\u00e1gina inicial","home_page_box_title":"T\u00edtulo da caixa da p\u00e1gina inicial","home_page_certified_box_description":"Descri\u00e7\u00e3o da caixa certificada da p\u00e1gina inicial","home_page_certified_box_title":"T\u00edtulo da caixa certificada da p\u00e1gina inicial","home_page_certified_doctor_description":"P\u00e1gina inicial Descri\u00e7\u00e3o do m\u00e9dico certificado","home_page_certified_doctor_image":"Imagem de m\u00e9dico certificado da p\u00e1gina inicial","home_page_certified_doctor_text":"Texto de m\u00e9dico certificado na p\u00e1gina inicial","home_page_certified_doctor_title":"T\u00edtulo de m\u00e9dico certificado na p\u00e1gina inicial","home_page_description":"Descri\u00e7\u00e3o da p\u00e1gina inicial","home_page_experience":"Experi\u00eancia na p\u00e1gina inicial","home_page_image":"Imagem da p\u00e1gina inicial","home_page_step_1_description":"P\u00e1gina inicial Etapa 1 Descri\u00e7\u00e3o","home_page_step_1_title":"T\u00edtulo da Etapa 1 da P\u00e1gina Inicial","home_page_step_2_description":"P\u00e1gina inicial Descri\u00e7\u00e3o da Etapa 2","home_page_step_2_title":"T\u00edtulo da Etapa 2 da P\u00e1gina Inicial","home_page_step_3_description":"P\u00e1gina inicial Etapa 3 Descri\u00e7\u00e3o","home_page_step_3_title":"T\u00edtulo da Etapa 3 da P\u00e1gina Inicial","home_page_step_4_description":"P\u00e1gina inicial Etapa 4 Descri\u00e7\u00e3o","home_page_step_4_title":"T\u00edtulo da Etapa 4 da P\u00e1gina Inicial","home_page_title":"T\u00edtulo da p\u00e1gina inicial","privacy_policy":"Pol\u00edtica de Privacidade","terms_condition_details":"Detalhes dos Termos e Condi\u00e7\u00f5es","terms_conditions":"termos e Condi\u00e7\u00f5es"},"front_settings":"Configura\u00e7\u00f5es frontais","general":"Geral","hospital_activities":"Atividades hospitalares","hospital_blood_bank":{"blood_bank":"Banco de sangue","blood_bank_details":"Detalhes do banco de sangue","blood_banks":"Bancos de sangue","blood_group":"Grupo sangu\u00edneo","edit_blood_group":"Editar grupo sangu\u00edneo","new_blood_group":"Novo grupo sangu\u00edneo","remained_bags":"Sacos restantes"},"hospital_charges":"Encargos Hospitalares","hospital_schedule":"Hor\u00e1rio do Hospital","hospital_schedules":{"exists_doctor_schedule":"Alguns m\u00e9dicos agendaram seus dias em dias n\u00e3o verificados, ent\u00e3o voc\u00ea tem certeza de que deseja realizar esta opera\u00e7\u00e3o?"},"icon":"\u00cdcone","income":"Renda","incomes":{"amount":"Montante","attachment":"Anexo","choose":"Escolher","date":"Encontro","description":"Descri\u00e7\u00e3o","document_error":"O documento deve ser um arquivo do tipo: jpeg, jpg, png, pdf, doc, docx.","download":"Baixar","edit_income":"Editar Renda","income_details":"Detalhes da Renda","income_head":"Chefe de Renda","incomes":"Rendimentos","invoice_number":"N\u00famero da Fatura","name":"Nome","new_income":"Nova Renda","select_income_head":"Selecionar Chefe de Renda"},"instagram_url":"URL do Instagram","insurance":{"discount":"Desconto","disease_details":"Detalhes da doen\u00e7a","diseases_charge":"Taxa de doen\u00e7as","diseases_name":"Nome das doen\u00e7as","edit_insurance":"Editar seguro","hospital_rate":"Taxa hospitalar","insurance":"Seguro","insurance_code":"C\u00f3digo de Seguro","insurance_details":"Detalhes do seguro","insurance_no":"Seguro N\u00e3o","insurances":"seguros","new_insurance":"Novo seguro","remark":"observa\u00e7\u00e3o","service_tax":"Taxa de servi\u00e7o","total_amount":"Valor total"},"insurances":"seguros","inventory":"Invent\u00e1rio","investigation_report":{"attachment":"Anexo","birth_date_validation":"A data do relat\u00f3rio de investiga\u00e7\u00e3o n\u00e3o deve ser menor que a data de nascimento do paciente.","date":"Data","description":"Descri\u00e7\u00e3o","doctor":"m\u00e9dico","edit_investigation_report":"Editar relat\u00f3rio de investiga\u00e7\u00e3o","investigation_report":"Relat\u00f3rio de investiga\u00e7\u00e3o","investigation_report_details":"Detalhes do relat\u00f3rio de investiga\u00e7\u00e3o","investigation_reports":"Relat\u00f3rios de investiga\u00e7\u00e3o","new_investigation_report":"Novo relat\u00f3rio de investiga\u00e7\u00e3o","patient":"paciente","title":"T\u00edtulo"},"investigation_reports":"Relat\u00f3rios de investiga\u00e7\u00e3o","invoice":{"account_name":"Nome da conta","add":"Adicionar","amount":"Montante","description":"Descri\u00e7\u00e3o","discount":"Discount","edit":"Editar","edit_invoice":"Editar fatura","hospital_address":"Endere\u00e7o do hospital","invoice":"fatura","invoice_date":"Data da fatura","invoice_details":"Detalhes da fatura","invoice_id":"ID da fatura","invoices":"faturas","new_invoice":"Nova fatura","not_paid":"N\u00e3o pago","paid":"Pago","patient":"paciente","patient_id":"ID do paciente","price":"Pre\u00e7o","print_invoice":"Imprimir fatura","qty":"Qty","sub_total":"Subtotal","total":"Montante total"},"invoices":"faturas","ipd_bill":{"discount_in_number":"Desconto em n\u00famero","discount_in_percentage":"Desconto em Porcentagem","gross_total":"Total bruto","net_payable_amount":"Valor l\u00edquido a pagar","other_charges":"Outras cobran\u00e7as","paid_amount":"Quantia paga","tax_in_number":"N\u00famero fiscal","tax_in_percentage":"Imposto em porcentagem","total_charges":"Total de encargos"},"ipd_charges":"Cobran\u00e7as","ipd_consultant_register":"Instru\u00e7\u00e3o do Consultor","ipd_diagnosis":"Diagn\u00f3stico","ipd_opd":"IPD\/OPD","ipd_patient":{"admission_date":"Data de admiss\u00e3o","bed_id":"Cama","bed_type_id":"Tipo de cama","bill_status":"Status da conta","bp":"Press\u00e3o Arterial","case_id":"Caso","doctor_id":"Doutor","edit_ipd_patient":"Editar Paciente IPD","height":"Altura","ipd_number":"IPD N\u00e3o","ipd_patient":"Paciente IPD","ipd_patient_details":"Detalhes do paciente IPD","ipd_patients":"Pacientes IPD","is_old_patient":"\u00c9 um paciente idoso","new_ipd_patient":"Novo paciente IPD","notes":"Notas","patient_id":"Paciente","symptoms":"Sintomas","the_bed_field_is_required":"O campo cama \u00e9 obrigat\u00f3rio.","the_case_field_is_required":"O campo caso \u00e9 obrigat\u00f3rio.","weight":"Peso"},"ipd_patient_charges":{"applied_charge":"Taxa aplicada","charge_category_id":"Categoria de cobran\u00e7a","charge_id":"C\u00f3digo","charge_type_id":"Tipo de cobran\u00e7a","date":"Data","new_charge":"Adicionar encargos","standard_charge":"Cobran\u00e7a padr\u00e3o"},"ipd_patient_consultant_register":{"applied_date":"Data de aplica\u00e7\u00e3o","doctor_id":"Doutor","instruction":"Instru\u00e7\u00e3o","instruction_date":"Data de instru\u00e7\u00e3o","new_consultant_register":"Adicionar Instru\u00e7\u00e3o do Consultor"},"ipd_patient_diagnosis":{"description":"Descri\u00e7\u00e3o","document":"Documento","edit_ipd_diagnosis":"Editar diagn\u00f3stico","new_ipd_diagnosis":"Adicionar diagn\u00f3stico","report_date":"Data do relat\u00f3rio","report_type":"Tipo de relat\u00f3rio"},"ipd_patient_prescription":{"category_id":"Categoria de Medicamentos","dosage":"Dosagem","edit_prescription":"Editar prescri\u00e7\u00e3o","footer_note":"Nota de rodap\u00e9","header_note":"Nota de cabe\u00e7alho","instruction":"Instru\u00e7\u00e3o","ipd_no":"IPD N\u00e3o","medicine_id":"Rem\u00e9dio","new_prescription":"Adicionar prescri\u00e7\u00e3o","prescription_details":"Detalhes da prescri\u00e7\u00e3o","print_prescription":"Imprimir Prescri\u00e7\u00e3o"},"ipd_patient_timeline":{"date":"Data","description":"Descri\u00e7\u00e3o","document":"Documento","edit_ipd_timeline":"Editar linha do tempo","new_ipd_timeline":"Adicionar linha do tempo","no_timeline_found":"Nenhuma linha de tempo encontrada","title":"T\u00edtulo","visible_to_person":"Vis\u00edvel para a pessoa"},"ipd_patients":"Pacientes IPD","ipd_payment":"Pagamento IPD","ipd_payments":{"add_ipd_payment":"Adicionar pagamento IPd","edit_ipd_payment":"Edit IPD Payment","make_payment":"Efetuar pagamento","payment_mode":"Modo de pagamento"},"ipd_prescription":"Prescri\u00e7\u00f5es","ipd_timelines":"Cronogramas","issued_item":{"are_you_sure_want_to_return_this_item":"Tem certeza de que deseja devolver este item","available_quantity":"Quantidade dispon\u00edvel","department_id":"Tipo de usu\u00e1rio","description":"Descri\u00e7\u00e3o","edit_issued_item":"Editar Item Emitido","issued_by":"Emitido por","issued_date":"Data de emiss\u00e3o","issued_item":"Item Emitido","issued_item_details":"Detalhes de itens emitidos","issued_items":"Itens Emitidos","item":"Item","item_category":"Categoria de Item","item_return":"Devolver item","item_returned":"Retornou","new_issued_item":"Novo Item Emitido","quantity":"Quantidade","return_date":"Data de retorno","user_id":"Emitir para"},"issued_items":"Itens Emitidos","item":{"available_quantity":"Quantidade dispon\u00edvel","description":"Descri\u00e7\u00e3o","edit_item":"Editar Item","item":"Item","item_category":"Item Categoria","item_details":"Item Detalhes","items":"Itens","name":"Nome","new_item":"Novo Item","unit":"Unidade"},"item_category":{"edit_item_category":"Editar Categoria de Item","item_categories":"Categorias de item","item_category":"Categoria de Item","name":"Nome","new_item_category":"Nova Categoria de Item"},"item_stock":{"attachment":"Anexo","description":"Descri\u00e7\u00e3o","edit_item_stock":"Editar estoque do item","item":"Item","item_category":"Categoria de Item","item_stock":"Item Estoque","item_stock_details":"Detalhes de estoque do item","item_stocks":"Estoque de itens","new_item_stock":"Novo estoque de item","purchase_price":"Pre\u00e7o de compra","quantity":"Quantidade","store_name":"Nome da loja","supplier_name":"Nome do Fornecedor"},"items":"Itens","items_categories":"Categorias de Itens","items_stocks":"Estoque de itens","lab_tech":{"edit_lab_tech":"Editar T\u00e9cnico de Laborat\u00f3rio","lab_tech_detail":"Detalhes do t\u00e9cnico de laborat\u00f3rio","lab_technician":"T\u00e9cnico de laborat\u00f3rio","new_lab_tech":"Novo t\u00e9cnico de laborat\u00f3rio"},"lab_technicians":"T\u00e9cnicos de laborat\u00f3rio","language":{"Arabic":"\u00e1rabe","Chinese":"chin\u00eas","English":"Ingl\u00eas","French":"Franc\u00eas","German":"Alem\u00e3o","Portuguese":"Portugu\u00eas","Russian":"russo","Spanish":"Espanhol","Turkish":"turco"},"linkedIn_url":"URL do LinkedIn","live_consultation":{"add_credential":"Adicionar credencial","client_video":"V\u00eddeo do cliente","consultation_date":"Data de Consulta","consultation_duration_minutes":"Minutos de dura\u00e7\u00e3o da consulta","consultation_title":"T\u00edtulo de consulta","created_by":"Criado por","created_for":"Criado para","disabled":"Desativado","edit_live_consultation":"Editar consulta ao vivo","edit_live_meeting":"Editar Reuni\u00e3o ao vivo","enable":"Habilitar","host_video":"Hospedar v\u00eddeo","join_now":"Entrar","live_consultation":"Consultoria ao vivo","new_live_consultation":"Nova consulta ao vivo","new_live_meeting":"Nova reuni\u00e3o ao vivo","staff_list":"Lista de trabalhadores","type":"Tipo","type_number":"Digite o n\u00famero","zoom_api_key":"Chave da API de zoom","zoom_api_secret":"Segredo da API do Zoom"},"live_consultations":"Consultas ao vivo","live_meeting":"Reuni\u00e3o ao vivo","live_meetings":"Viver Encontros","mail":"Enviar","make_an_appointment":"Marque um compromisso","medicine":{"brand":"Marca","brand_name":"Marca","buying_price":"Pre\u00e7o de compra","category":"Categoria","category_id":"ID da categoria","description":"Descri\u00e7\u00e3o","edit_medicine":"Editar medicamento","edit_medicine_brand":"Editar marca de medicamento","edit_medicine_category":"Editar Categoria Medicina","medicine":"medicamento","medicine_brands":"Marcas de Medicina","medicine_brands_details":"Detalhes da marca de medicamentos","medicine_category":"Categoria da medicina","medicine_category_details":"Detalhes da categoria de medicina","medicine_details":"Detalhes do medicamento","medicines":"medicamentos","name":"Nome","new_brand":"Nova marca","new_medicine":"Novo medicamento","new_medicine_brand":"Nova marca de medicamentos","new_medicine_category":"Nova categoria de medicamentos","salt_composition":"Composi\u00e7\u00e3o do sal","selling_price":"Pre\u00e7o de venda","side_effects":"Efeitos colaterais"},"medicine_brands":"Marcas de medicamentos","medicine_categories":"Categorias de medicamentos","medicines":"medicamentos","message":{"date":"Encontro","message":"Mensagem","messages":"Mensagens","messages_details":"detalhes da Mensagem","new_message":"Nova Mensagem","select_user":"Selecionar Usu\u00e1rio","send_to":"Enviar para","sender_name":"Nome do Remetente","subject":"Sujeito"},"months":{"apr":"abril","aug":"Agosto","dec":"dezembro","feb":"Fevereiro","jan":"Janeiro","july":"Julho","jun":"Junho","mar":"Marchar","may":"Poderia","nov":"novembro","oct":"Outubro","sep":"Setembro"},"my_payroll":{"allowance":"subs\u00eddio","basic_salary":"Sal\u00e1rio b\u00e1sico","deductions":"Dedu\u00e7\u00f5es","my_payrolls":"Minhas folhas de pagamento","net_salary":"Sal\u00e1rio l\u00edquido"},"my_payrolls":"Minhas folhas de pagamento","new_patient":"Novo paciente","no_data_available":"Sem dados dispon\u00edveis na tabela","notice_board":{"created_at":"criado em","description":"Descri\u00e7\u00e3o","details":"Detalhes do quadro de avisos","edit":"Editar quadro de avisos","new":"Novo quadro de avisos","notice_board":"Quadro de not\u00edcias","title":"T\u00edtulo"},"notice_boards":"Quadros de avisos","notification":{"mark_all_as_read":"Marcar tudo como lido","notifications":"Notifica\u00e7\u00f5es","you_don`t_have_any_new_notification":"Voc\u00ea n\u00e3o tem nenhuma notifica\u00e7\u00e3o nova"},"nurse":{"birth_date":"Data de nascimento","choose":"Escolha","edit_nurse":"Editar enfermeira","new_nurse":"Nova enfermeira","nurse":"Enfermeira","nurse_details":"Detalhes da enfermeira","phone_no":"Telefone n\u00e3o"},"nurses":"Enfermeiras","old_patient":"Paciente Antigo","opd_diagnosis":"Diagn\u00f3stico OPD","opd_patient":{"appointment_date":"Data do encontro","edit_opd_patient":"Editar paciente OPD","new_opd_patient":"Novo paciente OPD","opd_number":"OPD N\u00e3o","opd_patient":"Paciente OPD","opd_patient_details":"Detalhes do paciente OPD","opd_patients":"Pacientes OPD","revisits":"Revisitar","total_visits":"Visitas totais","visits":"Visitas"},"opd_patients":"Pacientes OPD","opd_payments":{"add_opd_payment":"Adicionar Pagamento Opd","edit_opd_payment":"Editar Pagamento Opd","make_payment":"Fa\u00e7a o pagamento","payment_mode":"Modo de pagamento"},"opd_timeline":"Cronograma OPD","operation_report":{"case_id":"ID do caso","date":"Data","description":"Descri\u00e7\u00e3o","doctor_name":"Nome do M\u00e9dico","edit_operation_report":"Editar relat\u00f3rio de opera\u00e7\u00e3o","new_operation_report":"Novo relat\u00f3rio de opera\u00e7\u00e3o","operation_report":"Relat\u00f3rio de Opera\u00e7\u00e3o","operation_report_details":"Detalhes do relat\u00f3rio de opera\u00e7\u00e3o","operation_reports":"Relat\u00f3rios de Opera\u00e7\u00e3o","patient_name":"Nome do paciente"},"operation_reports":"Relat\u00f3rios de Opera\u00e7\u00e3o","overview":"Vis\u00e3o geral","package":{"amount":"Montante","description":"Descri\u00e7\u00e3o","discount":"Desconto","edit_package":"Editar pacote","name":"Nome","new_package":"Novo pacote","package":"Pacote","package_details":"Detalhes do pacote","packages":"Pacotes","qty":"Qty","rate":"Avaliar","select_service":"Selecionar servi\u00e7o","service":"Servi\u00e7o","total_amount":"Valor total"},"packages":"Pacotes","pathologies":"Patologia","pathology_categories":"Patologia Categoria","pathology_category":{"edit_pathology_category":"Editar Patologia Categoria","name":"Nome","new_pathology_category":"Nova Patologia Categoria","pathology_categories":"Patologia Categorias"},"pathology_test":{"category_name":"Categoria Nome","charge_category":"Carregar Categoria","edit_pathology_test":"Editar Patologia Teste","method":"M\u00e9todo","new_pathology_test":"Nova Patologia Teste","pathology_test_details":"Patologia Teste Detalhes","pathology_tests":"Patologia Testes","report_days":"Relat\u00f3rio Dias","short_name":"Curta Nome","standard_charge":"Padr\u00e3o Carregar","subcategory":"Sub Categoria","test_name":"Teste Nome","test_type":"Teste Tipo","unit":"Unidade"},"pathology_tests":"Patologia Testes","patient":{"edit_patient":"Editar paciente","new_patient":"Novo paciente","patient_details":"Detalhes do paciente","total_admissions":"Admiss\u00f5es totais","total_appointments":"Total de Compromissos","total_cases":"Total de casos"},"patient_admission":{"admission_date":"Data da admiss\u00e3o","agent_name":"Nome do agente","bed":"cama","details":"Detalhes da admiss\u00e3o do paciente","discharge_date":"Data da descarga","doctor":"m\u00e9dico","doctor_name":"Nome do M\u00e9dico","edit_patient_admission":"Editar admiss\u00e3o do paciente","guardian_address":"Endere\u00e7o do guardi\u00e3o","guardian_contact":"Contato do guardi\u00e3o","guardian_name":"Nome do guardi\u00e3o","guardian_relation":"Rela\u00e7\u00e3o com o Guardi\u00e3o","insurance":"Seguro","insurance_name":"Nome do seguro","new_patient_admission":"Admiss\u00e3o de novo paciente","package":"Pacote","package_name":"Nome do pacote","patient":"paciente","patient_admission":"Admiss\u00e3o do Paciente","patient_admission_id":"ID de admiss\u00e3o do paciente","patient_name":"Nome do paciente","policy_no":"Pol\u00edtica n\u00ba"},"patient_admissions":"Admiss\u00f5es de Pacientes","patient_appointment":"Consulta do paciente","patient_diagnosis_test":{"action":"A\u00e7ao","add_other_diagnosis_property":"Adicione outra propriedade de diagn\u00f3stico","age":"Era","average_glucose":"Glicose m\u00e9dia","blood_pressure":"Press\u00e3o sangu\u00ednea","cholesterol":"Colesterol","create_patient_diagnosis_test":"Criar teste de diagn\u00f3stico do paciente","created_at":"Criado em","diabetes":"Diabetes","diagnosis":"Diagn\u00f3stico","diagnosis_category":"Categoria de diagn\u00f3stico","diagnosis_property_name":"Nome da propriedade de diagn\u00f3stico","diagnosis_property_value":"Valor da propriedade de diagn\u00f3stico","diagnosis_test":"Testes de diagn\u00f3stico","doctor":"M\u00e9dico","doctor_name":"Nome m\u00e9dico","edit_patient_diagnosis_test":"Editar teste de diagn\u00f3stico do paciente","fasting_blood_sugar":"A\u00e7\u00facar no sangue em jejum","height":"Altura","new_patient_diagnosis_test":"Novo teste de diagn\u00f3stico do paciente","other_diagnosis_property":"Outra propriedade de diagn\u00f3stico","patient":"Paciente","patient_diagnosis_test":"Testes de diagn\u00f3stico do paciente","patient_diagnosis_test_details":"Detalhes do teste de diagn\u00f3stico do paciente","patient_name":"Nome do paciente","print_diagnosis_test":"Teste de diagn\u00f3stico de impress\u00e3o","report_number":"N\u00famero do relat\u00f3rio","urine_sugar":"A\u00e7\u00facar na Urina","weight":"Peso"},"patients":"Pacientes","patients_case_details":"Detalhes do caso do paciente","patients_cases":"Casos de pacientes","payment":{"account":"Conta","account_name":"Nome da conta","amount":"Pagar para","description":"Descri\u00e7\u00e3o","edit_payment":"Editar pagamento","new_payment":"Novo pagamento","pay_to":"Pagar para","payment":"Pagamento","payment_date":"Data do pagamento","payment_details":"Detalhes do pagamento","payment_reports":"Relat\u00f3rios de pagamento","payments":"Pagamentos"},"payments":"Pagamentos","pharmacist":{"edit_pharmacist":"Editar farmac\u00eautico","new_pharmacist":"Novo farmac\u00eautico","pharmacist_details":"Detalhes do farmac\u00eautico","pharmacists":"Farmac\u00eauticos"},"pharmacists":"Farmac\u00eauticos","postal":{"address":"Endere\u00e7o","date":"Encontro","dispatch":"Despacho","edit_dispatch":"Editar despacho","edit_receive":"Editar Receber","from_title":"Do T\u00edtulo","new_dispatch":"Novo Despacho","new_receive":"Nova Receber","postal":"Cart\u00e3o postal","receive":"Receber","reference_no":"N\u00famero de refer\u00eancia","to_title":"Para T\u00edtulo"},"postal_dispatch":"Despacho Postal","postal_receive":"Receber pelo correio","prescription":{"Rx":"Rx","accident":"Acidente","advice":"adendo","after_meal":"depois da refei\u00e7\u00e3o","before_meal":"antes da refei\u00e7\u00e3o","breast_feeding":"Amamenta\u00e7\u00e3o","comment":"Comente","current_medication":"Medica\u00e7\u00e3o atual","days":"dias","diabetic":"Diab\u00e9tica","duration":"Dura\u00e7\u00e3o","edit_prescription":"Editar Prescri\u00e7\u00e3o","female_pregnancy":"Gravidez Feminina","food_allergies":"Alergias a comida","health_insurance":"Plano de sa\u00fade","heart_disease":"Doen\u00e7a card\u00edaca","high_blood_pressure":"Press\u00e3o alta","low_income":"Baixa renda","medical_history":"Hist\u00f3rico m\u00e9dico","medicine_name":"nome_medicina","month":"M\u00eas","new_medicine":"novo medicamento","new_prescription":"Nova prescri\u00e7\u00e3o","next_visit":"pr\u00f3xima visita","no_data_available":"nenhum dado encontrado","others":"Outras","patient":"Paciente","physical_information":"informa\u00e7\u00e3o f\u00edsica","plus_rate":"Pulso taxa","prescription":"Prescri\u00e7\u00e3o","prescription_details":"Detalhes da prescri\u00e7\u00e3o","prescriptions":"Prescri\u00e7\u00f5es","problem":"problema","problem_description":"Descri\u00e7\u00e3o do Problema","reference":"Refer\u00eancia","surgery":"Cirurgia","temperature":"temperatura","tendency_bleed":"Sangramento por tend\u00eancia","test":"teste","time":"Tempo","year":"Ano"},"prescriptions":"Prescri\u00e7\u00f5es","profile":{"change_language":"Alterar idioma","edit_profile":"Editar Perfil","email":"E-mail","first_name":"Primeiro nome","language":"l\u00edngua","last_name":"Sobrenome","phone":"Telefone","profile":"Perfil"},"radiologies":"Radiologia","radiology_categories":"Radiologia Categoria","radiology_category":{"edit_radiology_category":"Editar Radiologia Categoria","name":"Nome","new_radiology_category":"Nova Radiologia Categoria","radiology_categories":"Radiologia Categorias"},"radiology_test":{"category_name":"Categoria Nome","charge_category":"Carregar Categoria","edit_radiology_test":"Editar Radiologia Teste","new_radiology_test":"Nova Radiologia Teste","radiology_test_details":"Radiologia Teste Detalhes","radiology_tests":"Radiologia Testes","report_days":"Relat\u00f3rio Dias","short_name":"Curta Nome","standard_charge":"Padr\u00e3o Carregar","subcategory":"Sub Categoria","test_name":"Teste Nome","test_type":"Teste Tipo"},"radiology_tests":"Radiologia Testes","receptionist":{"edit_receptionist":"Editar recepcionista","new_receptionist":"Nova recepcionista","receptionist":"recepcionista","receptionist_details":"Detalhes da recepcionista","receptionists":"Recepcionistas"},"receptionists":"Recepcionistas","reports":"Relat\u00f3rios","role":{"edit_role":"Editar fun\u00e7\u00e3o","new_role":"Nova fun\u00e7\u00e3o"},"roles":"Pap\u00e9is","schedule":{"available_from":"Dispon\u00edvel a partir de","available_on":"Dispon\u00edvel em","available_to":"Dispon\u00edvel para","details":"Detalhes da programa\u00e7\u00e3o","doctor_name":"Nome do M\u00e9dico","edit":"Editar programa\u00e7\u00e3o","new":"Nova programa\u00e7\u00e3o","per_patient_time":"Por tempo do paciente","select_doctor_name":"Selecionar nome do m\u00e9dico","select_serial_visibility":"Selecionar visibilidade serial","sequential":"Sequential","serial_visibility":"Serial Visibility","timestamp":"Timestamp"},"schedule_label":"Cronograma","schedules":"hor\u00e1rios","service":{"edit_service":"Servi\u00e7o de edi\u00e7\u00e3o","given":"Dado","new_service":"Novo servi\u00e7o","not_given":"N\u00e3o fornecido","quantity":"quantidade","rate":"Avaliar","service_details":"Detalhes do servi\u00e7o"},"services":"Servi\u00e7os","setting":{"address":"Endere\u00e7o do hospital","app_logo":"Logotipo do aplicativo","app_name":"Nome do aplicativo","company_name":"Nome da empresa","country_code":"C\u00f3digo do pa\u00eds","currency":"Moeda atual","hospital_email":"Email do Hospital","hospital_from_day":"Hospital do dia","hospital_from_time":"Hospital do Tempo","hospital_phone":"Telefone do hospital","image_validation":"A imagem deve ter pixel 90 x 60.","social_details":"Detalhes sociais"},"settings":"Configura\u00e7\u00f5es","short_description":"Pequena descri\u00e7\u00e3o","sidebar_setting":"Configura\u00e7\u00f5es dos m\u00f3dulos","sms":{"date":"Encontro","message":"Mensagem","new_sms":"Novo SMS","only_user_with_registered_phone_will_display":"(Somente usu\u00e1rios com um telefone registrado ser\u00e3o exibidos.)","phone_number":"N\u00famero de Telefone","role":"Fun\u00e7\u00e3o","send":"Enviar","send_by":"Enviar Por","send_sms_by_number_directly":"Envie SMS por n\u00famero diretamente","send_to":"Enviar Para","sms":"SMS","sms_details":"Detalhes do SMS"},"testimonial":{"description":"Descri\u00e7\u00e3o","edit_testimonial":"Editar Testemunho","new_testimonial":"Novo Testemunho","nome":"Nome","profile_error":"O documento deve ser um arquivo do tipo: jpeg, jpg, png.","testimonial":"Depoimento","testimonial_detail":"Detalhe do depoimento"},"testimonials":"Testemunhos","twitter_url":"URL do Twitter","user":{"address1":"Endere\u00e7o 1","address2":"Endere\u00e7o 2","address_details":"Detalhes do endere\u00e7o","address_not_found":"Nenhum detalhe de endere\u00e7o encontrado","blood_group":"Grupo sangu\u00edneo","change_password":"Changer le mot de passe","city":"Cidade","designation":"Designa\u00e7\u00e3o","dob":"Data de nascimento","edit_profile":"Editer le profil","edit_user":"Editar usu\u00e1rio","education":"educa\u00e7\u00e3o","email":"E-mail","email_verified_successfully":"E-mail verificado com sucesso.","female":"F\u00eameo","first_name":"Primeiro nome","gender":"G\u00eanero","invalid_password":"A senha atual \u00e9 inv\u00e1lida.","last_name":"Sobrenome","logout":"Se d\u00e9connecter","male":"Macho","name":"Nome","new_user":"Novo usu\u00e1rio","password":"Senha","password_confirmation":"Confirmar senha","phone":"Telefone","qualification":"Qualifica\u00e7\u00e3o","select_blood_group":"Selecionar grupo sangu\u00edneo","status":"Status","user_details":"Detalhes do usuario","usrs":"Do utilizador","validate_confirm_password":"A senha e a senha de confirma\u00e7\u00e3o devem corresponder.","validate_min_character_password":"A senha deve conter pelo menos 6 caracteres.","zip":"Zip"},"users":"Comercial","vaccinated_patient":{"add_vaccinate_patient":"Adicionar Paciente Vacinado","description":"Descri\u00e7\u00e3o","does_no":"Dose N\u00e3o","dose_given_date":"Dose Dado Data","edit_vaccinate_patient":"Editar Vacinar Paciente","new_vaccinate_patient":"Novo Paciente Vacinar","patient":"Paciente","serial_no":"N\u00famero de s\u00e9rie","vaccinate_patient":"Vacinar Paciente","vaccinated_patient":"Paciente Vacinado","vaccination":"Vacina\u00e7\u00e3o","vaccine":"Vacina"},"vaccinated_patients":"Pacientes Vacinados","vaccination":{"brand":"Marca","edit_vaccination":"Editar Vacina\u00e7\u00e3o","manufactured_by":"Fabricado por","name":"Nome","new_vaccination":"Nova Vacina\u00e7\u00e3o","vaccinated":"Vacinado","vaccinations":"Vacinas"},"vaccinations":"Vacinas","valid":"V\u00e1lida","verification":{"another_verify_request":"clique aqui para solicitar outro","verify_message":"Antes de continuar, verifique se h\u00e1 um link de verifica\u00e7\u00e3o em seu e-mail.Se voc\u00ea n\u00e3o recebeu o e-mail,\n","verify_your_email_address":"Verifique seu endere\u00e7o de e-mail."},"visitor":{"date":"Encontro","edit":"Editar Visitante","id_card":"Carteira de identidade","in_time":"Em tempo","name":"Nome","new":"Novo Visitante","note":"Nota","number_of_person":"N\u00famero de pessoas","out_time":"Out Time","phone":"telefone","purpose":"Objetivo","visitor":"Visitante"},"visitors":"Visitantes","web_appointment":{"call_now_and_get_a_free_consulting":"Ligue agora e obtenha uma consultoria gratuita","enter_confirm_password":"Digite a senha de confirma\u00e7\u00e3o","enter_description":"Insira a descri\u00e7\u00e3o","enter_your_first_name":"Digite seu primeiro nome","enter_your_last_name":"Digite seu sobrenome","enter_your_password":"Coloque sua senha","make_an_appointment":"Marque uma consulta","select_department":"Selecione o Departamento","select_doctor":"Selecione o m\u00e9dico","select_time":"Selecione o tempo"},"web_contact":{"call_today":"Liga hoje","contact_no":"Contato N\u00e3o","enter_your_email":"Digite seu e-mail","enter_your_name":"Digite seu nome","open_hours":"Hor\u00e1rio de funcionamento","our_location":"nossa localiza\u00e7\u00e3o","phone_number":"N\u00famero de telefone","please_enter_your_phone_number":"Por favor, digite seu n\u00famero de telefone","select_enquiry":"Selecione Inqu\u00e9rito","send_message":"Enviar mensagem","send_us_a_message":"Envie-nos uma mensagem","type_your_message":"Digite sua mensagem","write_your_message":"Escreva sua mensagem","your_email":"Seu email","your_message":"Sua mensagem","your_name":"Seu nome"},"web_home":{"4_easy_step_and_get_the_world_best_treatment":"4 Passo F\u00e1cil e Obtenha o Melhor Tratamento do Mundo","about_us":"Sobre n\u00f3s","available_doctors":"M\u00e9dicos Dispon\u00edveis","book_an_appointment":"Marque uma consulta","book_appointment":"Anota\u00e7\u00e3o de livro","book_now":"Agende agora","contact":"Contato","contact_doctors":"Fale com o m\u00e9dico","contact_hospital":"Contate o Hospital","doctors":"Doutoras","doctors_nurses":"M\u00e9dicos e enfermeiras","easy_solutions":"Solu\u00e7\u00f5es f\u00e1ceis","happy_patients":"Pacientes Felizes","home":"Casa","make_appointment":"Marque uma consulta","our_services":"Nossos servi\u00e7os","our_testimonials":"Nossos Testemunhos","patients":"Pacientes","patients_beds":"Camas de Pacientes","privacy_policy":"Pol\u00edtica de Privacidade","professional_doctors":"Doutores profissionais","select_doctor":"Selecione o m\u00e9dico","select_doctors":"Selecione M\u00e9dicos","services":"Servi\u00e7os","sign_up":"Inscrever-se","terms_of_service":"Termos de servi\u00e7o","testimonials":"Testemunhos","we_are_experienced_healthcare_professionals":"Somos profissionais de sa\u00fade experientes","we_offer_different_services_to_improve_your_health":"Oferecemos diversos servi\u00e7os para melhorar sua sa\u00fade","what_our_patient_say_about_medical_treatments":"O que nossos pacientes dizem sobre nossos tratamentos m\u00e9dicos","working_hours":"Jornada de trabalho","years_experience":"Anos de experi\u00eancia"},"web_menu":{"about":"Cerca de","all_rights_reserved_by":"All Rights Reserved by","appointment":"Compromisso","contact_information":"Informa\u00e7\u00f5es de contato","copyright":"direito autoral","login":"Conecte-se","our_features":"Nossos Recursos","useful_link":"Link \u00datil","working_hours":"Jornada de trabalho"},"web_password":{"password_and_confirm_password_not_match":"Senha e Confirmar senha n\u00e3o coincidem.","please_fill_all_the_required_fields":"Por favor, preencha todos os campos obrigat\u00f3rios."},"web_working_hours":{"no_yet_opening_hours":"Ainda n\u00e3o h\u00e1 hor\u00e1rio de funcionamento","opening_hours":"Hor\u00e1rio de Funcionamento"},"weekdays":{"fri":"SEX","mon":"SEG","sat":"SENTADA","sun":"SOL","thu":"QUI","tue":"TER","wed":"QUA"}},"ru.messages":{"about_us":"\u041e \u043d\u0430\u0441","account":{"account":"\u0443\u0447\u0435\u0442\u043d\u0430\u044f \u0437\u0430\u043f\u0438\u0441\u044c","account_details":"\u0414\u0430\u043d\u043d\u044b\u0435 \u0443\u0447\u0435\u0442\u043d\u043e\u0439 \u0437\u0430\u043f\u0438\u0441\u0438","accounts":"\u0421\u0447\u0435\u0442\u0430","credit":"\u041a\u0440\u0435\u0434\u0438\u0442","debit":"\u0421\u043f\u0438\u0441\u0430\u043d\u0438\u0435 \u0441\u0440\u0435\u0434\u0441\u0442\u0432","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_account":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0430\u043a\u043a\u0430\u0443\u043d\u0442","name":"\u0438\u043c\u044f","new_account":"\u041d\u043e\u0432\u0430\u044f \u0443\u0447\u0435\u0442\u043d\u0430\u044f \u0437\u0430\u043f\u0438\u0441\u044c","payments":"\u043f\u043b\u0430\u0442\u0435\u0436\u0438","status":"\u041f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0434\u0435\u043b","type":"\u0422\u0438\u043f"},"account_manager":"\u041c\u0435\u043d\u0435\u0434\u0436\u0435\u0440 \u043f\u043e \u0440\u0430\u0431\u043e\u0442\u0435 \u0441 \u043a\u043b\u0438\u0435\u043d\u0442\u0430\u043c\u0438","accountant":{"accountant_details":"\u0414\u0430\u043d\u043d\u044b\u0435 \u0431\u0443\u0445\u0433\u0430\u043b\u0442\u0435\u0440\u0430","accountants":"\u0431\u0443\u0445\u0433\u0430\u043b\u0442\u0435\u0440\u0430","edit_accountant":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0431\u0443\u0445\u0433\u0430\u043b\u0442\u0435\u0440\u0430","new_accountant":"\u041d\u043e\u0432\u044b\u0439 \u0431\u0443\u0445\u0433\u0430\u043b\u0442\u0435\u0440"},"accountants":"\u0431\u0443\u0445\u0433\u0430\u043b\u0442\u0435\u0440\u0430","accounts":"\u0421\u0447\u0435\u0442\u0430","admin":"\u0410\u0434\u043c\u0438\u043d\u044b","admins":"\u0410\u0434\u043c\u0438\u043d\u0438\u0441\u0442\u0440\u0430\u0442\u043e\u0440","advanced_payment":{"advanced_payment":"\u0410\u0432\u0430\u043d\u0441\u043e\u0432\u044b\u0439 \u043f\u043b\u0430\u0442\u0435\u0436","advanced_payment_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0430\u0432\u0430\u043d\u0441\u043e\u0432\u043e\u0433\u043e \u043f\u043b\u0430\u0442\u0435\u0436\u0430","advanced_payments":"\u0410\u0432\u0430\u043d\u0441\u043e\u0432\u044b\u0435 \u043f\u043b\u0430\u0442\u0435\u0436\u0438","amount":"\u0414\u0430\u0442\u0430","date":"\u0414\u0430\u0442\u0430","edit_advanced_payment":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0430\u0432\u0430\u043d\u0441\u043e\u0432\u044b\u0439 \u043f\u043b\u0430\u0442\u0435\u0436","new_advanced_payment":"\u041d\u043e\u0432\u044b\u0439 \u0430\u0432\u0430\u043d\u0441\u043e\u0432\u044b\u0439 \u043f\u043b\u0430\u0442\u0435\u0436","patient":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442","patient_name":"\u0418\u043c\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","receipt_no":"\u041a\u0432\u0438\u0442\u0430\u043d\u0446\u0438\u044f \u2116"},"advanced_payments":"\u0410\u0432\u0430\u043d\u0441\u043e\u0432\u044b\u0435 \u043f\u043b\u0430\u0442\u0435\u0436\u0438","allow_file_type":"\u0414\u043e\u043f\u0443\u0441\u0442\u0438\u043c\u044b\u0435 \u0442\u0438\u043f\u044b \u0444\u0430\u0439\u043b\u043e\u0432: png, jpg, jpeg.","ambulance":{"ambulance":"\u0441\u043a\u043e\u0440\u0430\u044f \u043f\u043e\u043c\u043e\u0449\u044c","ambulance_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0441\u043a\u043e\u0440\u043e\u0439 \u043f\u043e\u043c\u043e\u0449\u0438","ambulances":"Ambulances","driver_contact":"\u0412\u043e\u0434\u0438\u0442\u0435\u043b\u044c \u041a\u043e\u043d\u0442\u0430\u043a\u0442","driver_license":"\u0412\u043e\u0434\u0438\u0442\u0435\u043b\u044c\u0441\u043a\u0438\u0435 \u043f\u0440\u0430\u0432\u0430","driver_name":"\u0418\u043c\u044f \u0432\u043e\u0434\u0438\u0442\u0435\u043b\u044f","edit_ambulance":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0441\u043a\u043e\u0440\u0443\u044e \u043f\u043e\u043c\u043e\u0449\u044c","is_available":"\u0414\u043e\u0441\u0442\u0443\u043f\u0435\u043d","new_ambulance":"\u041d\u043e\u0432\u0430\u044f \u0441\u043a\u043e\u0440\u0430\u044f \u043f\u043e\u043c\u043e\u0449\u044c","note":"\u0417\u0430\u043c\u0435\u0442\u043a\u0430","vehicle_model":"\u041c\u043e\u0434\u0435\u043b\u044c \u0430\u0432\u0442\u043e\u043c\u043e\u0431\u0438\u043b\u044f","vehicle_number":"\u041d\u043e\u043c\u0435\u0440 \u0430\u0432\u0442\u043e\u043c\u043e\u0431\u0438\u043b\u044f","vehicle_type":"\u0442\u0438\u043f \u043c\u0430\u0448\u0438\u043d\u044b","year_made":"\u0413\u043e\u0434 \u043f\u0440\u043e\u0438\u0437\u0432\u043e\u0434\u0441\u0442\u0432\u0430"},"ambulance_call":{"ambulance_call":"\u0412\u044b\u0437\u043e\u0432 \u0441\u043a\u043e\u0440\u043e\u0439 \u043f\u043e\u043c\u043e\u0449\u0438","ambulance_call_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0432\u044b\u0437\u043e\u0432\u0430 \u0441\u043a\u043e\u0440\u043e\u0439 \u043f\u043e\u043c\u043e\u0449\u0438","ambulance_calls":"\u0412\u044b\u0437\u043e\u0432\u044b \u0441\u043a\u043e\u0440\u043e\u0439 \u043f\u043e\u043c\u043e\u0449\u0438","amount":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","date":"\u0414\u0430\u0442\u0430","driver_name":"\u0418\u043c\u044f \u0432\u043e\u0434\u0438\u0442\u0435\u043b\u044f","edit_ambulance_call":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0432\u044b\u0437\u043e\u0432 \u0441\u043a\u043e\u0440\u043e\u0439 \u043f\u043e\u043c\u043e\u0449\u0438","new_ambulance_call":"\u041d\u043e\u0432\u044b\u0439 \u0432\u044b\u0437\u043e\u0432 \u0441\u043a\u043e\u0440\u043e\u0439 \u043f\u043e\u043c\u043e\u0449\u0438","patient":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442","vehicle_model":"\u041c\u043e\u0434\u0435\u043b\u044c \u0430\u0432\u0442\u043e\u043c\u043e\u0431\u0438\u043b\u044f"},"ambulance_calls":"\u0412\u044b\u0437\u043e\u0432\u044b \u0441\u043a\u043e\u0440\u043e\u0439 \u043f\u043e\u043c\u043e\u0449\u0438","ambulances":"\u041c\u0430\u0448\u0438\u043d\u044b \u0441\u043a\u043e\u0440\u043e\u0439 \u043f\u043e\u043c\u043e\u0449\u0438","appointment":{"appointment_calendar":"\u041a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c \u0432\u0441\u0442\u0440\u0435\u0447","appointment_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0432\u0441\u0442\u0440\u0435\u0447\u0438","appointment_exists":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430 \u0443\u0436\u0435 \u0441\u0443\u0449\u0435\u0441\u0442\u0432\u0443\u0435\u0442","appointment_list":"\u0421\u043f\u0438\u0441\u043e\u043a \u0432\u0441\u0442\u0440\u0435\u0447","are_you_sure_want_to_cancel":"\u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u043e\u0442\u043c\u0435\u043d\u0438\u0442\u044c","are_you_sure_want_to_change":"\u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0438\u0437\u043c\u0435\u043d\u0438\u0442\u044c","available_slot":"\u0414\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0439 \u0441\u043b\u043e\u0442","calendar_view":"\u041f\u0440\u043e\u0441\u043c\u043e\u0442\u0440 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044f","change_status":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0441\u0442\u0430\u0442\u0443\u0441","changed_appointment":"\u0418\u0437\u043c\u0435\u043d\u0435\u043d\u043e \u043d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0435","completed":"\u0417\u0430\u0432\u0435\u0440\u0448\u0435\u043d\u043e","date":"\u0414\u0430\u0442\u0430","day":"\u0414\u0435\u043d\u044c","department_name":"\u0418\u043c\u044f \u043e\u0442\u0434\u0435\u043b\u0430","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","doctor":"\u0414\u043e\u043a\u0442\u043e\u0440","doctor_department":"\u0414\u043e\u043a\u0442\u043e\u0440\u0441\u043a\u043e\u0435 \u043e\u0442\u0434\u0435\u043b\u0435\u043d\u0438\u0435","doctor_department_name":"\u0418\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430 \u043e\u0442\u0434\u0435\u043b\u0435\u043d\u0438\u044f","doctor_name":"\u0418\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430","doctor_schedule_not_available_on_this_date":"\u0420\u0430\u0441\u043f\u0438\u0441\u0430\u043d\u0438\u0435 \u0432\u0440\u0430\u0447\u0435\u0439 \u043d\u0430 \u044d\u0442\u0443 \u0434\u0430\u0442\u0443 \u043d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u043d\u043e.","edit_appointment":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0432\u0441\u0442\u0440\u0435\u0447\u0443","has_been_cancelled":"\u0431\u044b\u043b\u0430 \u043e\u0442\u043c\u0435\u043d\u0435\u043d\u0430.","has_been_changed":"\u0431\u044b\u043b \u0438\u0437\u043c\u0435\u043d\u0435\u043d.","last_30_days":"\u041f\u043e\u0441\u043b\u0435\u0434\u043d\u0438\u0435 30 \u0434\u043d\u0435\u0439","last_7_days":"\u041f\u043e\u0441\u043b\u0435\u0434\u043d\u0438\u0435 7 \u0434\u043d\u0435\u0439","last_month":"\u041f\u0440\u043e\u0448\u043b\u044b\u0439 \u043c\u0435\u0441\u044f\u0446","month":"\u041c\u0435\u0441\u044f\u0446","new_appointment":"\u041d\u043e\u0432\u0430\u044f \u0432\u0441\u0442\u0440\u0435\u0447\u0430","no_available":"\u041d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u0435\u043d","old_patient_email_exists":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430 \u0443\u0436\u0435 \u0441\u0443\u0449\u0435\u0441\u0442\u0432\u0443\u0435\u0442, \u043f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0432\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0441\u0442\u0430\u0440\u043e\u0433\u043e \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430.","opd_date":"\u0414\u0430\u0442\u0430 \u043e\u043f\u0435\u0440\u0430\u0446\u0438\u0438","patient":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442","patient_name":"\u0418\u043c\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","patient_not_exists_or_status_is_not_active":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442 \u043d\u0435 \u0441\u0443\u0449\u0435\u0441\u0442\u0432\u0443\u0435\u0442 \u0438\u043b\u0438 \u0441\u0442\u0430\u0442\u0443\u0441 \u043d\u0435 \u0430\u043a\u0442\u0438\u0432\u0435\u043d.","pending":"\u0412 \u043e\u0436\u0438\u0434\u0430\u043d\u0438\u0438","please_select_appointment_time_slot":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0432\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0432\u0440\u0435\u043c\u0435\u043d\u043d\u043e\u0439 \u0438\u043d\u0442\u0435\u0440\u0432\u0430\u043b \u0432\u0441\u0442\u0440\u0435\u0447\u0438","please_select_doctor":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0432\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0414\u043e\u043a\u0442\u043e\u0440","please_select_doctor_department":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0432\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043e\u0442\u0434\u0435\u043b\u0435\u043d\u0438\u0435 \u0432\u0440\u0430\u0447\u0430","this_month":"\u042d\u0442\u043e\u0442 \u043c\u0435\u0441\u044f\u0446","this_week":"\u041d\u0430 \u044d\u0442\u043e\u0439 \u043d\u0435\u0434\u0435\u043b\u0435","today":"\u0421\u0435\u0433\u043e\u0434\u043d\u044f","week":"\u041d\u0435\u0434\u0435\u043b\u044f","yesterday":"\u0412\u0447\u0435\u0440\u0430\u0448\u043d\u0438\u0439 \u0434\u0435\u043d\u044c"},"appointment_calendar":"\u041d\u0430\u0437\u043d\u0430\u0447\u0438\u0442\u044c. \u041a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c","appointments":"\u041d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0439","available_slot":"\u0414\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0439 \u0441\u043b\u043e\u0442","bed":{"add":"\u0434\u043e\u0431\u0430\u0432\u043b\u044f\u0442\u044c","available":"\u0434\u043e\u0441\u0442\u0443\u043f\u043d\u043e","bed":"\u041d\u043e\u0432\u0430\u044f \u043a\u0440\u043e\u0432\u0430\u0442\u044c","bed_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043a\u0440\u043e\u0432\u0430\u0442\u0438","bed_id":"\u041f\u043e\u0441\u0442\u0435\u043b\u044c \u042f \u0431\u044b","bed_type":"\u0422\u0438\u043f \u043a\u0440\u043e\u0432\u0430\u0442\u0438","beds":"\u041a\u0440\u043e\u0432\u0430\u0442\u0438","charge":"\u0417\u0430\u0440\u044f\u0436\u0430\u0442\u044c","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_bed":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043a\u0440\u043e\u0432\u0430\u0442\u044c","name":"\u0438\u043c\u044f","new_bed":"\u041d\u043e\u0432\u0430\u044f \u043a\u0440\u043e\u0432\u0430\u0442\u044c","new_bulk_bed":"\u041d\u043e\u0432\u0430\u044f \u043d\u0430\u0441\u044b\u043f\u043d\u0430\u044f \u043a\u0440\u043e\u0432\u0430\u0442\u044c","not_available":"\u041d\u0435\u0442 \u0432 \u043d\u0430\u043b\u0438\u0447\u0438\u0438"},"bed_assign":{"assign_date":"\u041d\u0430\u0437\u043d\u0430\u0447\u0438\u0442\u044c \u0434\u0430\u0442\u0443","assign_date_should_not_be_smaller_than_patient_birth_date":"\u0414\u0430\u0442\u0430 \u043d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u0438\u044f \u043d\u0435 \u0434\u043e\u043b\u0436\u043d\u0430 \u0431\u044b\u0442\u044c \u043c\u0435\u043d\u044c\u0448\u0435 \u0434\u0430\u0442\u044b \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430.","assigned":"\u041d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u043e","bed":"\u041f\u043e\u0441\u0442\u0435\u043b\u044c","bed_assign":"\u041d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0435 \u043a\u0440\u043e\u0432\u0430\u0442\u0438","bed_assign_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u0438\u044f \u043a\u0440\u043e\u0432\u0430\u0442\u0438","bed_assigns":"\u041a\u0440\u043e\u0432\u0430\u0442\u044c \u043d\u0430\u0437\u043d\u0430\u0447\u0430\u0435\u0442","bed_name":"\u0418\u043c\u044f \u043a\u0440\u043e\u0432\u0430\u0442\u0438","case_id":"\u0441\u043b\u0443\u0447\u0430\u0439 \u042f \u0431\u044b","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","discharge_date":"\u0414\u0430\u0442\u0430 \u0432\u044b\u043f\u0438\u0441\u043a\u0438","edit_bed_assign":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0435 \u043a\u0440\u043e\u0432\u0430\u0442\u0438","ipd_patient_id":"\u0418\u0434\u0435\u043d\u0442\u0438\u0444\u0438\u043a\u0430\u0442\u043e\u0440 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430 IPD","new_bed_assign":"\u041d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0435 \u043d\u043e\u0432\u043e\u0439 \u043a\u0440\u043e\u0432\u0430\u0442\u0438","not_assigned":"\u041d\u0435 \u043d\u0430\u0437\u043d\u0430\u0447\u0435\u043d","patient_name":"\u0418\u043c\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430"},"bed_assigns":"\u041a\u0440\u043e\u0432\u0430\u0442\u044c \u043d\u0430\u0437\u043d\u0430\u0447\u0430\u0435\u0442","bed_management":"\u0423\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u0438\u0435 \u043a\u0440\u043e\u0432\u0430\u0442\u044c\u044e","bed_mgt":"\u0423\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u0438\u0435 \u043a\u0440\u043e\u0432\u0430\u0442\u044c\u044e","bed_status":{"admission_date":"\u0414\u0430\u0442\u0430 \u043f\u043e\u0441\u0442\u0443\u043f\u043b\u0435\u043d\u0438\u044f","assigned_beds":"\u041d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u043d\u044b\u0435 \u043a\u0440\u043e\u0432\u0430\u0442\u0438","available_beds":"\u0414\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0435 \u043a\u0440\u043e\u0432\u0430\u0442\u0438","bed_name":"\u0418\u043c\u044f \u043a\u0440\u043e\u0432\u0430\u0442\u0438","bed_status":"\u0421\u043e\u0441\u0442\u043e\u044f\u043d\u0438\u0435 \u043a\u0440\u043e\u0432\u0430\u0442\u0438","gender":"\u041f\u043e\u043b","patient_name":"\u0418\u043c\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d"},"bed_type":{"bed_type":"\u0422\u0438\u043f \u043a\u0440\u043e\u0432\u0430\u0442\u0438","bed_type_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0442\u0438\u043f\u0430 \u043a\u0440\u043e\u0432\u0430\u0442\u0438","bed_types":"\u0422\u0438\u043f\u044b \u043a\u0440\u043e\u0432\u0430\u0442\u0435\u0439","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_bed_type":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0442\u0438\u043f \u043a\u0440\u043e\u0432\u0430\u0442\u0438","new_bed_type":"\u041d\u043e\u0432\u044b\u0439 \u0442\u0438\u043f \u043a\u0440\u043e\u0432\u0430\u0442\u0438","title":"\u0437\u0430\u0433\u043b\u0430\u0432\u0438\u0435"},"bed_types":"\u0422\u0438\u043f\u044b \u043a\u0440\u043e\u0432\u0430\u0442\u0435\u0439","beds":"\u041a\u0440\u043e\u0432\u0430\u0442\u0438","bill":{"Calculate":"\u0420\u0430\u0441\u0441\u0447\u0438\u0442\u0430\u0442\u044c","add":"\u0434\u043e\u0431\u0430\u0432\u043b\u044f\u0442\u044c","admission_date":"\u0414\u0430\u0442\u0430 \u043f\u043e\u0441\u0442\u0443\u043f\u043b\u0435\u043d\u0438\u044f","admission_id":"ID \u043f\u0440\u0438\u0435\u043c\u0430","amount":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","bill":"\u0411\u0438\u043b\u043b","bill_date":"\u0411\u0438\u043b\u043b \u0414\u0430\u0442\u0430","bill_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0441\u0447\u0435\u0442\u0435","bill_id":"\u0418\u0434\u0435\u043d\u0442\u0438\u0444\u0438\u043a\u0430\u0442\u043e\u0440 \u0441\u0447\u0435\u0442\u0430","bill_summary":"\u0421\u0432\u043e\u0434\u043a\u0430 \u0441\u0447\u0435\u0442\u0430","bills":"\u0431\u0430\u043d\u043a\u043d\u043e\u0442\u044b","cell_no":"\u041d\u043e\u043c\u0435\u0440 \u044f\u0447\u0435\u0439\u043a\u0438","discharge_date":"\u0414\u0430\u0442\u0430 \u0432\u044b\u043f\u0438\u0441\u043a\u0438","doctor_name":"\u0418\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430","edit":"\u0440\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c","edit_bill":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0441\u0447\u0435\u0442","generate_bill":"\u0421\u043e\u0437\u0434\u0430\u0442\u044c \u0441\u0447\u0435\u0442","insurance_name":"\u0421\u0442\u0440\u0430\u0445\u043e\u0432\u043e\u0435 \u0438\u043c\u044f","item_name":"\u0418\u043c\u044f \u044d\u043b\u0435\u043c\u0435\u043d\u0442\u0430","new_bill":"\u041d\u043e\u0432\u044b\u0439 \u0411\u0438\u043b\u043b","package_name":"\u0418\u043c\u044f \u043f\u0430\u043a\u0435\u0442\u0430","patient":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442","patient_cell_no":"\u2116 \u044f\u0447\u0435\u0439\u043a\u0438 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","patient_dob":"\u0422\u0435\u0440\u043f\u0435\u043b\u0438\u0432\u044b\u0439 \u0434\u0430\u0442\u0430 \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u044f","patient_email":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","patient_gender":"\u041f\u043e\u043b \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","patient_name":"\u0418\u043c\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","policy_no":"\u041f\u043e\u043b\u0438\u0442\u0438\u043a\u0430 \u2116","price":"\u0426\u0435\u043d\u0430","print_bill":"\u0420\u0430\u0441\u043f\u0435\u0447\u0430\u0442\u0430\u0442\u044c \u0411\u0438\u043b\u043b","qty":"\u041a\u043e\u043b-\u0432\u043e","total_amount":"\u041e\u0431\u0449\u0435\u0435 \u043a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","total_days":"\u0412\u0441\u0435\u0433\u043e \u0434\u043d\u0435\u0439","update_bill":"\u041e\u0431\u043d\u043e\u0432\u0438\u0442\u044c \u0441\u0447\u0435\u0442"},"billing":"\u0411\u0438\u043b\u043b\u0438\u043d\u0433","bills":"\u0431\u0430\u043d\u043a\u043d\u043e\u0442\u044b","birth_report":{"birth_report":"\u041e\u0442\u0447\u0435\u0442 \u043e \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u0438","birth_report_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u0438","birth_reports":"\u041e\u0442\u0447\u0435\u0442\u044b \u043e \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u0438","case_id":"\u0441\u043b\u0443\u0447\u0430\u0439 \u042f \u0431\u044b","data_should_not_be_smaller_than_patient_birth_date":"\u0414\u0430\u0442\u0430 \u043d\u0435 \u0434\u043e\u043b\u0436\u043d\u0430 \u0431\u044b\u0442\u044c \u043c\u0435\u043d\u044c\u0448\u0435 \u0434\u0430\u0442\u044b \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430.","date":"\u0414\u0430\u0442\u0430","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","doctor_name":"\u0418\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430","edit_birth_report":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043e\u0442\u0447\u0435\u0442 \u043e \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u0438","new_birth_report":"\u041e\u0442\u0447\u0435\u0442 \u043e \u043d\u043e\u0432\u043e\u043c \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u0438","patient_birth_date_not_found":"\u0414\u0430\u0442\u0430 \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","patient_name":"\u0418\u043c\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430"},"birth_reports":"\u041e\u0442\u0447\u0435\u0442\u044b \u043e \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u0438","blood_bank":"\u0411\u0430\u043d\u043a \u043a\u0440\u043e\u0432\u0438","blood_banks":"\u0411\u0430\u043d\u043a\u0438 \u043a\u0440\u043e\u0432\u0438","blood_donation":{"bags":"\u0421\u0443\u043c\u043a\u0438","blood_donation":"\u0421\u0434\u0430\u0447\u0430 \u043a\u0440\u043e\u0432\u0438","donor_name":"\u0418\u043c\u044f \u0434\u043e\u043d\u043e\u0440\u0430","edit_blood_donation":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0441\u0434\u0430\u0447\u0443 \u043a\u0440\u043e\u0432\u0438","last_donate_date":"\u0414\u0430\u0442\u0430 \u043f\u043e\u0441\u043b\u0435\u0434\u043d\u0435\u0433\u043e \u043f\u043e\u0436\u0435\u0440\u0442\u0432\u043e\u0432\u0430\u043d\u0438\u044f","new_blood_donation":"\u041d\u043e\u0432\u043e\u0435 \u0434\u043e\u043d\u043e\u0440\u0441\u0442\u0432\u043e \u043a\u0440\u043e\u0432\u0438"},"blood_donations":"\u0421\u0434\u0430\u0447\u0430 \u043a\u0440\u043e\u0432\u0438","blood_donor":{"age":"\u0412\u043e\u0437\u0440\u0430\u0441\u0442","blood_donor":"\u0414\u043e\u043d\u043e\u0440 \u043a\u0440\u043e\u0432\u0438","blood_donor_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0434\u043e\u043d\u043e\u0440\u0435 \u043a\u0440\u043e\u0432\u0438","blood_donors":"\u0414\u043e\u043d\u043e\u0440\u044b \u043a\u0440\u043e\u0432\u0438","blood_group":"\u0413\u0440\u0443\u043f\u043f\u0430 \u043a\u0440\u043e\u0432\u0438","donation_date":"\u0414\u0430\u0442\u0430 \u043f\u043e\u0436\u0435\u0440\u0442\u0432\u043e\u0432\u0430\u043d\u0438\u044f","edit_blood_donor":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0434\u043e\u043d\u043e\u0440\u0430 \u043a\u0440\u043e\u0432\u0438","gender":"\u043f\u043e\u043b","last_donation_date":"\u0414\u0430\u0442\u0430 \u043f\u043e\u0441\u043b\u0435\u0434\u043d\u0435\u0433\u043e \u043f\u043e\u0436\u0435\u0440\u0442\u0432\u043e\u0432\u0430\u043d\u0438\u044f","name":"\u0438\u043c\u044f","new_blood_donor":"\u041d\u043e\u0432\u044b\u0439 \u0434\u043e\u043d\u043e\u0440 \u043a\u0440\u043e\u0432\u0438"},"blood_donors":"\u0414\u043e\u043d\u043e\u0440\u044b \u043a\u0440\u043e\u0432\u0438","blood_issue":{"Patient_name":"\u0418\u043c\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","amount":"\u0421\u0443\u043c\u043c\u0430","blood_issue":"\u041f\u0440\u043e\u0431\u043b\u0435\u043c\u0430 \u043a\u0440\u043e\u0432\u0438","doctor_name":"\u0418\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430","donor_name":"\u0418\u043c\u044f \u0434\u043e\u043d\u043e\u0440\u0430","edit_blood_issue":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0440\u043e\u0431\u043b\u0435\u043c\u0443 \u043a\u0440\u043e\u0432\u0438","issue_date":"\u0414\u0430\u0442\u0430 \u0432\u044b\u043f\u0443\u0441\u043a\u0430","new_blood_issue":"\u0412\u044b\u043f\u0443\u0441\u043a \u043d\u043e\u0432\u043e\u0439 \u043a\u0440\u043e\u0432\u0438","remarks":"\u0417\u0430\u043c\u0435\u0447\u0430\u043d\u0438\u044f"},"blood_issues":"\u041f\u0440\u043e\u0431\u043b\u0435\u043c\u044b \u0441 \u043a\u0440\u043e\u0432\u044c\u044e","call_log":{"call_log":"\u0416\u0443\u0440\u043d\u0430\u043b \u0432\u044b\u0437\u043e\u0432\u043e\u0432","call_type":"\u0422\u0438\u043f \u0437\u0432\u043e\u043d\u043a\u0430","edit":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0436\u0443\u0440\u043d\u0430\u043b \u0432\u044b\u0437\u043e\u0432\u043e\u0432","follow_up_date":"\u0414\u0430\u0442\u0430 \u043f\u043e\u0441\u043b\u0435\u0434\u0443\u044e\u0449\u0435\u0433\u043e \u043d\u0430\u0431\u043b\u044e\u0434\u0435\u043d\u0438\u044f","incoming":"\u0412\u0445\u043e\u0434\u044f\u0449\u0438\u0439","name":"\u0438\u043c\u044f","new":"\u041d\u043e\u0432\u044b\u0439 \u0436\u0443\u0440\u043d\u0430\u043b \u0432\u044b\u0437\u043e\u0432\u043e\u0432","note":"\u0417\u0430\u043f\u0438\u0441\u044c","outgoing":"\u0418\u0441\u0445\u043e\u0434\u044f\u0449\u0438\u0439","phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d","received_on":"\u041f\u043e\u043b\u0443\u0447\u0435\u043d\u043e"},"call_logs":"\u0416\u0443\u0440\u043d\u0430\u043b\u044b \u0432\u044b\u0437\u043e\u0432\u043e\u0432","case":{"case":"\u0441\u043b\u0443\u0447\u0430\u0439","case_date":"\u0414\u0430\u0442\u0430 \u0434\u0435\u043b\u0430","case_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0440\u0435\u0433\u0438\u0441\u0442\u0440\u0435","case_id":"\u0441\u043b\u0443\u0447\u0430\u0439 \u042f \u0431\u044b","date":"\u0414\u0430\u0442\u0430","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","doctor":"\u0414\u043e\u043a\u0442\u043e\u0440","edit_case":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0440\u0435\u0433\u0438\u0441\u0442\u0440","fee":"\u043f\u043b\u0430\u0442\u0430","new_case":"\u041d\u043e\u0432\u043e\u0435 \u0434\u0435\u043b\u043e","patient":"\u0422\u0435\u0440\u043f\u0435\u043b\u0438\u0432\u044b\u0439","phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d"},"case_handler":{"case_handler":"\u041e\u0431\u0440\u0430\u0431\u043e\u0442\u0447\u0438\u043a \u0434\u0435\u043b","case_handler_detail":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e\u0431 \u043e\u0431\u0440\u0430\u0431\u043e\u0442\u0447\u0438\u043a\u0435 \u0434\u0435\u043b\u0430","edit_case_handler":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043e\u0431\u0440\u0430\u0431\u043e\u0442\u0447\u0438\u043a \u0434\u0435\u043b","new_case_handler":"\u043d\u043e\u0432\u044b\u0439 \u0441\u043b\u0443\u0447\u0430\u0439 \u0443\u043a\u0440\u043e\u0442\u0438\u0442\u0435\u043b\u044c"},"case_handlers":"\u0441\u043b\u0443\u0447\u0430\u0439 \u0443\u043a\u0440\u043e\u0442\u0438\u0442\u0435\u043b\u044c","case_manager":"\u041a\u0435\u0439\u0441-\u043c\u0435\u043d\u0435\u0434\u0436\u0435\u0440","cases":"\u0441\u043b\u0443\u0447\u0430\u0438","change_password":{"change_password":"\u0418\u0437\u043c\u0435\u043d\u0438 \u043f\u0430\u0440\u043e\u043b\u044c","confirm_password":"\u041f\u043e\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u044c \u041f\u0430\u0440\u043e\u043b\u044c","current_password":"\u0422\u0435\u043a\u0443\u0449\u0438\u0439 \u043f\u0430\u0440\u043e\u043b\u044c","new_password":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0430\u0440\u043e\u043b\u044c"},"charge":{"charge_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0437\u0430\u0440\u044f\u0434\u0430","charge_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0437\u0430\u0440\u044f\u0434\u043a\u0438","code":"\u041a\u043e\u0434","edit_charge":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0437\u0430\u0440\u044f\u0434","new_charge":"\u041d\u043e\u0432\u044b\u0439 \u0437\u0430\u0440\u044f\u0434","standard_charge":"\u0421\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u043d\u044b\u0439 \u0437\u0430\u0440\u044f\u0434"},"charge_categories":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438 \u043e\u043f\u043b\u0430\u0442\u044b","charge_category":{"charge_categories":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438 \u043e\u043f\u043b\u0430\u0442\u044b","charge_category_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438 \u0437\u0430\u0440\u044f\u0434\u0430","charge_type":"\u0422\u0438\u043f \u0437\u0430\u0440\u044f\u0434\u0430","edit_charge_category":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044e \u0437\u0430\u0440\u044f\u0434\u0430","new_charge_category":"\u041d\u043e\u0432\u0430\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0437\u0430\u0440\u044f\u0434\u0430"},"charges":"\u0440\u0430\u0441\u0445\u043e\u0434\u044b","cms":"CMS","common":{"action":"\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0435","actions":"\u0414\u0435\u0439\u0441\u0442\u0432\u0438\u044f","active":"\u0430\u043a\u0442\u0438\u0432\u043d\u044b\u0439","add":"\u0434\u043e\u0431\u0430\u0432\u043b\u044f\u0442\u044c","address":"\u0410\u0434\u0440\u0435\u0441","apply":"\u043f\u043e\u0434\u0430\u0442\u044c \u0437\u0430\u044f\u0432\u043b\u0435\u043d\u0438\u0435","are_you_sure_want_to_delete_this":"\u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0443\u0434\u0430\u043b\u0438\u0442\u044c \u044d\u0442\u043e ","back":"\u043d\u0430\u0437\u0430\u0434","cancel":"\u041e\u0442\u043c\u0435\u043d\u0430","canceled":"O\u0442\u043c\u0435\u043d\u0435\u043d","cant_be_deleted":"\u043d\u0435 \u043c\u043e\u0436\u0435\u0442 \u0431\u044b\u0442\u044c \u0443\u0434\u0430\u043b\u0435\u043d","choose":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c","confirm":"\u041f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0430\u0442\u044c","created_at":"\u0421\u043e\u0437\u0434\u0430\u043d\u043e \u043d\u0430","created_on":"\u0421\u043e\u0437\u0434\u0430\u043d\u043e \u043d\u0430","custom":"\u041e\u0431\u044b\u0447\u0430\u0439","de_active":"De-\u0430\u043a\u0442\u0438\u0432\u043d\u044b\u0435","delete":"\u0443\u0434\u0430\u043b\u044f\u0442\u044c","deleted":"\u0423\u0434\u0430\u043b\u0435\u043d\u043e","deleted_successfully":"\u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0443\u0434\u0430\u043b\u0435\u043d","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","detail":"\u0414\u0435\u0442\u0430\u043b\u0438","edit":"\u0440\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c","export_to_excel":"\u042d\u043a\u0441\u043f\u043e\u0440\u0442 \u0432 Excel","filter_options":"\u041f\u0430\u0440\u0430\u043c\u0435\u0442\u0440\u044b \u0444\u0438\u043b\u044c\u0442\u0440\u0430","from":"\u0438\u0437","has_been_deleted":"\u0431\u044b\u043b \u0443\u0434\u0430\u043b\u0435\u043d.","invalid_country_code":"\u041d\u0435\u0432\u0435\u0440\u043d\u044b\u0439 \u043a\u043e\u0434 \u0441\u0442\u0440\u0430\u043d\u044b","invalid_number":"\u041d\u0435\u043f\u0440\u0430\u0432\u0438\u043b\u044c\u043d\u044b\u0439 \u043d\u043e\u043c\u0435\u0440","is_available":"\u0414\u043e\u0441\u0442\u0443\u043f\u0435\u043d","last_updated":"\u041f\u043e\u0441\u043b\u0435\u0434\u043d\u0435\u0435 \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0438\u0435","n\/a":"N\/A","name":"\u0438\u043c\u044f","new":"\u043d\u043e\u0432\u044b\u0439","next":"\u0421\u043b\u0435\u0434\u0443\u044e\u0449\u0438\u0439","no":"\u043d\u0435\u0442","not_found":"\u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d","ok":"Ok","previous":"\u041f\u0440\u0435\u0434\u044b\u0434\u0443\u0449\u0438\u0439","profile":"\u041f\u0440\u043e\u0444\u0438\u043b\u044c","reset":"\u0421\u0431\u0440\u043e\u0441 \u043d\u0430\u0441\u0442\u0440\u043e\u0435\u043a","save":"\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c","saved_successfully":"\u0423\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u043e.","search":"\u041f\u043e\u0438\u0441\u043a","status":"\u041f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0434\u0435\u043b","status_updated_successfully":"\u0421\u0442\u0430\u0442\u0443\u0441 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","this_action_is_not_allowed_for_default_record":"\u042d\u0442\u043e \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0435 \u043d\u0435 \u0440\u0430\u0437\u0440\u0435\u0448\u0435\u043d\u043e \u0434\u043b\u044f \u0437\u0430\u043f\u0438\u0441\u0438 \u043f\u043e \u0443\u043c\u043e\u043b\u0447\u0430\u043d\u0438\u044e.","to":"\u041a","too_long":"\u0421\u043b\u0438\u0448\u043a\u043e\u043c \u0434\u043e\u043b\u0433\u043e","too_short":"\u0421\u043b\u0438\u0448\u043a\u043e\u043c \u043a\u043e\u0440\u043e\u0442\u043a\u0438\u0439","total":"\u041e\u0431\u0449\u0435\u0435 \u043a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","updated_at":"\u041f\u043e\u0441\u043b\u0435\u0434\u043d\u0435\u0435 \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0438\u0435","updated_successfully":"\u0423\u0441\u043f\u0435\u0448\u043d\u043e \u041e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u043e","view":"\u041f\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c","view_attachment":"\u041f\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0432\u043b\u043e\u0436\u0435\u043d\u0438\u0435","yes":"\u0434\u0430"},"contact_us":"\u0421\u0432\u044f\u0436\u0438\u0442\u0435\u0441\u044c \u0441 \u043d\u0430\u043c\u0438","currency":{"add_currency_code_as_per_three_letter_iso_code":"\u0414\u043e\u0431\u0430\u0432\u044c\u0442\u0435 \u043a\u043e\u0434 \u0432\u0430\u043b\u044e\u0442\u044b \u0432 \u0441\u043e\u043e\u0442\u0432\u0435\u0442\u0441\u0442\u0432\u0438\u0438 \u0441 \u0442\u0440\u0435\u0445\u0431\u0443\u043a\u0432\u0435\u043d\u043d\u044b\u043c \u043a\u043e\u0434\u043e\u043c ISO","currency":"\u0412\u0430\u043b\u044e\u0442\u0430","currency_code":"\u041a\u043e\u0434 \u0432\u0430\u043b\u044e\u0442\u044b","currency_icon":"\u0417\u043d\u0430\u0447\u043e\u043a \u0432\u0430\u043b\u044e\u0442\u044b","currency_name":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u0432\u0430\u043b\u044e\u0442\u044b","edit_currency":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0432\u0430\u043b\u044e\u0442\u0443","new_currency":"\u041d\u043e\u0432\u0430\u044f \u0432\u0430\u043b\u044e\u0442\u0430","you_can_find_out_here":"\u0432\u044b \u043c\u043e\u0436\u0435\u0442\u0435 \u0443\u0437\u043d\u0430\u0442\u044c \u0437\u0434\u0435\u0441\u044c"},"currency_setting":"\u0412\u0430\u043b\u044e\u0442\u044b","dashboard":{"available_beds":"\u0414\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0435 \u043a\u0440\u043e\u0432\u0430\u0442\u0438","dashboard":"\u041f\u0440\u0438\u0431\u043e\u0440\u043d\u0430\u044f \u0434\u043e\u0441\u043a\u0430","doctors":"\u0412\u0440\u0430\u0447\u0438","income_and_expense_report":"\u041e\u0442\u0447\u0435\u0442 \u043e \u0434\u043e\u0445\u043e\u0434\u0430\u0445 \u0438 \u0440\u0430\u0441\u0445\u043e\u0434\u0430\u0445","income_and_expense_reports":"\u041e\u0442\u0447\u0435\u0442\u044b \u043e \u0434\u043e\u0445\u043e\u0434\u0430\u0445 \u0438 \u0440\u0430\u0441\u0445\u043e\u0434\u0430\u0445","no_enquiries_yet":"\u0417\u0430\u043f\u0440\u043e\u0441\u043e\u0432 \u043f\u043e\u043a\u0430 \u043d\u0435\u0442","no_notice_yet":"\u0423\u0432\u0435\u0434\u043e\u043c\u043b\u0435\u043d\u0438\u0439 \u043f\u043e\u043a\u0430 \u043d\u0435\u0442","notice_boards":"\u0414\u043e\u0441\u043a\u0438 \u043e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0439","patients":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442\u044b","title":"\u0437\u0430\u0433\u043b\u0430\u0432\u0438\u0435","total_advance_payments":"\u0421\u0443\u043c\u043c\u0430 \u0430\u0432\u0430\u043d\u0441\u043e\u0432\u043e\u0433\u043e \u043f\u043b\u0430\u0442\u0435\u0436\u0430","total_bills":"\u0421\u0443\u043c\u043c\u0430 \u0441\u0447\u0435\u0442\u0430","total_invoices":"\u0421\u0443\u043c\u043c\u0430 \u0441\u0447\u0435\u0442\u0430","total_payments":"\u041a \u043e\u043f\u043b\u0430\u0442\u0435"},"death_report":{"case_id":"\u0441\u043b\u0443\u0447\u0430\u0439 \u042f \u0431\u044b","date":"\u0414\u0430\u0442\u0430","death_report":"\u041e\u0442\u0447\u0435\u0442 \u043e \u0441\u043c\u0435\u0440\u0442\u0438","death_report_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043e\u0442\u0447\u0435\u0442\u0430 \u043e \u0441\u043c\u0435\u0440\u0442\u0438","death_reports":"\u041e\u0442\u0447\u0435\u0442\u044b \u043e \u0441\u043c\u0435\u0440\u0442\u0438","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","doctor_name":"\u0418\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430","edit_death_report":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043e\u0442\u0447\u0435\u0442 \u043e \u0441\u043c\u0435\u0440\u0442\u0438","new_death_report":"\u041d\u043e\u0432\u044b\u0439 \u043e\u0442\u0447\u0435\u0442 \u043e \u0441\u043c\u0435\u0440\u0442\u0438","patient_name":"\u0418\u043c\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430"},"death_reports":"\u041e\u0442\u0447\u0435\u0442\u044b \u043e \u0441\u043c\u0435\u0440\u0442\u0438","department":"\u043e\u0442\u0434\u0435\u043b","departments":"\u043e\u0442\u0434\u0435\u043b\u044b","diagnosis_category":{"category_name":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","diagnosis_categories":"\u0414\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u0447\u0435\u0441\u043a\u0430\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f","diagnosis_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0434\u0438\u0430\u0433\u043d\u043e\u0437\u0430","diagnosis_category_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438 \u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u043a\u0438","edit_diagnosis_category":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044e \u0434\u0438\u0430\u0433\u043d\u043e\u0437\u0430","new_diagnosis_category":"\u041d\u043e\u0432\u0430\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u043a\u0438"},"doc_type":{"edit_doc_type":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0442\u0438\u043f \u0434\u043e\u043a\u0443\u043c\u0435\u043d\u0442\u0430","name":"\u0438\u043c\u044f","new_doc_type":"\u041d\u043e\u0432\u044b\u0439 \u0442\u0438\u043f \u0434\u043e\u043a\u0443\u043c\u0435\u043d\u0442\u0430"},"doctor":{"doctor_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0434\u043e\u043a\u0442\u043e\u0440\u0435","edit_doctor":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0414\u043e\u043a\u0442\u043e\u0440\u0430","new_doctor":"\u041d\u043e\u0432\u044b\u0439 \u0414\u043e\u043a\u0442\u043e\u0440","specialist":"\u0441\u043f\u0435\u0446\u0438\u0430\u043b\u0438\u0441\u0442"},"doctor_department":{"description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","doctor_department":"\u0414\u043e\u043a\u0442\u043e\u0440\u0441\u043a\u043e\u0435 \u043e\u0442\u0434\u0435\u043b\u0435\u043d\u0438\u0435","doctor_department_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043e\u0442\u0434\u0435\u043b\u0435\u043d\u0438\u044f \u0432\u0440\u0430\u0447\u0430","doctor_departments":"\u0414\u043e\u043a\u0442\u043e\u0440\u0441\u043a\u0438\u0435 \u043e\u0442\u0434\u0435\u043b\u0435\u043d\u0438\u044f","edit_doctor_department":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043e\u0442\u0434\u0435\u043b\u0435\u043d\u0438\u0435 \u0434\u043e\u043a\u0442\u043e\u0440\u0430","new_doctor_department":"\u041e\u0442\u0434\u0435\u043b \u043d\u043e\u0432\u043e\u0433\u043e \u0434\u043e\u043a\u0442\u043e\u0440\u0430","title":"\u0437\u0430\u0433\u043b\u0430\u0432\u0438\u0435"},"doctor_departments":"\u0414\u043e\u043a\u0442\u043e\u0440\u0441\u043a\u0438\u0435 \u043e\u0442\u0434\u0435\u043b\u0435\u043d\u0438\u044f","doctor_opd_charge":{"doctor":"\u0414\u043e\u043a\u0442\u043e\u0440","doctor_name":"\u0418\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430","doctor_opd_charge":"\u0414\u043e\u043a\u0442\u043e\u0440 OPD \u0417\u0430\u0440\u044f\u0434\u043a\u0430","edit_doctor_opd_charge":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0414\u043e\u043a\u0442\u043e\u0440 OPD \u041e\u0431\u0432\u0438\u043d\u044f\u0442\u044c","new_doctor_opd_charge":"\u041d\u043e\u0432\u044b\u0439 \u0414\u043e\u043a\u0442\u043e\u0440 OPD Charge","standard_charge":"\u0421\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u043d\u044b\u0439 \u0437\u0430\u0440\u044f\u0434"},"doctor_opd_charges":"\u0414\u043e\u043a\u0442\u043e\u0440 \u041e\u041f\u0414 \u0417\u0430\u0440\u044f\u0434\u044b","doctors":"\u0412\u0440\u0430\u0447\u0438","doctors_list":"\u0421\u043f\u0438\u0441\u043e\u043a \u0432\u0440\u0430\u0447\u0435\u0439","document":{"attachment":"\u043f\u0440\u0438\u043a\u0440\u0435\u043f\u043b\u0435\u043d\u0438\u0435","document":"\u0414\u043e\u043a\u0443\u043c\u0435\u043d\u0442","document_detail":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0434\u043e\u043a\u0443\u043c\u0435\u043d\u0442\u0430","document_type":"\u0422\u0438\u043f \u0434\u043e\u043a\u0443\u043c\u0435\u043d\u0442\u0430","document_type_details":"\u0422\u0438\u043f \u0434\u043e\u043a\u0443\u043c\u0435\u043d\u0442\u0430 \u041f\u043e\u0434\u0440\u043e\u0431\u043d\u043e\u0441\u0442\u0438","download":"\u0421\u043a\u0430\u0447\u0430\u0442\u044c","edit_document":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0434\u043e\u043a\u0443\u043c\u0435\u043d\u0442","new_document":"\u041d\u043e\u0432\u044b\u0439 \u0434\u043e\u043a\u0443\u043c\u0435\u043d\u0442","notes":"\u041d\u043e\u0442\u044b","patient":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442","select_document_type":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c \u0442\u0438\u043f \u0434\u043e\u043a\u0443\u043c\u0435\u043d\u0442\u0430","select_patient":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","title":"\u0437\u0430\u0433\u043b\u0430\u0432\u0438\u0435","uploaded_by":"\u0417\u0430\u0433\u0440\u0443\u0436\u0435\u043d\u043e \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u0435\u043c"},"document_types":"\u0422\u0438\u043f\u044b \u0434\u043e\u043a\u0443\u043c\u0435\u043d\u0442\u043e\u0432","documents":"\u0434\u043e\u043a\u0443\u043c\u0435\u043d\u0442\u044b","email":{"attachment":"\u0412\u043b\u043e\u0436\u0435\u043d\u0438\u044f","message":"\u0421\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","subject":"\u041f\u0440\u0435\u0434\u043c\u0435\u0442","to":"\u043a"},"employee_payroll":{"allowance":"\u043f\u043e\u0441\u043e\u0431\u0438\u0435","basic_salary":"\u0411\u0430\u0437\u043e\u0432\u0430\u044f \u0437\u0430\u0440\u043f\u043b\u0430\u0442\u0430","deductions":"\u0432\u044b\u0447\u0435\u0442\u044b","edit_employee_payroll":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0437\u0430\u0440\u043f\u043b\u0430\u0442\u0443 \u0441\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a\u0430","employee":"\u0421\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a","employee_payroll":"\u0417\u0430\u0440\u0430\u0431\u043e\u0442\u043d\u0430\u044f \u043f\u043b\u0430\u0442\u0430 \u0441\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a\u0430","employee_payroll_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0437\u0430\u0440\u0430\u0431\u043e\u0442\u043d\u043e\u0439 \u043f\u043b\u0430\u0442\u0435 \u0441\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a\u0430","employee_payrolls":"\u0417\u0430\u0440\u0430\u0431\u043e\u0442\u043d\u0430\u044f \u043f\u043b\u0430\u0442\u0430 \u0441\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a\u043e\u0432","month":"\u041c\u0435\u0441\u044f\u0446","net_salary":"\u0427\u0438\u0441\u0442\u0430\u044f \u0437\u0430\u0440\u043f\u043b\u0430\u0442\u0430","new_employee_payroll":"\u0417\u0430\u0440\u043f\u043b\u0430\u0442\u0430 \u043d\u043e\u0432\u043e\u0433\u043e \u0441\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a\u0430","not_paid":"\u041d\u0435 \u043e\u043f\u043b\u0430\u0447\u0435\u043d","paid":"\u043e\u043f\u043b\u0430\u0447\u0435\u043d\u043d\u044b\u0439","payroll_id":"\u0418\u0434\u0435\u043d\u0442\u0438\u0444\u0438\u043a\u0430\u0442\u043e\u0440 \u043f\u043b\u0430\u0442\u0435\u0436\u043d\u043e\u0439 \u0432\u0435\u0434\u043e\u043c\u043e\u0441\u0442\u0438","role":"\u0420\u043e\u043b\u044c","sr_no":"\u0421\u0440 \u041d\u0435\u0442","year":"\u0413\u043e\u0434"},"employee_payrolls":"\u0417\u0430\u0440\u0430\u0431\u043e\u0442\u043d\u0430\u044f \u043f\u043b\u0430\u0442\u0430 \u0441\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a\u043e\u0432","enquiries":"\u0440\u0430\u0441\u0441\u043f\u0440\u043e\u0441\u044b","enquiry":{"contact":"\u043a\u043e\u043d\u0442\u0430\u043a\u0442","email":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0435 \u043f\u0438\u0441\u044c\u043c\u043e","enquiry_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0437\u0430\u043f\u0440\u043e\u0441\u0430","enquiry_send_successfully":"\u0417\u0430\u043f\u0440\u043e\u0441 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0442\u043f\u0440\u0430\u0432\u043b\u0435\u043d","message":"\u0421\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","name":"\u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","not_viewed":"\u041d\u0435 \u0441\u043c\u043e\u0442\u0440\u0435\u043b\u0438","read":"\u0427\u0438\u0442\u0430\u0442\u044c","received_on":"\u041f\u043e\u043b\u0443\u0447\u0435\u043d\u043e \u043d\u0430","send_enquiry":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c \u0437\u0430\u043f\u0440\u043e\u0441","type":"\u0422\u0438\u043f","unread":"\u041d\u0435 \u043f\u0440\u043e\u0447\u0438\u0442\u0430\u043d\u043e","viewed_by":"\u041f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u043d\u043e"},"expense":{"amount":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","attachment":"\u043f\u0440\u0438\u043a\u0440\u0435\u043f\u043b\u0435\u043d\u0438\u0435","choose":"\u0432\u044b\u0431\u0438\u0440\u0430\u0442\u044c","date":"\u0421\u0432\u0438\u0434\u0430\u043d\u0438\u0435","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","document_error":"\u0414\u043e\u043a\u0443\u043c\u0435\u043d\u0442 \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0444\u0430\u0439\u043b\u043e\u043c \u0442\u0438\u043f\u0430: jpeg, jpg, png, pdf, doc, docx.","download":"\u0421\u043a\u0430\u0447\u0430\u0442\u044c","edit_expense":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0420\u0430\u0441\u0445\u043e\u0434","expense":"\u0420\u0430\u0441\u0445\u043e\u0434","expense_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","expense_head":"\u0420\u0430\u0441\u0445\u043e\u0434\u043d\u0430\u044f \u0433\u043e\u043b\u043e\u0432\u043a\u0430","invoice_number":"\u041d\u043e\u043c\u0435\u0440 \u0441\u0447\u0435\u0442\u0430","name":"\u0438\u043c\u044f","new_expense":"\u041d\u043e\u0432\u044b\u0439 \u0420\u0430\u0441\u0445\u043e\u0434","select_expense_head":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0433\u043b\u0430\u0432\u0443 \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432"},"expenses":"\u0420\u0430\u0441\u0445\u043e\u0434\u044b","facebook_url":"\u0430\u0434\u0440\u0435\u0441 \u0444\u0435\u0439\u0441\u0431\u0443\u043a\u0430","file_name":"\u0418\u043c\u044f \u0444\u0430\u0439\u043b\u0430","finance":"\u0444\u0438\u043d\u0430\u043d\u0441\u043e\u0432","front_cms":"\u041f\u0435\u0440\u0435\u0434\u043d\u0438\u0435 \u0441\u043c\u0441","front_cms_services":"\u0424\u0440\u043e\u043d\u0442\u0430\u043b\u044c\u043d\u044b\u0435 CMS-\u0441\u0435\u0440\u0432\u0438\u0441\u044b","front_office":"\u0424\u0440\u043e\u043d\u0442-\u043e\u0444\u0438\u0441","front_service":"\u0424\u0440\u043e\u043d\u0442 \u0421\u0435\u0440\u0432\u0438\u0441","front_setting":{"about_us_description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","about_us_details":"\u041e \u043d\u0430\u0441 \u041f\u043e\u0434\u0440\u043e\u0431\u043d\u043e\u0441\u0442\u0438","about_us_image":"\u0418\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435","about_us_mission":"\u041c\u0438\u0441\u0441\u0438\u044f","about_us_title":"\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a","appointment_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0438","front_setting_details":"\u043f\u0435\u0440\u0435\u0434\u043d\u044f\u044f \u0434\u0435\u0442\u0430\u043b\u044c \u043d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438","home_page_box_description":"\u0414\u043e\u043c\u0430\u0448\u043d\u044f\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u041f\u043e\u043b\u0435 \u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","home_page_box_title":"\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a \u043e\u043a\u043d\u0430 \u0433\u043b\u0430\u0432\u043d\u043e\u0439 \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u044b","home_page_certified_box_description":"\u0414\u043e\u043c\u0430\u0448\u043d\u044f\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0421\u0435\u0440\u0442\u0438\u0444\u0438\u0446\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u0430\u044f \u043a\u043e\u0440\u043e\u0431\u043a\u0430 \u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","home_page_certified_box_title":"\u0413\u043b\u0430\u0432\u043d\u0430\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0421\u0435\u0440\u0442\u0438\u0444\u0438\u0446\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u043e\u0435 \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u043a\u043e\u0440\u043e\u0431\u043a\u0438","home_page_certified_doctor_description":"\u0413\u043b\u0430\u0432\u043d\u0430\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0421\u0435\u0440\u0442\u0438\u0444\u0438\u0446\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u044b\u0439 \u0432\u0440\u0430\u0447 \u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","home_page_certified_doctor_image":"\u0414\u043e\u043c\u0430\u0448\u043d\u044f\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0418\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435 \u0441\u0435\u0440\u0442\u0438\u0444\u0438\u0446\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u043e\u0433\u043e \u0434\u043e\u043a\u0442\u043e\u0440\u0430","home_page_certified_doctor_text":"\u0414\u043e\u043c\u0430\u0448\u043d\u044f\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0421\u0435\u0440\u0442\u0438\u0444\u0438\u0446\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u044b\u0439 \u0434\u043e\u043a\u0442\u043e\u0440 \u0422\u0435\u043a\u0441\u0442","home_page_certified_doctor_title":"\u0413\u043b\u0430\u0432\u043d\u0430\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0421\u0435\u0440\u0442\u0438\u0444\u0438\u0446\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u044b\u0439 \u0434\u043e\u043a\u0442\u043e\u0440 \u0414\u043e\u043b\u0436\u043d\u043e\u0441\u0442\u044c","home_page_description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435 \u0433\u043b\u0430\u0432\u043d\u043e\u0439 \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u044b","home_page_experience":"\u041e\u043f\u044b\u0442 \u0434\u043e\u043c\u0430\u0448\u043d\u0435\u0439 \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u044b","home_page_image":"\u0418\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435 \u0433\u043b\u0430\u0432\u043d\u043e\u0439 \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u044b","home_page_step_1_description":"\u0414\u043e\u043c\u0430\u0448\u043d\u044f\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0428\u0430\u0433 1 \u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","home_page_step_1_title":"\u0413\u043b\u0430\u0432\u043d\u0430\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0428\u0430\u0433 1 \u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","home_page_step_2_description":"\u0413\u043b\u0430\u0432\u043d\u0430\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0428\u0430\u0433 2 \u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","home_page_step_2_title":"\u0413\u043b\u0430\u0432\u043d\u0430\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0428\u0430\u0433 2 \u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","home_page_step_3_description":"\u0413\u043b\u0430\u0432\u043d\u0430\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0428\u0430\u0433 3 \u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","home_page_step_3_title":"\u0413\u043b\u0430\u0432\u043d\u0430\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0428\u0430\u0433 3 \u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","home_page_step_4_description":"\u0413\u043b\u0430\u0432\u043d\u0430\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0428\u0430\u0433 4 \u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","home_page_step_4_title":"\u0413\u043b\u0430\u0432\u043d\u0430\u044f \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u0428\u0430\u0433 4 \u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","home_page_title":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u0434\u043e\u043c\u0430\u0448\u043d\u0435\u0439 \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u044b","privacy_policy":"\u041f\u043e\u043b\u0438\u0442\u0438\u043a\u0430 \u043a\u043e\u043d\u0444\u0438\u0434\u0435\u043d\u0446\u0438\u0430\u043b\u044c\u043d\u043e\u0441\u0442\u0438","terms_condition_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0443\u0441\u043b\u043e\u0432\u0438\u0439 \u0438 \u0443\u0441\u043b\u043e\u0432\u0438\u0439","terms_conditions":"\u0443\u0441\u043b\u043e\u0432\u0438\u044f_\u0443\u0441\u043b\u043e\u0432\u0438\u044f"},"front_settings":"\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438 \u043f\u0435\u0440\u0435\u0434\u043d\u0435\u0439 \u043f\u0430\u043d\u0435\u043b\u0438","general":"\u041e\u0431\u0449\u0435\u0435","hospital_activities":"\u0411\u043e\u043b\u044c\u043d\u0438\u0447\u043d\u0430\u044f \u0434\u0435\u044f\u0442\u0435\u043b\u044c\u043d\u043e\u0441\u0442\u044c","hospital_blood_bank":{"blood_bank":"\u0411\u0430\u043d\u043a \u043a\u0440\u043e\u0432\u0438","blood_bank_details":"\u0420\u0435\u043a\u0432\u0438\u0437\u0438\u0442\u044b \u0431\u0430\u043d\u043a\u0430 \u043a\u0440\u043e\u0432\u0438","blood_banks":"\u0411\u0430\u043d\u043a\u0438 \u043a\u0440\u043e\u0432\u0438","blood_group":"\u0413\u0440\u0443\u043f\u043f\u0430 \u043a\u0440\u043e\u0432\u0438","edit_blood_group":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0433\u0440\u0443\u043f\u043f\u0443 \u043a\u0440\u043e\u0432\u0438","new_blood_group":"\u041d\u043e\u0432\u0430\u044f \u0433\u0440\u0443\u043f\u043f\u0430 \u043a\u0440\u043e\u0432\u0438","remained_bags":"\u041e\u0441\u0442\u0430\u0432\u0448\u0438\u0435\u0441\u044f \u0441\u0443\u043c\u043a\u0438"},"hospital_charges":"\u0411\u043e\u043b\u044c\u043d\u0438\u0447\u043d\u044b\u0435 \u0440\u0430\u0441\u0445\u043e\u0434\u044b","hospital_schedule":"\u0413\u0440\u0430\u0444\u0438\u043a \u0440\u0430\u0431\u043e\u0442\u044b \u0431\u043e\u043b\u044c\u043d\u0438\u0446\u044b","hospital_schedules":{"exists_doctor_schedule":"\u041d\u0435\u043a\u043e\u0442\u043e\u0440\u044b\u0435 \u0432\u0440\u0430\u0447\u0438 \u0437\u0430\u043f\u043b\u0430\u043d\u0438\u0440\u043e\u0432\u0430\u043b\u0438 \u0441\u0432\u043e\u0438 \u0434\u043d\u0438 \u0432 \u0443\u043a\u0430\u0437\u0430\u043d\u043d\u044b\u0435 \u043d\u0435\u043f\u0440\u043e\u0432\u0435\u0440\u0435\u043d\u043d\u044b\u0435 \u0434\u043d\u0438, \u0442\u0430\u043a \u0447\u0442\u043e \u0432\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0432\u044b\u043f\u043e\u043b\u043d\u0438\u0442\u044c \u044d\u0442\u0443 \u043e\u043f\u0435\u0440\u0430\u0446\u0438\u044e?"},"icon":"\u0417\u043d\u0430\u0447\u043e\u043a","income":"\u0434\u043e\u0445\u043e\u0434","incomes":{"amount":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","attachment":"\u043f\u0440\u0438\u043a\u0440\u0435\u043f\u043b\u0435\u043d\u0438\u0435","choose":"\u0432\u044b\u0431\u0438\u0440\u0430\u0442\u044c","date":"\u0421\u0432\u0438\u0434\u0430\u043d\u0438\u0435","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","document_error":"\u0414\u043e\u043a\u0443\u043c\u0435\u043d\u0442 \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0444\u0430\u0439\u043b\u043e\u043c \u0442\u0438\u043f\u0430: jpeg, jpg, png, pdf, doc, docx.","download":"\u0421\u043a\u0430\u0447\u0430\u0442\u044c","edit_income":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0434\u043e\u0445\u043e\u0434","income_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0434\u043e\u0445\u043e\u0434\u0430","income_head":"\u041d\u0430\u0447\u0430\u043b\u044c\u043d\u0438\u043a \u043e\u0442\u0434\u0435\u043b\u0430 \u0434\u043e\u0445\u043e\u0434\u043e\u0432","incomes":"\u0434\u043e\u0445\u043e\u0434\u043e\u0432","invoice_number":"\u041d\u043e\u043c\u0435\u0440 \u0441\u0447\u0435\u0442\u0430","name":"\u0438\u043c\u044f","new_income":"\u041d\u043e\u0432\u044b\u0439 \u0434\u043e\u0445\u043e\u0434","select_income_head":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0433\u043b\u0430\u0432\u0443 \u0434\u043e\u0445\u043e\u0434\u0430"},"instagram_url":"\u0430\u0434\u0440\u0435\u0441 \u0438\u043d\u0441\u0442\u0430\u0433\u0440\u0430\u043c\u0430","insurance":{"discount":"\u0441\u043a\u0438\u0434\u043a\u0430","disease_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0431\u043e\u043b\u0435\u0437\u043d\u0438","diseases_charge":"\u0417\u0430\u0440\u044f\u0434 \u0431\u043e\u043b\u0435\u0437\u043d\u0435\u0439","diseases_name":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u0431\u043e\u043b\u0435\u0437\u043d\u0438","edit_insurance":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0441\u0442\u0440\u0430\u0445\u043e\u0432\u0430\u043d\u0438\u0435","hospital_rate":"\u0411\u043e\u043b\u044c\u043d\u0438\u0447\u043d\u044b\u0439 \u0442\u0430\u0440\u0438\u0444","insurance":"\u0441\u0442\u0440\u0430\u0445\u043e\u0432\u0430\u043d\u0438\u0435","insurance_code":"\u0421\u0442\u0440\u0430\u0445\u043e\u0432\u043e\u0439 \u043a\u043e\u0434\u0435\u043a\u0441","insurance_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0441\u0442\u0440\u0430\u0445\u043e\u0432\u0430\u043d\u0438\u044f","insurance_no":"\u0421\u0442\u0440\u0430\u0445\u043e\u0432\u0430\u043d\u0438\u0435 \u2116'","insurances":"\u0441\u0442\u0440\u0430\u0445\u043e\u0432\u0430\u043d\u0438\u0435","new_insurance":"\u041d\u043e\u0432\u0430\u044f \u0441\u0442\u0440\u0430\u0445\u043e\u0432\u043a\u0430","remark":"\u043f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435","service_tax":"\u0421\u0435\u0440\u0432\u0438\u0441\u043d\u044b\u0439 \u043d\u0430\u043b\u043e\u0433","total_amount":"\u041e\u0431\u0449\u0430\u044f \u0441\u0443\u043c\u043c\u0430"},"insurances":"\u0441\u0442\u0440\u0430\u0445\u043e\u0432\u0430\u043d\u0438\u0435","inventory":"\u0418\u043d\u0432\u0435\u043d\u0442\u0430\u0440\u044c","investigation_report":{"attachment":"\u043f\u0440\u0438\u043a\u0440\u0435\u043f\u043b\u0435\u043d\u0438\u0435","birth_date_validation":"\u0414\u0430\u0442\u0430 \u043e\u0442\u0447\u0435\u0442\u0430 \u043e\u0431 \u0438\u0441\u0441\u043b\u0435\u0434\u043e\u0432\u0430\u043d\u0438\u0438 \u043d\u0435 \u0434\u043e\u043b\u0436\u043d\u0430 \u0431\u044b\u0442\u044c \u043c\u0435\u043d\u044c\u0448\u0435 \u0434\u0430\u0442\u044b \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430.","date":"\u0414\u0430\u0442\u0430","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","doctor":"\u0414\u043e\u043a\u0442\u043e\u0440","edit_investigation_report":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043e\u0442\u0447\u0435\u0442 \u043e \u0440\u0430\u0441\u0441\u043b\u0435\u0434\u043e\u0432\u0430\u043d\u0438\u0438","investigation_report":"\u041e\u0442\u0447\u0435\u0442 \u043e \u0440\u0430\u0441\u0441\u043b\u0435\u0434\u043e\u0432\u0430\u043d\u0438\u0438","investigation_report_details":"\u041f\u043e\u0434\u0440\u043e\u0431\u043d\u043e\u0441\u0442\u0438 \u043e\u0442\u0447\u0435\u0442\u0430 \u043e \u0440\u0430\u0441\u0441\u043b\u0435\u0434\u043e\u0432\u0430\u043d\u0438\u0438","investigation_reports":"\u041e\u0442\u0447\u0435\u0442\u044b \u043e \u0440\u0430\u0441\u0441\u043b\u0435\u0434\u043e\u0432\u0430\u043d\u0438\u0438","new_investigation_report":"\u041d\u043e\u0432\u044b\u0439 \u043e\u0442\u0447\u0435\u0442 \u043e \u0440\u0430\u0441\u0441\u043b\u0435\u0434\u043e\u0432\u0430\u043d\u0438\u0438","patient":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442","title":"\u0437\u0430\u0433\u043b\u0430\u0432\u0438\u0435"},"investigation_reports":"\u041e\u0442\u0447\u0435\u0442\u044b \u043e \u0440\u0430\u0441\u0441\u043b\u0435\u0434\u043e\u0432\u0430\u043d\u0438\u0438","invoice":{"account_name":"\u0441\u043a\u0438\u0434\u043a\u0430","add":"\u0434\u043e\u0431\u0430\u0432\u043b\u044f\u0442\u044c","amount":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","discount":"Discount","edit":"\u0440\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c","edit_invoice":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0441\u0447\u0435\u0442","hospital_address":"\u0410\u0434\u0440\u0435\u0441 \u0431\u043e\u043b\u044c\u043d\u0438\u0446\u044b","invoice":"\u0412\u044b\u0441\u0442\u0430\u0432\u043b\u0435\u043d\u043d\u044b\u0439 \u0441\u0447\u0435\u0442","invoice_date":"\u0414\u0430\u0442\u0430 \u0432\u044b\u0441\u0442\u0430\u0432\u043b\u0435\u043d\u0438\u044f \u0441\u0447\u0435\u0442\u0430","invoice_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0441\u0447\u0435\u0442\u0435","invoice_id":"\u0418\u0434\u0435\u043d\u0442\u0438\u0444\u0438\u043a\u0430\u0442\u043e\u0440 \u0441\u0447\u0435\u0442\u0430","invoices":"\u0421\u0447\u0435\u0442\u0430-\u0444\u0430\u043a\u0442\u0443\u0440\u044b","new_invoice":"\u041d\u043e\u0432\u044b\u0439 \u0421\u0447\u0435\u0442","not_paid":"\u041d\u0435 \u043e\u043f\u043b\u0430\u0447\u0435\u043d","paid":"\u043e\u043f\u043b\u0430\u0447\u0435\u043d\u043d\u044b\u0439","patient":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442","patient_id":"\u0422\u0435\u0440\u043f\u0435\u043b\u0438\u0432\u044b\u0439 \u042f \u0431\u044b","price":"\u0426\u0435\u043d\u0430","print_invoice":"\u0420\u0430\u0441\u043f\u0435\u0447\u0430\u0442\u0430\u0442\u044c \u0441\u0447\u0435\u0442","qty":"\u041a\u043e\u043b-\u0432\u043e","sub_total":"Sub Total","total":"\u041f\u0440\u043e\u043c\u0435\u0436\u0443\u0442\u043e\u0447\u043d\u044b\u0439 \u0438\u0442\u043e\u0433"},"invoices":"\u0421\u0447\u0435\u0442\u0430-\u0444\u0430\u043a\u0442\u0443\u0440\u044b","ipd_bill":{"discount_in_number":"\u0421\u043a\u0438\u0434\u043a\u0430 \u0432 \u043a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u0435","discount_in_percentage":"\u0421\u043a\u0438\u0434\u043a\u0430 \u0432 \u043f\u0440\u043e\u0446\u0435\u043d\u0442\u0430\u0445","gross_total":"\u0418\u0442\u043e\u0433\u043e \u0431\u0440\u0443\u0442\u0442\u043e","net_payable_amount":"\u0427\u0438\u0441\u0442\u0430\u044f \u0441\u0443\u043c\u043c\u0430 \u043a \u043e\u043f\u043b\u0430\u0442\u0435","other_charges":"\u041f\u0440\u043e\u0447\u0438\u0435 \u0441\u0431\u043e\u0440\u044b","paid_amount":"\u041e\u043f\u043b\u0430\u0447\u0435\u043d\u043d\u0430\u044f \u0441\u0443\u043c\u043c\u0430","tax_in_number":"\u041d\u043e\u043c\u0435\u0440 \u043d\u0430\u043b\u043e\u0433\u0430","tax_in_percentage":"\u041d\u0430\u043b\u043e\u0433 \u0432 \u043f\u0440\u043e\u0446\u0435\u043d\u0442\u0430\u0445","total_charges":"\u041e\u0431\u0449\u0438\u0435 \u0440\u0430\u0441\u0445\u043e\u0434\u044b"},"ipd_charges":"\u041d\u0430\u0447\u0438\u0441\u043b\u0435\u043d\u0438\u044f","ipd_consultant_register":"\u0418\u043d\u0441\u0442\u0440\u0443\u043a\u0446\u0438\u044f \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0430\u043d\u0442\u0430","ipd_diagnosis":"\u0414\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u043a\u0430","ipd_opd":"IPD\/OPD","ipd_patient":{"admission_date":"\u0414\u0430\u0442\u0430 \u043f\u043e\u0441\u0442\u0443\u043f\u043b\u0435\u043d\u0438\u044f","bed_id":"\u041a\u0440\u043e\u0432\u0430\u0442\u044c","bed_type_id":"\u0422\u0438\u043f \u043a\u0440\u043e\u0432\u0430\u0442\u0438","bill_status":"\u0421\u0442\u0430\u0442\u0443\u0441 \u0441\u0447\u0435\u0442\u0430","bp":"\u041a\u0440\u043e\u0432\u044f\u043d\u043e\u0435 \u0434\u0430\u0432\u043b\u0435\u043d\u0438\u0435","case_id":"\u0414\u0435\u043b\u043e","doctor_id":"\u0414\u043e\u043a\u0442\u043e\u0440","edit_ipd_patient":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430 IPD","height":"\u0412\u044b\u0441\u043e\u0442\u0430","ipd_number":"IPD \u041d\u0435\u0442","ipd_patient":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442 IPD","ipd_patient_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0435 IPD","ipd_patients":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442\u044b IPD","is_old_patient":"\u0421\u0442\u0430\u0440\u044b\u0439 \u043f\u0430\u0446\u0438\u0435\u043d\u0442","new_ipd_patient":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0430\u0446\u0438\u0435\u043d\u0442 IPD","notes":"\u0417\u0430\u043c\u0435\u0442\u043a\u0438","patient_id":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442","symptoms":"\u0421\u0438\u043c\u043f\u0442\u043e\u043c\u044b","the_bed_field_is_required":"\u041f\u043e\u043b\u0435 \u043a\u0440\u043e\u0432\u0430\u0442\u0438 \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e.","the_case_field_is_required":"\u041f\u043e\u043b\u0435 \u0441\u043b\u0443\u0447\u0430\u044f \u044f\u0432\u043b\u044f\u0435\u0442\u0441\u044f \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u044b\u043c.","weight":"\u0412\u0435\u0441"},"ipd_patient_charges":{"applied_charge":"\u041f\u0440\u0438\u043c\u0435\u043d\u0435\u043d\u043d\u044b\u0439 \u0437\u0430\u0440\u044f\u0434","charge_category_id":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u043d\u0430\u0447\u0438\u0441\u043b\u0435\u043d\u0438\u044f","charge_id":"\u041a\u043e\u0434","charge_type_id":"\u0422\u0438\u043f \u043d\u0430\u0447\u0438\u0441\u043b\u0435\u043d\u0438\u044f","date":"\u0414\u0430\u0442\u0430","new_charge":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u0430\u0447\u0438\u0441\u043b\u0435\u043d\u0438\u044f","standard_charge":"\u0421\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u043d\u044b\u0439 \u0441\u0431\u043e\u0440"},"ipd_patient_consultant_register":{"applied_date":"\u0414\u0430\u0442\u0430 \u043f\u0440\u0438\u043c\u0435\u043d\u0435\u043d\u0438\u044f","doctor_id":"\u0414\u043e\u043a\u0442\u043e\u0440","instruction":"\u0418\u043d\u0441\u0442\u0440\u0443\u043a\u0446\u0438\u044f","instruction_date":"\u0414\u0430\u0442\u0430 \u0438\u043d\u0441\u0442\u0440\u0443\u043a\u0446\u0438\u0438","new_consultant_register":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0438\u043d\u0441\u0442\u0440\u0443\u043a\u0446\u0438\u044e \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0430\u043d\u0442\u0430"},"ipd_patient_diagnosis":{"description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","document":"\u0414\u043e\u043a\u0443\u043c\u0435\u043d\u0442","edit_ipd_diagnosis":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0434\u0438\u0430\u0433\u043d\u043e\u0437","new_ipd_diagnosis":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u043a\u0443","report_date":"\u0414\u0430\u0442\u0430 \u043e\u0442\u0447\u0435\u0442\u0430","report_type":"\u0422\u0438\u043f \u043e\u0442\u0447\u0435\u0442\u0430"},"ipd_patient_prescription":{"category_id":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u043c\u0435\u0434\u0438\u0446\u0438\u043d\u044b","dosage":"\u0414\u043e\u0437\u0438\u0440\u043e\u0432\u043a\u0430","edit_prescription":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0440\u0435\u0446\u0435\u043f\u0442","footer_note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435 \u043a \u043d\u0438\u0436\u043d\u0435\u043c\u0443 \u043a\u043e\u043b\u043e\u043d\u0442\u0438\u0442\u0443\u043b\u0443","header_note":"\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a","instruction":"\u0418\u043d\u0441\u0442\u0440\u0443\u043a\u0446\u0438\u044f","ipd_no":"IPD \u041d\u0435\u0442","medicine_id":"\u041c\u0435\u0434\u0438\u0446\u0438\u043d\u0430","new_prescription":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0440\u0435\u0446\u0435\u043f\u0442","prescription_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0440\u0435\u0446\u0435\u043f\u0442\u0435","print_prescription":"\u0420\u0430\u0441\u043f\u0435\u0447\u0430\u0442\u0430\u0442\u044c \u0440\u0435\u0446\u0435\u043f\u0442"},"ipd_patient_timeline":{"date":"\u0414\u0430\u0442\u0430","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","document":"\u0414\u043e\u043a\u0443\u043c\u0435\u043d\u0442","edit_ipd_timeline":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0432\u0440\u0435\u043c\u0435\u043d\u043d\u0443\u044e \u0448\u043a\u0430\u043b\u0443","new_ipd_timeline":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0432\u0440\u0435\u043c\u0435\u043d\u043d\u0443\u044e \u0448\u043a\u0430\u043b\u0443","no_timeline_found":"TimeLine \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d","title":"\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a","visible_to_person":"\u0412\u0438\u0434\u043d\u043e \u0447\u0435\u043b\u043e\u0432\u0435\u043a\u0443"},"ipd_patients":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442\u044b IPD","ipd_payment":"\u041e\u043f\u043b\u0430\u0442\u0430 \u0418\u041f\u0414","ipd_payments":{"add_ipd_payment":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043f\u043b\u0430\u0442\u0435\u0436 Ipd","edit_ipd_payment":"Edit IPD Payment","make_payment":"\u0412\u043d\u0435\u0441\u0442\u0438 \u043f\u043b\u0430\u0442\u0435\u0436","payment_mode":"\u0420\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b"},"ipd_prescription":"\u0420\u0435\u0446\u0435\u043f\u0442\u044b","ipd_timelines":"\u0425\u0440\u043e\u043d\u043e\u043b\u043e\u0433\u0438\u044f","issued_item":{"are_you_sure_want_to_return_this_item":"\u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0432\u0435\u0440\u043d\u0443\u0442\u044c \u044d\u0442\u043e\u0442 \u0442\u043e\u0432\u0430\u0440?","available_quantity":"\u0414\u043e\u0441\u0442\u0443\u043f\u043d\u043e\u0435 \u043a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","department_id":"\u0422\u0438\u043f \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044f","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_issued_item":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0432\u044b\u0434\u0430\u043d\u043d\u044b\u0439 \u044d\u043b\u0435\u043c\u0435\u043d\u0442","issued_by":"\u0412\u044b\u043f\u0443\u0441\u043a \u043f\u043e","issued_date":"\u0414\u0430\u0442\u0430 \u0432\u044b\u043f\u0443\u0441\u043a\u0430","issued_item":"\u0412\u044b\u0434\u0430\u043d\u043d\u044b\u0439 \u043f\u0440\u0435\u0434\u043c\u0435\u0442","issued_item_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0432\u044b\u0434\u0430\u043d\u043d\u044b\u0445 \u0442\u043e\u0432\u0430\u0440\u0430\u0445","issued_items":"\u0412\u044b\u043f\u0443\u0449\u0435\u043d\u043d\u044b\u0435 \u043f\u0440\u0435\u0434\u043c\u0435\u0442\u044b","item":"\u041f\u0443\u043d\u043a\u0442","item_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0442\u043e\u0432\u0430\u0440\u0430","item_return":"\u0412\u0435\u0440\u043d\u0443\u0442\u044c \u0438\u0437\u0434\u0435\u043b\u0438\u0435","item_returned":"\u0412\u0435\u0440\u043d\u0443\u043b\u0441\u044f","new_issued_item":"\u041d\u043e\u0432\u044b\u0439 \u0432\u044b\u043f\u0443\u0449\u0435\u043d\u043d\u044b\u0439 \u043f\u0440\u0435\u0434\u043c\u0435\u0442","quantity":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","return_date":"\u0414\u0430\u0442\u0430 \u0432\u043e\u0437\u0432\u0440\u0430\u0449\u0435\u043d\u0438\u044f","user_id":"\u0412\u044b\u043f\u0443\u0441\u043a \u043a"},"issued_items":"\u0412\u044b\u043f\u0443\u0449\u0435\u043d\u043d\u044b\u0435 \u043f\u0440\u0435\u0434\u043c\u0435\u0442\u044b","item":{"available_quantity":"\u0414\u043e\u0441\u0442\u0443\u043f\u043d\u043e\u0435 \u043a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_item":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u044d\u043b\u0435\u043c\u0435\u043d\u0442","item":"\u041f\u0443\u043d\u043a\u0442","item_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0442\u043e\u0432\u0430\u0440\u0430","item_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043f\u0440\u0435\u0434\u043c\u0435\u0442\u0430","items":"\u041f\u0440\u0435\u0434\u043c\u0435\u0442\u044b","name":"\u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","new_item":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0440\u0435\u0434\u043c\u0435\u0442","unit":"\u0415\u0434. \u0438\u0437\u043c"},"item_category":{"edit_item_category":"\u0440\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0442\u043e\u0432\u0430\u0440\u0430","item_categories":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438 \u043f\u0440\u0435\u0434\u043c\u0435\u0442\u043e\u0432","item_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0442\u043e\u0432\u0430\u0440\u0430","name":"\u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","new_item_category":"\u041d\u043e\u0432\u044b\u0439 \u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0442\u043e\u0432\u0430\u0440\u0430"},"item_stock":{"attachment":"\u0412\u043b\u043e\u0436\u0435\u043d\u0438\u0435","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_item_stock":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e \u043f\u0440\u0435\u0434\u043c\u0435\u0442\u043e\u0432","item":"\u041f\u0443\u043d\u043a\u0442","item_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0442\u043e\u0432\u0430\u0440\u0430","item_stock":"\u0422\u043e\u0432\u0430\u0440 \u043d\u0430 \u0441\u043a\u043b\u0430\u0434\u0435","item_stock_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0437\u0430\u043f\u0430\u0441\u043e\u0432 \u0442\u043e\u0432\u0430\u0440\u0430","item_stocks":"\u0422\u043e\u0432\u0430\u0440 \u043d\u0430 \u0441\u043a\u043b\u0430\u0434\u0435","new_item_stock":"\u0417\u0430\u043f\u0430\u0441 \u043d\u043e\u0432\u044b\u0445 \u043f\u0440\u0435\u0434\u043c\u0435\u0442\u043e\u0432","purchase_price":"\u0426\u0435\u043d\u0430","quantity":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","store_name":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u043c\u0430\u0433\u0430\u0437\u0438\u043d\u0430","supplier_name":"\u043d\u0430\u0438\u043c\u0435\u043d\u043e\u0432\u0430\u043d\u0438\u0435 \u043f\u043e\u0441\u0442\u0430\u0432\u0449\u0438\u043a\u0430"},"items":"\u041f\u0440\u0435\u0434\u043c\u0435\u0442\u044b","items_categories":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438 \u043f\u0440\u0435\u0434\u043c\u0435\u0442\u043e\u0432","items_stocks":"\u0422\u043e\u0432\u0430\u0440 \u043d\u0430 \u0441\u043a\u043b\u0430\u0434\u0435","lab_tech":{"edit_lab_tech":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u041b\u0430\u0431\u043e\u0440\u0430\u043d\u0442","lab_tech_detail":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043b\u0430\u0431\u043e\u0440\u0430\u043d\u0442\u0435","lab_technician":"\u041b\u0430\u0431\u043e\u0440\u0430\u043d\u0442","new_lab_tech":"\u041d\u043e\u0432\u044b\u0439 \u043b\u0430\u0431\u043e\u0440\u0430\u043d\u0442"},"lab_technicians":"\u041b\u0430\u0431\u043e\u0440\u0430\u043d\u0442\u044b","language":{"Arabic":"\u0430\u0440\u0430\u0431\u0441\u043a\u0438\u0439","Chinese":"\u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438\u0439 \u044f\u0437\u044b\u043a","English":"\u0410\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439","French":"\u0424\u0440\u0430\u043d\u0446\u0443\u0437\u0441\u043a\u0438\u0439","German":"\u041d\u0435\u043c\u0435\u0446\u043a\u0438\u0439","Portuguese":"\u043f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u044c\u0441\u043a\u0438\u0439","Russian":"\u0420\u0443\u0441\u0441\u043a\u0438\u0439","Spanish":"\u0438\u0441\u043f\u0430\u043d\u0441\u043a\u0438\u0439","Turkish":"\u0442\u0443\u0440\u0435\u0446\u043a\u0438\u0439"},"linkedIn_url":"URL-\u0430\u0434\u0440\u0435\u0441 LinkedIn","live_consultation":{"add_credential":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0443\u0447\u0435\u0442\u043d\u044b\u0435 \u0434\u0430\u043d\u043d\u044b\u0435","client_video":"\u041a\u043b\u0438\u0435\u043d\u0442\u0441\u043a\u043e\u0435 \u0432\u0438\u0434\u0435\u043e","consultation_date":"\u0414\u0430\u0442\u0430 \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0430\u0446\u0438\u0438","consultation_duration_minutes":"\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u0435\u043b\u044c\u043d\u043e\u0441\u0442\u044c \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0430\u0446\u0438\u0438, \u043c\u0438\u043d\u0443\u0442\u044b","consultation_title":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0430\u0446\u0438\u0438","created_by":"\u041a\u0435\u043c \u0441\u043e\u0437\u0434\u0430\u043d\u043e","created_for":"\u0421\u043e\u0437\u0434\u0430\u043d \u0434\u043b\u044f","disabled":"\u041e\u0442\u043a\u043b\u044e\u0447\u0435\u043d\u043e","edit_live_consultation":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0438\u043d\u0442\u0435\u0440\u0430\u043a\u0442\u0438\u0432\u043d\u0443\u044e \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0430\u0446\u0438\u044e","edit_live_meeting":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0436\u0438\u0432\u0443\u044e \u0432\u0441\u0442\u0440\u0435\u0447\u0443","enable":"\u0412\u043a\u043b\u044e\u0447\u0438\u0442\u044c","host_video":"\u0425\u043e\u0441\u0442-\u0432\u0438\u0434\u0435\u043e","join_now":"\u041f\u0440\u0438\u0441\u043e\u0435\u0434\u0438\u043d\u044f\u0439\u0441\u044f \u0441\u0435\u0439\u0447\u0430\u0441","live_consultation":"\u0416\u0438\u0432\u043e\u0435 \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0438\u0440\u043e\u0432\u0430\u043d\u0438\u0435","new_live_consultation":"\u041d\u043e\u0432\u0430\u044f \u0436\u0438\u0432\u0430\u044f \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0430\u0446\u0438\u044f","new_live_meeting":"\u041d\u043e\u0432\u0430\u044f \u0436\u0438\u0432\u0430\u044f \u0432\u0441\u0442\u0440\u0435\u0447\u0430","staff_list":"\u0421\u043f\u0438\u0441\u043e\u043a \u0441\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a\u043e\u0432","type":"\u0422\u0438\u043f","type_number":"\u041d\u043e\u043c\u0435\u0440 \u0442\u0438\u043f\u0430","zoom_api_key":"\u041a\u043b\u044e\u0447 Zoom API","zoom_api_secret":"\u0421\u0435\u043a\u0440\u0435\u0442 Zoom API"},"live_consultations":"\u0416\u0438\u0432\u044b\u0435 \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0430\u0446\u0438\u0438","live_meeting":"\u0416\u0438\u0432\u0430\u044f \u0432\u0441\u0442\u0440\u0435\u0447\u0430","live_meetings":"\u0416\u0438\u0432\u044b\u0435 \u0432\u0441\u0442\u0440\u0435\u0447\u0438","mail":"\u043f\u043e\u0447\u0442\u0430","make_an_appointment":"\u041d\u0430\u0437\u043d\u0430\u0447\u0438\u0442\u044c \u0432\u0441\u0442\u0440\u0435\u0447\u0443","medicine":{"brand":"\u043c\u0430\u0440\u043a\u0430","brand_name":"\u043c\u0430\u0440\u043a\u0430 \u0438\u043c\u044f","buying_price":"\u0426\u0435\u043d\u0430 \u043f\u043e\u043a\u0443\u043f\u043a\u0438","category":"\u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f","category_id":"\u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u042f \u0431\u044b","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_medicine":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043b\u0435\u043a\u0430\u0440\u0441\u0442\u0432\u043e","edit_medicine_brand":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0411\u0440\u0435\u043d\u0434 \u041c\u0435\u0434\u0438\u0446\u0438\u043d\u044b","edit_medicine_category":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044e \u043c\u0435\u0434\u0438\u0446\u0438\u043d\u044b","medicine":"\u043c\u0435\u0434\u0438\u0446\u0438\u043d\u0430","medicine_brands":"\u0411\u0440\u0435\u043d\u0434\u044b \u043b\u0435\u043a\u0430\u0440\u0441\u0442\u0432","medicine_brands_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0442\u043e\u0440\u0433\u043e\u0432\u043e\u0439 \u043c\u0430\u0440\u043a\u0438 \u043c\u0435\u0434\u0438\u0446\u0438\u043d\u044b","medicine_category":"\u041c\u0435\u0434\u0438\u0446\u0438\u043d\u0430 \u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f","medicine_category_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438 \u043c\u0435\u0434\u0438\u0446\u0438\u043d\u044b","medicine_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043c\u0435\u0434\u0438\u0446\u0438\u043d\u044b","medicines":"\u041b\u0435\u043a\u0430\u0440\u0441\u0442\u0432\u0430","name":"\u0438\u043c\u044f","new_brand":"\u041d\u043e\u0432\u044b\u0439 \u0431\u0440\u0435\u043d\u0434","new_medicine":"\u041d\u043e\u0432\u0430\u044f \u043c\u0435\u0434\u0438\u0446\u0438\u043d\u0430","new_medicine_brand":"\u0411\u0440\u0435\u043d\u0434 \u043d\u043e\u0432\u043e\u0439 \u043c\u0435\u0434\u0438\u0446\u0438\u043d\u044b","new_medicine_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u043d\u043e\u0432\u043e\u0439 \u043c\u0435\u0434\u0438\u0446\u0438\u043d\u044b","salt_composition":"\u0421\u043e\u043b\u044c \u0421\u043e\u0441\u0442\u0430\u0432","selling_price":"\u041f\u0440\u043e\u0434\u0430\u0436\u043d\u0430\u044f \u0446\u0435\u043d\u0430","side_effects":"\u041f\u043e\u0431\u043e\u0447\u043d\u044b\u0435 \u044d\u0444\u0444\u0435\u043a\u0442\u044b"},"medicine_brands":"\u041b\u0435\u043a\u0430\u0440\u0441\u0442\u0432\u0435\u043d\u043d\u044b\u0435 \u0431\u0440\u0435\u043d\u0434\u044b","medicine_categories":"\u041c\u0435\u0434\u0438\u0446\u0438\u043d\u0430 \u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438","medicines":"\u041b\u0435\u043a\u0430\u0440\u0441\u0442\u0432\u0430","message":{"date":"\u0421\u0432\u0438\u0434\u0430\u043d\u0438\u0435","message":"C\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","messages":"\u0421\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u044f","messages_details":"\u0414\u0435\u0442\u0430\u043b\u0438 C\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u044f","new_message":"\u041d\u043e\u0432\u043e\u0435 C\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","select_user":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044f","send_to":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c","sender_name":"\u0418\u043c\u044f \u043e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u0435\u043b\u044f","subject":"\u0442\u0435\u043c\u0430"},"months":{"apr":"\u0430\u043f\u0440\u0435\u043b\u044f","aug":"\u0410\u0432\u0433\u0443\u0441\u0442","dec":"\u0414\u0435\u043a\u0430\u0431\u0440\u044c","feb":"\u0444\u0435\u0432\u0440\u0430\u043b\u044c","jan":"\u044f\u043d\u0432\u0430\u0440\u044c","july":"\u0418\u044e\u043b\u044c","jun":"\u0418\u044e\u043d\u044c","mar":"\u041c\u0430\u0440\u0448\u0438\u0440\u043e\u0432\u0430\u0442\u044c","may":"\u041c\u0430\u0439","nov":"\u043d\u043e\u044f\u0431\u0440\u044c","oct":"\u041e\u043a\u0442\u044f\u0431\u0440\u044c","sep":"\u0421\u0435\u043d\u0442\u044f\u0431\u0440\u044c"},"my_payroll":{"allowance":"\u043f\u043e\u0441\u043e\u0431\u0438\u0435","basic_salary":"\u0411\u0430\u0437\u043e\u0432\u0430\u044f \u0437\u0430\u0440\u043f\u043b\u0430\u0442\u0430","deductions":"\u0432\u044b\u0447\u0435\u0442\u044b","my_payrolls":"\u041c\u043e\u0438 \u043f\u043b\u0430\u0442\u0435\u0436\u043d\u044b\u0435 \u0432\u0435\u0434\u043e\u043c\u043e\u0441\u0442\u0438","net_salary":"\u0427\u0438\u0441\u0442\u0430\u044f \u0437\u0430\u0440\u043f\u043b\u0430\u0442\u0430"},"my_payrolls":"\u041c\u043e\u0438 \u043f\u043b\u0430\u0442\u0435\u0436\u043d\u044b\u0435 \u0432\u0435\u0434\u043e\u043c\u043e\u0441\u0442\u0438","new_patient":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0430\u0446\u0438\u0435\u043d\u0442","no_data_available":"\u0414\u0430\u043d\u043d\u044b\u0435 \u043e\u0442\u0441\u0443\u0442\u0441\u0442\u0432\u0443\u044e\u0442 \u0432 \u0442\u0430\u0431\u043b\u0438\u0446\u0435","notice_board":{"created_at":"\u0441\u043e\u0437\u0434\u0430\u043d \u0432","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0434\u043e\u0441\u043a\u0435 \u043e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0439","edit":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0434\u043e\u0441\u043a\u0443 \u043e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0439","new":"\u041d\u043e\u0432\u0430\u044f \u0434\u043e\u0441\u043a\u0430 \u043e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0439","notice_board":"\u0414\u043e\u0441\u043a\u0430 \u043e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0439","title":"\u0437\u0430\u0433\u043b\u0430\u0432\u0438\u0435"},"notice_boards":"\u0414\u043e\u0441\u043a\u0438 \u043e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0439","notification":{"mark_all_as_read":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u0432\u0441\u0435 \u043a\u0430\u043a \u043f\u0440\u043e\u0447\u0438\u0442\u0430\u043d\u043d\u043e\u0435","notifications":"\u0423\u0432\u0435\u0434\u043e\u043c\u043b\u0435\u043d\u0438\u044f","you_don`t_have_any_new_notification":"\u0423 \u0432\u0430\u0441 \u043d\u0435\u0442 \u043d\u043e\u0432\u044b\u0445 \u0443\u0432\u0435\u0434\u043e\u043c\u043b\u0435\u043d\u0438\u0439"},"nurse":{"birth_date":"\u0414\u0430\u0442\u0430 \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u044f","choose":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c","edit_nurse":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u041c\u0435\u0434\u0441\u0435\u0441\u0442\u0440\u0430","new_nurse":"\u041d\u043e\u0432\u0430\u044f \u043c\u0435\u0434\u0441\u0435\u0441\u0442\u0440\u0430","nurse":"\u041c\u0435\u0434\u0441\u0435\u0441\u0442\u0440\u0430","nurse_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043c\u0435\u0434\u0441\u0435\u0441\u0442\u0440\u044b","phone_no":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d \u043d\u0435\u0442"},"nurses":"\u041c\u0435\u0434\u0441\u0435\u0441\u0442\u0440\u044b","old_patient":"\u0421\u0442\u0430\u0440\u044b\u0439 \u043f\u0430\u0446\u0438\u0435\u043d\u0442","opd_diagnosis":"\u0414\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u043a\u0430 \u041e\u041f\u0414","opd_patient":{"appointment_date":"\u041d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u043d\u0430\u044f \u0434\u0430\u0442\u0430","edit_opd_patient":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430 OPD","new_opd_patient":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0430\u0446\u0438\u0435\u043d\u0442 \u0441 OPD","opd_number":"OPD \u041d\u0435\u0442","opd_patient":"OPD \u041f\u0430\u0446\u0438\u0435\u043d\u0442","opd_patient_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0435 OPD","opd_patients":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442\u044b \u0441 OPD","revisits":"\u041f\u0435\u0440\u0435\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c","total_visits":"\u0412\u0441\u0435\u0433\u043e \u043f\u043e\u0441\u0435\u0449\u0435\u043d\u0438\u0439","visits":"\u041f\u043e\u0441\u0435\u0449\u0435\u043d\u0438\u044f"},"opd_patients":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442\u044b \u0441 OPD","opd_payments":{"add_opd_payment":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043f\u043b\u0430\u0442\u0435\u0436 Opd","edit_opd_payment":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043e\u043f\u043b\u0430\u0442\u0443 Opd","make_payment":"\u0421\u043e\u0432\u0435\u0440\u0448\u0430\u0442\u044c \u043f\u043b\u0430\u0442\u0435\u0436","payment_mode":"\u0420\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b"},"opd_timeline":"\u0425\u0440\u043e\u043d\u043e\u043b\u043e\u0433\u0438\u044f OPD","operation_report":{"case_id":"\u0441\u043b\u0443\u0447\u0430\u0439 \u042f \u0431\u044b","date":"\u0414\u0430\u0442\u0430","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","doctor_name":"\u0418\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430","edit_operation_report":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043e\u0442\u0447\u0435\u0442 \u043e \u0440\u0430\u0431\u043e\u0442\u0435","new_operation_report":"\u041e\u0442\u0447\u0435\u0442 \u043e \u043d\u043e\u0432\u043e\u0439 \u043e\u043f\u0435\u0440\u0430\u0446\u0438\u0438","operation_report":"\u041e\u0442\u0447\u0435\u0442 \u043e \u0440\u0430\u0431\u043e\u0442\u0435","operation_report_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043e\u0442\u0447\u0435\u0442\u0430 \u043e\u0431 \u043e\u043f\u0435\u0440\u0430\u0446\u0438\u0438","operation_reports":"\u041e\u0442\u0447\u0435\u0442\u044b \u043e\u0431 \u043e\u043f\u0435\u0440\u0430\u0446\u0438\u044f\u0445","patient_name":"\u0418\u043c\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430"},"operation_reports":"\u041e\u0442\u0447\u0435\u0442\u044b \u043e\u0431 \u043e\u043f\u0435\u0440\u0430\u0446\u0438\u044f\u0445","overview":"\u041e\u0431\u0437\u043e\u0440","package":{"amount":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","discount":"\u0441\u043a\u0438\u0434\u043a\u0430","edit_package":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0430\u043a\u0435\u0442","name":"\u0438\u043c\u044f","new_package":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0430\u043a\u0435\u0442","package":"\u043f\u0430\u043a\u0435\u0442","package_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043f\u0430\u043a\u0435\u0442\u0435","packages":"\u043f\u0430\u043a\u0435\u0442\u044b","qty":"\u041a\u043e\u043b-\u0432\u043e","rate":"\u0422\u0435\u043c\u043f","select_service":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c \u0441\u0435\u0440\u0432\u0438\u0441","service":"\u043e\u0431\u0441\u043b\u0443\u0436\u0438\u0432\u0430\u043d\u0438\u0435","total_amount":"\u041e\u0431\u0449\u0430\u044f \u0441\u0443\u043c\u043c\u0430"},"packages":"\u043f\u0430\u043a\u0435\u0442\u044b","pathologies":"\u043f\u0430\u0442\u043e\u043b\u043e\u0433\u0438\u044f","pathology_categories":"\u043f\u0430\u0442\u043e\u043b\u043e\u0433\u0438\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f","pathology_category":{"edit_pathology_category":"\u0440\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0430\u0442\u043e\u043b\u043e\u0433\u0438\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f","name":"\u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","new_pathology_category":"\u043d\u043e\u0432\u044b\u0439 \u043f\u0430\u0442\u043e\u043b\u043e\u0433\u0438\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f","pathology_categories":"\u043f\u0430\u0442\u043e\u043b\u043e\u0433\u0438\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438"},"pathology_test":{"category_name":"\u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","charge_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0437\u0430\u0440\u044f\u0434\u0430","edit_pathology_test":"\u0440\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0430\u0442\u043e\u043b\u043e\u0433\u0438\u044f \u0422\u0435\u0441\u0442","method":"\u043c\u0435\u0442\u043e\u0434","new_pathology_test":"\u043d\u043e\u0432\u044b\u0439 \u043f\u0430\u0442\u043e\u043b\u043e\u0433\u0438\u044f \u0422\u0435\u0441\u0442","pathology_test_details":"\u043f\u0430\u0442\u043e\u043b\u043e\u0433\u0438\u044f \u0422\u0435\u0441\u0442 \u043f\u043e\u0434\u0440\u043e\u0431\u043d\u043e\u0441\u0442\u0438","pathology_tests":"\u043f\u0430\u0442\u043e\u043b\u043e\u0433\u0438\u044f \u0442\u0435\u0441\u0442\u044b","report_days":"\u0414\u043d\u0438 \u043e\u0442\u0447\u0435\u0442\u0430","short_name":"\u043a\u043e\u0440\u043e\u0442\u043a\u0438\u0439 \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","standard_charge":"\u0421\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u043d\u044b\u0439 \u0437\u0430\u0440\u044f\u0434","subcategory":"\u041f\u043e\u0434\u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f","test_name":"\u0422\u0435\u0441\u0442 \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","test_type":"\u0422\u0435\u0441\u0442 \u0422\u0438\u043f","unit":"\u0415\u0434. \u0438\u0437\u043c"},"pathology_tests":"\u043f\u0430\u0442\u043e\u043b\u043e\u0433\u0438\u044f \u0442\u0435\u0441\u0442\u044b","patient":{"edit_patient":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","new_patient":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0430\u0446\u0438\u0435\u043d\u0442","patient_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0435","total_admissions":"\u0412\u0441\u0435\u0433\u043e \u043f\u043e\u0441\u0442\u0443\u043f\u043b\u0435\u043d\u0438\u0439","total_appointments":"\u0412\u0441\u0435\u0433\u043e \u043d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0439","total_cases":"\u0412\u0441\u0435\u0433\u043e \u0441\u043b\u0443\u0447\u0430\u0435\u0432"},"patient_admission":{"admission_date":"\u0414\u0430\u0442\u0430 \u043f\u043e\u0441\u0442\u0443\u043f\u043b\u0435\u043d\u0438\u044f","agent_name":"\u0418\u043c\u044f \u0430\u0433\u0435\u043d\u0442\u0430","bed":"\u041f\u043e\u0441\u0442\u0435\u043b\u044c","details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043f\u0440\u0438\u0435\u043c\u0435 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","discharge_date":"\u0414\u0430\u0442\u0430 \u0432\u044b\u043f\u0438\u0441\u043a\u0438","doctor":"\u0414\u043e\u043a\u0442\u043e\u0440","doctor_name":"\u0418\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430","edit_patient_admission":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043f\u0440\u0438\u0435\u043c \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u043e\u0432","guardian_address":"\u0410\u0434\u0440\u0435\u0441 \u0445\u0440\u0430\u043d\u0438\u0442\u0435\u043b\u044f","guardian_contact":"\u041e\u043f\u0435\u043a\u0443\u043d \u041a\u043e\u043d\u0442\u0430\u043a\u0442","guardian_name":"\u0418\u043c\u044f \u043e\u043f\u0435\u043a\u0443\u043d\u0430","guardian_relation":"\u041e\u0442\u043d\u043e\u0448\u0435\u043d\u0438\u044f \u0425\u0440\u0430\u043d\u0438\u0442\u0435\u043b\u044f","insurance":"\u0441\u0442\u0440\u0430\u0445\u043e\u0432\u0430\u043d\u0438\u0435","insurance_name":"\u0421\u0442\u0440\u0430\u0445\u043e\u0432\u043e\u0435 \u0438\u043c\u044f","new_patient_admission":"\u041f\u043e\u0441\u0442\u0443\u043f\u043b\u0435\u043d\u0438\u0435 \u043d\u043e\u0432\u043e\u0433\u043e \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","package":"\u043f\u0430\u043a\u0435\u0442","package_name":"\u0418\u043c\u044f \u043f\u0430\u043a\u0435\u0442\u0430","patient":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442","patient_admission":"\u041f\u0440\u0438\u0435\u043c \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u043e\u0432","patient_admission_id":"\u0418\u0434\u0435\u043d\u0442\u0438\u0444\u0438\u043a\u0430\u0446\u0438\u043e\u043d\u043d\u044b\u0439 \u043d\u043e\u043c\u0435\u0440 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","patient_name":"\u0418\u043c\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","policy_no":"\u041f\u043e\u043b\u0438\u0442\u0438\u043a\u0430 \u2116"},"patient_admissions":"\u041f\u0440\u0438\u0435\u043c \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u043e\u0432","patient_appointment":"\u041f\u0440\u0438\u0451\u043c \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","patient_diagnosis_test":{"action":"\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0435","add_other_diagnosis_property":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0434\u0440\u0443\u0433\u043e\u0435 \u0441\u0432\u043e\u0439\u0441\u0442\u0432\u043e \u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u043a\u0438","age":"\u0412\u043e\u0437\u0440\u0430\u0441\u0442","average_glucose":"\u0421\u0440\u0435\u0434\u043d\u044f\u044f \u0433\u043b\u044e\u043a\u043e\u0437\u0430","blood_pressure":"\u0410\u0440\u0442\u0435\u0440\u0438\u0430\u043b\u044c\u043d\u043e\u0435 \u0434\u0430\u0432\u043b\u0435\u043d\u0438\u0435","cholesterol":"\u0425\u043e\u043b\u0435\u0441\u0442\u0435\u0440\u0438\u043d","create_patient_diagnosis_test":"\u0421\u043e\u0437\u0434\u0430\u0442\u044c \u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u0447\u0435\u0441\u043a\u0438\u0439 \u0442\u0435\u0441\u0442 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","created_at":"\u0421\u043e\u0437\u0434\u0430\u043d\u043e \u043d\u0430","diabetes":"\u0421\u0430\u0445\u0430\u0440\u043d\u044b\u0439 \u0434\u0438\u0430\u0431\u0435\u0442","diagnosis":"\u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u043a\u0430","diagnosis_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0434\u0438\u0430\u0433\u043d\u043e\u0437\u0430","diagnosis_property_name":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u0441\u0432\u043e\u0439\u0441\u0442\u0432\u0430 \u0434\u0438\u0430\u0433\u043d\u043e\u0437\u0430","diagnosis_property_value":"\u0417\u043d\u0430\u0447\u0435\u043d\u0438\u0435 \u0441\u0432\u043e\u0439\u0441\u0442\u0432\u0430 \u0434\u0438\u0430\u0433\u043d\u043e\u0437\u0430","diagnosis_test":"\u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u0447\u0435\u0441\u043a\u0438\u0435 \u0442\u0435\u0441\u0442\u044b","doctor":"\u0414\u043e\u043a\u0442\u043e\u0440","doctor_name":"\u0418\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430","edit_patient_diagnosis_test":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0434\u0438\u0430\u0433\u043d\u043e\u0437 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","fasting_blood_sugar":"\u0423\u0440\u043e\u0432\u0435\u043d\u044c \u0441\u0430\u0445\u0430\u0440\u0430 \u0432 \u043a\u0440\u043e\u0432\u0438 \u043d\u0430\u0442\u043e\u0449\u0430\u043a","height":"\u0412\u044b\u0441\u043e\u0442\u0430","new_patient_diagnosis_test":"\u041d\u043e\u0432\u044b\u0439 \u0414\u0438\u0430\u0433\u043d\u043e\u0437 \u041f\u0430\u0446\u0438\u0435\u043d\u0442\u0430 \u0414\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u043a\u0430","other_diagnosis_property":"\u0414\u0440\u0443\u0433\u043e\u0435 \u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u0447\u0435\u0441\u043a\u043e\u0435 \u0441\u0432\u043e\u0439\u0441\u0442\u0432\u043e","patient":"\u0422\u0435\u0440\u043f\u0435\u043b\u0438\u0432\u044b\u0439","patient_diagnosis_test":"\u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u0447\u0435\u0441\u043a\u0438\u0435 \u0442\u0435\u0441\u0442\u044b \u0434\u043b\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u043e\u0432","patient_diagnosis_test_details":"\u0414\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u0447\u0435\u0441\u043a\u0438\u0439 \u0442\u0435\u0441\u0442 \u0434\u043b\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","patient_name":"\u0418\u043c\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","print_diagnosis_test":"\u0420\u0430\u0441\u043f\u0435\u0447\u0430\u0442\u0430\u0442\u044c \u0434\u0438\u0430\u0433\u043d\u043e\u0441\u0442\u0438\u0447\u0435\u0441\u043a\u0438\u0439 \u0442\u0435\u0441\u0442","report_number":"\u041d\u043e\u043c\u0435\u0440 \u043e\u0442\u0447\u0435\u0442\u0430","urine_sugar":"\u0421\u0430\u0445\u0430\u0440 \u0432 \u043c\u043e\u0447\u0435","weight":"\u041c\u0430\u0441\u0441\u0430"},"patients":"\u043f\u0430\u0446\u0438\u0435\u043d\u0442\u044b","patients_case_details":"\u041f\u043e\u0434\u0440\u043e\u0431\u043d\u0430\u044f \u0438\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f \u043e \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0435","patients_cases":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442\u044b","payment":{"account":"\u0443\u0447\u0435\u0442\u043d\u0430\u044f \u0437\u0430\u043f\u0438\u0441\u044c","account_name":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u0430\u043a\u043a\u0430\u0443\u043d\u0442\u0430","amount":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_payment":"\u041d\u043e\u0432\u044b\u0439 \u043f\u043b\u0430\u0442\u0435\u0436","new_payment":"\u041d\u043e\u0432\u044b\u0439 \u043f\u043b\u0430\u0442\u0435\u0436","pay_to":"\u041f\u043b\u0430\u0442\u0438\u0442\u044c","payment":"\u041e\u043f\u043b\u0430\u0442\u0430","payment_date":"\u0414\u0430\u0442\u0430 \u043f\u043b\u0430\u0442\u0435\u0436\u0430","payment_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043f\u043b\u0430\u0442\u0435\u0436\u0430","payment_reports":"\u041e\u0442\u0447\u0435\u0442\u044b \u043e\u0431 \u043e\u043f\u043b\u0430\u0442\u0435","payments":"\u043f\u043b\u0430\u0442\u0435\u0436\u0438"},"payments":"\u043f\u043b\u0430\u0442\u0435\u0436\u0438","pharmacist":{"edit_pharmacist":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0444\u0430\u0440\u043c\u0430\u0446\u0435\u0432\u0442\u0430","new_pharmacist":"\u041d\u043e\u0432\u044b\u0439 \u0444\u0430\u0440\u043c\u0430\u0446\u0435\u0432\u0442","pharmacist_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0444\u0430\u0440\u043c\u0430\u0446\u0435\u0432\u0442\u0435","pharmacists":"\u0424\u0430\u0440\u043c\u0430\u0446\u0435\u0432\u0442\u044b"},"pharmacists":"\u0424\u0430\u0440\u043c\u0430\u0446\u0435\u0432\u0442\u044b","postal":{"address":"\u0410\u0434\u0440\u0435\u0441","date":"\u0414\u0430\u0442\u0430","dispatch":"\u041e\u0442\u043f\u0440\u0430\u0432\u043a\u0430","edit_dispatch":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043e\u0442\u043f\u0440\u0430\u0432\u043a\u0443","edit_receive":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043f\u043e\u043b\u0443\u0447\u0435\u043d\u0438\u0435","from_title":"\u0418\u0437 \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u044f","new_dispatch":"\u041d\u043e\u0432\u0430\u044f \u043e\u0442\u043f\u0440\u0430\u0432\u043a\u0430","new_receive":"\u041d\u043e\u0432\u043e\u0435 \u043f\u043e\u043b\u0443\u0447\u0435\u043d\u0438\u0435","postal":"\u041e\u0442\u043a\u0440\u044b\u0442\u043a\u0430","receive":"\u041f\u043e\u043b\u0443\u0447\u0438\u0442\u044c","reference_no":"\u041d\u043e\u043c\u0435\u0440 \u0441\u0441\u044b\u043b\u043a\u0438","to_title":"\u041a \u0437\u0430\u0433\u043e\u043b\u043e\u0432\u043a\u0443"},"postal_dispatch":"\u041f\u043e\u0447\u0442\u043e\u0432\u0430\u044f \u043e\u0442\u043f\u0440\u0430\u0432\u043a\u0430","postal_receive":"\u041f\u043e\u0447\u0442\u043e\u0432\u044b\u0439 \u043f\u0440\u0438\u0435\u043c","prescription":{"Rx":"Rx","accident":"\u041d\u0435\u0441\u0447\u0430\u0441\u0442\u043d\u044b\u0439 \u0441\u043b\u0443\u0447\u0430\u0439","advice":"\u0441\u043e\u0432\u0435\u0442","after_meal":"\u043f\u043e\u0441\u043b\u0435 \u0435\u0434\u044b","before_meal":"\u043f\u0435\u0440\u0435\u0434 \u0435\u0434\u043e\u0439","breast_feeding":"\u0413\u0440\u0443\u0434\u043d\u043e\u0435 \u0432\u0441\u043a\u0430\u0440\u043c\u043b\u0438\u0432\u0430\u043d\u0438\u0435","comment":"\u043a\u043e\u043c\u043c\u0435\u043d\u0442\u0430\u0440\u0438\u0439","current_medication":"\u0422\u0435\u043a\u0443\u0449\u0435\u0435 \u043b\u0435\u0447\u0435\u043d\u0438\u0435","days":"\u0434\u043d\u0438","diabetic":"\u0434\u0438\u0430\u0431\u0435\u0442\u0438\u0447\u0435\u0441\u043a\u0438\u0439","duration":"\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u0435\u043b\u044c\u043d\u043e\u0441\u0442\u044c","edit_prescription":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0440\u0435\u0446\u0435\u043f\u0442","female_pregnancy":"\u0416\u0435\u043d\u0441\u043a\u0430\u044f \u0431\u0435\u0440\u0435\u043c\u0435\u043d\u043d\u043e\u0441\u0442\u044c","food_allergies":"\u041f\u0438\u0449\u0435\u0432\u044b\u0435 \u0430\u043b\u043b\u0435\u0440\u0433\u0438\u0438","health_insurance":"\u041c\u0435\u0434\u0438\u0446\u0438\u043d\u0441\u043a\u0430\u044f \u0441\u0442\u0440\u0430\u0445\u043e\u0432\u043a\u0430","heart_disease":"\u0411\u043e\u043b\u0435\u0437\u043d\u044c \u0441\u0435\u0440\u0434\u0446\u0430","high_blood_pressure":"\u0412\u044b\u0441\u043e\u043a\u043e\u0435 \u043a\u0440\u043e\u0432\u044f\u043d\u043e\u0435 \u0434\u0430\u0432\u043b\u0435\u043d\u0438\u0435","low_income":"\u041d\u0438\u0437\u043a\u0438\u0439 \u0443\u0440\u043e\u0432\u0435\u043d\u044c \u0434\u043e\u0445\u043e\u0434\u0430","medical_history":"\u0418\u0441\u0442\u043e\u0440\u0438\u044f \u0431\u043e\u043b\u0435\u0437\u043d\u0438","medicine_name":"\u0438\u043c\u044f_\u043c\u0435\u0434\u0438\u0446\u0438\u043d\u044b","month":"\u041c\u0435\u0441\u044f\u0446","new_medicine":"\u043d\u043e\u0432\u043e\u0435 \u043b\u0435\u043a\u0430\u0440\u0441\u0442\u0432\u043e","new_prescription":"\u041d\u043e\u0432\u044b\u0439 \u0440\u0435\u0446\u0435\u043f\u0442","next_visit":"\u0441\u043b\u0435\u0434\u0443\u044e\u0449\u0438\u0439 \u0432\u0438\u0437\u0438\u0442","no_data_available":"\u0434\u0430\u043d\u043d\u044b\u0435 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u044b","others":"\u0434\u0440\u0443\u0433\u0438\u0435","patient":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442","physical_information":"\u0444\u0438\u0437\u0438\u0447\u0435\u0441\u043a\u0430\u044f \u0438\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f","plus_rate":"\u041f\u0443\u043b\u044c\u0441 \u0441\u0442\u0430\u0432\u043a\u0430","prescription":"\u0434\u0430\u0432\u043d\u043e\u0441\u0442\u044c","prescription_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0440\u0435\u0446\u0435\u043f\u0442\u0430","prescriptions":"\u041f\u0440\u0435\u0434\u043f\u0438\u0441\u0430\u043d\u0438\u044f","problem":"\u043f\u0440\u043e\u0431\u043b\u0435\u043c\u0430","problem_description":"\u043e\u043f\u0438\u0441\u0430\u043d\u0438\u0435 \u043f\u0440\u043e\u0431\u043b\u0435\u043c\u044b","reference":"\u0421\u0441\u044b\u043b\u043a\u0430","surgery":"\u0425\u0438\u0440\u0443\u0440\u0433\u0438\u044f","temperature":"\u0442\u0435\u043c\u043f\u0435\u0440\u0430\u0442\u0443\u0440\u0430","tendency_bleed":"\u0422\u0435\u043d\u0434\u0435\u043d\u0446\u0438\u044f \u041a\u0440\u043e\u0432\u043e\u0442\u0435\u0447\u0435\u043d\u0438\u0435","test":"\u0442\u0435\u0441\u0442","time":"\u0432\u0440\u0435\u043c\u044f","year":"\u0413\u043e\u0434"},"prescriptions":"\u041f\u0440\u0435\u0434\u043f\u0438\u0441\u0430\u043d\u0438\u044f","profile":{"change_language":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u044f\u0437\u044b\u043a","edit_profile":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0440\u043e\u0444\u0438\u043b\u044c","email":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0435 \u043f\u0438\u0441\u044c\u043c\u043e","first_name":"\u0418\u043c\u044f","language":"\u044f\u0437\u044b\u043a","last_name":"\u0424\u0430\u043c\u0438\u043b\u0438\u044f","phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d","profile":"\u041f\u0440\u043e\u0444\u0438\u043b\u044c"},"radiologies":"\u0440\u0430\u0434\u0438\u043e\u043b\u043e\u0433\u0438\u044f","radiology_categories":"\u0440\u0430\u0434\u0438\u043e\u043b\u043e\u0433\u0438\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f","radiology_category":{"edit_radiology_category":"\u0440\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0440\u0430\u0434\u0438\u043e\u043b\u043e\u0433\u0438\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f","name":"\u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","new_radiology_category":"\u043d\u043e\u0432\u044b\u0439 \u0440\u0430\u0434\u0438\u043e\u043b\u043e\u0433\u0438\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f","radiology_categories":"\u0440\u0430\u0434\u0438\u043e\u043b\u043e\u0433\u0438\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438"},"radiology_test":{"category_name":"\u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","charge_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u043d\u0430\u0447\u0438\u0441\u043b\u0435\u043d\u0438\u044f","edit_radiology_test":"\u0440\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0440\u0430\u0434\u0438\u043e\u043b\u043e\u0433\u0438\u044f \u0422\u0435\u0441\u0442","new_radiology_test":"\u043d\u043e\u0432\u044b\u0439 \u0440\u0430\u0434\u0438\u043e\u043b\u043e\u0433\u0438\u044f \u0422\u0435\u0441\u0442","radiology_test_details":"\u0440\u0430\u0434\u0438\u043e\u043b\u043e\u0433\u0438\u044f \u0422\u0435\u0441\u0442 \u043f\u043e\u0434\u0440\u043e\u0431\u043d\u043e\u0441\u0442\u0438","radiology_tests":"\u0440\u0430\u0434\u0438\u043e\u043b\u043e\u0433\u0438\u044f \u0442\u0435\u0441\u0442\u044b","report_days":"\u0414\u043d\u0438 \u043e\u0442\u0447\u0435\u0442\u0430","short_name":"\u043a\u043e\u0440\u043e\u0442\u043a\u0438\u0439 \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","standard_charge":"\u0421\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u043d\u044b\u0439 \u0437\u0430\u0440\u044f\u0434","subcategory":"\u041f\u043e\u0434\u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f","test_name":"\u0422\u0435\u0441\u0442 \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435","test_type":"\u0422\u0435\u0441\u0442 \u0422\u0438\u043f"},"radiology_tests":"\u0440\u0430\u0434\u0438\u043e\u043b\u043e\u0433\u0438\u044f \u0442\u0435\u0441\u0442\u044b","receptionist":{"edit_receptionist":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0440\u0435\u0433\u0438\u0441\u0442\u0440\u0430\u0442\u043e\u0440","new_receptionist":"\u041d\u043e\u0432\u044b\u0439 \u0440\u0435\u0433\u0438\u0441\u0442\u0440\u0430\u0442\u043e\u0440","receptionist":"\u041f\u043e\u0440\u0442\u044c\u0435","receptionist_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043f\u0440\u0438\u0435\u043c\u043d\u043e\u0439","receptionists":"\u041f\u043e\u0440\u0442\u044c\u0435"},"receptionists":"\u041f\u043e\u0440\u0442\u044c\u0435","reports":"\u041e\u0442\u0447\u0435\u0442\u044b","role":{"edit_role":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0440\u043e\u043b\u044c","new_role":"\u041d\u043e\u0432\u0430\u044f \u0440\u043e\u043b\u044c"},"roles":"\u0420\u043e\u043b\u0438","schedule":{"available_from":"\u0414\u043e\u0441\u0442\u0443\u043f\u043d\u0430 \u0441","available_on":"\u0414\u043e\u0441\u0442\u0443\u043f\u043d\u043e \u043d\u0430","available_to":"\u0414\u043e\u0441\u0442\u0443\u043f\u0435\u043d","details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u0440\u0430\u0441\u043f\u0438\u0441\u0430\u043d\u0438\u0438","doctor_name":"\u0418\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430","edit":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0440\u0430\u0441\u043f\u0438\u0441\u0430\u043d\u0438\u0435","new":"\u041d\u043e\u0432\u043e\u0435 \u0440\u0430\u0441\u043f\u0438\u0441\u0430\u043d\u0438\u0435","per_patient_time":"\u0412\u0440\u0435\u043c\u044f \u043d\u0430 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","select_doctor_name":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c \u0438\u043c\u044f \u0434\u043e\u043a\u0442\u043e\u0440\u0430","select_serial_visibility":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c \u043f\u043e\u0441\u043b\u0435\u0434\u043e\u0432\u0430\u0442\u0435\u043b\u044c\u043d\u0443\u044e \u0432\u0438\u0434\u0438\u043c\u043e\u0441\u0442\u044c","sequential":"\u043f\u043e\u0441\u043b\u0435\u0434\u043e\u0432\u0430\u0442\u0435\u043b\u044c\u043d\u044b\u0439","serial_visibility":"\u0421\u0435\u0440\u0438\u0439\u043d\u0430\u044f \u0432\u0438\u0434\u0438\u043c\u043e\u0441\u0442\u044c","timestamp":"\u041e\u0442\u043c\u0435\u0442\u043a\u0430"},"schedule_label":"\u0420\u0430\u0441\u043f\u0438\u0441\u0430\u043d\u0438\u0435","schedules":"\u0420\u0430\u0441\u043f\u0438\u0441\u0430\u043d\u0438\u044f","service":{"edit_service":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0441\u0435\u0440\u0432\u0438\u0441","given":"\u0434\u0430\u043d\u043e","new_service":"\u041d\u043e\u0432\u044b\u0439 \u0421\u0435\u0440\u0432\u0438\u0441","not_given":"\u041d\u0435 \u0434\u0430\u043d\u043e","quantity":"\u043a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","rate":"\u0422\u0435\u043c\u043f","service_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e\u0431 \u0443\u0441\u043b\u0443\u0433\u0435"},"services":"\u0421\u0435\u0440\u0432\u0438\u0441\u044b","setting":{"address":"\u0410\u0434\u0440\u0435\u0441 \u0411\u043e\u043b\u044c\u043d\u0438\u0446\u0430","app_logo":"\u041b\u043e\u0433\u043e\u0442\u0438\u043f \u043f\u0440\u0438\u043b\u043e\u0436\u0435\u043d\u0438\u044f","app_name":"\u0418\u043c\u044f \u043f\u0440\u0438\u043b\u043e\u0436\u0435\u043d\u0438\u044f","company_name":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u043a\u043e\u043c\u043f\u0430\u043d\u0438\u0438","country_code":"\u041a\u043e\u0434 \u0441\u0442\u0440\u0430\u043d\u044b","currency":"\u0422\u0435\u043a\u0443\u0449\u0430\u044f \u0432\u0430\u043b\u044e\u0442\u0430","hospital_email":"\u0411\u043e\u043b\u044c\u043d\u0438\u0446\u0430 \u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430","hospital_from_day":"\u0411\u043e\u043b\u044c\u043d\u0438\u0446\u0430 \u043e\u0442 \u0434\u043d\u044f","hospital_from_time":"\u0411\u043e\u043b\u044c\u043d\u0438\u0446\u0430 \u043e\u0442 \u0432\u0440\u0435\u043c\u0435\u043d\u0438","hospital_phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d \u0431\u043e\u043b\u044c\u043d\u0438\u0446\u044b","image_validation":"\u0418\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435 \u0434\u043e\u043b\u0436\u043d\u043e \u0431\u044b\u0442\u044c \u0440\u0430\u0437\u043c\u0435\u0440\u043e\u043c 90 x 60 \u043f\u0438\u043a\u0441\u0435\u043b\u0435\u0439.","social_details":"\u0421\u043e\u0446\u0438\u0430\u043b\u044c\u043d\u044b\u0435 \u0434\u0435\u0442\u0430\u043b\u0438"},"settings":"\u043d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438","short_description":"\u041a\u0440\u0430\u0442\u043a\u043e\u0435 \u043e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","sidebar_setting":"\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438 \u043c\u043e\u0434\u0443\u043b\u0435\u0439","sms":{"date":"\u0421\u0432\u0438\u0434\u0430\u043d\u0438\u0435","message":"\u0421\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","new_sms":"\u041d\u043e\u0432\u044b\u0435 \u0441\u043c\u0441","only_user_with_registered_phone_will_display":"(\u041e\u0442\u043e\u0431\u0440\u0430\u0436\u0430\u044e\u0442\u0441\u044f \u0442\u043e\u043b\u044c\u043a\u043e \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u0438 \u0441 \u0437\u0430\u0440\u0435\u0433\u0438\u0441\u0442\u0440\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u044b\u043c \u0442\u0435\u043b\u0435\u0444\u043e\u043d\u043e\u043c.)","phone_number":"\u041d\u043e\u043c\u0435\u0440 \u0442\u0435\u043b\u0435\u0444\u043e\u043d\u0430","role":"\u0420\u043e\u043b\u044c","send":"\u043f\u043e\u0441\u043b\u0430\u0442\u044c","send_by":"\u041e\u0442\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u043e","send_sms_by_number_directly":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c SMS \u043f\u043e \u043d\u043e\u043c\u0435\u0440\u0443 \u043d\u0430\u043f\u0440\u044f\u043c\u0443\u044e","send_to":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c","sms":"\u0441\u043c\u0441","sms_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0441\u043c\u0441"},"testimonial":{"description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_testimonial":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043e\u0442\u0437\u044b\u0432","name":"\u0418\u043c\u044f","new_testimonial":"\u041d\u043e\u0432\u044b\u0439 \u043e\u0442\u0437\u044b\u0432","profile_error":"\u0414\u043e\u043a\u0443\u043c\u0435\u043d\u0442 \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0444\u0430\u0439\u043b\u043e\u043c \u0442\u0438\u043f\u0430: jpeg, jpg, png.","testimonial":"\u041e\u0442\u0437\u044b\u0432","testimonial_detail":"\u0414\u0435\u0442\u0430\u043b\u044c \u043e\u0442\u0437\u044b\u0432\u0430"},"testimonials":"\u041e\u0442\u0437\u044b\u0432\u044b","twitter_url":"\u0430\u0434\u0440\u0435\u0441 \u0442\u0432\u0438\u0442\u0442\u0435\u0440\u0430","user":{"address1":"\u0430\u0434\u0440\u0435\u0441 1","address2":"\u0410\u0434\u0440\u0435\u0441 2","address_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0430\u0434\u0440\u0435\u0441\u0430","address_not_found":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0430\u0434\u0440\u0435\u0441\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u044b","blood_group":"\u0413\u0440\u0443\u043f\u043f\u0430 \u043a\u0440\u043e\u0432\u0438","change_password":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043f\u0430\u0440\u043e\u043b\u044c","city":"\u0433\u043e\u0440\u043e\u0434","designation":"\u043e\u0431\u043e\u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0435","dob":"\u0414\u0430\u0442\u0430 \u0440\u043e\u0436\u0434\u0435\u043d\u0438\u044f","edit_profile":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0440\u043e\u0444\u0438\u043b\u044c","edit_user":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044f","education":"\u043e\u0431\u0440\u0430\u0437\u043e\u0432\u0430\u043d\u0438\u0435","email":"\u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0435 \u043f\u0438\u0441\u044c\u043c\u043e","email_verified_successfully":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430 \u043f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0435\u043d\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e.","female":"\u0436\u0435\u043d\u0441\u043a\u0438\u0439","first_name":"\u0418\u043c\u044f","gender":"\u043f\u043e\u043b","invalid_password":"\u0422\u0435\u043a\u0443\u0449\u0438\u0439 \u043f\u0430\u0440\u043e\u043b\u044c \u043d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u0435\u043d.","last_name":"\u0424\u0430\u043c\u0438\u043b\u0438\u044f","logout":"\u0412\u044b\u0439\u0442\u0438","male":"\u043c\u0443\u0436\u0447\u0438\u043d\u0430","name":"\u0438\u043c\u044f","new_user":"\u041d\u043e\u0432\u044b\u0439 \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c","password":"\u043f\u0430\u0440\u043e\u043b\u044c","password_confirmation":"\u041f\u043e\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u044c \u043f\u0430\u0440\u043e\u043b\u044c","phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d","qualification":"\u041a\u0432\u0430\u043b\u0438\u0444\u0438\u043a\u0430\u0446\u0438\u044f","select_blood_group":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c \u0433\u0440\u0443\u043f\u043f\u0443 \u043a\u0440\u043e\u0432\u0438","status":"\u041f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0434\u0435\u043b","user_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044f","usrs":"\u041f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c","validate_confirm_password":"\u041f\u0430\u0440\u043e\u043b\u044c \u0438 \u043f\u0430\u0440\u043e\u043b\u044c \u043f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0435\u043d\u0438\u044f \u0434\u043e\u043b\u0436\u043d\u044b \u0441\u043e\u0432\u043f\u0430\u0434\u0430\u0442\u044c.","validate_min_character_password":"\u041f\u0430\u0440\u043e\u043b\u044c \u0434\u043e\u043b\u0436\u0435\u043d \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u0442\u044c \u043d\u0435 \u043c\u0435\u043d\u0435\u0435 6 \u0441\u0438\u043c\u0432\u043e\u043b\u043e\u0432.","zip":"\u0437\u0430\u0441\u0442\u0435\u0436\u043a\u0430-\u043c\u043e\u043b\u043d\u0438\u044f"},"users":"\u041f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u0438","vaccinated_patient":{"add_vaccinate_patient":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430 \u0434\u043b\u044f \u0432\u0430\u043a\u0446\u0438\u043d\u0430\u0446\u0438\u0438","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","does_no":"\u0414\u043e\u0437\u0430 \u2116","dose_given_date":"\u0414\u0430\u0442\u0430 \u0432\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u0434\u043e\u0437\u044b","edit_vaccinate_patient":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0432\u0430\u043a\u0446\u0438\u043d\u0430\u0446\u0438\u044e \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","new_vaccinate_patient":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0430\u0446\u0438\u0435\u043d\u0442 \u0432\u0430\u043a\u0446\u0438\u043d\u0438\u0440\u043e\u0432\u0430\u043d","patient":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442","serial_no":"\u0421\u0435\u0440\u0438\u0439\u043d\u044b\u0439 \u043d\u043e\u043c\u0435\u0440","vaccinate_patient":"\u0412\u0430\u043a\u0446\u0438\u043d\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u0430","vaccinated_patient":"\u0412\u0430\u043a\u0446\u0438\u043d\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u044b\u0439 \u043f\u0430\u0446\u0438\u0435\u043d\u0442","vaccination":"\u0412\u0430\u043a\u0446\u0438\u043d\u0430\u0446\u0438\u044f","vaccine":"\u0412\u0430\u043a\u0446\u0438\u043d\u0430"},"vaccinated_patients":"\u0412\u0430\u043a\u0446\u0438\u043d\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u044b\u0435 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u044b","vaccination":{"brand":"\u041c\u0430\u0440\u043a\u0430","edit_vaccination":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0432\u0430\u043a\u0446\u0438\u043d\u0430\u0446\u0438\u044e","manufactured_by":"\u0418\u0437\u0433\u043e\u0442\u043e\u0432\u043b\u0435\u043d\u044b \u043f\u043e","name":"\u0418\u043c\u044f","new_vaccination":"\u041d\u043e\u0432\u0430\u044f \u0432\u0430\u043a\u0446\u0438\u043d\u0430\u0446\u0438\u044f","vaccinated":"\u0412\u0430\u043a\u0446\u0438\u043d\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u044b\u0439","vaccinations":"\u041f\u0440\u0438\u0432\u0438\u0432\u043a\u0438"},"vaccinations":"\u041f\u0440\u0438\u0432\u0438\u0432\u043a\u0438","valid":"\u0414\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u0439","verification":{"another_verify_request":"\u043d\u0430\u0436\u043c\u0438\u0442\u0435 \u0437\u0434\u0435\u0441\u044c, \u0447\u0442\u043e\u0431\u044b \u0437\u0430\u043f\u0440\u043e\u0441\u0438\u0442\u044c \u0434\u0440\u0443\u0433\u043e\u0439","verify_message":"\u041f\u0440\u0435\u0436\u0434\u0435 \u0447\u0435\u043c \u043f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u044c, \u043f\u0440\u043e\u0432\u0435\u0440\u044c\u0442\u0435 \u0441\u0432\u043e\u044e \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0443\u044e \u043f\u043e\u0447\u0442\u0443 \u043d\u0430 \u043d\u0430\u043b\u0438\u0447\u0438\u0435 \u0441\u0441\u044b\u043b\u043a\u0438 \u0434\u043b\u044f \u043f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0435\u043d\u0438\u044f. \u0415\u0441\u043b\u0438 \u0432\u044b \u043d\u0435 \u043f\u043e\u043b\u0443\u0447\u0438\u043b\u0438 \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0435 \u043f\u0438\u0441\u044c\u043c\u043e,","verify_your_email_address":"\u041f\u0440\u043e\u0432\u0435\u0440\u044c\u0442\u0435 \u0441\u0432\u043e\u0439 \u0430\u0434\u0440\u0435\u0441 \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b."},"visitor":{"date":"\u0414\u0430\u0442\u0430","edit":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043f\u043e\u0441\u0435\u0442\u0438\u0442\u0435\u043b\u044f","id_card":"\u0423\u0434\u043e\u0441\u0442\u043e\u0432\u0435\u0440\u0435\u043d\u0438\u0435 \u043b\u0438\u0447\u043d\u043e\u0441\u0442\u0438","in_time":"\u0412\u043e \u0432\u0440\u0435\u043c\u044f","name":"\u0438\u043c\u044f","new":"\u041d\u043e\u0432\u044b\u0439 \u043f\u043e\u0441\u0435\u0442\u0438\u0442\u0435\u043b\u044c","note":"\u0417\u0430\u043f\u0438\u0441\u044c","number_of_person":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e \u0447\u0435\u043b\u043e\u0432\u0435\u043a","out_time":"\u0412\u0440\u0435\u043c\u044f \u0432\u044b\u0445\u043e\u0434\u0430","phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d","purpose":"\u0426\u0435\u043b\u044c","visitor":"\u041f\u043e\u0441\u0435\u0442\u0438\u0442\u0435\u043b\u044c"},"visitors":"\u041f\u043e\u0441\u0435\u0442\u0438\u0442\u0435\u043b\u0438","web_appointment":{"call_now_and_get_a_free_consulting":"\u0417\u0432\u043e\u043d\u0438\u0442\u0435 \u0441\u0435\u0439\u0447\u0430\u0441 \u0438 \u043f\u043e\u043b\u0443\u0447\u0438\u0442\u0435 \u0431\u0435\u0441\u043f\u043b\u0430\u0442\u043d\u0443\u044e \u043a\u043e\u043d\u0441\u0443\u043b\u044c\u0442\u0430\u0446\u0438\u044e","enter_confirm_password":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u041f\u043e\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u0435 \u041f\u0430\u0440\u043e\u043b\u044c","enter_description":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u043e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","enter_your_first_name":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0441\u0432\u043e\u0435 \u0438\u043c\u044f","enter_your_last_name":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0432\u0430\u0448\u0443 \u0444\u0430\u043c\u0438\u043b\u0438\u044e","enter_your_password":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0432\u0430\u0448 \u043f\u0430\u0440\u043e\u043b\u044c","make_an_appointment":"\u0417\u0430\u043f\u0438\u0441\u0430\u0442\u044c\u0441\u044f \u043d\u0430 \u043f\u0440\u0438\u0435\u043c","select_department":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043e\u0442\u0434\u0435\u043b","select_doctor":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0434\u043e\u043a\u0442\u043e\u0440\u0430","select_time":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0432\u0440\u0435\u043c\u044f"},"web_contact":{"call_today":"\u0417\u0432\u043e\u043d\u0438\u0442\u0435 \u0441\u0435\u0433\u043e\u0434\u043d\u044f","contact_no":"\u041a\u043e\u043d\u0442\u0430\u043a\u0442 \u041d\u0435\u0442","enter_your_email":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0430\u0434\u0440\u0435\u0441 \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b","enter_your_name":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0432\u0430\u0448\u0435 \u0438\u043c\u044f","open_hours":"\u041e\u0442\u043a\u0440\u044b\u0442\u044b\u0435 \u0447\u0430\u0441\u044b","our_location":"\u043d\u0430\u0448\u0435 \u043c\u0435\u0441\u0442\u043e\u043f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u0435","phone_number":"\u041d\u043e\u043c\u0435\u0440 \u0442\u0435\u043b\u0435\u0444\u043e\u043d\u0430","please_enter_your_phone_number":"\u043f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430 \u0432\u0432\u0435\u0434\u0438\u0442\u0435 \u0432\u0430\u0448 \u043d\u043e\u043c\u0435\u0440 \u0442\u0435\u043b\u0435\u0444\u043e\u043d\u0430","select_enquiry":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0437\u0430\u043f\u0440\u043e\u0441","send_message":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c \u0441\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","send_us_a_message":"\u041e\u0442\u043f\u0440\u0430\u0432\u044c\u0442\u0435 \u043d\u0430\u043c \u0441\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","type_your_message":"\u041d\u0430\u043f\u0438\u0448\u0438\u0442\u0435 \u0432\u0430\u0448\u0435 \u0441\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","write_your_message":"\u041d\u0430\u043f\u0438\u0448\u0438\u0442\u0435 \u0432\u0430\u0448\u0435 \u0441\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","your_email":"\u0412\u0430\u0448 \u0430\u0434\u0440\u0435\u0441 \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b","your_message":"\u0422\u0432\u043e\u0435 \u0441\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","your_name":"\u0412\u0430\u0448\u0435 \u0438\u043c\u044f"},"web_home":{"4_easy_step_and_get_the_world_best_treatment":"4 Easy Step \u0438 \u043b\u0443\u0447\u0448\u0435\u0435 \u0432 \u043c\u0438\u0440\u0435 \u043b\u0435\u0447\u0435\u043d\u0438\u0435","about_us":"\u041e \u043d\u0430\u0441","available_doctors":"\u0414\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0435 \u0432\u0440\u0430\u0447\u0438","book_an_appointment":"\u0417\u0430\u043f\u0438\u0441\u0430\u0442\u044c\u0441\u044f \u043d\u0430 \u043f\u0440\u0438\u0435\u043c","book_appointment":"\u0417\u0430\u043f\u0438\u0441\u044c \u043d\u0430 \u043f\u0440\u0438\u0435\u043c","book_now":"\u0417\u0430\u043a\u0430\u0437\u0430\u0442\u044c \u0441\u0435\u0439\u0447\u0430\u0441","contact":"\u041a\u043e\u043d\u0442\u0430\u043a\u0442","contact_doctors":"\u0421\u0432\u044f\u0437\u0430\u0442\u044c\u0441\u044f \u0441 \u0434\u043e\u043a\u0442\u043e\u0440\u043e\u043c","contact_hospital":"\u0421\u0432\u044f\u0437\u0430\u0442\u044c\u0441\u044f \u0441 \u0431\u043e\u043b\u044c\u043d\u0438\u0446\u0435\u0439","doctors":"\u0412\u0440\u0430\u0447\u0438","doctors_nurses":"\u0412\u0440\u0430\u0447\u0438 \u0438 \u043c\u0435\u0434\u0441\u0435\u0441\u0442\u0440\u044b","easy_solutions":"\u041f\u0440\u043e\u0441\u0442\u044b\u0435 \u0440\u0435\u0448\u0435\u043d\u0438\u044f","happy_patients":"\u0421\u0447\u0430\u0441\u0442\u043b\u0438\u0432\u044b\u0435 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u044b","home":"\u0414\u043e\u043c","make_appointment":"\u041d\u0430\u0437\u043d\u0430\u0447\u0438\u0442\u044c \u0432\u0441\u0442\u0440\u0435\u0447\u0443","our_services":"\u043d\u0430\u0448\u0438 \u0441\u0435\u0440\u0432\u0438\u0441\u044b","our_testimonials":"\u041d\u0430\u0448\u0438 \u043e\u0442\u0437\u044b\u0432\u044b","patients":"\u041f\u0430\u0446\u0438\u0435\u043d\u0442\u044b","patients_beds":"\u041a\u0440\u043e\u0432\u0430\u0442\u0438 \u0434\u043b\u044f \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u043e\u0432","privacy_policy":"\u041f\u043e\u043b\u0438\u0442\u0438\u043a\u0430 \u043a\u043e\u043d\u0444\u0438\u0434\u0435\u043d\u0446\u0438\u0430\u043b\u044c\u043d\u043e\u0441\u0442\u0438","professional_doctors":"\u041f\u0440\u043e\u0444\u0435\u0441\u0441\u0438\u043e\u043d\u0430\u043b\u044c\u043d\u044b\u0435 \u0432\u0440\u0430\u0447\u0438","select_doctor":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0434\u043e\u043a\u0442\u043e\u0440\u0430","select_doctors":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0432\u0440\u0430\u0447\u0435\u0439","services":"\u0423\u0441\u043b\u0443\u0433\u0438","sign_up":"\u0417\u0430\u0440\u0435\u0433\u0438\u0441\u0442\u0440\u0438\u0440\u043e\u0432\u0430\u0442\u044c\u0441\u044f","terms_of_service":"\u0443\u0441\u043b\u043e\u0432\u0438\u044f \u043e\u0431\u0441\u043b\u0443\u0436\u0438\u0432\u0430\u043d\u0438\u044f","testimonials":"\u041e\u0442\u0437\u044b\u0432\u044b","we_are_experienced_healthcare_professionals":"\u041c\u044b \u043e\u043f\u044b\u0442\u043d\u044b\u0435 \u0441\u043f\u0435\u0446\u0438\u0430\u043b\u0438\u0441\u0442\u044b \u0432 \u043e\u0431\u043b\u0430\u0441\u0442\u0438 \u0437\u0434\u0440\u0430\u0432\u043e\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0438\u044f","we_offer_different_services_to_improve_your_health":"\u041c\u044b \u043f\u0440\u0435\u0434\u043b\u0430\u0433\u0430\u0435\u043c \u0440\u0430\u0437\u043b\u0438\u0447\u043d\u044b\u0435 \u0443\u0441\u043b\u0443\u0433\u0438 \u0434\u043b\u044f \u0443\u043b\u0443\u0447\u0448\u0435\u043d\u0438\u044f \u0432\u0430\u0448\u0435\u0433\u043e \u0437\u0434\u043e\u0440\u043e\u0432\u044c\u044f","what_our_patient_say_about_medical_treatments":"\u0427\u0442\u043e \u043d\u0430\u0448\u0438 \u043f\u0430\u0446\u0438\u0435\u043d\u0442\u044b \u0433\u043e\u0432\u043e\u0440\u044f\u0442 \u043e \u043d\u0430\u0448\u0435\u043c \u043b\u0435\u0447\u0435\u043d\u0438\u0438","working_hours":"\u0420\u0430\u0431\u043e\u0447\u0438\u0435 \u0447\u0430\u0441\u044b","years_experience":"\u041b\u0435\u0442 \u043e\u043f\u044b\u0442\u0430"},"web_menu":{"about":"\u041e","all_rights_reserved_by":"\u0412\u0441\u0435 \u043f\u0440\u0430\u0432\u0430 \u0437\u0430\u0449\u0438\u0449\u0435\u043d\u044b.","appointment":"\u0414\u0435\u043b\u043e\u0432\u043e\u0435 \u0441\u0432\u0438\u0434\u0430\u043d\u0438\u0435, \u0432\u0441\u0442\u0440\u0435\u0447\u0430","contact_information":"\u041a\u043e\u043d\u0442\u0430\u043a\u0442\u043d\u0430\u044f \u0438\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f","copyright":"\u0430\u0432\u0442\u043e\u0440\u0441\u043a\u043e\u0435 \u043f\u0440\u0430\u0432\u043e","login":"\u0410\u0432\u0442\u043e\u0440\u0438\u0437\u043e\u0432\u0430\u0442\u044c\u0441\u044f","our_features":"\u041d\u0430\u0448\u0438 \u043e\u0441\u043e\u0431\u0435\u043d\u043d\u043e\u0441\u0442\u0438","useful_link":"\u041f\u043e\u043b\u0435\u0437\u043d\u0430\u044f \u0441\u0441\u044b\u043b\u043a\u0430","working_hours":"\u0420\u0430\u0431\u043e\u0447\u0438\u0435 \u0447\u0430\u0441\u044b"},"web_password":{"password_and_confirm_password_not_match":"\u041f\u0430\u0440\u043e\u043b\u044c \u0438 \u043f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0435\u043d\u0438\u0435 \u043f\u0430\u0440\u043e\u043b\u044f \u043d\u0435 \u0441\u043e\u0432\u043f\u0430\u0434\u0430\u044e\u0442.","please_fill_all_the_required_fields":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0437\u0430\u043f\u043e\u043b\u043d\u0438\u0442\u0435 \u0432\u0441\u0435 \u043d\u0435\u043e\u0431\u0445\u043e\u0434\u0438\u043c\u044b\u0435 \u043f\u043e\u043b\u044f."},"web_working_hours":{"no_yet_opening_hours":"\u0415\u0449\u0435 \u043d\u0435\u0442 \u0447\u0430\u0441\u043e\u0432 \u0440\u0430\u0431\u043e\u0442\u044b","opening_hours":"\u0427\u0430\u0441\u044b \u0440\u0430\u0431\u043e\u0442\u044b"},"weekdays":{"fri":"\u041f\u0422","mon":"\u041f\u041d","sat":"\u0421\u0418\u0414\u0415\u041b","sun":"\u0421\u041e\u041b\u041d\u0426\u0415","thu":"\u0427\u0422","tue":"\u0412\u0422","wed":"\u041c\u042b \u0411"}},"tr.messages":{"about_us":"Hakk\u0131m\u0131zda","account":{"account":"hesap","account_details":"hesap detaylar\u0131","accounts":"Hesaplar","credit":"Kredi","debit":"bor\u00e7","description":"A\u00e7\u0131klama","edit_account":"Hesab\u0131 d\u00fczenlemek","name":"ad","new_account":"Yeni hesap","payments":"\u00d6demeler","status":"durum","type":"tip"},"account_manager":"Muhasebe M\u00fcd\u00fcr\u00fc","accountant":{"accountant_details":"Muhasebeci Detaylar\u0131","accountants":"Muhasebeciler","edit_accountant":"Muhasebeciyi D\u00fczenle","new_accountant":"Yeni Muhasebeci"},"accountants":"Muhasebeciler","accounts":"Hesaplar","admin":"Y\u00f6neticiler","admins":"y\u00f6netici","advanced_payment":{"advanced_payment":"Avans \u00f6demesi","advanced_payment_details":"Pe\u015fin \u00d6deme Detaylar\u0131","advanced_payments":"Pe\u015fin \u00d6demeler","amount":"Miktar","date":"tarih","edit_advanced_payment":"Pe\u015fin \u00d6demeyi D\u00fczenle","new_advanced_payment":"Yeni Pe\u015fin \u00d6deme","patient":"Hasta","patient_name":"Hasta ad\u0131","receipt_no":"Makbuz No"},"advanced_payments":"Pe\u015fin \u00d6demeler","allow_file_type":"\u0130zin verilen dosya t\u00fcrleri: png, jpg, jpeg.","ambulance":{"ambulance":"Ambulans","ambulance_details":"Ambulans Detaylar\u0131","ambulances":"Ambulanslar","driver_contact":"S\u00fcr\u00fcc\u00fc Konta\u011f\u0131","driver_license":"Ehliyet","driver_name":"S\u00fcr\u00fcc\u00fc ad\u0131","edit_ambulance":"Ambulans\u0131 D\u00fczenle","is_available":"Gecerli","new_ambulance":"Yeni Ambulans","note":"Not","vehicle_model":"Ara\u00e7 modeli","vehicle_number":"Ara\u00e7 numaras\u0131","vehicle_type":"ara\u00e7 tipi","year_made":"Yap\u0131m Y\u0131l\u0131"},"ambulance_call":{"ambulance_call":"Ambulans \u00c7a\u011fr\u0131s\u0131","ambulance_call_details":"Ambulans \u00c7a\u011fr\u0131 Detaylar\u0131","ambulance_calls":"Ambulans \u00c7a\u011fr\u0131lar\u0131","amount":"Miktar","date":"tarih","driver_name":"S\u00fcr\u00fcc\u00fc ad\u0131","edit_ambulance_call":"Ambulans \u00c7a\u011fr\u0131s\u0131n\u0131 D\u00fczenle","new_ambulance_call":"Yeni Ambulans \u00c7a\u011fr\u0131s\u0131","patient":"Hasta","vehicle_model":"Ara\u00e7 modeli"},"ambulance_calls":"Ambulans \u00c7a\u011fr\u0131lar\u0131","ambulances":"Ambulanslar","appointment":{"appointment_calendar":"Randevu Takvimi","appointment_details":"Randevu Detaylar\u0131","appointment_exists":"Hasta e-postas\u0131 zaten var","appointment_list":"Randevu Listesi","are_you_sure_want_to_cancel":"\u0130ptal etmek istedi\u011fine emin misin","are_you_sure_want_to_change":"de\u011fi\u015ftirmek istedi\u011finden emin misin","available_slot":"Mevcut Yuva","calendar_view":"Takvim G\u00f6r\u00fcn\u00fcm\u00fc","change_status":"Durum de\u011fi\u015ftirmek","changed_appointment":"Randevu De\u011fi\u015ftirildi","completed":"Tamamland\u0131","date":"tarih","day":"G\u00fcn","department_name":"B\u00f6l\u00fcm Ad\u0131","description":"A\u00e7\u0131klama","doctor":"doktor","doctor_department":"Doktor B\u00f6l\u00fcm\u00fc","doctor_department_name":"Doktor B\u00f6l\u00fcm Ad\u0131","doctor_name":"Doktor Ad\u0131","doctor_schedule_not_available_on_this_date":"Doktor Program\u0131 bu tarihte m\u00fcsait de\u011fil.","edit_appointment":"Randevuyu D\u00fczenle","has_been_cancelled":"iptal edildi.","has_been_changed":"de\u011fi\u015ftirildi","last_30_days":"Son 30 g\u00fcn","last_7_days":"Son 7 g\u00fcn","last_month":"Ge\u00e7en ay","month":"Ay","new_appointment":"Yeni randevu","no_available":"M\u00fcsait de\u011fil","old_patient_email_exists":"E-posta zaten var, l\u00fctfen eski hastay\u0131 se\u00e7in.","opd_date":"\u0130\u015flem Tarihi","patient":"Hasta","patient_name":"Hasta ad\u0131","patient_not_exists_or_status_is_not_active":"Hasta mevcut de\u011fil veya durum aktif de\u011fil.","pending":"Bekliyor","please_select_appointment_time_slot":"L\u00fctfen randevu zaman aral\u0131\u011f\u0131n\u0131 se\u00e7in","please_select_doctor":"L\u00fctfen Doktor se\u00e7in","please_select_doctor_department":"L\u00fctfen Doktor Departman\u0131 se\u00e7iniz","this_month":"Bu ay","this_week":"Bu hafta","today":"Bug\u00fcn","week":"Hafta","yesterday":"D\u00fcn"},"appointment_calendar":"Atanmas\u0131. Takvim","appointments":"randevular","available_slot":"Mevcut Yuva","bed":{"add":"Ekle","available":"Mevcut","bed":"Yeni Yatak","bed_details":"Yatak Detaylar\u0131","bed_id":"Yatak No","bed_type":"Yatak Tipi","beds":"Yataklar","charge":"\u015earj etmek","description":"A\u00e7\u0131klama","edit_bed":"Yata\u011f\u0131 D\u00fczenle","name":"ad","new_bed":"Yeni Yatak","new_bulk_bed":"Yeni Toplu Yatak","not_available":"M\u00fcsait de\u011fil"},"bed_assign":{"assign_date":"Atama Tarihi","assign_date_should_not_be_smaller_than_patient_birth_date":"Atama tarihi, hastan\u0131n do\u011fum tarihinden k\u00fc\u00e7\u00fck olmamal\u0131d\u0131r.","assigned":"atanan","bed":"Yatak","bed_assign":"Yatak Atama","bed_assign_details":"Yatak Tayin Detaylar\u0131","bed_assigns":"Yatak \u00d6devleri","bed_name":"Yatak Ad\u0131","case_id":"Dava numaras\u0131","description":"A\u00e7\u0131klama","discharge_date":"\u00c7\u0131k\u0131\u015f Tarihi","edit_bed_assign":"Yatak Atamas\u0131n\u0131 D\u00fczenle","ipd_patient_id":"IPD Hasta Kimli\u011fi","new_bed_assign":"Yeni Yatak Atama","not_assigned":"Atanmad\u0131","patient_name":"Hasta ad\u0131"},"bed_assigns":"Bed Assigns","bed_management":"Yatak Y\u00f6netimi","bed_mgt":"Yatak Y\u00f6netimi","bed_status":{"admission_date":"Kabul Tarihi","assigned_beds":"Atanm\u0131\u015f Yataklar","available_beds":"Mevcut Yataklar","bed_name":"Yatak Ad\u0131","bed_status":"Yatak Durumu","gender":"Cinsiyet","patient_name":"Hasta ad\u0131","phone":"Telefon"},"bed_type":{"bed_type":"Yatak Tipi","bed_type_details":"Yatak Tipi Detaylar\u0131","bed_types":"Yatak \u00c7e\u015fitleri","description":"A\u00e7\u0131klama","edit_bed_type":"Yatak Tipini D\u00fczenle","new_bed_type":"Yeni Yatak Tipi","title":"Ba\u015fl\u0131k"},"bed_types":"Yatak \u00c7e\u015fitleri","beds":"Yataklar","bill":{"add":"Ekle","admission_date":"Kabul Tarihi","admission_id":"Giri\u015f Kimli\u011fi","amount":"Miktar","bill":"fatura","bill_date":"Fatura tarihi","bill_details":"Fatura Ayr\u0131nt\u0131lar\u0131","bill_id":"fatura kimli\u011fi","bill_summary":"Fatura \u00d6zeti","bills":"fatura","calculate":"Hesaplamak","cell_no":"Telefon numaras\u0131","discharge_date":"\u00c7\u0131k\u0131\u015f Tarihi","doctor_name":"Doktor Ad\u0131","edit":"D\u00fczenle","edit_bill":"Faturay\u0131 D\u00fczenle","generate_bill":"Fatura Olu\u015ftur","insurance_name":"Sigorta Ad\u0131","item_name":"\u00d6\u011fe ad\u0131","new_bill":"Yeni Fatura","package_name":"Paket ismi","patient":"Hasta","patient_cell_no":"Hasta H\u00fccresi No","patient_dob":"Hasta DOB","patient_email":"Hasta E-postas\u0131","patient_gender":"Hasta Cinsiyeti","patient_name":"Hasta ad\u0131","policy_no":"Politika No","price":"Fiyat","print_bill":"Faturay\u0131 Yazd\u0131r","qty":"Adet","total_amount":"Toplam tutar","total_days":"Toplam G\u00fcn","update_bill":"Faturay\u0131 G\u00fcncelle"},"billing":"fatura","bills":"fatura","birth_report":{"birth_report":"Do\u011fum Raporu","birth_report_details":"Do\u011fum Raporu Ayr\u0131nt\u0131lar\u0131","birth_reports":"Do\u011fum Raporlar\u0131","case_id":"Dava numaras\u0131","data_should_not_be_smaller_than_patient_birth_date":"Tarih, hastan\u0131n do\u011fum tarihinden k\u00fc\u00e7\u00fck olmamal\u0131d\u0131r.","date":"tarih","description":"A\u00e7\u0131klama","doctor_name":"Doktor Ad\u0131","edit_birth_report":"Do\u011fum Raporunu D\u00fczenle","new_birth_report":"Yeni Do\u011fum Raporu","patient_birth_date_not_found":"Hasta Do\u011fum Tarihi bulunamad\u0131.","patient_name":"Hasta ad\u0131"},"birth_reports":"Do\u011fum Raporlar\u0131","blood_bank":"Kan Bankas\u0131","blood_banks":"Kan Bankalar\u0131","blood_donation":{"bags":"\u00c7antalar","blood_donation":"Kan ba\u011f\u0131\u015f\u0131","donor_name":"Don\u00f6r Ad\u0131","edit_blood_donation":"Kan Ba\u011f\u0131\u015f\u0131n\u0131 D\u00fczenle","last_donate_date":"Son ba\u011f\u0131\u015f tarihi","new_blood_donation":"Yeni Kan Ba\u011f\u0131\u015f\u0131"},"blood_donations":"Kan Ba\u011f\u0131\u015f\u0131","blood_donor":{"age":"Ya\u015f","blood_donor":"Kan ba\u011f\u0131\u015f\u00e7\u0131s\u0131","blood_donor_details":"Kan Ba\u011f\u0131\u015f\u00e7\u0131s\u0131 Detaylar\u0131","blood_donors":"Kan vericiler","blood_group":"Kan grubu","donation_date":"Ba\u011f\u0131\u015f Tarihi","edit_blood_donor":"Kan Ba\u011f\u0131\u015f\u00e7\u0131s\u0131n\u0131 D\u00fczenle","gender":"Cinsiyet","last_donation_date":"Son Ba\u011f\u0131\u015f Tarihi","name":"ad","new_blood_donor":"Yeni Kan Ba\u011f\u0131\u015f\u00e7\u0131s\u0131"},"blood_donors":"Kan vericiler","blood_issue":{"amount":"Tutar","blood_issue":"Kan Sorunu","doctor_name":"Doktor Ad\u0131","donor_name":"Don\u00f6r Ad\u0131","edit_blood_issue":"Kan Sorununu D\u00fczenle","issue_date":"Verili\u015f Tarihi","new_blood_issue":"Yeni Kan Sorunu","patient_name":"Hasta Ad\u0131","remarks":"A\u00e7\u0131klamalar"},"blood_issues":"Kan Sorunus","call_log":{"call_log":"\u00c7a\u011fr\u0131 ge\u00e7mi\u015fi","call_type":"\u00c7a\u011fr\u0131 tipi","edit":"\u00c7a\u011fr\u0131 G\u00fcnl\u00fc\u011f\u00fcn\u00fc D\u00fczenle","follow_up_date":"Takip Tarihi","incoming":"Gelen","name":"\u0130sim","new":"Yeni \u00c7a\u011fr\u0131 Kayd\u0131","note":"Not","outgoing":"D\u0131\u015fa d\u00f6n\u00fck","phone":"Telefon","received_on":"Al\u0131nd\u0131\u011f\u0131 Tarih"},"call_logs":"Arama kay\u0131tlar\u0131","case":{"case":"Durum","case_date":"Vaka Tarihi","case_details":"Vaka Detaylar\u0131","case_id":"Dava numaras\u0131","date":"tarih","description":"A\u00e7\u0131klama","doctor":"doktor","edit_case":"Vakay\u0131 D\u00fczenle","fee":"\u00fccret","new_case":"Yeni dava","patient":"Hasta","phone":"Telefon"},"case_handler":{"case_handler":"Vaka \u0130\u015fleyici","case_handler_detail":"Kasa \u0130\u015fleyici Ayr\u0131nt\u0131lar\u0131","edit_case_handler":"Servis Talebi \u0130\u015fleyicisini D\u00fczenle","new_case_handler":"Yeni Kasa \u0130\u015fleyici"},"case_handlers":"Kasa \u0130\u015fleyicileri","case_manager":"Vaka y\u00f6neticisi","cases":"K\u0131l\u0131flar","change_password":{"change_password":"\u015eifre de\u011fi\u015ftir","confirm_password":"\u015eifreyi Onayla","current_password":"\u015eimdiki \u015eifre","new_password":"Yeni \u015eifre"},"charge":{"charge_category":"\u015earj Kategorisi","charge_details":"\u00dccret Ayr\u0131nt\u0131lar\u0131","code":"kod","edit_charge":"\u00dccreti D\u00fczenle","new_charge":"Yeni \u00d6deme","standard_charge":"Standart fiyat"},"charge_categories":"\u015earj Kategorileri","charge_category":{"charge_categories":"\u015earj Kategorileri","charge_category_details":"\u015earj Kategorisi Detaylar\u0131","charge_type":"\u015earj tipi","edit_charge_category":"\u00dccret Kategorisini D\u00fczenle","new_charge_category":"Yeni \u00dccret Kategorisi"},"charges":"Masraflar","cms":"CMS","common":{"action":"Aksiyon","actions":"Hareketler","active":"Aktif","add":"Ekle","address":"Adres","apply":"uygulamak","are_you_sure_want_to_delete_this":"Bunu silmek istedi\u011finizden emin misiniz ","back":"Geri","cancel":"\u0130ptal etmek","canceled":"\u0130ptal edildi","cant_be_deleted":"silinemez","choose":"Se\u00e7","confirm":"Onaylamak","created_at":"Olu\u015fturma Tarihi","created_on":"Olu\u015fturma Tarihi","custom":"Gelenek","de_active":"De-aktif","delete":"Sil","deleted":"silindi","deleted_successfully":"ba\u015far\u0131yla silindi","description":"A\u00e7\u0131klama","detail":"detaylar","edit":"D\u00fczenle","export_to_excel":"Excel'e aktar","filter_options":"Filtre se\u00e7enekleri","from":"itibaren","has_been_deleted":"silindi.","invalid_country_code":"Ge\u00e7ersiz \u00fclke kodu","invalid_number":"Ge\u00e7ersiz numara","is_available":"Gecerli","last_updated":"Son g\u00fcncelleme","n\/a":"N \/ A","name":"ad","new":"Yeni","next":"Sonraki","no":"Hay\u0131r","not_found":"bulunamad\u0131","ok":"Tamam","previous":"\u00d6ncesi","profile":"Profil","reset":"S\u0131f\u0131rla","save":"Kay\u0131t etmek","saved_successfully":"Ba\u015far\u0131yla kaydedildi.","search":"Arama","status":"durum","status_updated_successfully":"Durum ba\u015far\u0131yla g\u00fcncellendi.","this_action_is_not_allowed_for_default_record":"Bu eyleme varsay\u0131lan kay\u0131t i\u00e7in izin verilmez.","to":"\u0130le","too_long":"\u00c7ok uzun","too_short":"\u00c7ok k\u0131sa","total":"Toplam","updated_at":"Son g\u00fcncelleme","updated_successfully":"ba\u015far\u0131yla g\u00fcncellendi","view":"G\u00f6r\u00fcn\u00fcm","view_attachment":"Eki g\u00f6r\u00fcnt\u00fcle","yes":"Evet"},"contact_us":"Bize Ula\u015f\u0131n","currency":{"add_currency_code_as_per_three_letter_iso_code":"\u00dc\u00e7 harfli ISO koduna g\u00f6re para birimi kodu ekleyin","currency":"Para birimi","currency_code":"Para Birimi Kodu","currency_icon":"Para Birimi Simgesi","currency_name":"Para Birimi Ad\u0131","edit_currency":"Para Birimi D\u00fczenle","new_currency":"Yeni Para Birimi","you_can_find_out_here":"buradan \u00f6\u011frenebilirsin"},"currency_setting":"para birimleri","dashboard":{"available_beds":"Mevcut yataklar","dashboard":"G\u00f6sterge Paneli","doctors":"Doktorlar","income_and_expense_report":"Gelir ve Gider Raporu","income_and_expense_reports":"Gelir ve Gider Raporlar\u0131","no_enquiries_yet":"Hen\u00fcz Soru\u015fturma Yok","no_notice_yet":"Hen\u00fcz Bildirim Yok","notice_boards":"\u0130lan Panolar\u0131","patients":"hastalar","title":"Ba\u015fl\u0131k","total_advance_payments":"Pe\u015fin \u00d6deme Tutar\u0131","total_bills":"Fatura tutar\u0131","total_invoices":"Fatura tutar\u0131","total_payments":"\u00d6deme miktar\u0131"},"death_report":{"case_id":"Dava numaras\u0131","date":"tarih","death_report":"\u00d6l\u00fcm Raporu","death_report_details":"\u00d6l\u00fcm Raporu Detaylar\u0131","death_reports":"\u00d6l\u00fcm Raporlar\u0131","description":"A\u00e7\u0131klama","doctor_name":"Doktor Ad\u0131","edit_death_report":"\u00d6l\u00fcm Raporunu D\u00fczenle","new_death_report":"Yeni \u00d6l\u00fcm Raporu","patient_name":"Hasta ad\u0131"},"death_reports":"Death Reports","department":"B\u00f6l\u00fcm","departments":"B\u00f6l\u00fcmler","diagnosis_category":{"category_name":"Kategori ad\u0131","description":"A\u00e7\u0131klama","diagnosis_categories":"Te\u015fhis kategorisi","diagnosis_category":"Te\u015fhis Kategorisi","diagnosis_category_details":"Te\u015fhis Kategorisi Detaylar\u0131","edit_diagnosis_category":"Tan\u0131 Kategorisini D\u00fczenle","new_diagnosis_category":"Yeni Tan\u0131 Kategorisi"},"doc_type":{"edit_doc_type":"Belge T\u00fcr\u00fcn\u00fc D\u00fczenle","name":"ad","new_doc_type":"Yeni Belge T\u00fcr\u00fc"},"doctor":{"doctor_details":"Doktor Detaylar\u0131","edit_doctor":"Doktoru D\u00fczenle","name":"ad","new_doctor":"Yeni Doktor","specialist":"uzman"},"doctor_department":{"description":"A\u00e7\u0131klama","doctor_department":"Doktor B\u00f6l\u00fcm\u00fc","doctor_department_details":"Doktor Departman\u0131 Detaylar\u0131","doctor_departments":"Doktor B\u00f6l\u00fcmleri","edit_doctor_department":"Doktor B\u00f6l\u00fcm\u00fcn\u00fc D\u00fczenle","new_doctor_department":"Yeni Doktor Departman\u0131","title":"Ba\u015fl\u0131k"},"doctor_departments":"Doktor B\u00f6l\u00fcmleri","doctor_opd_charge":{"doctor":"Doktor","doctor_name":"Doktor Ad\u0131","doctor_opd_charge":"Doktor OPD \u00dccreti","edit_doctor_opd_charge":"Doktor OPD \u00dccretini D\u00fczenle","new_doctor_opd_charge":"Yeni Doktor OPD \u00dccreti","standard_charge":"Standart Fiyat"},"doctor_opd_charges":"Doktor OPD \u00dccretleri","doctors":"Doktorlar","doctors_list":"Doktor Listesi","document":{"attachment":"Ek dosya","document":"belge","document_detail":"Belge Ayr\u0131nt\u0131lar\u0131","document_type":"d\u00f6k\u00fcman tipi","document_type_details":"Belge T\u00fcr\u00fc Ayr\u0131nt\u0131lar\u0131","download":"\u0130ndir","edit_document":"Belgeyi D\u00fczenle","new_document":"Yeni belge","notes":"Notlar","patient":"Hasta","select_document_type":"Belge T\u00fcr\u00fcn\u00fc Se\u00e7in","select_patient":"Hastay\u0131 Se\u00e7","title":"Ba\u015fl\u0131k","uploaded_by":"Y\u00fckleyen"},"document_types":"Belge T\u00fcrleri","documents":"evraklar","email":{"attachment":"Ekler","message":"\u0130leti","subject":"konu","to":"i\u00e7in"},"employee_payroll":{"allowance":"\u00f6denek","basic_salary":"Temel maa\u015f","deductions":"Kesintiler","edit_employee_payroll":"\u00c7al\u0131\u015fan Bordrounu D\u00fczenle","employee":"i\u015f\u00e7i","employee_name":"\u00c7al\u0131\u015fan Ad\u0131","employee_payroll":"\u00c7al\u0131\u015fan Bordro","employee_payroll_details":"\u00c7al\u0131\u015fan Bordro Detaylar\u0131","employee_payrolls":"\u00c7al\u0131\u015fan Bordrolar\u0131","month":"Ay","net_salary":"Net maa\u015f","new_employee_payroll":"Yeni \u00c7al\u0131\u015fan Bordro","not_paid":"\u00d6denmeyen","paid":"\u00dccretli","payroll_id":"Bordro Kimli\u011fi","role":"Role","sr_no":"Bay hay\u0131r","year":"Y\u0131l"},"employee_payrolls":"\u00c7al\u0131\u015fan Bordrolar\u0131","enquiries":"Ara\u015ft\u0131rma","enquiry":{"contact":"\u0130leti\u015fim","email":"E-posta","enquiry_details":"sorgu detaylar\u0131","enquiry_send_successfully":"Sorgu ba\u015far\u0131yla g\u00f6nderildi","message":"\u0130leti","name":"ad","not_viewed":"G\u00f6r\u00fcnt\u00fclenmedi","read":"Okuma","received_on":"Al\u0131nd\u0131\u011f\u0131 Tarih","send_enquiry":"Soru\u015fturma G\u00f6nder","type":"tip","unread":"Okunmam\u0131\u015f","viewed_by":"\u0130zleyen"},"expense":{"amount":"Miktar","attachment":"Ek dosya","choose":"Se\u00e7","date":"Tarih","description":"A\u00e7\u0131klama","document_error":"Belge t\u00fcr\u00fcnde bir dosya olmal\u0131d\u0131r: jpeg, jpg, png, pdf, doc, docx.","download":"\u0130ndir","edit_expense":"Giderleri D\u00fczenle","expense":"gider","expense_details":"Gider Ayr\u0131nt\u0131lar\u0131","expense_head":"Gider Ba\u015fkan\u0131","invoice_number":"Fatura Numaras\u0131","name":"Ad","new_expense":"Yeni Gider","select_expense_head":"Gider Masas\u0131n\u0131 Se\u00e7in"},"expenses":"Masraflar","facebook_url":"Facebook URL","file_name":"Dosya ad\u0131","finance":"Maliye","front_cms":"\u00d6n Cms","front_cms_services":"\u00d6n CMS Hizmetleri","front_office":"\u00d6n ofis","front_service":"\u00d6n Servis","front_setting":{"about_us_description":"A\u00e7\u0131klama","about_us_details":"Hakk\u0131m\u0131zda Detaylar","about_us_image":"Resim","about_us_mission":"Misyon","about_us_title":"Ba\u015fl\u0131k","appointment_details":"Randevu Detaylar\u0131","front_setting_details":"\u00f6n ayar detay\u0131","home_page_box_description":"Ana Sayfa Kutu A\u00e7\u0131klamas\u0131","home_page_box_title":"Ana Sayfa Kutu Ba\u015fl\u0131\u011f\u0131","home_page_certified_box_description":"Ana Sayfa Onayl\u0131 Kutu A\u00e7\u0131klamas\u0131","home_page_certified_box_title":"Ana Sayfa Onayl\u0131 Kutu Ba\u015fl\u0131\u011f\u0131","home_page_certified_doctor_description":"Ana Sayfa Sertifikal\u0131 Doktor Tan\u0131m\u0131","home_page_certified_doctor_image":"Ana Sayfa Sertifikal\u0131 Doktor Resmi","home_page_certified_doctor_text":"Ana Sayfa Sertifikal\u0131 Doktor Metni","home_page_certified_doctor_title":"Ana Sayfa Sertifikal\u0131 Doktor Unvan\u0131","home_page_description":"Ana Sayfa A\u00e7\u0131klamas\u0131","home_page_experience":"Ana Sayfa Deneyimi","home_page_image":"Ana Sayfa resmi","home_page_step_1_description":"Ana Sayfa Ad\u0131m 1 A\u00e7\u0131klama","home_page_step_1_title":"Ana Sayfa 1. Ad\u0131m Ba\u015fl\u0131k","home_page_step_2_description":"Ana Sayfa 2. Ad\u0131m A\u00e7\u0131klama","home_page_step_2_title":"Ana Sayfa 2. Ad\u0131m Ba\u015fl\u0131k","home_page_step_3_description":"Ana Sayfa Ad\u0131m 3 A\u00e7\u0131klama","home_page_step_3_title":"Ana Sayfa Ad\u0131m 3 Ba\u015fl\u0131k","home_page_step_4_description":"Ana Sayfa Ad\u0131m 4 A\u00e7\u0131klama","home_page_step_4_title":"Ana Sayfa Ad\u0131m 4 Ba\u015fl\u0131k","home_page_title":"Ana Sayfa ba\u015fl\u0131\u011f\u0131","privacy_policy":"Gizlilik Politikas\u0131","terms_condition_details":"\u015eartlar ve Ko\u015fullar Ayr\u0131nt\u0131lar\u0131","terms_conditions":"\u015fartlar ve ko\u015fullar"},"front_settings":"\u00d6n Ayarlar","general":"Genel","hasta_appointment":"Hasta Randevusu","hospital_activities":"Hastane Faaliyetleri","hospital_blood_bank":{"blood_bank":"Kan Bankas\u0131","blood_bank_details":"Kan Bankas\u0131 Detaylar\u0131","blood_banks":"Kan Bankalar\u0131","blood_group":"Kan grubu","edit_blood_group":"Kan Grubunu D\u00fczenle","new_blood_group":"Yeni Kan Grubu","remained_bags":"Kalan \u00c7antalar"},"hospital_charges":"Hastane \u00dccretleri","hospital_schedule":"Hastane Takvimi","hospital_schedules":{"exists_doctor_schedule":"SBaz\u0131 doktorlar g\u00fcnlerini kontrol edilmeyen g\u00fcnlerde planlad\u0131lar, bu ameliyat\u0131 yapmak istedi\u011finizden emin misiniz?"},"icon":"Simge","income":"Gelir","incomes":{"amount":"Miktar","attachment":"Ek dosya","choose":"Se\u00e7","date":"Tarih","description":"A\u00e7\u0131klama","document_error":"Belge t\u00fcr\u00fcnde bir dosya olmal\u0131d\u0131r: jpeg, jpg, png, pdf, doc, docx.","download":"\u0130ndir","edit_income":"Geliri D\u00fczenle","income_details":"Gelir Ayr\u0131nt\u0131lar\u0131","income_head":"Gelir Sorumlusu","incomes":"Gelirleri","invoice_number":"Fatura Numaras\u0131","name":"Ad","new_income":"Yeni Gelir","select_income_head":"Gelir Ba\u015fkan\u0131n\u0131 Se\u00e7in"},"instagram_url":"Instagram URL'si","insurance":{"discount":"\u0130ndirim","disease_details":"Hastal\u0131k Detaylar\u0131","diseases_charge":"Hastal\u0131klar\u0131n \u00fccretleri","diseases_name":"Hastal\u0131klar Ad\u0131","edit_insurance":"Sigortay\u0131 D\u00fczenle","hospital_rate":"Hastane Oran\u0131","insurance":"Sigorta","insurance_code":"Sigorta Kodu","insurance_details":"Sigorta Bilgileri","insurance_no":"Sigorta No","insurances":"Sigorta","new_insurance":"Yeni Sigorta","remark":"d\u00fc\u015f\u00fcnce","service_tax":"Hizmet vergisi","total_amount":"Toplam tutar"},"insurances":"Sigorta","inventory":"Envanter","investigation_report":{"attachment":"Ek dosya","birth_date_validation":"Ara\u015ft\u0131rma raporu tarihi, hastan\u0131n do\u011fum tarihinden k\u00fc\u00e7\u00fck olmamal\u0131d\u0131r.","date":"tarih","description":"A\u00e7\u0131klama","doctor":"doktor","edit_investigation_report":"Ara\u015ft\u0131rma Raporunu D\u00fczenle","investigation_report":"Soru\u015fturma raporu","investigation_report_details":"Ara\u015ft\u0131rma Raporu Ayr\u0131nt\u0131lar\u0131","investigation_reports":"Soru\u015fturma Raporlar\u0131","new_investigation_report":"Yeni Ara\u015ft\u0131rma Raporu","patient":"Hasta","title":"Ba\u015fl\u0131k"},"investigation_reports":"Soru\u015fturma Raporlar\u0131","invoice":{"account_name":"Hesap ad\u0131","add":"Ekle","amount":"Miktar","description":"A\u00e7\u0131klama","discount":"\u0130ndirim","edit":"D\u00fczenle","edit_invoice":"Edit Invoice","hospital_address":"Hastane Adresi","invoice":"Fatura","invoice_date":"Fatura tarihi","invoice_details":"Invoice Details","invoice_id":"Fatura No","invoices":"Faturalar","new_invoice":"Yeni fatura","not_paid":"\u00d6denmeyen","paid":"\u00dccretli","patient":"Hasta","patient_id":"Hasta Kimli\u011fi","price":"Fiyat","print_invoice":"Faturay\u0131 Yazd\u0131r","qty":"Adet","sub_total":"Ara toplam","total":"Toplam tutar"},"invoices":"Faturalar","ipd_bill":{"discount_in_number":"Say\u0131da \u0130ndirim","discount_in_percentage":"Y\u00fczde Olarak \u0130ndirim","gross_total":"Br\u00fct Toplam","net_payable_amount":"\u00d6denecek Net Tutar","other_charges":"Di\u011fer Masraflar","paid_amount":"\u00d6denen Tutar","tax_in_number":"Numaral\u0131 Vergi","tax_in_percentage":"Y\u00fczde Olarak Vergi","total_charges":"Toplam Masraflar"},"ipd_charges":"\u00dccretler","ipd_consultant_register":"Dan\u0131\u015fman Talimat\u0131","ipd_diagnosis":"Te\u015fhis","ipd_opd":"IPD\/OPD","ipd_patient":{"admission_date":"Kabul Tarihi","bed_id":"Yatak","bed_type_id":"Yatak Tipi","bill_status":"Fatura Durumu","bp":"Kan Bas\u0131nc\u0131","case_id":"Durum","doctor_id":"Doktor","edit_ipd_patient":"IPD Hastas\u0131n\u0131 D\u00fczenle","height":"Y\u00fckseklik","ipd_number":"IPD Hay\u0131r","ipd_patient":"IPD Hastas\u0131","ipd_patient_details":"IPD Hasta Ayr\u0131nt\u0131lar\u0131","ipd_patients":"IPD Hastalar\u0131","is_old_patient":"Eski Hasta","new_ipd_patient":"Yeni IPD Hastas\u0131","notes":"Notlar","patient_id":"Hasta","symptoms":"Semptomlar","the_bed_field_is_required":"Yatak alan\u0131 gereklidir.","the_case_field_is_required":"Vaka alan\u0131 zorunludur.","weight":"A\u011f\u0131rl\u0131k"},"ipd_patient_charges":{"applied_charge":"Uygulanan \u00dccret","charge_category_id":"\u00dccret Kategorisi","charge_id":"Kod","charge_type_id":"\u00dccret T\u00fcr\u00fc","date":"Tarih","new_charge":"\u00dccret Ekle","standard_charge":"Standart \u00dccret"},"ipd_patient_consultant_register":{"applied_date":"Uygulama Tarihi","doctor_id":"Doktor","instruction":"Talimat","instruction_date":"Talimat Tarihi","new_consultant_register":"Dan\u0131\u015fman Talimat\u0131 Ekle"},"ipd_patient_diagnosis":{"description":"A\u00e7\u0131klama","document":"Belge","edit_ipd_diagnosis":"Te\u015fhisi D\u00fczenle","new_ipd_diagnosis":"Te\u015fhis Ekle","report_date":"Rapor Tarihi","report_type":"Rapor T\u00fcr\u00fc"},"ipd_patient_prescription":{"category_id":"\u0130la\u00e7 Kategorisi","dosage":"Dozaj","edit_prescription":"Re\u00e7eteyi D\u00fczenle","footer_note":"Altbilgi Notu","header_note":"Ba\u015fl\u0131k Notu","instruction":"Talimat","ipd_no":"IPD Hay\u0131r","medicine_id":"T\u0131p","new_prescription":"Re\u00e7ete Ekle","prescription_details":"Re\u00e7ete Ayr\u0131nt\u0131lar\u0131","print_prescription":"Re\u00e7eteyi Yazd\u0131r"},"ipd_patient_timeline":{"date":"Tarih","description":"A\u00e7\u0131klama","document":"Belge","edit_ipd_timeline":"Zaman \u00c7izelgesini D\u00fczenle","new_ipd_timeline":"Zaman \u00c7izelgesi Ekle","no_timeline_found":"Zaman \u00c7izgisi Bulunamad\u0131","title":"Ba\u015fl\u0131k","visible_to_person":"Ki\u015fi Taraf\u0131ndan G\u00f6r\u00fcn\u00fcr"},"ipd_patients":"IPD Hastalar\u0131","ipd_payment":"IPD \u00d6deme","ipd_payments":{"add_ipd_payment":"Ipd \u00d6demesi Ekle","edit_ipd_payment":"Edit IPD Payment","make_payment":"\u00d6deme Yap","payment_mode":"\u00d6deme Modu"},"ipd_prescription":"Re\u00e7eteler","ipd_timelines":"Zaman \u00c7izelgeleri","issued_item":{"are_you_sure_want_to_return_this_item":"Bu \u00f6\u011feyi iade etmek istedi\u011finizden emin misiniz?","available_quantity":"Mevcut Miktar\u0131","department_id":"Kullan\u0131c\u0131 tipi","description":"A\u00e7\u0131klama","edit_issued_item":"Verilen \u00d6\u011feyi D\u00fczenle","issued_by":"Yay\u0131nlayan","issued_date":"Verili\u015f tarihi","issued_item":"Verilen \u00d6\u011fe","issued_item_details":"Verilen \u00dcr\u00fcn Ayr\u0131nt\u0131lar\u0131","issued_items":"Verilen \u00d6\u011feler","item":"\u00d6\u011fe","item_category":"\u00d6\u011fe Kategorisi","item_return":"\u00dcr\u00fcn\u00fc geri vermek","item_returned":"\u0130ade","new_issued_item":"Yeni Verilen \u00dcr\u00fcn","quantity":"Miktar","return_date":"D\u00f6n\u00fc\u015f tarihi","user_id":"Sorun"},"issued_items":"Verilen \u00d6\u011feler","item":{"available_quantity":"Mevcut Miktar\u0131","description":"A\u00e7\u0131klama","edit_item":"\u00d6geyi d\u00fczenle","item":"\u00d6\u011fe","item_category":"\u00d6\u011fe Kategorisi","item_details":"\u00dcr\u00fcn Detaylar\u0131","items":"\u00d6\u011feler","name":"\u0130sim","new_item":"Yeni \u00f6\u011fe","unit":"Birim"},"item_category":{"edit_item_category":"D\u00fczenle \u00d6\u011fe Kategorisi","item_categories":"\u00d6\u011fe Kategorileri","item_category":"\u00d6\u011fe Kategorisi","name":"\u0130sim","new_item_category":"Yeni \u00d6\u011fe Kategorisi"},"item_stock":{"attachment":"Ek dosya","description":"A\u00e7\u0131klama","edit_item_stock":"\u00dcr\u00fcn Stokunu D\u00fczenle","item":"\u00d6\u011fe","item_category":"\u00d6\u011fe Kategorisi","item_stock":"\u00dcr\u00fcn Stoku","item_stock_details":"\u00dcr\u00fcn Stok Detaylar\u0131","item_stocks":"\u00dcr\u00fcn Stoklar\u0131","new_item_stock":"Yeni \u00dcr\u00fcn Stoku","purchase_price":"Al\u0131\u015f fiyat\u0131","quantity":"Miktar","store_name":"D\u00fckkan ad\u0131","supplier_name":"sa\u011flay\u0131c\u0131 ad\u0131"},"items":"\u00d6\u011feler","items_categories":"\u00d6\u011feler Kategoriler","items_stocks":"\u00dcr\u00fcn Stoklar\u0131","kullan\u0131c\u0131lar":"Kullan\u0131c\u0131lar","lab_tech":{"edit_lab_tech":"Laboratuvar Teknisyenini D\u00fczenle","lab_tech_detail":"Laboratuvar Teknisyeni Detaylar\u0131","lab_technician":"Laboratuvar teknisyeni","new_lab_tech":"Yeni Laboratuar Teknisyeni"},"lab_technicians":"Laboratuar Teknisyenleri","language":{"Arabic":"Arap\u00e7a","Chinese":"\u00c7ince","English":"ingilizce","French":"Frans\u0131zca","German":"Almanca","Portuguese":"Portekizce","Russian":"Rus\u00e7a","Spanish":"\u0130spanyol","Turkish":"T\u00fcrk"},"linkedIn_url":"Linkedin URL'si","live_consultation":{"add_credential":"Kimlik Bilgisi Ekle","client_video":"\u0130stemci Videosu","consultation_date":"Dan\u0131\u015fma Tarihi","consultation_duration_minutes":"G\u00f6r\u00fc\u015fme S\u00fcresi Dakikalar\u0131","consultation_title":"Dan\u0131\u015fma Ba\u015fl\u0131\u011f\u0131","created_by":"Olu\u015fturan","created_for":"Olu\u015fturulma Yeri","disabled":"Devre d\u0131\u015f\u0131","edit_live_consultation":"Canl\u0131 Dan\u0131\u015fmanl\u0131\u011f\u0131 D\u00fczenle","edit_live_meeting":"Canl\u0131 Toplant\u0131y\u0131 D\u00fczenle","enable":"Etkinle\u015ftir","host_video":"Ana Video","join_now":"\u015eimdi Kat\u0131l","live_consultation":"Canl\u0131 Dan\u0131\u015fmanl\u0131k","new_live_consultation":"Yeni Canl\u0131 Dan\u0131\u015fma","new_live_meeting":"Yeni Canl\u0131 Toplant\u0131","staff_list":"Personel listesi","type":"T\u00fcr","type_number":"Type Number","zoom_api_key":"Zoom API Anahtar\u0131","zoom_api_secret":"Yak\u0131nla\u015ft\u0131rma API S\u0131rr\u0131"},"live_consultations":"Canl\u0131 Kons\u00fcltasyonlar","live_meeting":"Canl\u0131 toplant\u0131","live_meetings":"Canl\u0131 Toplant\u0131lar","mail":"Posta","make_an_appointment":"Randevu Al","medicine":{"brand":"Marka","brand_name":"Marka ad\u0131","buying_price":"Al\u0131\u015f fiyat\u0131","category":"Kategori","category_id":"Kimlik kategorisi","description":"A\u00e7\u0131klama","edit_medicine":"T\u0131bb\u0131 D\u00fczenle","edit_medicine_brand":"\u0130la\u00e7 Markas\u0131n\u0131 D\u00fczenle","edit_medicine_category":"T\u0131p Kategorisini D\u00fczenle","medicine":"\u0130la\u00e7","medicine_brands":"\u0130la\u00e7 Markalar\u0131","medicine_brands_details":"\u0130la\u00e7 Marka Ayr\u0131nt\u0131lar\u0131","medicine_category":"T\u0131p Kategorisi","medicine_category_details":"T\u0131p Kategorisi Detaylar\u0131","medicine_details":"\u0130la\u00e7 Ayr\u0131nt\u0131lar\u0131","medicines":"\u0130la\u00e7lar","name":"ad","new_brand":"Yeni marka","new_medicine":"Yeni T\u0131p","new_medicine_brand":"Yeni \u0130la\u00e7 Markas\u0131","new_medicine_category":"Yeni T\u0131p Kategorisi","salt_composition":"Salt Composition","selling_price":"Sat\u0131\u015f fiyat\u0131","side_effects":"Yan etkiler"},"medicine_brands":"\u0130la\u00e7 Markalar\u0131","medicine_categories":"T\u0131p Kategorileri","medicines":"\u0130la\u00e7lar","message":{"date":"Tarih","message":"\u0130leti","messages":"\u0130leti","messages_details":"Mesaj Detaylar\u0131","new_message":"Yeni Mesaj","select_user":"Kullan\u0131c\u0131 se\u00e7","send_to":"G\u00f6nderildi","sender_name":"G\u00f6nderenin ad\u0131","subject":"konu"},"months":{"apr":"Nisan","aug":"A\u011fustos","dec":"Aral\u0131k","feb":"\u015eubat","jan":"Ocak","july":"Temmuz","jun":"Haziran","mar":"Mart","may":"May\u0131s","nov":"Kas\u0131m","oct":"Ekim","sep":"Eyl\u00fcl"},"my_payroll":{"allowance":"\u00f6denek","basic_salary":"Temel maa\u015f","deductions":"Kesintiler","my_payrolls":"Bordrolar\u0131m","net_salary":"Net maa\u015f"},"my_payrolls":"Bordrolar\u0131m","new_patient":"Yeni Hasta","no_data_available":"Tabloda veri yok","notice_board":{"created_at":"olu\u015fturuldu","description":"A\u00e7\u0131klama","details":"\u0130lan Panosu Detaylar\u0131","edit":"\u0130lan Tahtas\u0131n\u0131 D\u00fczenle","new":"Yeni \u0130lan Panosu","notice_board":"Duyuru Panosu","title":"Ba\u015fl\u0131k"},"notice_boards":"\u0130lan Panolar\u0131","notification":{"mark_all_as_read":"T\u00fcm\u00fcn\u00fc Okundu Olarak \u0130\u015faretle","notifications":"Bildirimler","you_don`t_have_any_new_notification":"Yeni bildiriminiz yok"},"nurse":{"birth_date":"Do\u011fum g\u00fcn\u00fc","choose":"Se\u00e7","edit_nurse":"Hem\u015fire D\u00fczenle","new_nurse":"Yeni hem\u015fire","nurse":"Hem\u015fire","nurse_details":"Hem\u015fire Detaylar\u0131","phone_no":"Telefon yok"},"nurses":"Hem\u015fireler","old_patient":"Ya\u015fl\u0131 Hasta","opd_diagnosis":"OPD Te\u015fhisi","opd_patient":{"appointment_date":"Randevu Tarihi","edit_opd_patient":"OPD Hastas\u0131n\u0131 D\u00fczenle","new_opd_patient":"Yeni OPD Hastas\u0131","opd_number":"OPD Hay\u0131r","opd_patient":"OPD Hastas\u0131","opd_patient_details":"OPD Hasta Detaylar\u0131","opd_patients":"OPD Hastalar\u0131","revisits":"Tekrar ziyaret edin","total_visits":"Toplam Ziyaret","visits":"Ziyaretler"},"opd_patients":"OPD Hastalar\u0131","opd_payments":{"add_opd_payment":"Opd \u00d6deme Ekle","edit_opd_payment":"Opd \u00d6demesini D\u00fczenle","make_payment":"\u00d6deme yapmak","payment_mode":"\u00d6deme \u015fekli"},"opd_timeline":"OPD Zaman \u00c7izelgesi","operation_report":{"case_id":"Dava numaras\u0131","date":"tarih","description":"A\u00e7\u0131klama","doctor_name":"Doktor Ad\u0131","edit_operation_report":"\u0130\u015flem Raporunu D\u00fczenle","new_operation_report":"Yeni Operasyon Raporu","operation_report":"Operasyon Raporu","operation_report_details":"Faaliyet Raporu Ayr\u0131nt\u0131lar\u0131","operation_reports":"Faaliyet Raporlar\u0131","patient_name":"Hasta ad\u0131"},"operation_reports":"Faaliyet Raporlar\u0131","overview":"genel bak\u0131\u015f","package":{"amount":"Miktar","description":"A\u00e7\u0131klama","discount":"\u0130ndirim","edit_package":"Paketi D\u00fczenle","name":"ad","new_package":"Yeni Paket","package":"paket","package_details":"Paket ayr\u0131nt\u0131lar\u0131","packages":"Paketler","qty":"Adet","rate":"oran","select_service":"Hizmet Se\u00e7in","service":"Hizmet","total_amount":"Toplam tutar"},"packages":"Paketler","pathologies":"Patoloji","pathology_categories":"Patoloji Kategori","pathology_category":{"edit_pathology_category":"D\u00fczenle Patoloji Kategori","name":"ad","new_pathology_category":"Yeni Patoloji Kategori","pathology_categories":"Patoloji Kategoriler"},"pathology_test":{"category_name":"Kategori ad","charge_category":"\u015earj Kategorisi","edit_pathology_test":"D\u00fczenle Patoloji \u00d6l\u00e7ek","method":"Y\u00f6ntem","new_pathology_test":"Yeni Patoloji \u00d6l\u00e7ek","pathology_test_details":"Patoloji \u00d6l\u00e7ek ayr\u0131nt\u0131lar","pathology_tests":"Patoloji Testler","report_days":"Bildiri g\u00fcnler","short_name":"Short ad","standard_charge":"Standart fiyat","subcategory":"Alt Kategori","test_name":"\u00d6l\u00e7ek ad","test_type":"\u00d6l\u00e7ek tip","unit":"birim"},"pathology_tests":"Patoloji Testler","patient":{"edit_patient":"Hastay\u0131 D\u00fczenle","new_patient":"Yeni Hasta","patient_details":"Hasta Detaylar\u0131","total_admissions":"Toplam Kabul","total_appointments":"Toplam Randevu","total_cases":"Toplam Vaka"},"patient_admission":{"admission_date":"Kabul Tarihi","agent_name":"Ajan ad\u0131","bed":"Yatak","details":"Hasta Kabul Detaylar\u0131","discharge_date":"\u00c7\u0131k\u0131\u015f Tarihi","doctor":"doktor","doctor_name":"Doktor Ad\u0131","edit_patient_admission":"Hasta Kabul\u00fcn\u00fc D\u00fczenle","guardian_address":"Vasi Adresi","guardian_contact":"Guardian \u0130leti\u015fim","guardian_name":"Muhaf\u0131z ad\u0131","guardian_relation":"Koruyucu \u0130li\u015fkisi","insurance":"Sigorta","insurance_name":"Sigorta Ad\u0131","new_patient_admission":"Yeni Hasta Kabul\u00fc","package":"paket","package_name":"Paket ismi","patient":"Hasta","patient_admission":"Hasta Kabul\u00fc","patient_admission_id":"Hasta Kabul Kimli\u011fi","patient_name":"Hasta ad\u0131","policy_no":"Politika No"},"patient_admissions":"Hasta Kabulleri","patient_appointment":"Cita del paciente","patient_diagnosis_test":{"action":"Aksiyon","add_other_diagnosis_property":"Ba\u015fka tan\u0131 \u00f6zelli\u011fi ekle","age":"Ya\u015f","average_glucose":"Ortalama glikoz","blood_pressure":"Kan bas\u0131nc\u0131","cholesterol":"Kolesterol","create_patient_diagnosis_test":"Hasta Te\u015fhis Testi Olu\u015ftur","created_at":"Olu\u015fturma tarihi","diabetes":"\u015eeker hastal\u0131\u011f\u0131","diagnosis":"Te\u015fhis","diagnosis_category":"Te\u015fhis Kategorisi","diagnosis_property_name":"Te\u015fhis \u00d6zellik Ad\u0131","diagnosis_property_value":"Te\u015fhis \u00d6zellik De\u011feri","diagnosis_test":"Tan\u0131 testleri","doctor":"doktor","doctor_name":"Doktor ad\u0131","edit_patient_diagnosis_test":"Hasta Tan\u0131 Testini D\u00fczenle","fasting_blood_sugar":"Oru\u00e7 Kan \u015eekeri","height":"Y\u00fckseklik","new_patient_diagnosis_test":"Yeni Hasta Tan\u0131 Testi","other_diagnosis_property":"Di\u011fer tan\u0131 \u00f6zellikleri","patient":"Hasta","patient_diagnosis_test":"Hasta tan\u0131 testleri","patient_diagnosis_test_details":"Hasta Te\u015fhis Testi Detaylar\u0131","patient_name":"Hasta ad\u0131","print_diagnosis_test":"Tan\u0131lama Testini Yazd\u0131r","report_number":"Numaray\u0131 bildir","urine_sugar":"\u0130drar \u015eekeri","weight":"A\u011f\u0131rl\u0131k"},"patients":"hastalar","patients_case_details":"Hasta Vaka Detaylar\u0131","patients_cases":"Hasta Vakalar\u0131","payment":{"account":"hesap","account_name":"Hesap ad\u0131","amount":"Miktar","description":"A\u00e7\u0131klama","edit_payment":"\u00d6demeyi D\u00fczenle","new_payment":"Yeni \u00d6deme","pay_to":"Paul To","payment":"\u00d6deme","payment_date":"\u00d6deme tarihi","payment_details":"\u00d6deme detaylar\u0131","payment_reports":"\u00d6deme Raporlar\u0131","payments":"\u00d6demeler"},"payments":"\u00d6demeler","pharmacist":{"edit_pharmacist":"Eczac\u0131y\u0131 D\u00fczenle","new_pharmacist":"Yeni Eczac\u0131","pharmacist_details":"Eczac\u0131 Detaylar\u0131","pharmacists":"eczac\u0131lar"},"pharmacists":"eczac\u0131lar","postal":{"address":"Adres","date":"Tarih","dispatch":"Sevk etmek","edit_dispatch":"G\u00f6nderimi D\u00fczenle","edit_receive":"Almay\u0131 D\u00fczenle","from_title":"Ba\u015fl\u0131ktan","new_dispatch":"Yeni G\u00f6nderim","new_receive":"Yeni Alma","postal":"Kartpostal","receive":"Teslim almak","reference_no":"Referans numaras\u0131","to_title":"Ba\u015fl\u0131\u011fa"},"postal_dispatch":"Posta G\u00f6nderimi","postal_receive":"Posta Alma","prescription":{"Rx":"Rx","accident":"Kaza","advice":"tavsiye","after_meal":"apr\u00e8s manger","before_meal":"yemekten \u00f6nce","breast_feeding":"Emzirme","comment":"yorum","current_medication":"Mevcut \u0130la\u00e7lar","days":"g\u00fcnler","diabetic":"\u015eeker hastas\u0131","duration":"S\u00fcre","edit_prescription":"Re\u00e7eteyi D\u00fczenle","female_pregnancy":"Kad\u0131n Hamileli\u011fi","food_allergies":"Yiyecek alerjisi","health_insurance":"Sa\u011fl\u0131k Sigortas\u0131","heart_disease":"Kalp hastal\u0131\u011f\u0131","high_blood_pressure":"Y\u00fcksek tansiyon","low_income":"D\u00fc\u015f\u00fck Gelir","medical_history":"T\u0131bbi ge\u00e7mi\u015f","medicine_name":"t\u0131p_ad\u0131","month":"Ay","new_medicine":"yeni ila\u00e7","new_prescription":"Yeni Re\u00e7ete","next_visit":"Bir sonraki ziyaret","no_data_available":"veri bulunamad\u0131","others":"Di\u011ferleri","patient":"Hasta","physical_information":"fiziksel bilgi","plus_rate":"Nab\u0131z oran","prescription":"re\u00e7ete","prescription_details":"Re\u00e7ete Detaylar\u0131","prescriptions":"re\u00e7eteler","problem":"sorun","problem_description":"Sorun A\u00e7\u0131klamas\u0131","reference":"Referans","surgery":"cerrahl\u0131k","temperature":"s\u0131cakl\u0131k","tendency_bleed":"E\u011filim Kanamas\u0131","test":"\u00d6l\u00e7ek","time":"zaman","year":"Y\u0131l"},"prescriptions":"re\u00e7eteler","profile":{"change_language":"Dili de\u011fi\u015ftir","edit_profile":"Profili D\u00fczenle","email":"E-posta","first_name":"\u0130sim","language":"Dil","last_name":"Soyad\u0131","phone":"Telefon","profile":"Profil"},"radiologies":"Radyoloji","radiology_categories":"Radyoloji Kategori","radiology_category":{"edit_radiology_category":"D\u00fczenle Radyoloji Kategori","name":"Ad","new_radiology_category":"Yeni Radyoloji Kategori","radiology_categories":"Radyoloji Kategoriler"},"radiology_test":{"category_name":"Kategori ad\u0131","charge_category":"\u015earj Kategorisi","edit_radiology_test":"Radyoloji Testini D\u00fczenle","new_radiology_test":"Yeni Radyoloji Testi","radiology_test_details":"Radyoloji Test Detaylar\u0131","radiology_tests":"Radyoloji Testleri","report_days":"Rapor G\u00fcnleri","short_name":"K\u0131sa ad\u0131","standard_charge":"Standart fiyat","subcategory":"Alt Kategori","test_name":"Test Ad\u0131","test_type":"Test T\u00fcr\u00fc"},"radiology_tests":"Radyoloji Testleri","receptionist":{"edit_receptionist":"Resepsiyonist D\u00fczenle","new_receptionist":"Yeni Resepsiyonist","receptionist":"Resepsiyonist","receptionist_details":"Resepsiyonist Detaylar\u0131","receptionists":"Resepsiyonistler"},"receptionists":"Resepsiyonistler","reports":"Raporlar","roles":"Roller","schedule":{"available_from":"Kullan\u0131labilir","available_on":"Kullan\u0131ld\u0131\u011f\u0131 Tarih","available_to":"Uygun","details":"Zamanlama Ayr\u0131nt\u0131lar\u0131","doctor_name":"Doktor Ad\u0131","edit":"Program\u0131 D\u00fczenle","new":"Yeni program","per_patient_time":"Hasta Ba\u015f\u0131na","select_doctor_name":"Doktor Ad\u0131 Se\u00e7in","select_serial_visibility":"Seri G\u00f6r\u00fcn\u00fcrl\u00fc\u011f\u00fc Se\u00e7in","sequential":"Ard\u0131\u015f\u0131k","serial_visibility":"Seri G\u00f6r\u00fcn\u00fcrl\u00fck","timestamp":"Zaman Damgas\u0131"},"schedule_label":"program","schedules":"Programlar\u0131","service":{"edit_service":"Hizmeti D\u00fczenle","given":"verilmi\u015f","new_service":"Yeni Hizmet","not_given":"Verilmedi","quantity":"miktar","rate":"oran","service_details":"Servis Detaylar\u0131"},"services":"Hizmetler","setting":{"address":"Hastane Adresi","app_logo":"Uygulama Logosu","app_name":"Uygulama ismi","company_name":"\u015eirket Ad\u0131","country_code":"\u00dclke Kodu","currency":"Ge\u00e7erli Para Birimi","hospital_email":"Hastane E-postas\u0131","hospital_from_day":"G\u00fcnden Hastane","hospital_from_time":"Hastaneden Zaman","hospital_phone":"Hastane Telefonu","image_validation":"Resim, 90 x 60 piksel boyutunda olmal\u0131d\u0131r.","social_details":"Sosyal Detaylar"},"settings":"Ayarlar","short_description":"K\u0131sa A\u00e7\u0131klama","sidebar_setting":"Mod\u00fcl Ayarlar\u0131","sms":{"date":"Tarih","message":"\u0130leti","new_sms":"Yeni SMS","only_user_with_registered_phone_will_display":"(Yaln\u0131zca kay\u0131tl\u0131 telefonu olan Kullan\u0131c\u0131lar g\u00f6r\u00fcnt\u00fclenecektir.)","phone_number":"Telefon numaras\u0131","role":"Role","send":"G\u00f6nder","send_by":"G\u00f6nderen","send_sms_by_number_directly":"Do\u011frudan numarayla SMS g\u00f6nderin","send_to":"G\u00f6nderildi","sms":"SMS","sms_details":"SMS Detaylar\u0131"},"testimonial":{"description":"A\u00e7\u0131klama","edit_testimonial":"\u00d6yk\u00fcy\u00fc D\u00fczenle","name":"\u0130sim","new_testimonial":"Yeni Referans","profile_error":"Dok\u00fcman \u015fu tipte bir dosya olmal\u0131d\u0131r: jpeg, jpg, png.","testimonial":"referans","testimonial_detail":"Referans Detay\u0131"},"testimonials":"G\u00f6r\u00fc\u015fler","twitter_url":"twitter URL'si","user":{"address1":"Adres 1","address2":"Adres 2","address_details":"adres detaylar\u0131","address_not_found":"Adres bilgisi bulunamad\u0131","blood_group":"Kan grubu","change_password":"\u015eifre de\u011fi\u015ftir","city":"Kent","designation":"tayin","dob":"Do\u011fum tarihi","edit_profile":"Profili D\u00fczenle","edit_user":"Kullan\u0131c\u0131y\u0131 D\u00fczenle","education":"E\u011fitim","email":"E-posta","email_verified_successfully":"E-posta Ba\u015far\u0131yla Do\u011fruland\u0131.","female":"Kad\u0131n","first_name":"\u0130sim","gender":"Cinsiyet","invalid_password":"Mevcut \u015fifre ge\u00e7ersiz.","last_name":"Soyad\u0131","logout":"\u00c7\u0131k\u0131\u015f Yap","male":"Erkek","name":"ad","new_user":"Yeni Kullan\u0131c\u0131","password":"Parola","password_confirmation":"\u015eifreyi Onayla","phone":"Telefon","qualification":"Vas\u0131f","select_blood_group":"Kan Grubunu Se\u00e7in","status":"durum","user_details":"Kullan\u0131c\u0131 detaylar\u0131","usrs":"kullan\u0131c\u0131","validate_confirm_password":"Parola ve onay parolas\u0131 e\u015fle\u015fmelidir.","validate_min_character_password":"\u015eifre en az 6 karakter i\u00e7ermelidir.","zip":"Zip"},"users":"Kullan\u0131c\u0131lar","vaccinated_patient":{"add_vaccinate_patient":"A\u015f\u0131lanan Hastay\u0131 Ekle","description":"A\u00e7\u0131klama","does_no":"Doz No","dose_given_date":"Tarih Verilen Doz","edit_vaccinate_patient":"Hastay\u0131 A\u015f\u0131lamay\u0131 D\u00fczenle","new_vaccinate_patient":"Yeni A\u015f\u0131 Yapan Hasta","patient":"Hasta","serial_no":"Seri numaras\u0131","vaccinate_patient":"Hastay\u0131 A\u015f\u0131lamak","vaccinated_patient":"A\u015f\u0131l\u0131 Hasta","vaccination":"A\u015f\u0131lama","vaccine":"A\u015f\u0131"},"vaccinated_patients":"A\u015f\u0131lanm\u0131\u015f Hastalar","vaccinations":"A\u015f\u0131lar","valid":"Ge\u00e7erli","visitor":{"date":"Tarih","edit":"Ziyaret\u00e7iyi D\u00fczenle","id_card":"Kimlik kart\u0131","in_time":"Zaman\u0131nda","name":"\u0130sim","new":"Yeni Ziyaret\u00e7i","note":"Not","number_of_person":"Ki\u015fi say\u0131s\u0131","out_time":"\u00c7\u0131k\u0131\u015f S\u00fcresi","phone":"Telefon","purpose":"Ama\u00e7","visitor":"Ziyaret\u00e7i"},"visitors":"Ziyaret\u00e7i","0":false,"vaccination":{"brand":"Marka","edit_vaccination":"A\u015f\u0131y\u0131 D\u00fczenle","manufactured_by":"Taraf\u0131ndan \u00fcretildi","name":"\u0130sim","new_vaccination":"Yeni A\u015f\u0131lama","vaccinated":"A\u015f\u0131lanm\u0131\u015f","vaccinations":"A\u015f\u0131lar"},"verification":{"another_verify_request":"ba\u015fka bir istek i\u00e7in buraya t\u0131klay\u0131n","verify_message":"Devam etmeden \u00f6nce, l\u00fctfen do\u011frulama ba\u011flant\u0131s\u0131 i\u00e7in e-postan\u0131z\u0131 kontrol edin. E-postay\u0131 almad\u0131ysan\u0131z,","verify_your_email_address":"Eposta adresinizi do\u011frulay\u0131n."},"web_appointment":{"call_now_and_get_a_free_consulting":"Hemen Aray\u0131n ve \u00dccretsiz Dan\u0131\u015fmanl\u0131k Al\u0131n","enter_confirm_password":"\u015eifreyi Onayla Girin","enter_description":"A\u00e7\u0131klama Girin","enter_your_first_name":"\u0130lk ad\u0131n\u0131z\u0131 girin","enter_your_last_name":"Soyad\u0131n\u0131z\u0131 giriniz","enter_your_password":"\u015eifrenizi girin","make_an_appointment":"Randevu Al","select_department":"Departman Se\u00e7in","select_doctor":"Doktor Se\u00e7","select_time":"Zaman Se\u00e7"},"web_contact":{"call_today":"Bug\u00fcn ara","contact_no":"\u0130leti\u015fim Numaras\u0131","enter_your_email":"E-postan\u0131z\u0131 giriniz","enter_your_name":"Ad\u0131n\u0131z\u0131 giriniz","open_hours":"A\u00e7\u0131k saatler","our_location":"Konumumuz","phone_number":"Telefon numaras\u0131","please_enter_your_phone_number":"L\u00fctfen telefon numaran\u0131z\u0131 girin","select_enquiry":"Sorgu Se\u00e7","send_message":"Mesaj g\u00f6nder","send_us_a_message":"Bize mesaj g\u00f6nder","type_your_message":"Mesaj\u0131n\u0131 yaz","write_your_message":"mesaj\u0131n\u0131z\u0131 yaz\u0131n","your_email":"E-posta adresiniz","your_message":"Mesaj\u0131n","your_name":"Ad\u0131n\u0131z"},"web_home":{"4_easy_step_and_get_the_world_best_treatment":"4 Kolay Ad\u0131m ve D\u00fcnyan\u0131n En \u0130yi Tedavisini Al\u0131n","about_us":"Hakk\u0131m\u0131zda","available_doctors":"Mevcut Doktorlar","book_an_appointment":"Randevu Al","book_appointment":"Kitap randevusu","book_now":"\u015eimdi Rezervasyon Yap","contact":"Temas","contact_doctors":"Doktorla \u0130leti\u015fime Ge\u00e7in","contact_hospital":"\u0130leti\u015fim Hastanesi","doctors":"doktorlar","doctors_nurses":"Doktorlar ve Hem\u015fireler","easy_solutions":"Kolay \u00c7\u00f6z\u00fcmler","happy_patients":"Mutlu Hastalar","home":"Ev","make_appointment":"Randevu ayarlamak","our_services":"hizmetlerimiz","our_testimonials":"G\u00f6r\u00fc\u015flerimiz","patients":"Hastalar","patients_beds":"Hasta Yataklar\u0131","privacy_policy":"Gizlilik Politikas\u0131","professional_doctors":"Profesyonel Doktorlar","select_doctor":"Doktor Se\u00e7","select_doctors":"Doktorlar\u0131 Se\u00e7in","services":"Hizmetler","sign_up":"\u00dcye olmak","terms_of_service":"Kullan\u0131m \u015eartlar\u0131","testimonials":"referanslar","we_are_experienced_healthcare_professionals":"Biz Deneyimli Sa\u011fl\u0131k Profesyonelleriyiz","we_offer_different_services_to_improve_your_health":"Sa\u011fl\u0131\u011f\u0131n\u0131z\u0131 \u0130yile\u015ftirmek \u0130\u00e7in Farkl\u0131 Hizmetler Sunuyoruz","what_our_patient_say_about_medical_treatments":"Hastalar\u0131m\u0131z Medikal Tedavilerimiz Hakk\u0131nda Ne Diyor?","working_hours":"\u00c7al\u0131\u015fma saatleri","years_experience":"Y\u0131llar\u0131n tecr\u00fcbesi"},"web_menu":{"about":"Hakk\u0131nda","all_rights_reserved_by":"T\u00fcm Haklar\u0131 Sakl\u0131d\u0131r","appointment":"Randevu","contact_information":"\u0130leti\u015fim bilgileri","copyright":"Telif hakk\u0131","login":"Giri\u015f yapmak","our_features":"\u00d6zelliklerimiz","useful_link":"Faydal\u0131 Ba\u011flant\u0131","working_hours":"\u00c7al\u0131\u015fma saatleri"},"web_password":{"password_and_confirm_password_not_match":"Parola ve Parolay\u0131 Onayla e\u015fle\u015fmiyor.","please_fill_all_the_required_fields":"L\u00fctfen gerekli t\u00fcm alanlar\u0131 doldurun."},"web_working_hours":{"no_yet_opening_hours":"Hen\u00fcz \u00c7al\u0131\u015fma Saatleri","opening_hours":"A\u00e7\u0131l\u0131\u015f saatleri"},"weekdays":{"fri":"Cuma","mon":"AY","sat":"OTURDU","sun":"G\u00dcNE\u015e","thu":"PHU","tue":"sal","wed":"EVLENMEK"}},"zh.messages":{"about_us":"\u5173\u4e8e\u6211\u4eec","account":{"account":"\u5e10\u6237","account_details":"\u5e10\u6237\u8be6\u7ec6\u8d44\u6599","accounts":"\u5e10\u76ee","credit":"\u4fe1\u7528","debit":"\u501f\u65b9","description":"\u63cf\u8ff0","edit_account":"\u7f16\u8f91\u5e10\u6237","name":"\u540d\u79f0","new_account":"\u65b0\u8d26\u6237","payments":"\u4ed8\u6b3e\u65b9\u5f0f","status":"\u72b6\u6001","type":"\u7c7b\u578b"},"account_manager":"\u5ba2\u6237\u7ecf\u7406","accountant":{"accountant_details":"\u4f1a\u8ba1\u5e08\u8be6\u7ec6\u4fe1\u606f","accountants":"\u4f1a\u8ba1\u5e08","edit_accountant":"\u7f16\u8f91\u4f1a\u8ba1\u5e08","new_accountant":"\u65b0\u4f1a\u8ba1"},"accountants":"\u4f1a\u8ba1\u5e08","accounts":"\u5e10\u76ee","admin":"\u7ba1\u7406\u5458","admins":"\u884c\u653f","advanced_payment":{"advanced_payment":"\u9884\u4ed8\u6b3e","advanced_payment_details":"\u9884\u4ed8\u6b3e\u660e\u7ec6","advanced_payments":"\u9884\u4ed8\u6b3e","amount":"\u91cf","date":"\u65e5\u671f","edit_advanced_payment":"\u7f16\u8f91\u9884\u4ed8\u6b3e","new_advanced_payment":"\u65b0\u9884\u4ed8\u6b3e","patient":"\u60a3\u8005","patient_name":"\u60a3\u8005\u59d3\u540d","receipt_no":"\u6536\u636e\u7f16\u53f7"},"advanced_payments":"\u9884\u4ed8\u6b3e","allow_file_type":"\u5141\u8bb8\u7684\u6587\u4ef6\u7c7b\u578b\uff1apng\u3001jpg\u3001jpeg\u3002","ambulance":{"ambulance":"\u6551\u62a4\u8f66","ambulance_details":"\u6551\u62a4\u8f66\u8be6\u7ec6\u4fe1\u606f","ambulances":"\u6551\u62a4\u8f66","driver_contact":"\u9a7e\u9a76\u5458\u8054\u7cfb","driver_license":"\u9a7e\u9a76\u6267\u7167","driver_name":"\u9a71\u52a8\u7a0b\u5f0f\u540d\u79f0","edit_ambulance":"\u7f16\u8f91\u6551\u62a4\u8f66","is_available":"\u6709\u7a7a","new_ambulance":"\u65b0\u6551\u62a4\u8f66","note":"\u6ce8\u610f","vehicle_model":"\u8f66\u8f86\u578b\u53f7","vehicle_number":"\u8f66\u53f7","vehicle_type":"\u8f66\u8f86\u7c7b\u578b","year_made":"\u5e74\u4efd"},"ambulance_call":{"ambulance_call":"\u6551\u62a4\u8f66\u547c\u53eb","ambulance_call_details":"\u6551\u62a4\u8f66\u901a\u8bdd\u8be6\u60c5","ambulance_calls":"\u6551\u62a4\u8f66\u7535\u8bdd","amount":"\u91cf","date":"\u65e5\u671f","driver_name":"\u9a71\u52a8\u7a0b\u5f0f\u540d\u79f0","edit_ambulance_call":"\u7f16\u8f91\u6551\u62a4\u8f66\u901a\u8bdd","new_ambulance_call":"\u65b0\u7684\u6551\u62a4\u8f66\u547c\u53eb","patient":"\u60a3\u8005","vehicle_model":"\u8f66\u8f86\u578b\u53f7"},"ambulance_calls":"\u6551\u62a4\u8f66\u7535\u8bdd","ambulances":"\u6551\u62a4\u8f66","appointment":{"appointment_calendar":"\u9884\u7ea6\u65e5\u5386","appointment_details":"\u9884\u7ea6\u8be6\u60c5","appointment_exists":"\u60a3\u8005\u7535\u5b50\u90ae\u4ef6\u5df2\u5b58\u5728","appointment_list":"\u9884\u7ea6\u8868","are_you_sure_want_to_change":"\u60a8\u786e\u5b9a\u8981\u66f4\u6539\u5417","available_slot":"\u53ef\u7528\u63d2\u69fd","calendar_view":"\u65e5\u5386\u89c6\u56fe","change_status":"\u66f4\u6539\u72b6\u6001","changed_appointment":"\u66f4\u6539\u7ea6\u4f1a","completed":"\u5df2\u5b8c\u6210","date":"\u65e5\u671f","day":"\u65e5","department_name":"\u90e8\u95e8\u540d\u79f0","description":"\u63cf\u8ff0","doctor":"\u533b\u751f","doctor_department":"\u533b\u751f\u79d1","doctor_department_name":"\u533b\u751f\u79d1\u540d\u79f0","doctor_name":"\u533b\u751f\u59d3\u540d","doctor_schedule_not_available_on_this_date":"\u533b\u751f\u65f6\u95f4\u8868\u6b64\u65e5\u671f\u4e0d\u53ef\u7528\u3002","edit_appointment":"\u7f16\u8f91\u7ea6\u4f1a","has_been_changed":"\u5df2\u7ecf\u53d8\u4e86\u3002","last_30_days":"\u8fc7\u53bb 30 \u5929","last_7_days":"\u8fc7\u53bb 7 \u5929","last_month":"\u4e0a\u4e2a\u6708","month":"\u6708","new_appointment":"\u65b0\u4efb\u547d","no_available":"\u65e0\u6cd5\u4f7f\u7528","old_patient_email_exists":"\u90ae\u7bb1\u5df2\u7ecf\u5b58\u5728\uff0c\u8bf7\u9009\u62e9\u8001\u75c5\u4eba\u3002","opd_date":"\u65e5\u671f","patient":"\u60a3\u8005","patient_name":"\u60a3\u8005\u59d3\u540d","patient_not_exists_or_status_is_not_active":"\u60a3\u8005\u4e0d\u5b58\u5728\u6216\u72b6\u6001\u672a\u6fc0\u6d3b\u3002","pending":"\u5f85\u5b9a","please_select_appointment_time_slot":"\u8bf7\u9009\u62e9\u9884\u7ea6\u65f6\u95f4\u6bb5","please_select_doctor":"\u8bf7\u9009\u62e9\u533b\u751f","please_select_doctor_department":"\u8bf7\u9009\u62e9\u533b\u751f\u79d1\u5ba4","this_month":"\u8fd9\u4e2a\u6708","this_week":"\u672c\u661f\u671f","today":"\u4eca\u5929","week":"\u661f\u671f","yesterday":"\u6628\u5929"},"appointment_calendar":"\u59d4\u3002 \u65e5\u5386","appointments":"\u9884\u7ea6\u65f6\u95f4","available_slot":"\u53ef\u7528\u63d2\u69fd","bed":{"add":"\u52a0","available":"\u53ef\u7528\u7684","bed":"\u65b0\u5e8a","bed_details":"\u5e8a\u8be6\u60c5","bed_id":"\u5e8a\u53f7","bed_type":"\u5e8a\u578b","beds":"\u5e8a\u94fa","charge":"\u6536\u8d39","description":"\u63cf\u8ff0","edit_bed":"\u7f16\u8f91\u5e8a","name":"\u540d\u79f0","new_bed":"\u65b0\u5e8a","new_bulk_bed":"\u65b0\u5927\u5e8a","not_available":"\u65e0\u6cd5\u4f7f\u7528"},"bed_assign":{"assign_date":"\u5206\u914d\u65e5\u671f","assign_date_should_not_be_smaller_than_patient_birth_date":"\u5206\u914d\u65e5\u671f\u4e0d\u5e94\u5c0f\u4e8e\u60a3\u8005\u51fa\u751f\u65e5\u671f\u3002","assigned":"\u5df2\u5206\u914d","bed":"\u5e8a","bed_assign":"\u5e8a\u5206\u914d","bed_assign_details":"\u5e8a\u5206\u914d\u8be6\u7ec6\u4fe1\u606f","bed_assigns":"\u5e8a\u5206\u914d","bed_name":"\u5e8a\u540d","case_id":"\u6848\u4f8bID","description":"\u63cf\u8ff0","discharge_date":"\u51fa\u9662\u65e5\u671f","edit_bed_assign":"\u7f16\u8f91\u5e8a\u5206\u914d","ipd_patient_id":"IPD\u60a3\u8005\u7f16\u53f7","new_bed_assign":"\u65b0\u5e8a\u5206\u914d","not_assigned":"\u672a\u5206\u914d","patient_name":"\u60a3\u8005\u59d3\u540d"},"bed_assigns":"\u5e8a\u5206\u914d","bed_management":"\u5e8a\u4f4d\u7ba1\u7406","bed_mgt":"\u5e8a\u7ba1\u7406","bed_status":{"admission_date":"\u5165\u5b66\u65e5\u671f","assigned_beds":"Assigned Beds","available_beds":"\u53ef\u7528\u5e8a","bed_name":"Bed Name","bed_status":"Bed Status","gender":"\u6027\u522b","patient_name":"\u60a3\u8005\u59d3\u540d","phone":"\u7535\u8bdd"},"bed_type":{"bed_type":"\u5e8a\u578b","bed_type_details":"\u5e8a\u578b\u8be6\u60c5","bed_types":"\u5e8a\u578b","description":"\u63cf\u8ff0","edit_bed_type":"\u7f16\u8f91\u5e8a\u578b","new_bed_type":"\u65b0\u5e8a\u578b","title":"\u6807\u9898"},"bed_types":"\u5e8a\u578b","beds":"\u5e8a\u94fa","bill":{"add":"\u52a0","admission_date":"\u5165\u5b66\u65e5\u671f","admission_id":"\u5165\u573a\u8bc1","amount":"\u91cf","bill":"\u6cd5\u6848","bill_date":"\u5e10\u5355\u65e5\u671f","bill_details":"\u8d26\u5355\u660e\u7ec6","bill_id":"\u5e10\u5355\u7f16\u53f7","bill_summary":"\u8d26\u5355\u6458\u8981","bills":"\u8d26\u5355","calculate":"\u8ba1\u7b97","cell_no":"\u5355\u5143\u53f7","discharge_date":"\u51fa\u9662\u65e5\u671f","doctor_name":"\u533b\u751f\u59d3\u540d","edit":"\u7f16\u8f91","edit_bill":"\u7f16\u8f91\u5e10\u5355","generate_bill":"\u751f\u6210\u8d26\u5355","insurance_name":"\u4fdd\u9669\u540d\u79f0","item_name":"\u9879\u76ee\u540d\u79f0","new_bill":"\u65b0\u6cd5\u6848","package_name":"\u5305\u88f9\u540d\u5b57","patient":"\u60a3\u8005","patient_cell_no":"\u60a3\u8005\u7ec6\u80de\u7f16\u53f7","patient_dob":"\u60a3\u8005DOB","patient_email":"\u60a3\u8005\u7535\u5b50\u90ae\u4ef6","patient_gender":"\u75c5\u4eba\u6027\u522b","patient_name":"\u60a3\u8005\u59d3\u540d","policy_no":"\u4fdd\u5355\u7f16\u53f7","price":"\u4ef7\u94b1","print_bill":"\u5217\u5370\u5e10\u5355","qty":"\u6570\u91cf","total_amount":"\u603b\u91d1\u989d","total_days":"\u603b\u5929\u6570","update_bill":"\u66f4\u65b0\u8d26\u5355"},"billing":"\u5f00\u7968","bills":"\u8d26\u5355","birth_report":{"birth_report":"\u51fa\u751f\u62a5\u544a","birth_report_details":"\u51fa\u751f\u62a5\u544a\u8be6\u7ec6\u4fe1\u606f","birth_reports":"\u51fa\u751f\u62a5\u544a","case_id":"\u6848\u4f8bID","data_should_not_be_smaller_than_patient_birth_date":"\u65e5\u671f\u4e0d\u5e94\u5c0f\u4e8e\u60a3\u8005\u51fa\u751f\u65e5\u671f.","date":"\u65e5\u671f","description":"\u63cf\u8ff0","doctor_name":"\u533b\u751f\u59d3\u540d","edit_birth_report":"\u7f16\u8f91\u51fa\u751f\u62a5\u544a","new_birth_report":"\u65b0\u51fa\u751f\u62a5\u544a","patient_birth_date_not_found":"\u672a\u627e\u5230\u60a3\u8005\u51fa\u751f\u65e5\u671f.","patient_name":"\u60a3\u8005\u59d3\u540d"},"birth_reports":"\u51fa\u751f\u62a5\u544a","blood_bank":"\u8840\u5e93","blood_banks":"\u8840\u5e93","blood_donation":{"bags":"\u5305\u888b","blood_donation":"\u732e\u8840","donor_name":"\u6350\u52a9\u8005\u540d\u79f0","edit_blood_donation":"\u7f16\u8f91\u732e\u8840","last_donate_date":"\u6700\u540e\u6350\u8d60\u65e5\u671f","new_blood_donation":"\u65b0\u732e\u8840"},"blood_donations":"\u732e\u8840","blood_donor":{"age":"\u5e74\u9f84","blood_donor":"\u732e\u8840\u8005","blood_donor_details":"\u732e\u8840\u8005\u8be6\u7ec6\u8d44\u6599","blood_donors":"\u732e\u8840\u8005","blood_group":"\u8840\u578b","donation_date":"\u6350\u8d60\u65e5\u671f","edit_blood_donor":"\u7f16\u8f91\u732e\u8840\u8005","gender":"\u6027\u522b","last_donation_date":"\u6700\u540e\u6350\u8d60\u65e5\u671f","name":"\u540d\u79f0","new_blood_donor":"\u65b0\u732e\u8840\u8005"},"blood_donors":"\u732e\u8840\u8005","blood_issue":{"amount":"\u91cf","blood_issue":"\u8840\u6db2\u95ee\u9898","doctor_name":"\u533b\u751f\u59d3\u540d","donor_name":"\u6350\u8d60\u4eba\u540d\u79f0","edit_blood_issue":"\u7f16\u8f91\u8840\u6db2\u95ee\u9898","issue_date":"\u53d1\u884c\u65e5\u671f","new_blood_issue":"\u65b0\u8840\u95ee\u9898","patient_name":"\u60a3\u8005\u540d\u79f0","remarks":"\u5907\u6ce8"},"blood_issues":"\u8840\u6db2\u95ee\u9898","call_log":{"call_log":"\u901a\u8bdd\u8bb0\u5f55","call_type":"\u901a\u8bdd\u7c7b\u578b","edit":"\u7f16\u8f91\u901a\u8bdd\u8bb0\u5f55","follow_up_date":"\u8ddf\u8fdb\u65e5\u671f","incoming":"\u4f20\u5165","name":"\u540d\u79f0","new":"\u65b0\u901a\u8bdd\u8bb0\u5f55","note":"\u6ce8\u610f","outgoing":"\u5916\u5411","phone":"\u7535\u8bdd","received_on":"\u6536\u5230\u65e5\u671f"},"call_logs":"\u901a\u8bdd\u8bb0\u5f55","case":{"case":"\u6848\u4ef6","case_date":"\u6848\u4ef6\u65e5\u671f","case_details":"\u6848\u4ef6\u8be6\u60c5","case_id":"\u6848\u4f8bID","date":"\u65e5\u671f","description":"\u8bf4\u660ez","doctor":"\u533b\u751f","edit_case":"\u7f16\u8f91\u6848\u4f8b","fee":"\u8d39\u7528","new_case":"\u65b0\u6848\u4f8b","patient":"\u60a3\u8005","phone":"\u7535\u8bdd"},"case_handler":{"case_handler":"\u529e\u6848\u5458","case_handler_detail":"\u6848\u4ef6\u5904\u7406\u4eba\u5458\u8be6\u7ec6\u4fe1\u606f","edit_case_handler":"\u7f16\u8f91\u6848\u4f8b\u5904\u7406\u7a0b\u5e8f","new_case_handler":"\u65b0\u6848\u5904\u7406\u4eba"},"case_handlers":"\u6848\u4ef6\u5904\u7406\u4eba\u5458","case_manager":"\u4e2a\u6848\u7ecf\u7406","cases":"\u6848\u4f8b","change_password":{"change_password":"\u66f4\u6539\u5bc6\u7801","confirm_password":"\u786e\u8ba4\u5bc6\u7801","current_password":"\u5f53\u524d\u5bc6\u7801","new_password":"\u65b0\u5bc6\u7801"},"charge":{"charge_category":"\u6536\u8d39\u7c7b\u522b","charge_details":"\u6536\u8d39\u660e\u7ec6","code":"\u7801","edit_charge":"\u7f16\u8f91\u8d39\u7528","new_charge":"\u65b0\u6536\u8d39","standard_charge":"\u6807\u51c6\u6536\u8d39"},"charge_categories":"\u6536\u8d39\u7c7b\u522b","charge_category":{"charge_categories":"\u6536\u8d39\u7c7b\u522b","charge_category_details":"\u6536\u8d39\u7c7b\u522b\u8be6\u7ec6\u4fe1\u606f","charge_type":"\u6536\u8d39\u7c7b\u578b","edit_charge_category":"\u7f16\u8f91\u8d39\u7528\u7c7b\u522b","new_charge_category":"\u65b0\u6536\u8d39\u7c7b\u522b"},"charges":"\u6536\u8d39\u6807\u51c6","cms":"\u5185\u5bb9\u7ba1\u7406\u7cfb\u7edf","common":{"action":"\u884c\u52a8","actions":"\u884c\u52a8","active":"\u6d3b\u6027","add":"\u52a0","address":"\u5730\u5740","apply":"\u7533\u8bf7","are_you_sure_want_to_delete_this":"\u4f60\u786e\u5b9a\u8981\u5220\u9664\u8fd9\u4e2a ","back":"\u80cc\u90e8","cancel":"\u53d6\u6d88","canceled":"\u53d6\u6d88","cant_be_deleted":"\u65e0\u6cd5\u5220\u9664","choose":"\u9009\u62e9","confirm":"\u786e\u8ba4","created_at":"\u521b\u5efa\u4e8e","created_on":"\u521b\u5efa\u4e8e","custom":"\u98ce\u4fd7","de_active":"\u505c\u7528","delete":"\u5220\u9664","deleted":"\u5df2\u5220\u9664","deleted_successfully":"\u5220\u9664\u6210\u529f","description":"\u63cf\u8ff0","detail":"\u7ec6\u8282","edit":"\u7f16\u8f91","export_to_excel":"\u8f93\u51fa\u5230\u7535\u5b50\u8868\u683c","filter_options":"\u8fc7\u6ee4\u5668\u9009\u9879","from":"\u4ece","has_been_deleted":"\u5df2\u88ab\u5220\u9664\u3002","invalid_country_code":"\u56fd\u5bb6\u4ee3\u7801\u65e0\u6548","invalid_number":"\u65e0\u6548\u53f7\u7801","is_available":"\u6709\u7a7a","last_updated":"\u6700\u8fd1\u66f4\u65b0\u65f6\u95f4","n\/a":"\u4e0d\u9002\u7528","name":"\u540d\u79f0","new":"\u65b0","next":"\u4e0b\u4e00\u4e2a","no":"\u6ca1\u6709","not_found":"\u672a\u627e\u5230","ok":"\u597d\u7684","previous":"\u4ee5\u524d\u7684","profile":"\u8f6e\u5ed3","reset":"\u91cd\u542f","save":"\u4fdd\u5b58","saved_successfully":"\u4fdd\u5b58\u6210\u529f\u3002","search":"\u641c\u7d22","status":"\u72b6\u6001","status_updated_successfully":"\u72b6\u6001\u66f4\u65b0\u6210\u529f\u3002","this_action_is_not_allowed_for_default_record":"\u9ed8\u8ba4\u8bb0\u5f55\u4e0d\u5141\u8bb8\u6b64\u64cd\u4f5c\u3002","to":"\u81f3","too_long":"\u592a\u957f","too_short":"\u592a\u77ed","total":"\u603b","updated_at":"\u6700\u8fd1\u66f4\u65b0\u65f6\u95f4","updated_successfully":"\u66f4\u65b0\u6210\u529f","user_details":"\u7528\u6237","view":"\u89c6\u56fe","view_attachment":"\u67e5\u770b\u9644\u4ef6","yes":"\u662f"},"contact_us":"\u8054\u7cfb\u6211\u4eec","currency":{"add_currency_code_as_per_three_letter_iso_code":"\u6309\u7167\u4e09\u5b57\u6bcd ISO \u4ee3\u7801\u6dfb\u52a0\u8d27\u5e01\u4ee3\u7801","currency":"\u8d27\u5e01","currency_code":"\u8d27\u5e01\u4ee3\u7801","currency_icon":"\u8d27\u5e01\u56fe\u6807","currency_name":"\u8d27\u5e01\u540d\u79f0","edit_currency":"\u7f16\u8f91\u8d27\u5e01","new_currency":"\u65b0\u8d27\u5e01","you_can_find_out_here":"\u4f60\u53ef\u4ee5\u5728\u8fd9\u91cc\u627e\u5230"},"currency_setting":"\u8d27\u5e01","dashboard":{"available_beds":"\u53ef\u7528\u5e8a","dashboard":"\u4eea\u8868\u677f","doctors":"\u91ab\u751f","income_and_expense_report":"\u6536\u652f\u62a5\u544a","income_and_expense_reports":"\u6536\u652f\u62a5\u544a","no_enquiries_yet":"\u8fd8\u6ca1\u6709\u67e5\u8be2","no_notice_yet":"\u8fd8\u6ca1\u6709\u901a\u77e5","notice_boards":"\u516c\u544a\u680f","patients":"\u8010\u5fc3","title":"\u6807\u9898","total_advance_payments":"\u9884\u4ed8\u6b3e\u603b\u989d","total_bills":"\u8d26\u5355\u603b\u989d","total_invoices":"\u53d1\u7968\u603b\u989d","total_payments":"\u603b\u4ed8\u6b3e\u989d"},"death_report":{"case_id":"\u6848\u4f8bID","date":"\u65e5\u671f","death_report":"\u6b7b\u4ea1\u62a5\u544a","death_report_details":"\u6b7b\u4ea1\u62a5\u544a\u8be6\u7ec6\u4fe1\u606f","death_reports":"\u6b7b\u4ea1\u62a5\u544a","description":"\u63cf\u8ff0","doctor_name":"\u533b\u751f\u59d3\u540d","edit_death_report":"\u7f16\u8f91\u6b7b\u4ea1\u62a5\u544a","new_death_report":"\u65b0\u6b7b\u4ea1\u62a5\u544a","patient_name":"\u60a3\u8005\u59d3\u540d"},"death_reports":"\u6b7b\u4ea1\u62a5\u544a","department":"\u90e8\u95e8","departments":"\u90e8\u95e8","diagnosis_category":{"category_name":"\u5206\u7c7b\u540d\u79f0","description":"\u63cf\u8ff0","diagnosis_categories":"\u8bca\u65ad\u7c7b\u522b","diagnosis_category":"\u8bca\u65ad\u7c7b\u522b","diagnosis_category_details":"\u8bca\u65ad\u7c7b\u522b\u8be6\u7ec6\u4fe1\u606f","edit_diagnosis_category":"\u7f16\u8f91\u8bca\u65ad\u7c7b\u522b","new_diagnosis_category":"\u65b0\u8bca\u65ad\u7c7b\u522b"},"doc_type":{"edit_doc_type":"\u7f16\u8f91\u6587\u4ef6\u7c7b\u578b","name":"\u540d\u79f0","new_doc_type":"\u65b0\u6587\u4ef6\u7c7b\u578b"},"doctor":{"doctor_details":"\u533b\u751f\u8be6\u7ec6\u8d44\u6599","edit_doctor":"\u7f16\u8f91\u533b\u751f","name":"\u540d\u79f0","new_doctor":"\u65b0\u533b\u751f","specialist":"\u4e13\u5bb6"},"doctor_department":{"description":"\u63cf\u8ff0","doctor_department":"\u533b\u751f\u79d1","doctor_department_details":"\u533b\u751f\u79d1\u8be6\u7ec6\u8d44\u6599","doctor_departments":"\u533b\u751f\u79d1\u5ba4","edit_doctor_department":"\u7f16\u8f91\u533b\u751f\u90e8\u95e8","new_doctor_department":"\u65b0\u533b\u751f\u79d1","title":"\u6807\u9898"},"doctor_departments":"\u533b\u751f\u79d1\u5ba4","doctor_opd_charge":{"doctor":"\u533b\u751f","doctor_name":"\u533b\u751f\u59d3\u540d","doctor_opd_charge":"\u533b\u751f OPD \u8d39\u7528","edit_doctor_opd_charge":"\u7f16\u8f91\u533b\u751fOPD\u8d39\u7528","new_doctor_opd_charge":"\u65b0\u533b\u751fOPD\u8d39\u7528","standard_charge":"\u6807\u51c6\u6536\u8d39"},"doctor_opd_charges":"\u533b\u751fOPD\u6536\u8d39","doctors":"\u533b\u751f","doctors_list":"\u533b\u751f\u540d\u5355","document":{"attachment":"\u9644\u4ef6","document":"\u6587\u732e","document_detail":"\u6587\u4ef6\u8be6\u7ec6\u8d44\u6599","document_type":"\u6587\u4ef6\u7c7b\u578b","document_type_details":"\u6587\u4ef6\u7c7b\u578b\u8be6\u7ec6\u8d44\u6599","documents":"\u6587\u4ef6\u8d44\u6599","download":"\u4e0b\u8f7d","edit_document":"\u7f16\u8f91\u6587\u4ef6","new_document":"\u65b0\u6587\u4ef6","notes":"\u7b14\u8bb0","patient":"\u60a3\u8005","select_document_type":"\u9009\u62e9\u6587\u4ef6\u7c7b\u578b","select_patient":"\u9009\u62e9\u60a3\u8005","title":"\u6807\u9898","uploaded_by":"\u4e0a\u4f20\u8005"},"document_types":"\u6587\u4ef6\u7c7b\u578b","documents":"\u6587\u4ef6\u8d44\u6599","email":{"attachment":"\u9644\u4ef6","message":"\u4fe1\u606f","subject":"\u5b66\u79d1","to":"\u81f3"},"employee_payroll":{"allowance":"\u6d25\u8d34","basic_salary":"\u57fa\u7840\u5de5\u8d44","deductions":"\u6263\u9664\u989d","edit_employee_payroll":"\u7f16\u8f91\u5458\u5de5\u5de5\u8d44\u5355","employee":"\u96c7\u5458","employee_name":"\u5458\u5de5\u59d3\u540d","employee_payroll":"\u5458\u5de5\u5de5\u8d44\u5355","employee_payroll_details":"\u5458\u5de5\u5de5\u8d44\u660e\u7ec6","employee_payrolls":"\u5458\u5de5\u5de5\u8d44\u5355","month":"\u6708","net_salary":"\u51c0\u5de5\u8d44","new_employee_payroll":"\u65b0\u5458\u5de5\u5de5\u8d44\u5355","not_paid":"\u6ca1\u6709\u652f\u4ed8","paid":"\u5df2\u4ed8\u8d39","payroll_id":"\u5de5\u8d44\u5355\u7f16\u53f7","role":"\u89d2\u8272","sr_no":"\u9ad8\u7ea7","year":"\u5e74"},"employee_payrolls":"\u5458\u5de5\u5de5\u8d44\u5355","enquiries":"\u54a8\u8be2\u5904","enquiry":{"contact":"\u8054\u7cfb","email":"\u7535\u5b50\u90ae\u4ef6","enquiry_details":"\u67e5\u8be2\u8be6\u60c5","enquiry_send_successfully":"\u8be2\u76d8\u53d1\u9001\u6210\u529f","message":"\u4fe1\u606f","name":"\u540d\u79f0","not_viewed":"\u672a\u67e5\u770b","read":"\u8bfb","received_on":"\u6536\u5230\u65e5\u671f","send_enquiry":"\u53d1\u9001\u67e5\u8be2","type":"\u7c7b\u578b","unread":"\u672a\u8bfb","viewed_by":"\u67e5\u770b\u8005"},"expense":{"amount":"\u91cf","attachment":"\u9644\u4ef6","choose":"\u9009\u62e9","date":"\u65e5\u671f","description":"\u63cf\u8ff0","document_error":"\u8be5\u6587\u6863\u5fc5\u987b\u662f\u7c7b\u578b\u7684\u6587\u4ef6: jpeg, jpg, png, pdf, doc, docx.","download":"\u4e0b\u8f7d","edit_expense":"\u7f16\u8f91\u8d39\u7528","expense":"\u8d39\u7528","expense_details":"\u8d39\u7528\u660e\u7ec6","expense_head":"\u8d39\u7528\u5934","invoice_number":"\u53d1\u7968\u7f16\u53f7","name":"\u540d\u79f0","new_expense":"\u65b0\u8d39\u7528","select_expense_head":"\u9009\u62e9\u8d39\u7528\u5934"},"expenses":"\u82b1\u8d39","facebook_url":"\u8138\u4e66\u7f51\u5740","file_name":"\u6587\u4ef6\u540d","finance":"\u91d1\u878d","front_cms":"\u524d\u5398\u7c73","front_cms_services":"\u524d\u7aef CMS \u670d\u52a1","front_office":"\u524d\u5385","front_service":"\u524d\u53f0\u670d\u52a1","front_setting":{"about_us_description":"\u63cf\u8ff0","about_us_details":"\u5173\u4e8e\u6211\u4eec \u8be6\u60c5","about_us_image":"\u56fe\u50cf","about_us_mission":"\u4f7f\u547d","about_us_title":"\u6807\u9898","appointment_details":"\u9884\u7ea6\u8be6\u60c5","front_setting_details":"\u6b63\u9762\u8bbe\u7f6e\u7ec6\u8282","home_page_box_description":"\u4e3b\u9875\u6846\u8bf4\u660e","home_page_box_title":"\u4e3b\u9875\u6846\u6807\u9898","home_page_certified_box_description":"\u4e3b\u9875 \u8ba4\u8bc1\u6846\u8bf4\u660e","home_page_certified_box_title":"\u4e3b\u9875\u8ba4\u8bc1\u6846\u6807\u9898","home_page_certified_doctor_description":"\u4e3b\u9875 \u8ba4\u8bc1\u533b\u751f \u8bf4\u660e","home_page_certified_doctor_image":"\u9996\u9875\u8ba4\u8bc1\u533b\u751f\u5f62\u8c61","home_page_certified_doctor_text":"\u4e3b\u9875\u8ba4\u8bc1\u533b\u751f\u6587\u672c","home_page_certified_doctor_title":"\u4e3b\u9875 \u8ba4\u8bc1\u533b\u751f\u804c\u79f0","home_page_description":"\u4e3b\u9875\u8bf4\u660e","home_page_experience":"\u9996\u9875\u4f53\u9a8c","home_page_image":"\u4e3b\u9875\u56fe\u7247","home_page_step_1_description":"\u4e3b\u9875 \u6b65\u9aa4 1 \u8bf4\u660e","home_page_step_1_title":"\u4e3b\u9875 \u6b65\u9aa4 1 \u6807\u9898","home_page_step_2_description":"\u4e3b\u9875 \u6b65\u9aa4 2 \u8bf4\u660e","home_page_step_2_title":"\u4e3b\u9875 \u6b65\u9aa4 2 \u6807\u9898","home_page_step_3_description":"\u4e3b\u9875 \u6b65\u9aa4 3 \u8bf4\u660e","home_page_step_3_title":"\u4e3b\u9875 \u6b65\u9aa4 3 \u6807\u9898","home_page_step_4_description":"\u4e3b\u9875 \u6b65\u9aa4 4 \u8bf4\u660e","home_page_step_4_title":"\u4e3b\u9875 \u6b65\u9aa4 4 \u6807\u9898","home_page_title":"\u4e3b\u9875\u6807\u9898","privacy_policy":"\u9690\u79c1\u653f\u7b56","terms_condition_details":"\u6761\u6b3e\u53ca\u7ec6\u5219\u8be6\u60c5","terms_conditions":"\u6761\u6b3e\u548c\u6761\u4ef6"},"front_settings":"\u6b63\u9762\u8bbe\u7f6e","general":"\u4e00\u822c","hospital_activities":"\u533b\u9662\u6d3b\u52a8","hospital_blood_bank":{"blood_bank":"\u8840\u5e93","blood_bank_details":"\u8840\u5e93\u8be6\u7ec6\u4fe1\u606f","blood_banks":"\u8840\u5e93","blood_group":"\u8840\u578b","edit_blood_group":"\u7f16\u8f91\u8840\u578b","new_blood_group":"\u65b0\u8840\u578b","remained_bags":"\u5269\u4f59\u884c\u674e"},"hospital_charges":"\u4f4f\u9662\u8d39\u7528","hospital_schedule":"\u4f4f\u9662\u65f6\u95f4\u8868","hospital_schedules":{"exists_doctor_schedule":"\u4e00\u4e9b\u533b\u751f\u5c06\u4ed6\u4eec\u7684\u65e5\u5b50\u5b89\u6392\u5728\u7ed9\u5b9a\u7684\u672a\u7ecf\u68c0\u67e5\u7684\u65e5\u5b50\u91cc\uff0c\u6240\u4ee5\u60a8\u786e\u5b9a\u8981\u6267\u884c\u6b64\u64cd\u4f5c\u5417\uff1f"},"icon":"\u56fe\u6807","income":"\u6536\u5165","incomes":{"amount":"\u91cf","attachment":"\u9644\u4ef6","choose":"\u9009\u62e9","date":"\u65e5\u671f","description":"\u63cf\u8ff0","document_error":"\u8be5\u6587\u6863\u5fc5\u987b\u662f\u7c7b\u578b\u7684\u6587\u4ef6: jpeg, jpg, png, pdf, doc, docx.","download":"\u4e0b\u8f7d","edit_income":"\u7f16\u8f91\u6536\u5165","income_details":"\u6536\u5165\u660e\u7ec6","income_head":"\u6536\u5165\u5934","incomes":"\u6536\u5165\u72b6\u51b5","invoice_number":"\u53d1\u7968\u7f16\u53f7","name":"\u540d\u79f0","new_income":"\u65b0\u6536\u5165","select_income_head":"\u9009\u62e9\u6536\u5165\u5934"},"instagram_url":"Instagram \u7f51\u5740","insurance":{"discount":"\u6298\u6263","disease_details":"\u75be\u75c5\u8be6\u60c5","diseases_charge":"\u75be\u75c5\u8d39","diseases_name":"\u75be\u75c5\u540d\u79f0","edit_insurance":"\u7f16\u8f91\u4fdd\u9669","hospital_rate":"\u4f4f\u9662\u7387","insurance":"\u4fdd\u9669","insurance_code":"\u4fdd\u9669\u5b88\u5219","insurance_details":"\u4fdd\u9669\u660e\u7ec6","insurance_no":"\u4fdd\u9669\u4e1a","insurances":"\u4fdd\u9669","new_insurance":"\u65b0\u4fdd\u9669","remark":"\u5907\u6ce8","service_tax":"\u670d\u52a1\u7a0e","total_amount":"\u603b\u91d1\u989d"},"insurances":"\u4fdd\u9669","inventory":"\u5e93\u5b58","investigation_report":{"attachment":"\u9644\u4ef6","birth_date_validation":"\u8c03\u67e5\u62a5\u544a\u65e5\u671f\u4e0d\u5e94\u5c0f\u4e8e\u60a3\u8005\u51fa\u751f\u65e5\u671f\u3002","date":"\u65e5\u671f","description":"\u63cf\u8ff0","doctor":"\u533b\u751f","edit_investigation_report":"\u7f16\u8f91\u8c03\u67e5\u62a5\u544a","investigation_report":"\u8c03\u67e5\u62a5\u544a","investigation_report_details":"\u8c03\u67e5\u62a5\u544a\u660e\u7ec6","investigation_reports":"\u8c03\u67e5\u62a5\u544a","new_investigation_report":"\u65b0\u8c03\u67e5\u62a5\u544a","patient":"\u60a3\u8005","title":"\u6807\u9898"},"investigation_reports":"\u8c03\u67e5\u62a5\u544a","invoice":{"account_name":"\u7528\u6237\u540d","add":"\u52a0","amount":"\u91cf","description":"\u63cf\u8ff0","discount":"\u6298\u6263","edit":"\u7f16\u8f91","edit_invoice":"\u7f16\u8f91\u53d1\u7968","hospital_address":"\u533b\u9662\u5730\u5740","invoice":"\u53d1\u7968","invoice_date":"\u53d1\u7968\u65e5\u671f","invoice_details":"\u53d1\u7968\u660e\u7ec6","invoice_id":"\u53d1\u7968\u7f16\u53f7","invoices":"\u53d1\u7968","new_invoice":"\u65b0\u53d1\u7968","not_paid":"\u6ca1\u6709\u652f\u4ed8","paid":"\u5df2\u4ed8\u8d39","patient":"\u60a3\u8005","patient_id":"\u60a3\u8005\u7f16\u53f7","price":"\u4ef7\u94b1","print_invoice":"\u5217\u5370\u53d1\u7968","qty":"\u6570\u91cf","sub_total":"\u5c0f\u8ba1","total":"\u603b\u91d1\u989d"},"invoices":"\u53d1\u7968","ipd_bill":{"discount_in_number":"\u6570\u5b57\u6298\u6263","discount_in_percentage":"\u767e\u5206\u6bd4\u6298\u6263","gross_total":"\u603b\u6536\u5165","net_payable_amount":"\u51c0\u5e94\u4ed8\u91d1\u989d","other_charges":"\u5176\u4ed6\u8d39\u7528","paid_amount":"\u5df2\u4ed8\u91d1\u989d","tax_in_number":"\u7a0e\u53f7","tax_in_percentage":"\u767e\u5206\u6bd4\u7a0e","total_charges":"\u603b\u8d39\u7528"},"ipd_charges":"\u6536\u8d39\u6807\u51c6","ipd_consultant_register":"\u987e\u95ee\u6307\u5bfc","ipd_diagnosis":"\u8bca\u65ad","ipd_opd":"\u77b3\u8ddd\/\u77b3\u8ddd","ipd_patient":{"admission_date":"\u5165\u5b66\u65e5\u671f","bed_id":"\u5e8a","bed_type_id":"\u5e8a\u578b","bill_status":"\u8d26\u5355\u72b6\u6001","bp":"\u8840\u538b","case_id":"\u6848\u4ef6","doctor_id":"\u533b\u751f","edit_ipd_patient":"\u7f16\u8f91IPD\u60a3\u8005","height":"\u9ad8\u5ea6","ipd_number":"IPD\u53f7\u7801","ipd_patient":"IPD\u60a3\u8005","ipd_patient_details":"IPD\u60a3\u8005\u8be6\u7ec6\u4fe1\u606f","ipd_patients":"IPD\u60a3\u8005","is_old_patient":"\u662f\u8001\u5e74\u60a3\u8005","new_ipd_patient":"\u65b0IPD\u60a3\u8005","notes":"\u6ce8\u91ca","patient_id":"\u60a3\u8005","symptoms":"\u75c7\u72b6","the_bed_field_is_required":"\u5e8a\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","the_case_field_is_required":"\u6848\u4f8b\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","weight":"\u91cd\u91cf"},"ipd_patient_charges":{"applied_charge":"\u5e94\u7528\u6536\u8d39","charge_category_id":"\u6536\u8d39\u7c7b\u522b","charge_id":"\u4ee3\u7801","charge_type_id":"\u6536\u8d39\u7c7b\u578b","date":"\u65e5\u671f","new_charge":"\u6dfb\u52a0\u8d39\u7528","standard_charge":"\u6807\u51c6\u8d39\u7528"},"ipd_patient_consultant_register":{"applied_date":"\u5e94\u7528\u65e5\u671f","doctor_id":"\u533b\u751f","instruction":"\u6307\u4ee4","instruction_date":"\u6307\u4ee4\u65e5\u671f","new_consultant_register":"\u6dfb\u52a0\u987e\u95ee\u6307\u4ee4"},"ipd_patient_diagnosis":{"description":"\u63cf\u8ff0","document":"\u6587\u4ef6","edit_ipd_diagnosis":"\u7f16\u8f91\u8bca\u65ad","new_ipd_diagnosis":"\u6dfb\u52a0\u8bca\u65ad","report_date":"\u62a5\u544a\u65e5\u671f","report_type":"\u62a5\u544a\u7c7b\u578b"},"ipd_patient_prescription":{"category_id":"\u533b\u5b66\u7c7b\u522b","dosage":"\u5242\u91cf","edit_prescription":"\u7f16\u8f91\u5904\u65b9","footer_note":"\u811a\u6ce8","header_note":"\u6807\u9898\u8bf4\u660e","instruction":"\u6307\u4ee4","ipd_no":"IPD\u5426","medicine_id":"\u533b\u5b66","new_prescription":"\u6dfb\u52a0\u5904\u65b9","prescription_details":"\u5904\u65b9\u8be6\u7ec6\u4fe1\u606f","print_prescription":"\u6253\u5370\u5904\u65b9"},"ipd_patient_timeline":{"date":"\u65e5\u671f","description":"\u63cf\u8ff0","document":"\u6587\u4ef6","edit_ipd_timeline":"\u7f16\u8f91\u65f6\u95f4\u8f74","new_ipd_timeline":"\u6dfb\u52a0\u65f6\u95f4\u8868","no_timeline_found":"\u627e\u4e0d\u5230\u65f6\u95f4\u7ebf","title":"\u6807\u9898","visible_to_person":"\u5bf9\u4eba\u53ef\u89c1"},"ipd_patients":"IPD\u60a3\u8005","ipd_payment":"\u77e5\u8bc6\u4ea7\u6743\u652f\u4ed8","ipd_payments":{"add_ipd_payment":"\u6dfb\u52a0ipd\u4ed8\u6b3e","edit_ipd_payment":"Edit IPD Payment","make_payment":"\u8fdb\u884c\u4ed8\u6b3e","payment_mode":"\u4ed8\u6b3e\u65b9\u5f0f"},"ipd_prescription":"\u5904\u65b9\u836f","ipd_timelines":"\u65f6\u95f4\u7ebf","issued_item":{"are_you_sure_want_to_return_this_item":"\u60a8\u786e\u5b9a\u8981\u9000\u56de\u6b64\u5546\u54c1\u5417","available_quantity":"\u53ef\u7528\u6570\u91cf","department_id":"\u7528\u6237\u7c7b\u578b","description":"\u63cf\u8ff0","edit_issued_item":"\u7f16\u8f91\u7b7e\u53d1\u9879\u76ee","issued_by":"\u53d1\u884c\u4eba","issued_date":"\u53d1\u884c\u65e5\u671f","issued_item":"\u53d1\u884c\u7269\u54c1","issued_item_details":"\u53d1\u8d27\u9879\u76ee\u660e\u7ec6","issued_items":"\u53d1\u884c\u7269\u54c1","item":"\u9879\u76ee","item_category":"\u9879\u76ee\u7c7b\u522b","item_return":"\u5f52\u8fd8\u7269\u54c1","item_returned":"\u56de\u6765","new_issued_item":"\u65b0\u53d1\u884c\u7269\u54c1","quantity":"\u6570\u91cf","return_date":"\u5f52\u671f","user_id":"\u53d1\u7ed9"},"issued_items":"\u53d1\u884c\u7269\u54c1","item":{"available_quantity":"\u53ef\u7528\u6570\u91cf","description":"\u63cf\u8ff0","edit_item":"\u7f16\u8f91\u9879\u76ee","item":"\u9879\u76ee","item_category":"\u9879\u76ee\u7c7b\u522b","item_details":"\u9879\u76ee\u660e\u7ec6","items":"\u7269\u54c1","name":"\u540d\u79f0","new_item":"\u65b0\u7269\u54c1","unit":"\u5355\u5143"},"item_category":{"edit_item_category":"\u7f16\u8f91\u9879\u76ee\u7c7b\u522b","item_categories":"\u9879\u76ee\u7c7b\u522b","item_category":"\u9879\u76ee\u7c7b\u522b","name":"\u540d\u79f0","new_item_category":"\u65b0\u5546\u54c1\u7c7b\u522b"},"item_stock":{"attachment":"\u9644\u4ef6","description":"\u63cf\u8ff0","edit_item_stock":"\u7f16\u8f91\u7269\u54c1\u5e93\u5b58","item":"\u9879\u76ee","item_category":"\u9879\u76ee\u7c7b\u522b","item_stock":"\u7269\u54c1\u5e93\u5b58","item_stock_details":"\u9879\u76ee\u5e93\u5b58\u660e\u7ec6","item_stocks":"\u7269\u54c1\u5e93\u5b58","new_item_stock":"\u65b0\u5546\u54c1\u5e93\u5b58","purchase_price":"\u8d2d\u4e70\u4ef7\u683c","quantity":"\u6570\u91cf","store_name":"\u5e97\u94fa\u540d\u79f0","supplier_name":"\u4f9b\u5e94\u5546\u540d\u79f0"},"items":"\u7269\u54c1","items_categories":"\u9879\u76ee\u7c7b\u522b","items_stocks":"\u7269\u54c1\u5e93\u5b58","lab_tech":{"edit_lab_tech":"\u7f16\u8f91\u5b9e\u9a8c\u5ba4\u6280\u672f\u5458","lab_tech_detail":"\u5b9e\u9a8c\u5ba4\u6280\u672f\u5458\u8be6\u7ec6\u4fe1\u606f","lab_technician":"\u5b9e\u9a8c\u5ba4\u6280\u672f\u5458","new_lab_tech":"\u65b0\u5b9e\u9a8c\u5ba4\u6280\u672f\u5458"},"lab_technicians":"\u5b9e\u9a8c\u5ba4\u6280\u672f\u5458","language":{"Arabic":"\u963f\u62c9\u4f2f","Chinese":"\u4e2d\u56fd\u4eba","English":"\u82f1\u8bed","French":"\u6cd5\u8bed","German":"\u5fb7\u8bed","Portuguese":"\u8461\u8404\u7259\u8bed","Russian":"\u4fc4\u8bed","Spanish":"\u897f\u73ed\u7259\u8bed","Turkish":"\u571f\u8033\u5176"},"linkedIn_url":"\u9886\u82f1\u7f51\u5740","live_consultation":{"add_credential":"\u6dfb\u52a0\u51ed\u636e","client_video":"\u5ba2\u6237\u89c6\u9891","consultation_date":"\u54a8\u8be2\u65e5\u671f","consultation_duration_minutes":"\u54a8\u8be2\u6301\u7eed\u65f6\u95f4\u5206\u949f","consultation_title":"\u54a8\u8be2\u6807\u9898","created_by":"\u521b\u5efa\u8005","created_for":"\u521b\u5efa\u4e8e","disabled":"\u6b8b\u969c\u4eba\u58eb","edit_live_consultation":"\u7f16\u8f91\u5b9e\u65f6\u54a8\u8be2","edit_live_meeting":"\u7f16\u8f91\u73b0\u573a\u4f1a\u8bae","enable":"\u542f\u7528","host_video":"\u4e3b\u6301\u4eba\u89c6\u9891","join_now":"\u73b0\u5728\u52a0\u5165","live_consultation":"\u73b0\u573a\u54a8\u8be2","new_live_consultation":"\u65b0\u5b9e\u65f6\u54a8\u8be2","new_live_meeting":"\u65b0\u7684\u5b9e\u65f6\u4f1a\u8bae","staff_list":"\u5458\u5de5\u540d\u5355","type":"\u7c7b\u578b","type_number":"\u7c7b\u578b\u7f16\u53f7","zoom_api_key":"\u7f29\u653e API \u5bc6\u94a5","zoom_api_secret":"\u7f29\u653e API \u79d8\u5bc6"},"live_consultations":"\u73b0\u573a\u54a8\u8be2","live_meeting":"\u73b0\u573a\u4f1a\u8bae","live_meetings":"\u5b9e\u65f6\u4f1a\u8bae","mail":"\u90ae\u4ef6","make_an_appointment":"\u9884\u7ea6","medicine":{"brand":"\u724c","brand_name":"\u54c1\u724c","buying_price":"\u4e70\u4ef7","category":"\u7c7b\u522b","category_id":"\u7c7b\u522b\u7f16\u53f7","description":"\u63cf\u8ff0","edit_medicine":"\u7f16\u8f91\u533b\u5b66","edit_medicine_brand":"\u7f16\u8f91\u533b\u836f\u54c1\u724c","edit_medicine_category":"\u7f16\u8f91\u836f\u7269\u7c7b\u522b","medicine":"\u533b\u5b66","medicine_brands":"\u533b\u836f\u54c1\u724c","medicine_brands_details":"\u836f\u54c1\u54c1\u724c\u8be6\u7ec6\u4fe1\u606f","medicine_category":"\u836f\u7269\u7c7b\u522b","medicine_category_details":"\u836f\u7269\u7c7b\u522b\u8be6\u7ec6\u4fe1\u606f","medicine_details":"\u836f\u7269\u7ec6\u8282","medicines":"\u836f\u54c1","name":"\u540d\u79f0","new_brand":"\u65b0\u54c1\u724c","new_medicine":"\u65b0\u836f","new_medicine_brand":"\u65b0\u836f\u54c1\u724c","new_medicine_category":"\u65b0\u836f\u5206\u7c7b","salt_composition":"\u76d0\u6210\u5206","selling_price":"\u552e\u4ef7","side_effects":"\u526f\u4f5c\u7528"},"medicine_brands":"\u533b\u836f\u54c1\u724c","medicine_categories":"\u533b\u836f\u7c7b\u522b","medicines":"\u836f\u54c1","message":{"date":"\u65e5\u671f","message":"\u4fe1\u606f","messages":"\u7559\u8a00\u5185\u5bb9","messages_details":"\u8baf\u606f\u8be6\u60c5","new_message":"\u65b0\u6d88\u606f","select_user":"\u9009\u62e9\u7528\u6237","send_to":"\u53d1\u9001\u81f3","sender_name":"\u53d1\u4ef6\u8005\u59d3\u540d","subject":"\u5b66\u79d1"},"months":{"apr":"\u56db\u6708","aug":"\u516b\u6708","dec":"\u5341\u4e8c\u6708","feb":"\u4e8c\u6708","jan":"\u4e00\u6708","july":"\u4e03\u6708","jun":"\u516d\u6708","mar":"\u884c\u8fdb","may":"\u53ef\u80fd","nov":"\u5341\u4e00\u6708","oct":"\u5341\u6708","sep":"\u4e5d\u6708"},"my_payroll":{"allowance":"\u6d25\u8d34","basic_salary":"\u57fa\u7840\u5de5\u8d44","deductions":"\u6263\u9664\u989d","my_payrolls":"\u6211\u7684\u5de5\u8d44\u5355","net_salary":"\u51c0\u5de5\u8d44"},"my_payrolls":"\u6211\u7684\u5de5\u8d44\u5355","new_patient":"\u65b0\u75c5\u4eba","no_data_available":"\u8868\u4e2d\u65e0\u53ef\u7528\u6570\u636e","notice_board":{"created_at":"\u5275\u5efa\u65bc","description":"\u63cf\u8ff0","details":"\u516c\u544a\u680f\u8be6\u7ec6\u4fe1\u606f","edit":"\u7f16\u8f91\u516c\u544a\u680f","new":"\u65b0\u516c\u544a\u677f","notice_board":"\u516c\u544a\u680f","title":"\u6807\u9898"},"notice_boards":"\u516c\u544a\u680f","notification":{"mark_all_as_read":"\u6807\u8bb0\u4e3a\u5df2\u8bfb","notifications":"\u901a\u77e5\u4e8b\u9879","you_don`t_have_any_new_notification":"\u60a8\u6ca1\u6709\u4efb\u4f55\u65b0\u901a\u77e5"},"nurse":{"birth_date":"\u751f\u65e5","choose":"\u9009\u62e9","edit_nurse":"Edit Nurse","new_nurse":"\u65b0\u62a4\u58eb","nurse":"\u62a4\u58eb","nurse_details":"\u62a4\u58eb\u8be6\u7ec6\u4fe1\u606f","phone_no":"\u7535\u8bdd\u53f7\u7801"},"nurses":"\u62a4\u58eb","old_patient":"\u8001\u75c5\u4eba","opd_diagnosis":"OPD\u8bca\u65ad","opd_patient":{"appointment_date":"\u7ea6\u5b9a\u65e5\u671f","edit_opd_patient":"\u7f16\u8f91OPD\u60a3\u8005","new_opd_patient":"\u65b0\u7684OPD\u60a3\u8005","opd_number":"OPD\u53f7","opd_patient":"OPD\u60a3\u8005","opd_patient_details":"OPD\u60a3\u8005\u8be6\u7ec6\u4fe1\u606f","opd_patients":"OPD\u60a3\u8005","revisits":"\u91cd\u8bbf","total_visits":"\u603b\u9020\u8bbf","visits":"\u6765\u8bbf"},"opd_patients":"OPD\u60a3\u8005","opd_payments":{"add_opd_payment":"\u6dfb\u52a0Opd\u4ed8\u6b3e","edit_opd_payment":"\u7f16\u8f91Opd\u4ed8\u6b3e","make_payment":"\u4ed8\u6b3e","payment_mode":"\u4ed8\u6b3e\u65b9\u5f0f"},"opd_timeline":"OPD \u65f6\u95f4\u7ebf","operation_report":{"case_id":"\u6848\u4f8bID","date":"\u65e5\u671f","description":"\u63cf\u8ff0","doctor_name":"\u533b\u751f\u59d3\u540d","edit_operation_report":"\u7f16\u8f91\u64cd\u4f5c\u62a5\u544a","new_operation_report":"\u65b0\u8fd0\u4f5c\u62a5\u544a","operation_report":"\u8425\u8fd0\u62a5\u544a","operation_report_details":"\u8fd0\u8425\u62a5\u544a\u660e\u7ec6","operation_reports":"\u8425\u8fd0\u62a5\u544a","patient_name":"\u60a3\u8005\u59d3\u540d"},"operation_reports":"\u8425\u8fd0\u62a5\u544a","overview":"\u6982\u8ff0","package":{"amount":"\u91cf","description":"\u63cf\u8ff0","discount":"\u6298\u6263","edit_package":"\u7f16\u8f91\u5305","name":"\u540d\u79f0","new_package":"\u65b0\u5305\u88c5","package":"\u5305","package_details":"\u5305\u88c5\u8be6\u60c5","packages":"\u914d\u5957","qty":"\u6570\u91cf","rate":"\u7387","select_service":"\u9009\u62e9\u670d\u52a1","service":"\u670d\u52a1","total_amount":"\u603b\u91d1\u989d"},"packages":"\u914d\u5957","pathologies":"\u75c5\u7406","pathology_categories":"\u75c5\u7406 \u7c7b\u522b","pathology_category":{"edit_pathology_category":"\u7f16\u8f91 \u75c5\u7406 \u7c7b\u522b","name":"\u540d\u79f0","new_pathology_category":"\u65b0 \u75c5\u7406 \u7c7b\u522b","pathology_categories":"\u75c5\u7406 \u5206\u7c7b\u76ee\u5f55"},"pathology_test":{"category_name":"\u5206\u7c7b\u540d\u79f0","charge_category":"\u6536\u8d39\u7c7b\u522b","edit_pathology_test":"\u7f16\u8f91\u75c5\u7406\u6d4b\u8bd5","method":"\u65b9\u6cd5","new_pathology_test":"\u65b0\u75c5\u7406\u5b66\u68c0\u67e5","pathology_test_details":"\u75c5\u7406\u5b66\u68c0\u67e5\u7ec6\u8282","pathology_tests":"\u75c5\u7406\u68c0\u67e5","report_days":"\u62a5\u544a\u5929\u6570","short_name":"\u7b80\u79f0","standard_charge":"\u6807\u51c6\u6536\u8d39","subcategory":"\u5b50\u7c7b\u522b","test_name":"\u6d4b\u8bd5\u540d\u79f0","test_type":"\u6d4b\u8bd5\u7c7b\u578b","unit":"\u5355\u5143"},"pathology_tests":"\u75c5\u7406\u68c0\u67e5","patient":{"edit_patient":"\u7f16\u8f91\u75c5\u4eba","new_patient":"\u65b0\u75c5\u4eba","patient_details":"\u60a3\u8005\u8be6\u7ec6\u8d44\u6599","total_admissions":"\u603b\u62db\u751f","total_appointments":"\u603b\u7ea6\u4f1a","total_cases":"\u603b\u75c5\u4f8b"},"patient_admission":{"admission_date":"\u5165\u5b66\u65e5\u671f","agent_name":"\u4ee3\u7406\u540d\u79f0","bed":"\u5e8a","details":"\u75c5\u4eba\u5165\u9662\u8be6\u60c5","discharge_date":"\u51fa\u9662\u65e5\u671f","doctor":"\u533b\u751f","doctor_name":"\u533b\u751f\u59d3\u540d","edit_patient_admission":"\u7f16\u8f91\u60a3\u8005\u5165\u573a","guardian_address":"\u76d1\u62a4\u4eba\u5730\u5740","guardian_contact":"\u76d1\u62a4\u4eba\u8054\u7cfb","guardian_name":"\u76d1\u62a4\u4eba\u59d3\u540d","guardian_relation":"\u76d1\u62a4\u4eba\u5173\u7cfb","insurance":"\u4fdd\u9669","insurance_name":"\u4fdd\u9669\u540d\u79f0","new_patient_admission":"\u65b0\u75c5\u4eba\u5165\u9662","package":"\u5305","package_name":"\u5305\u88f9\u540d\u5b57","patient":"\u60a3\u8005","patient_admission":"\u75c5\u4eba\u5165\u9662","patient_admission_id":"\u75c5\u4eba\u5165\u573a\u8bc1","patient_name":"\u60a3\u8005\u59d3\u540d","policy_no":"\u4fdd\u5355\u7f16\u53f7"},"patient_admissions":"\u75c5\u4eba\u5165\u9662","patient_appointment":"\u60a3\u8005\u9884\u7ea6","patient_diagnosis_test":{"action":"\u884c\u52a8","add_other_diagnosis_property":"\u6dfb\u52a0\u5176\u4ed6\u8bca\u65ad\u5c5e\u6027","age":"\u5e74\u9f84","average_glucose":"\u5e73\u5747\u8840\u7cd6","blood_pressure":"\u8840\u538b","cholesterol":"\u80c6\u56fa\u9187","create_patient_diagnosis_test":"\u521b\u5efa\u60a3\u8005\u8bca\u65ad\u6d4b\u8bd5","created_at":"\u521b\u5efa\u4e8e","diabetes":"\u7cd6\u5c3f\u75c5","diagnosis":"\u8bca\u65ad","diagnosis_category":"\u8bca\u65ad\u7c7b\u522b","diagnosis_property_name":"\u8bca\u65ad\u5c5e\u6027\u540d\u79f0","diagnosis_property_value":"\u8bca\u65ad\u5c5e\u6027\u503c","diagnosis_test":"\u8bca\u65ad\u6d4b\u8bd5","doctor":"\u533b\u751f","doctor_name":"\u533b\u751f\u59d3\u540d","edit_patient_diagnosis_test":"\u7f16\u8f91\u60a3\u8005\u8bca\u65ad\u6d4b\u9a8c","fasting_blood_sugar":"\u7a7a\u8179\u8840\u7cd6","height":"\u9ad8\u5ea6","new_patient_diagnosis_test":"\u65b0\u75c5\u4eba\u8bca\u65ad\u6d4b\u8bd5","other_diagnosis_property":"\u5176\u4ed6\u8bca\u65ad\u5c5e\u6027","patient":"\u60a3\u8005","patient_diagnosis_test":"\u60a3\u8005\u8bca\u65ad\u6d4b\u8bd5","patient_diagnosis_test_details":"\u60a3\u8005\u8bca\u65ad\u6d4b\u8bd5\u8be6\u7ec6\u4fe1\u606f","patient_name":"\u60a3\u8005\u59d3\u540d","print_diagnosis_test":"\u6253\u5370\u8bca\u65ad\u6d4b\u8bd5","report_number":"\u62a5\u544a\u7f16\u53f7","urine_sugar":"\u5c3f\u7cd6","weight":"\u91cd\u91cf"},"patients":"\u8010\u5fc3","patients_case_details":"\u60a3\u8005\u75c5\u4f8b\u8be6\u60c5","patients_cases":"\u60a3\u8005\u6848\u4f8b","payment":{"account":"\u5e10\u6237","account_name":"\u7528\u6237\u540d","amount":"\u91cf","description":"\u63cf\u8ff0","edit_payment":"\u7f16\u8f91\u4ed8\u6b3e","new_payment":"\u65b0\u4ed8\u6b3e","pay_to":"\u4ed8\u7ed9","payment":"\u4ed8\u6b3e","payment_date":"\u652f\u4ed8\u65e5\u671f","payment_details":"\u4ed8\u6b3e\u8be6\u60c5","payment_reports":"\u4ed8\u6b3e\u62a5\u544a","payments":"\u4ed8\u6b3e\u65b9\u5f0f"},"payments":"\u4ed8\u6b3e\u65b9\u5f0f","pharmacist":{"edit_pharmacist":"\u7f16\u8f91\u836f\u5242\u5e08","new_pharmacist":"\u65b0\u836f\u5e08","pharmacist_details":"\u836f\u5242\u5e08\u8be6\u7ec6\u4fe1\u606f","pharmacists":"\u836f\u5242\u5e08"},"pharmacists":"\u836f\u5242\u5e08","postal":{"address":"\u5730\u5740","date":"\u65e5\u671f","dispatch":"\u8c03\u5ea6","edit_dispatch":"\u7f16\u8f91\u6d3e\u9063","edit_receive":"\u7f16\u8f91\u63a5\u6536","from_title":"\u4ece\u6807\u9898","new_dispatch":"\u65b0\u6d3e\u9063","new_receive":"\u65b0\u6536\u5230","postal":"\u660e\u4fe1\u7247","receive":"\u63a5\u6536","reference_no":"\u53c2\u8003\u7f16\u53f7","to_title":"\u5230\u6807\u9898"},"postal_dispatch":"\u90ae\u653f\u6d3e\u9063","postal_receive":"\u90ae\u653f\u6536\u636e","prescription":{"Rx":"\u63a5\u6536","accident":"\u4e8b\u6545","advice":"\u5efa\u8bae","after_meal":"\u5403\u996d\u540e","before_meal":"\u996d\u524d","breast_feeding":"\u6bcd\u4e73\u5582\u517b","comment":"\u8bc4\u8bba","current_medication":"\u5f53\u524d\u836f\u7269","days":"\u5929","diabetic":"\u7cd6\u5c3f\u75c5\u7684","duration":"\u671f\u95f4","edit_prescription":"\u7f16\u8f91\u5904\u65b9","female_pregnancy":"\u5973\u6027\u6000\u5b55","food_allergies":"\u98df\u7269\u8fc7\u654f","health_insurance":"\u5065\u5eb7\u4fdd\u9669","heart_disease":"\u5fc3\u810f\u75c5","high_blood_pressure":"\u9ad8\u8840\u538b","low_income":"\u4f4e\u6536\u5165","medical_history":"\u75c5\u53f2","medicine_name":"\u836f\u540d","month":"\u6708","new_medicine":"\u65b0\u836f","new_prescription":"\u65b0\u5904\u65b9","next_visit":"\u4e0b\u6b21\u8bbf\u95ee","no_data_available":"\u6ca1\u6709\u627e\u5230\u6570\u636e","others":"\u5176\u4ed6","patient":"\u60a3\u8005","physical_information":"\u7269\u7406\u4fe1\u606f","plus_rate":"\u5fc3\u7387","prescription":"\u5904\u65b9","prescription_details":"\u5904\u65b9\u8be6\u60c5","prescriptions":"\u5904\u65b9\u836f","problem":"\u95ee\u9898","problem_description":"\u95ee\u9898\u63cf\u8ff0","reference":"\u53c2\u8003","surgery":"\u624b\u672f","temperature":"\u6e29\u5ea6","tendency_bleed":"\u503e\u5411\u6d41\u8840","test":"\u6d4b\u8bd5","time":"\u65f6\u95f4","year":"\u5e74"},"prescriptions":"\u5904\u65b9\u836f","profile":{"change_language":"\u6539\u53d8\u8bed\u8a00","edit_profile":"\u7f16\u8f91\u4e2a\u4eba\u8d44\u6599","email":"\u7535\u5b50\u90ae\u4ef6","first_name":"\u540d","language":"\u8bed\u8a00","last_name":"\u59d3","phone":"\u7535\u8bdd","profile":"\u8f6e\u5ed3"},"radiologies":"\u653e\u5c04\u5b66","radiology_categories":"\u653e\u5c04\u5b66 \u7c7b\u522b","radiology_category":{"edit_radiology_category":"\u7f16\u8f91 \u653e\u5c04\u5b66 \u7c7b\u522b","name":"\u540d\u79f0","new_radiology_category":"\u65b0 \u653e\u5c04\u5b66 \u7c7b\u522b","radiology_categories":"\u653e\u5c04\u5b66 \u5206\u7c7b\u76ee\u5f55"},"radiology_test":{"category_name":"\u5206\u7c7b\u540d\u79f0","charge_category":"\u6536\u8d39\u7c7b\u522b","edit_radiology_test":"\u7f16\u8f91\u653e\u5c04\u5b66\u6d4b\u8bd5","new_radiology_test":"\u65b0\u653e\u5c04\u5b66\u6d4b\u8bd5","radiology_test_details":"\u653e\u5c04\u5b66\u68c0\u67e5\u8be6\u7ec6\u4fe1\u606f","radiology_tests":"\u653e\u5c04\u5b66\u68c0\u67e5","report_days":"\u62a5\u544a\u5929\u6570","short_name":"\u7b80\u79f0","standard_charge":"\u6807\u51c6\u6536\u8d39","subcategory":"\u5b50\u7c7b\u522b","test_name":"\u6d4b\u8bd5\u540d\u79f0","test_type":"\u6d4b\u8bd5\u7c7b\u578b"},"radiology_tests":"\u653e\u5c04\u5b66\u68c0\u67e5","receptionist":{"edit_receptionist":"\u7f16\u8f91\u63a5\u5f85\u5458","new_receptionist":"\u65b0\u63a5\u5f85\u5458","receptionist":"\u63a5\u5f85\u5458","receptionist_details":"\u63a5\u5f85\u5458\u8be6\u7ec6\u4fe1\u606f","receptionists":"\u63a5\u5f85\u5458"},"receptionists":"\u63a5\u5f85\u5458","reports":"\u62a5\u544a\u4e66","role":{"edit_role":"\u7f16\u8f91\u89d2\u8272","new_role":"\u65b0\u89d2\u8272"},"roles":"\u7684\u89d2\u8272","schedule":{"available_from":"\u53ef\u4ece","available_on":"\u53ef\u7528","available_to":"\u6709\u7a7a","details":"\u65f6\u95f4\u8868\u8be6\u60c5","doctor_name":"\u533b\u751f\u59d3\u540d","edit":"\u7f16\u8f91\u65f6\u95f4\u8868","new":"\u65b0\u65f6\u95f4\u8868","per_patient_time":"\u6bcf\u4f4d\u60a3\u8005\u65f6\u95f4","select_doctor_name":"\u9009\u62e9\u533b\u751f\u59d3\u540d","select_serial_visibility":"\u9009\u62e9\u4e32\u884c\u53ef\u89c1\u6027","sequential":"\u987a\u5e8f\u7684","serial_visibility":"\u4e32\u884c\u53ef\u89c1\u6027","timestamp":"\u65f6\u95f4\u6233\u8bb0"},"schedule_label":"\u65e5\u7a0b","schedules":"\u65f6\u95f4\u8868","service":{"edit_service":"\u7f16\u8f91\u670d\u52a1","given":"\u7ed9\u5b9a","new_service":"\u65b0\u670d\u52a1","not_given":"\u6ca1\u6709\u7ed9","quantity":"\u6570\u91cf","rate":"\u7387","service_details":"\u670d\u52a1\u8be6\u60c5"},"services":"\u670d\u52a1","setting":{"address":"\u533b\u9662\u5730\u5740","app_logo":"\u5e94\u7528\u5fbd\u6807","app_name":"\u5e94\u7528\u540d\u79f0","company_name":"\u516c\u53f8\u540d","country_code":"\u56fd\u5bb6\u4ee3\u7801","currency":"\u5f53\u524d\u8d27\u5e01","hospital_email":"\u533b\u9662\u7535\u90ae","hospital_from_day":"\u533b\u9662\u4ece\u4e00\u5929","hospital_from_time":"\u533b\u9662\u4ece\u65f6\u95f4","hospital_phone":"\u533b\u9662\u7535\u8bdd","image_validation":"\u56fe\u7247\u7684\u50cf\u7d20\u5fc5\u987b\u4e3a90 x 60\u3002","social_details":"\u793e\u4ea4\u7ec6\u8282"},"settings":"\u8bbe\u5b9a\u503c","short_description":"\u7b80\u77ed\u7684\u4ecb\u7ecd","sidebar_setting":"\u6a21\u5757\u8bbe\u7f6e","sms":{"date":"\u65e5\u671f","message":"\u4fe1\u606f","new_sms":"\u65b0\u77ed\u4fe1","only_user_with_registered_phone_will_display":"\uff08\u4ec5\u663e\u793a\u5177\u6709\u6ce8\u518c\u7535\u8bdd\u7684\u7528\u6237\u3002\uff09","phone_number":"\u7535\u8bdd\u53f7\u7801","role":"\u89d2\u8272","send":"\u53d1\u9001","send_by":"\u53d1\u9001\u8005","send_sms_by_number_directly":"\u901a\u8fc7\u53f7\u7801\u76f4\u63a5\u53d1\u9001\u77ed\u4fe1","send_to":"\u53d1\u9001\u81f3","sms":"\u77ed\u4fe1","sms_details":"\u77ed\u4fe1\u8be6\u7ec6\u4fe1\u606f"},"testimonial":{"description":"\u63cf\u8ff0","edit_testimonial":"\u7f16\u8f91\u63a8\u8350\u4e66","name":"\u540d\u79f0","new_testimonial":"\u65b0\u63a8\u8350\u4e66","profile_error":"\u6587\u6863\u5fc5\u987b\u662f\u7c7b\u578b\u4e3ajpeg\uff0cjpg\uff0cpng\u7684\u6587\u4ef6\u3002","testimonial":"\u611f\u8a00","testimonial_detail":"\u63a8\u8350\u7ec6\u8282"},"testimonials":"\u611f\u8a00","twitter_url":"\u63a8\u7279\u7f51\u5740","user":{"address1":"\u5730\u57401","address2":"\u5730\u57402","address_details":"\u8be6\u7ec6\u5730\u5740","address_not_found":"\u627e\u4e0d\u5230\u5730\u5740\u8be6\u7ec6\u4fe1\u606f","blood_group":"\u8840\u578b","change_password":"\u66f4\u6539\u5bc6\u7801","city":"\u5e02","designation":"\u6307\u5b9a","dob":"\u51fa\u751f\u65e5\u671f","edit_profile":"\u7f16\u8f91\u4e2a\u4eba\u8d44\u6599","edit_user":"\u7f16\u8f91\u7528\u6237","education":"\u6559\u80b2","email":"\u7535\u5b50\u90ae\u4ef6","email_verified_successfully":"\u90ae\u7bb1\u9a8c\u8bc1\u6210\u529f\u3002","female":"\u5973","first_name":"\u540d\u5b57","gender":"\u6027\u522b","invalid_password":"\u5f53\u524d\u5bc6\u7801\u65e0\u6548\u3002","last_name":"\u59d3","logout":"\u767b\u51fa","male":"\u7537","name":"\u540d\u79f0","new_user":"\u65b0\u7528\u6237","password":"\u5bc6\u7801","password_confirmation":"\u786e\u8ba4\u5bc6\u7801","phone":"\u7535\u8bdd","qualification":"\u8d44\u8d28","select_blood_group":"\u9009\u62e9\u8840\u578b","status":"\u72b6\u6001","user_details":"\u4f7f\u7528\u8005\u8be6\u7ec6\u8d44\u6599","usrs":"\u7528\u6237","validate_confirm_password":"\u5bc6\u7801\u548c\u786e\u8ba4\u5bc6\u7801\u5fc5\u987b\u5339\u914d\u3002","validate_min_character_password":"\u5bc6\u7801\u5fc5\u987b\u81f3\u5c11\u5305\u542b 6 \u4e2a\u5b57\u7b26\u3002","zip":"\u538b\u7f29"},"users":"\u7528\u6237\u6570","vaccinated_patient":{"add_vaccinate_patient":"\u6dfb\u52a0\u75ab\u82d7\u63a5\u7a2e\u60a3\u8005","description":"\u63cf\u8ff0","does_no":"\u5291\u91cf","dose_given_date":"\u7d66\u5b9a\u5291\u91cf","edit_vaccinate_patient":"\u7de8\u8f2f\u75ab\u82d7\u63a5\u7a2e\u60a3\u8005","new_vaccinate_patient":"\u65b0\u75ab\u82d7\u63a5\u7a2e\u60a3\u8005","patient":"\u75c5\u4eba","serial_no":"\u5e8f\u5217\u865f","vaccinate_patient":"\u7d66\u75c5\u4eba\u63a5\u7a2e\u75ab\u82d7","vaccinated_patient":"\u63a5\u79cd\u75ab\u82d7\u7684\u75c5\u4eba","vaccination":"\u9810\u9632\u63a5\u7a2e","vaccine":"\u75ab\u82d7"},"vaccinated_patients":"\u63a5\u7a2e\u75ab\u82d7\u7684\u60a3\u8005","vaccination":{"brand":"\u54c1\u724c","edit_vaccination":"\u7de8\u8f2f\u75ab\u82d7\u63a5\u7a2e","manufactured_by":"\u88fd\u9020\u8005","name":"\u59d3\u540d","new_vaccination":"\u65b0\u75ab\u82d7","vaccinated":"\u5df2\u63a5\u7a2e\u75ab\u82d7","vaccinations":"\u9810\u9632\u63a5\u7a2e"},"vaccinations":"\u9810\u9632\u63a5\u7a2e","valid":"\u6709\u6548\u7684","verification":{"another_verify_request":"\u5355\u51fb\u6b64\u5904\u8bf7\u6c42\u53e6\u4e00\u4e2a","verify_message":"\u5728\u7ee7\u7eed\u4e4b\u524d\uff0c\u8bf7\u68c0\u67e5\u60a8\u7684\u7535\u5b50\u90ae\u4ef6\u4ee5\u83b7\u53d6\u9a8c\u8bc1\u94fe\u63a5\u3002\u5982\u679c\u60a8\u6ca1\u6709\u6536\u5230\u7535\u5b50\u90ae\u4ef6\uff0c","verify_your_email_address":"\u786e\u8ba4\u4f60\u7684\u90ae\u4ef6\u5730\u5740"},"visitor":{"date":"\u65e5\u671f","edit":"\u7f16\u8f91\u8bbf\u5ba2","id_card":"\u8eab\u4efd\u8bc1","in_time":"\u53ca\u65f6","name":"\u540d\u79f0","new":"\u65b0\u8bbf\u5ba2","note":"\u6ce8\u610f","number_of_person":"\u4eba\u6570","out_time":"\u65f6\u5dee","phone":"\u7535\u8bdd","purpose":"\u76ee\u7684","visitor":"\u6e38\u5ba2"},"visitors":"\u53c2\u89c2\u8005","web_appointment":{"call_now_and_get_a_free_consulting":"\u7acb\u5373\u81f4\u7535\u5e76\u83b7\u5f97\u514d\u8d39\u54a8\u8be2","enter_confirm_password":"\u8f93\u5165\u786e\u8ba4\u5bc6\u7801","enter_description":"\u8f93\u5165\u8bf4\u660e","enter_your_first_name":"\u8f93\u5165\u60a8\u7684\u540d\u5b57","enter_your_last_name":"\u8f93\u5165\u60a8\u7684\u59d3\u6c0f","enter_your_password":"\u8f93\u5165\u60a8\u7684\u5bc6\u7801","make_an_appointment":"\u9884\u7ea6","select_department":"\u9009\u62e9\u90e8\u95e8","select_doctor":"\u9009\u62e9\u533b\u751f","select_time":"\u9009\u62e9\u65f6\u95f4"},"web_contact":{"call_today":"\u4eca\u5929\u6253\u7535\u8bdd","contact_no":"\u8054\u7cfb\u65b9\u5f0f","enter_your_email":"\u8f93\u5165\u4f60\u7684\u7535\u5b50\u90ae\u7bb1","enter_your_name":"\u8f93\u5165\u4f60\u7684\u540d\u5b57","open_hours":"\u8425\u4e1a\u65f6\u95f4","our_location":"\u6211\u4eec\u7684\u4f4d\u7f6e","phone_number":"\u7535\u8bdd\u53f7\u7801","please_enter_your_phone_number":"\u8bf7\u8f93\u5165\u60a8\u7684\u7535\u8bdd\u53f7\u7801","select_enquiry":"\u9009\u62e9\u8be2\u4ef7","send_message":"\u53d1\u4fe1\u606f","send_us_a_message":"\u7ed9\u6211\u4eec\u53d1\u4fe1\u606f","type_your_message":"\u8f93\u5165\u60a8\u7684\u6d88\u606f","write_your_message":"\u5199\u4e0b\u4f60\u7684\u4fe1\u606f","your_email":"\u4f60\u7684\u90ae\u4ef6","your_message":"\u60a8\u7684\u7559\u8a00","your_name":"\u4f60\u7684\u540d\u5b57"},"web_home":{"4_easy_step_and_get_the_world_best_treatment":"4\u4e2a\u7b80\u5355\u7684\u6b65\u9aa4\u5e76\u83b7\u5f97\u4e16\u754c\u4e0a\u6700\u597d\u7684\u6cbb\u7597","about_us":"\u5173\u4e8e\u6211\u4eec","available_doctors":"\u53ef\u7528\u533b\u751f","book_an_appointment":"\u9884\u7ea6","book_appointment":"\u9884\u7ea6","book_now":"\u73b0\u5728\u9884\u8ba2","contact":"\u63a5\u89e6","contact_doctors":"\u9009\u62e9\u533b\u751f","contact_hospital":"\u8054\u7cfb\u533b\u9662","doctors":"\u533b\u751f","doctors_nurses":"\u533b\u751f\u548c\u62a4\u58eb","easy_solutions":"\u7b80\u5355\u7684\u89e3\u51b3\u65b9\u6848","happy_patients":"\u5feb\u4e50\u7684\u75c5\u4eba","home":"\u5bb6","make_appointment":"\u7ea6\u4e2a\u65f6\u95f4","our_services":"\u6211\u4eec\u7684\u670d\u52a1","our_testimonials":"\u6211\u4eec\u7684\u89c1\u8bc1","patients":"\u8010\u5fc3","patients_beds":"\u75c5\u5e8a","privacy_policy":"\u9690\u79c1\u653f\u7b56","professional_doctors":"\u4e13\u4e1a\u533b\u751f","select_doctor":"\u9009\u62e9\u533b\u751f","select_doctors":"\u9009\u62e9\u533b\u751f","services":"\u670d\u52a1","sign_up":"\u62a5\u540d","terms_of_service":"\u670d\u52a1\u6761\u6b3e","testimonials":"\u611f\u8a00","we_are_experienced_healthcare_professionals":"\u6211\u4eec\u662f\u7ecf\u9a8c\u4e30\u5bcc\u7684\u533b\u7597\u4fdd\u5065\u4e13\u4e1a\u4eba\u5458","we_offer_different_services_to_improve_your_health":"\u6211\u4eec\u63d0\u4f9b\u4e0d\u540c\u7684\u670d\u52a1\u6765\u6539\u5584\u60a8\u7684\u5065\u5eb7","what_our_patient_say_about_medical_treatments":"\u6211\u4eec\u7684\u60a3\u8005\u5bf9\u6211\u4eec\u7684\u533b\u7597\u7684\u8bc4\u4ef7","working_hours":"\u5de5\u4f5c\u65f6\u95f4","years_experience":"\u591a\u5e74\u7ecf\u9a8c"},"web_menu":{"about":"\u5173\u4e8e","all_rights_reserved_by":"\u7248\u6743\u6240\u6709","appointment":"\u9884\u7ea6","contact_information":"\u8054\u7cfb\u4fe1\u606f","copyright":"\u7248\u6743","login":"\u767b\u5f55","our_features":"\u6211\u4eec\u7684\u7279\u8272","useful_link":"\u6709\u7528\u7684\u94fe\u63a5","working_hours":"\u5de5\u4f5c\u65f6\u95f4"},"web_password":{"password_and_confirm_password_not_match":"\u5bc6\u7801\u548c\u786e\u8ba4\u5bc6\u7801\u4e0d\u5339\u914d\u3002","please_fill_all_the_required_fields":"\u8bf7\u586b\u5199\u6240\u6709\u5fc5\u586b\u5b57\u6bb5\u3002"},"web_working_hours":{"no_yet_opening_hours":"\u6682\u65e0\u8425\u4e1a\u65f6\u95f4","opening_hours":"\u8425\u4e1a\u65f6\u95f4"},"weekdays":{"fri":"\u5468\u4e94","mon":"\u661f\u671f\u4e00","sat":"\u5750","sun":"\u592a\u9633","thu":"\u5468\u56db","tue":"\u5468\u4e8c","wed":"\u661f\u671f\u4e09"}}});})();